searchData={"items":[{"type":"module","doc":"Money implements a set of functions to store, retrieve, convert and perform\narithmetic on a `t:Money.t/0` type that is composed of a currency code and\na decimal currency amount.\n\nMoney is very opinionated in the interests of serving as a dependable library\nthat can underpin accounting and financial applications.\n\nThis opinion expressed by ensuring that:\n\n1. Money must always have both a amount and a currency code.\n\n2. The currency code must always be valid.\n\n3. Money arithmetic can only be performed when both operands are of the\n   same currency.\n\n4. Money amounts are represented as a `Decimal`.\n\n5. Money is serialised to the database as a custom Postgres composite type\n   that includes both the amount and the currency. Therefore for Ecto\n   serialization Postgres is assumed as the data store. Serialization is\n   entirely optional and Ecto is not a package dependency.\n\n6. All arithmetic functions work in fixed point decimal.  No rounding\n   occurs automatically (unless expressly called out for a function).\n\n7. Explicit rounding obeys the rounding rules for a given currency.  The\n   rounding rules are defined by the Unicode consortium in its CLDR\n   repository as implemented by the hex package `ex_cldr`.  These rules\n   define the number of fractional digits for a currency and the rounding\n   increment where appropriate.","title":"Money","ref":"Money.html"},{"type":"function","doc":"The absolute value of a `Money` amount.\nReturns a `t:Money.t/0` type with a positive sign for the amount.","title":"Money.abs/1","ref":"Money.html#abs/1"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`.","title":"Arguments - Money.abs/1","ref":"Money.html#abs/1-arguments"},{"type":"function","doc":"* a `t:Money.t/0`.","title":"Returns - Money.abs/1","ref":"Money.html#abs/1-returns"},{"type":"function","doc":"iex> m = Money.new(\"USD\", -100)\n    iex> Money.abs(m)\n    Money.new(:USD, \"100\")","title":"Example - Money.abs/1","ref":"Money.html#abs/1-example"},{"type":"function","doc":"Add two `Money` values.","title":"Money.add/2","ref":"Money.html#add/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`","title":"Arguments - Money.add/2","ref":"Money.html#add/2-arguments"},{"type":"function","doc":"* `{:ok, money}` or\n\n* `{:error, reason}`","title":"Returns - Money.add/2","ref":"Money.html#add/2-returns"},{"type":"function","doc":"iex> Money.add Money.new(:USD, 200), Money.new(:USD, 100)\n    {:ok, Money.new(:USD, 300)}\n\n    iex> Money.add Money.new(:USD, 200), Money.new(:AUD, 100)\n    {:error, {ArgumentError, \"Cannot add monies with different currencies. \" <>\n      \"Received :USD and :AUD.\"}}","title":"Example - Money.add/2","ref":"Money.html#add/2-example"},{"type":"function","doc":"Add two `Money` values and raise on error.","title":"Money.add!/2","ref":"Money.html#add!/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`","title":"Arguments - Money.add!/2","ref":"Money.html#add!/2-arguments"},{"type":"function","doc":"* a `t:Money.t/0` struct or\n\n* raises an exception","title":"Returns - Money.add!/2","ref":"Money.html#add!/2-returns"},{"type":"function","doc":"iex> Money.add! Money.new(:USD, 200), Money.new(:USD, 100)\n    Money.new(:USD, \"300\")\n\n    Money.add! Money.new(:USD, 200), Money.new(:CAD, 500)\n    ** (ArgumentError) Cannot add two %Money{} with different currencies. Received :USD and :CAD.","title":"Examples - Money.add!/2","ref":"Money.html#add!/2-examples"},{"type":"function","doc":"Compares two `Money` values numerically. If the first number is greater\nthan the second #Integer<1> is returned, if less than Integer<-1> is\nreturned. Otherwise, if both numbers are equal Integer<0> is returned.","title":"Money.cmp/2","ref":"Money.html#cmp/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`.","title":"Arguments - Money.cmp/2","ref":"Money.html#cmp/2-arguments"},{"type":"function","doc":"*  `-1` | `0` | `1` or\n\n* `{:error, {module(), String.t}}`","title":"Returns - Money.cmp/2","ref":"Money.html#cmp/2-returns"},{"type":"function","doc":"iex> Money.cmp Money.new(:USD, 200), Money.new(:USD, 100)\n    1\n\n    iex> Money.cmp Money.new(:USD, 200), Money.new(:USD, 200)\n    0\n\n    iex> Money.cmp Money.new(:USD, 200), Money.new(:USD, 500)\n    -1\n\n    iex> Money.cmp Money.new(:USD, 200), Money.new(:CAD, 500)\n    {:error,\n     {ArgumentError,\n      \"Cannot compare monies with different currencies. Received :USD and :CAD.\"}}","title":"Examples - Money.cmp/2","ref":"Money.html#cmp/2-examples"},{"type":"function","doc":"Compares two `Money` values numerically and raises on error.","title":"Money.cmp!/2","ref":"Money.html#cmp!/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`","title":"Arguments - Money.cmp!/2","ref":"Money.html#cmp!/2-arguments"},{"type":"function","doc":"*  `-1` | `0` | `1` or\n\n* raises an exception","title":"Returns - Money.cmp!/2","ref":"Money.html#cmp!/2-returns"},{"type":"function","doc":"Money.cmp! Money.new(:USD, 200), Money.new(:CAD, 500)\n    ** (ArgumentError) Cannot compare monies with different currencies. Received :USD and :CAD.","title":"Examples - Money.cmp!/2","ref":"Money.html#cmp!/2-examples"},{"type":"function","doc":"Compares two `Money` values numerically. If the first number is greater\nthan the second :gt is returned, if less than :lt is returned, if both\nnumbers are equal :eq is returned.","title":"Money.compare/2","ref":"Money.html#compare/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`","title":"Arguments - Money.compare/2","ref":"Money.html#compare/2-arguments"},{"type":"function","doc":"*  `:gt` | `:eq` | `:lt` or\n\n* `{:error, {module(), String.t}}`","title":"Returns - Money.compare/2","ref":"Money.html#compare/2-returns"},{"type":"function","doc":"iex> Money.compare Money.new(:USD, 200), Money.new(:USD, 100)\n    :gt\n\n    iex> Money.compare Money.new(:USD, 200), Money.new(:USD, 200)\n    :eq\n\n    iex> Money.compare Money.new(:USD, 200), Money.new(:USD, 500)\n    :lt\n\n    iex> Money.compare Money.new(:USD, 200), Money.new(:CAD, 500)\n    {:error,\n     {ArgumentError,\n      \"Cannot compare monies with different currencies. Received :USD and :CAD.\"}}","title":"Examples - Money.compare/2","ref":"Money.html#compare/2-examples"},{"type":"function","doc":"Compares two `Money` values numerically and raises on error.","title":"Money.compare!/2","ref":"Money.html#compare!/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`.","title":"Arguments - Money.compare!/2","ref":"Money.html#compare!/2-arguments"},{"type":"function","doc":"*  `:gt` | `:eq` | `:lt` or\n\n* raises an exception","title":"Returns - Money.compare!/2","ref":"Money.html#compare!/2-returns"},{"type":"function","doc":"Money.compare! Money.new(:USD, 200), Money.new(:CAD, 500)\n    ** (ArgumentError) Cannot compare monies with different currencies. Received :USD and :CAD.","title":"Examples - Money.compare!/2","ref":"Money.html#compare!/2-examples"},{"type":"function","doc":"Returns the effective cross-rate to convert from one currency\nto another.","title":"Money.cross_rate/3","ref":"Money.html#cross_rate/3"},{"type":"function","doc":"* `from` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2` or a valid\n   currency code.\n\n* `to_currency` is a valid currency code into which the `money` is converted.\n\n* `rates` is a `Map` of currency rates where the map key is an upcased\n  atom or string and the value is a Decimal conversion factor.  The default is the\n  latest available exchange rates returned from `Money.ExchangeRates.latest_rates/0`.","title":"Arguments - Money.cross_rate/3","ref":"Money.html#cross_rate/3-arguments"},{"type":"function","doc":"Money.cross_rate(Money.new(:USD, 100), :AUD, %{USD: Decimal.new(1), AUD: Decimal.new(\"0.7345\")})\n    {:ok, Decimal.new(\"0.7345\")}\n\n    Money.cross_rate Money.new(:USD, 100), :ZZZ, %{USD: Decimal.new(1), AUD: Decimal.new(0.7345)}\n    ** (Cldr.UnknownCurrencyError) Currency :ZZZ is not known","title":"Examples - Money.cross_rate/3","ref":"Money.html#cross_rate/3-examples"},{"type":"function","doc":"Returns the effective cross-rate to convert from one currency\nto another.","title":"Money.cross_rate!/3","ref":"Money.html#cross_rate!/3"},{"type":"function","doc":"* `from` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2` or a valid\n   currency code.\n\n* `to_currency` is a valid currency code into which the `money` is converted.\n\n* `rates` is a `Map` of currency rates where the map key is an upcased\n  atom or string and the value is a Decimal conversion factor.  The default is the\n  latest available exchange rates returned from `Money.ExchangeRates.latest_rates/0`.","title":"Arguments - Money.cross_rate!/3","ref":"Money.html#cross_rate!/3-arguments"},{"type":"function","doc":"iex> Money.cross_rate!(Money.new(:USD, 100), :AUD, %{USD: Decimal.new(1), AUD: Decimal.new(\"0.7345\")})\n    Decimal.new(\"0.7345\")\n\n    iex> Money.cross_rate!(:USD, :AUD, %{USD: Decimal.new(1), AUD: Decimal.new(\"0.7345\")})\n    Decimal.new(\"0.7345\")\n\n    Money.cross_rate Money.new(:USD, 100), :ZZZ, %{USD: Decimal.new(1), AUD: Decimal.new(\"0.7345\")}\n    ** (Cldr.UnknownCurrencyError) Currency :ZZZ is not known","title":"Examples - Money.cross_rate!/3","ref":"Money.html#cross_rate!/3-examples"},{"type":"function","doc":"Returns the default `ex_cldr` backend configured\nfor `Money`, if any. If no default backing is\nconfigured, an exception is raised.","title":"Money.default_backend/0","ref":"Money.html#default_backend/0"},{"type":"function","doc":"Divide a `Money` value by a number.","title":"Money.div/2","ref":"Money.html#div/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` types returned\n  by `Money.new/2`\n\n* `number` is an integer, float or `Decimal.t`\n\n> Note that dividing one %Money{} by another is not supported.","title":"Arguments - Money.div/2","ref":"Money.html#div/2-arguments"},{"type":"function","doc":"* `{:ok, money}` or\n\n* `{:error, reason}`","title":"Returns - Money.div/2","ref":"Money.html#div/2-returns"},{"type":"function","doc":"iex> Money.div Money.new(:USD, 200), 2\n    {:ok, Money.new(:USD, 100)}\n\n    iex> Money.div(Money.new(:USD, 200), \"xx\")\n    {:error, {ArgumentError, \"Cannot divide money by \\\"xx\\\"\"}}","title":"Example - Money.div/2","ref":"Money.html#div/2-example"},{"type":"function","doc":"Divide a `Money` value by a number and raise on error.","title":"Money.div!/2","ref":"Money.html#div!/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` types returned\n  by `Money.new/2`\n\n* `number` is an integer, float or `Decimal.t`","title":"Arguments - Money.div!/2","ref":"Money.html#div!/2-arguments"},{"type":"function","doc":"* a `t:Money.t/0` struct or\n\n* raises an exception","title":"Returns - Money.div!/2","ref":"Money.html#div!/2-returns"},{"type":"function","doc":"iex> Money.div!(Money.new(:USD, 200), 2)\n    Money.new(:USD, \"100\")\n\n    iex> Money.div!(Money.new(:USD, 200), \"xx\")\n    ** (ArgumentError) Cannot divide money by \"xx\"","title":"Examples - Money.div!/2","ref":"Money.html#div!/2-examples"},{"type":"function","doc":"Returns a boolean indicating if two `Money` values are equal","title":"Money.equal?/2","ref":"Money.html#equal?/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`","title":"Arguments - Money.equal?/2","ref":"Money.html#equal?/2-arguments"},{"type":"function","doc":"* `true` or `false`","title":"Returns - Money.equal?/2","ref":"Money.html#equal?/2-returns"},{"type":"function","doc":"iex> Money.equal?(Money.new(:USD, 200), Money.new(:USD, 200))\n    true\n\n    iex> Money.equal?(Money.new(:USD, 200), Money.new(:USD, 100))\n    false","title":"Example - Money.equal?/2","ref":"Money.html#equal?/2-example"},{"type":"function","doc":"Returns a %Money{} struct from a currency code and a float amount, or\nan error tuple of the form `{:error, {exception, message}}`.\n\nFloats are fraught with danger in computer arithmetic due to the\nunexpected loss of precision during rounding. The IEEE754 standard\nindicates that a number with a precision of 16 digits should\nround-trip convert without loss of fidelity. This function supports\nnumbers with a precision up to 15 digits and will error if the\nprovided amount is outside that range.\n\n**Note** that `Money` cannot detect lack of precision or rounding errors\nintroduced upstream. This function therefore should be used with\ngreat care and its use should be considered potentially harmful.","title":"Money.from_float/3","ref":"Money.html#from_float/3"},{"type":"function","doc":"* `currency_code` is an [ISO4217](https://en.wikipedia.org/wiki/ISO_4217)\n  binary or atom currency code or an\n  [ISO 24165](https://www.iso.org/standard/80601.html) token identifier or shortname.\n\n* `amount` is a float\n\n* `options` is a keyword list of options passed\n  to `Money.new/3`. The default is `[]`.","title":"Arguments - Money.from_float/3","ref":"Money.html#from_float/3-arguments"},{"type":"function","doc":"iex> Money.from_float 1.23456, :USD\n    Money.new(:USD, \"1.23456\")\n\n    iex> Money.from_float 1.234567890987656, :USD\n    {:error,\n      {Money.InvalidAmountError,\n        \"The precision of the float 1.234567890987656 is \" <>\n        \"greater than 15 which could lead to unexpected results. \" <>\n        \"Reduce the precision or call Money.new/2 with a Decimal or String amount\"}}","title":"Examples - Money.from_float/3","ref":"Money.html#from_float/3-examples"},{"type":"function","doc":"Returns a %Money{} struct from a currency code and a float amount, or\nraises an exception if the currency code is invalid.\n\nSee `Money.from_float/2` for further information.\n\n**Note** that `Money` cannot detect lack of precision or rounding errors\nintroduced upstream. This function therefore should be used with\ngreat care and its use should be considered potentially harmful.","title":"Money.from_float!/3","ref":"Money.html#from_float!/3"},{"type":"function","doc":"* `currency_code` is an [ISO4217](https://en.wikipedia.org/wiki/ISO_4217)\n  binary or atom currency code or an\n  [ISO 24165](https://www.iso.org/standard/80601.html) token identifier or shortname.\n\n* `amount` is a float\n\n* `options` is a keyword list of options passed\n  to `Money.new/3`. The default is `[]`.","title":"Arguments - Money.from_float!/3","ref":"Money.html#from_float!/3-arguments"},{"type":"function","doc":"iex> Money.from_float!(:USD, 1.234)\n    Money.new(:USD, \"1.234\")\n\n    Money.from_float!(:USD, 1.234567890987654)\n    #=> ** (Money.InvalidAmountError) The precision of the float 1.234567890987654 is greater than 15 which could lead to unexpected results. Reduce the precision or call Money.new/2 with a Decimal or String amount\n        (ex_money) lib/money.ex:293: Money.from_float!/2","title":"Examples - Money.from_float!/3","ref":"Money.html#from_float!/3-examples"},{"type":"function","doc":"Convert an integer representation of money into a `Money` struct.","title":"Money.from_integer/3","ref":"Money.html#from_integer/3"},{"type":"function","doc":"* `integer` is an integer representation of a money amount including\n  any decimal digits.  ie. `20000` would be interpreted to mean `$200.00`\n  if the `currency` is `:USD` and no `:fractional_digits` option\n  was provided.\n\n* `currency` is the currency code for the `integer`.  The assumed\n  decimal precision is derived from the currency code if no `fractional_digits`\n  option is specified.\n\n* `options` is a keyword list of options.","title":"Arguments - Money.from_integer/3","ref":"Money.html#from_integer/3-arguments"},{"type":"function","doc":"* `:fractional_digits` which determines the currency precision implied\n  by the `integer`. The valid options are `:cash`, `:accounting`,\n  `:iso` or a non-negative integer. The default is `:iso` which uses the\n  [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) definition of\n  currency digits.\n\nAll other options are passed to `Money.new/3`.","title":"Options - Money.from_integer/3","ref":"Money.html#from_integer/3-options"},{"type":"function","doc":"* A `t:Money.t/0` struct or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.from_integer/3","ref":"Money.html#from_integer/3-returns"},{"type":"function","doc":"Some currencies, like the [Iraqi Dinar](https://en.wikipedia.org/wiki/Iraqi_dinar)\nhave a difference in the decimal digits defined by CLDR versus\nthose defined by [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217). CLDR\ndefines the decimal digits for `IQD` as `0` whereas ISO 4217 defines\n`3` decimal digits.\n\nSince converting an integer to a money amount is very\nsensitive to the number of fractional digits specified it is\nimportant to be very clear about the precision of the data used\nwith this function and care taken in specifying the `:fractional_digits`\nparameter.","title":"Notes - Money.from_integer/3","ref":"Money.html#from_integer/3-notes"},{"type":"function","doc":"iex> Money.from_integer(20000, :USD)\n    Money.new(:USD, \"200.00\")\n\n    iex> Money.from_integer(200, :JPY)\n    Money.new(:JPY, \"200\")\n\n    iex> Money.from_integer(20012, :USD)\n    Money.new(:USD, \"200.12\")\n\n    iex> Money.from_integer(20012, :USD, fractional_digits: 3)\n    Money.new(:USD, \"20.012\")\n\n    iex> Money.from_integer(20012, :IQD)\n    Money.new(:IQD, \"20.012\")","title":"Examples - Money.from_integer/3","ref":"Money.html#from_integer/3-examples"},{"type":"function","doc":"","title":"Money.get_env/3","ref":"Money.html#get_env/3"},{"type":"function","doc":"Returns a boolean indicating if `t:Money.t/0`\nis an integer value (has no significant fractional\ndigits).","title":"Money.integer?/1","ref":"Money.html#integer?/1"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`","title":"Arguments - Money.integer?/1","ref":"Money.html#integer?/1-arguments"},{"type":"function","doc":"iex> Money.integer?(Money.new(:USD, 0))\n    true\n\n    iex> Money.integer?(Money.new(:USD, \"1.10\"))\n    false","title":"Example - Money.integer?/1","ref":"Money.html#integer?/1-example"},{"type":"function","doc":"","title":"Money.known_currencies/0","ref":"Money.html#known_currencies/0"},{"type":"function","doc":"","title":"Money.known_current_currencies/0","ref":"Money.html#known_current_currencies/0"},{"type":"function","doc":"","title":"Money.known_historic_currencies/0","ref":"Money.html#known_historic_currencies/0"},{"type":"function","doc":"","title":"Money.known_tender_currencies/0","ref":"Money.html#known_tender_currencies/0"},{"type":"function","doc":"Localizes a `Money` by converting it to the currency\nof the specified locale.","title":"Money.localize/2","ref":"Money.html#localize/2"},{"type":"function","doc":"* `money` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2`.\n\n* `options` is a keyword list of options.","title":"Arguments - Money.localize/2","ref":"Money.html#localize/2-arguments"},{"type":"function","doc":"* `:locale` is any valid locale returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is ` .get_locale()`\n\n* `:backend` is any module() that includes `use Cldr` and therefore\n  is a `Cldr` backend module(). The default is `Money.default_backend()`","title":"Options - Money.localize/2","ref":"Money.html#localize/2-options"},{"type":"function","doc":"* `{:ok, localized_money}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.localize/2","ref":"Money.html#localize/2-returns"},{"type":"function","doc":"Multiply a `Money` value by a number.","title":"Money.mult/2","ref":"Money.html#mult/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`\n\n* `number` is an integer, float or `Decimal.t`\n\n> Note that multipling one %Money{} by another is not supported.","title":"Arguments - Money.mult/2","ref":"Money.html#mult/2-arguments"},{"type":"function","doc":"* `{:ok, money}` or\n\n* `{:error, reason}`","title":"Returns - Money.mult/2","ref":"Money.html#mult/2-returns"},{"type":"function","doc":"iex> Money.mult(Money.new(:USD, 200), 2)\n    {:ok, Money.new(:USD, 400)}\n\n    iex> Money.mult(Money.new(:USD, 200), \"xx\")\n    {:error, {ArgumentError, \"Cannot multiply money by \\\"xx\\\"\"}}","title":"Example - Money.mult/2","ref":"Money.html#mult/2-example"},{"type":"function","doc":"Multiply a `Money` value by a number and raise on error.","title":"Money.mult!/2","ref":"Money.html#mult!/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` types returned\n  by `Money.new/2`\n\n* `number` is an integer, float or `Decimal.t`","title":"Arguments - Money.mult!/2","ref":"Money.html#mult!/2-arguments"},{"type":"function","doc":"* a `t:Money.t/0` or\n\n* raises an exception","title":"Returns - Money.mult!/2","ref":"Money.html#mult!/2-returns"},{"type":"function","doc":"iex> Money.mult!(Money.new(:USD, 200), 2)\n    Money.new(:USD, \"400\")\n\n    Money.mult!(Money.new(:USD, 200), :invalid)\n    ** (ArgumentError) Cannot multiply money by :invalid","title":"Examples - Money.mult!/2","ref":"Money.html#mult!/2-examples"},{"type":"function","doc":"Returns a boolean indicating if `t:Money.t/0`\nhas a negative value.","title":"Money.negative?/1","ref":"Money.html#negative?/1"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`","title":"Arguments - Money.negative?/1","ref":"Money.html#negative?/1-arguments"},{"type":"function","doc":"iex> Money.negative?(Money.new(:USD, -1))\n    true\n\n    iex> Money.negative?(Money.new(:USD, 0))\n    false\n\n    iex> Money.negative?(Money.new(:USD, 1))\n    false","title":"Example - Money.negative?/1","ref":"Money.html#negative?/1-example"},{"type":"function","doc":"Returns a %Money{} struct from a currency code and a currency amount or\nan error tuple of the form `{:error, {exception, message}}`.","title":"Money.new/3","ref":"Money.html#new/3"},{"type":"function","doc":"* `currency_code` is an [ISO4217](https://en.wikipedia.org/wiki/ISO_4217)\n  binary or atom currency code or an\n  [ISO 24165](https://www.iso.org/standard/80601.html) token identifier or shortname.\n\n* `amount` is an integer, string or Decimal money amount.\n\n* `options` is a keyword list of options.","title":"Arguments - Money.new/3","ref":"Money.html#new/3-arguments"},{"type":"function","doc":"* `:locale` is any known locale.  The locale is used to normalize any\n  binary (String) amounts to a form that can be consumed by `Decimal.new/1`.\n  This consists of removing any localised grouping characters and replacing\n  the localised decimal separator with a \".\".\n  The default is `Cldr.get_locale/0`.\n\n* `:backend` is any module() that includes `use Cldr` and therefore\n  is a `Cldr` backend module(). The default is `Money.default_backend/0`.\n\n* Any other options are considered as formatting options to\n  be applied by default when calling `Money.to_string/2`.\n\nNote that the `currency_code` and `amount` arguments can be supplied in\neither order,","title":"Options - Money.new/3","ref":"Money.html#new/3-options"},{"type":"function","doc":"iex> Money.new(:USD, 100)\n    Money.new(:USD, \"100\")\n\n    iex> Money.new(100, :USD)\n    Money.new(:USD, \"100\")\n\n    iex> Money.new(\"USD\", 100)\n    Money.new(:USD, \"100\")\n\n    iex> Money.new(\"thb\", 500)\n    Money.new(:THB, \"500\")\n\n    iex> Money.new(\"EUR\", Decimal.new(100))\n    Money.new(:EUR, \"100\")\n\n    iex> Money.new(:EUR, \"100.30\")\n    Money.new(:EUR, \"100.30\")\n\n    iex> Money.new(:EUR, \"100.30\", fractional_digits: 4)\n    Money.new(:EUR, \"100.30\", fractional_digits: 4)\n\n    iex> Money.new(:XYZZ, 100)\n    {:error, {Money.UnknownCurrencyError, \"The currency :XYZZ is invalid\"}}\n\n    iex> Money.new(\"1.000,99\", :EUR, locale: \"de\")\n    Money.new(:EUR, \"1000.99\")\n\n    iex> Money.new 123.445, :USD\n    {:error,\n     {Money.InvalidAmountError,\n      \"Float amounts are not supported in new/2 due to potenial \" <>\n      \"rounding and precision issues.  If absolutely required, \" <>\n      \"use Money.from_float/2\"}}","title":"Examples - Money.new/3","ref":"Money.html#new/3-examples"},{"type":"function","doc":"Returns a %Money{} struct from a currency code and a currency amount. Raises an\nexception if the current code is invalid.","title":"Money.new!/3","ref":"Money.html#new!/3"},{"type":"function","doc":"* `currency_code` is an [ISO4217](https://en.wikipedia.org/wiki/ISO_4217)\n  binary or atom currency code or an\n  [ISO 24165](https://www.iso.org/standard/80601.html) token identifier or shortname.\n\n* `amount` is an integer, float or Decimal","title":"Arguments - Money.new!/3","ref":"Money.html#new!/3-arguments"},{"type":"function","doc":"Money.new!(:XYZZ, 100)\n    ** (Money.UnknownCurrencyError) Currency :XYZZ is not known\n      (ex_money) lib/money.ex:177: Money.new!/2","title":"Examples - Money.new!/3","ref":"Money.html#new!/3-examples"},{"type":"function","doc":"Normalizes the underlying decimal amount in a\ngiven `t:Money.t/0`.\n\nThis will normalize the coefficient and exponent of the\ndecimal amount in a standard way that may aid in\nnative comparison of `t:Money.t/0` items.","title":"Money.normalize/1","ref":"Money.html#normalize/1"},{"type":"function","doc":"iex> x = %Money{currency: :USD, amount: %Decimal{sign: 1, coef: 42, exp: 0}}\n    Money.new(:USD, \"42\")\n    iex> y = %Money{currency: :USD, amount: %Decimal{sign: 1, coef: 4200000000, exp: -8}}\n    Money.new(:USD, \"42.00000000\")\n    iex> x == y\n    false\n    iex> y = Money.normalize(x)\n    Money.new(:USD, \"42\")\n    iex> x == y\n    true","title":"Example - Money.normalize/1","ref":"Money.html#normalize/1-example"},{"type":"function","doc":"Parse a string and return a `t:Money.t/0` or an error.\n\nThe string to be parsed is required to have a currency\ncode and an amount.  The currency code may be placed\nbefore the amount or after, but not both.\n\nParsing is strict.  Additional text surrounding the\ncurrency code and amount will cause the parse to\nfail.","title":"Money.parse/2","ref":"Money.html#parse/2"},{"type":"function","doc":"* `string` is a string to be parsed\n\n* `options` is a keyword list of options that is\n  passed to `Money.new/3` with the exception of\n  the options listed below","title":"Arguments - Money.parse/2","ref":"Money.html#parse/2-arguments"},{"type":"function","doc":"* `:backend` is any module() that includes `use Cldr` and therefore\n  is a `Cldr` backend module(). The default is `Money.default_backend()`\n\n* `:locale` is any valid locale returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is ` .get_locale()`\n\n* `:only` is an `atom` or list of `atoms` representing the\n  currencies or currency types to be considered for a match.\n  The equates to a list of acceptable currencies for parsing.\n  See the notes below for currency types.\n\n* `:except` is an `atom` or list of `atoms` representing the\n  currencies or currency types to be not considered for a match.\n  This equates to a list of unacceptable currencies for parsing.\n  See the notes below for currency types.\n\n* `:fuzzy` is a float greater than `0.0` and less than or\n  equal to `1.0` which is used as input to the\n  `String.jaro_distance/2` to determine is the provided\n  currency string is *close enough* to a known currency\n  string for it to identify definitively a currency code.\n  It is recommended to use numbers greater than `0.8` in\n  order to reduce false positives.\n\n* `:default_currency` is any valid currency code or `false`\n  that will used if no currency code, symbol or description is\n  indentified in the parsed string. The default is `nil`\n  which means that the default currency associated with\n  the `:locale` option will be used. If `false` then the\n  currency assocated with the `:locale` option will not be\n  used and an error will be returned if there is no currency\n  in the string being parsed.","title":"Options - Money.parse/2","ref":"Money.html#parse/2-options"},{"type":"function","doc":"* a `t:Money.t/0` if parsing is successful or\n\n* `{:error, {exception, reason}}` if an error is\n  detected.","title":"Returns - Money.parse/2","ref":"Money.html#parse/2-returns"},{"type":"function","doc":"The `:only` and `:except` options accept a list of\ncurrency codes and/or currency types.  The following\ntypes are recognised.\n\nIf both `:only` and `:except` are specified,\nthe `:except` entries take priority - that means\nany entries in `:except` are removed from the `:only`\nentries.\n\n  * `:all`, the default, considers all currencies\n\n  * `:current` considers those currencies that have a `:to`\n    date of nil and which also is a known ISO4217 currency\n\n  * `:historic` is the opposite of `:current`\n\n  * `:tender` considers currencies that are legal tender\n\n  * `:unannotated` considers currencies that don't have\n    \"(some string)\" in their names.  These are usually\n    financial instruments.","title":"Notes - Money.parse/2","ref":"Money.html#parse/2-notes"},{"type":"function","doc":"iex> Money.parse(\"USD 100\")\n    Money.new(:USD, \"100\")\n\n    iex> Money.parse \"USD 100,00\", locale: \"de\"\n    Money.new(:USD, \"100.00\")\n\n    iex> Money.parse(\"100 USD\")\n    Money.new(:USD, \"100\")\n\n    iex> Money.parse(\"100 eurosports\", fuzzy: 0.8)\n    Money.new(:EUR, \"100\")\n\n    iex> Money.parse(\"100\", default_currency: :EUR)\n    Money.new(:EUR, \"100\")\n\n    iex> Money.parse(\"100 eurosports\", fuzzy: 0.9)\n    {:error, {Money.UnknownCurrencyError, \"The currency \\\"eurosports\\\" is unknown or not supported\"}}\n\n    iex> Money.parse(\"100 afghan afghanis\")\n    Money.new(:AFN, \"100\")\n\n    iex> Money.parse(\"100\", default_currency: false)\n    {:error, {Money.Invalid,\n      \"A currency code, symbol or description must be specified but was not found in \\\"100\\\"\"}}\n\n    iex> Money.parse(\"USD 100 with trailing text\")\n    {:error, {Money.ParseError, \"Could not parse \\\"USD 100 with trailing text\\\".\"}}","title":"Examples - Money.parse/2","ref":"Money.html#parse/2-examples"},{"type":"function","doc":"Returns a boolean indicating if `t:Money.t/0`\nhas a positive value.","title":"Money.positive?/1","ref":"Money.html#positive?/1"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`","title":"Arguments - Money.positive?/1","ref":"Money.html#positive?/1-arguments"},{"type":"function","doc":"iex> Money.positive?(Money.new(:USD, 1))\n    true\n\n    iex> Money.positive?(Money.new(:USD, 0))\n    false\n\n    iex> Money.positive?(Money.new(:USD, -1))\n    false","title":"Example - Money.positive?/1","ref":"Money.html#positive?/1-example"},{"type":"function","doc":"Add format options to a `t:Money.t/0`.","title":"Money.put_format_options/2","ref":"Money.html#put_format_options/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`\n\n* `options` is a keyword list of options. These\n  options are used when calling `Money.to_string/2`.\n  The default is `[]`","title":"Arguments - Money.put_format_options/2","ref":"Money.html#put_format_options/2-arguments"},{"type":"function","doc":"Set the fractional part of a `Money`.","title":"Money.put_fraction/2","ref":"Money.html#put_fraction/2"},{"type":"function","doc":"* `money` is any `t:Money.t/0`\n\n* `fraction` is an integer amount that will be set\n  as the fraction of the `money`","title":"Arguments - Money.put_fraction/2","ref":"Money.html#put_fraction/2-arguments"},{"type":"function","doc":"The fraction can only be set if it matches the number of\ndecimal digits for the currency associated with the `money`.\nTherefore, for a currency with 2 decimal digits, the\nmaximum for `fraction` is `99`.","title":"Notes - Money.put_fraction/2","ref":"Money.html#put_fraction/2-notes"},{"type":"function","doc":"iex> Money.put_fraction Money.new(:USD, \"2.49\"), 99\n    Money.new(:USD, \"2.99\")\n\n    iex> Money.put_fraction Money.new(:USD, \"2.49\"), 0\n    Money.new(:USD, \"2.0\")\n\n    iex> Money.put_fraction Money.new(:USD, \"2.49\"), 999\n    {:error,\n     {Money.InvalidAmountError, \"Rounding up to 999 is invalid for currency :USD\"}}","title":"Examples - Money.put_fraction/2","ref":"Money.html#put_fraction/2-examples"},{"type":"function","doc":"","title":"Money.reduce/1","ref":"Money.html#reduce/1"},{"type":"function","doc":"Round a `Money` value into the acceptable range for the requested currency.","title":"Money.round/2","ref":"Money.html#round/2"},{"type":"function","doc":"* `money` is any `t:Money.t/0`\n\n* `opts` is a keyword list of options","title":"Arguments - Money.round/2","ref":"Money.html#round/2-arguments"},{"type":"function","doc":"* `:rounding_mode` that defines how the number will be rounded.  See\n    `Decimal.Context`.  The default is `:half_even` which is also known\n    as \"banker's rounding\"\n\n  * `:currency_digits` which determines the rounding increment.\n    The valid options are `:cash`, `:accounting` and `:iso` or\n    an integer value representing the rounding factor.  The\n    default is `:iso`.","title":"Options - Money.round/2","ref":"Money.html#round/2-options"},{"type":"function","doc":"There are two kinds of rounding applied:\n\n1. Round to the appropriate number of fractional digits\n\n3. Apply an appropriate rounding increment.  Most currencies\n   round to the same precision as the number of decimal digits, but some\n   such as `:CHF` round to a minimum such as `0.05` when its a cash\n   amount. The rounding increment is applied when the option\n   `:currency_digits` is set to `:cash`\n\n3. Digital Tokens (crypto currencies) do not have formal definitions\n   of decimal digits or rounding strategies. Therefore the `money` is\n   returned unmodified.","title":"Notes - Money.round/2","ref":"Money.html#round/2-notes"},{"type":"function","doc":"iex> Money.round Money.new(\"123.73\", :CHF), currency_digits: :cash\n    Money.new(:CHF, \"123.75\")\n\n    iex> Money.round Money.new(\"123.73\", :CHF), currency_digits: 0\n    Money.new(:CHF, \"124\")\n\n    iex> Money.round Money.new(\"123.7456\", :CHF)\n    Money.new(:CHF, \"123.75\")\n\n    iex> Money.round Money.new(\"123.7456\", :JPY)\n    Money.new(:JPY, \"124\")","title":"Examples - Money.round/2","ref":"Money.html#round/2-examples"},{"type":"function","doc":"Split a `Money` value into a number of parts maintaining the currency's\nprecision and rounding and ensuring that the parts sum to the original\namount.","title":"Money.split/2","ref":"Money.html#split/2"},{"type":"function","doc":"* `money` is any `t:Money.t/0`\n\n* `parts` is an integer number of parts into which the `money` is split\n\nReturns a tuple `{dividend, remainder}` as the function result\nderived as follows:\n\n1. Round the money amount to the required currency precision using\n`Money.round/1`\n\n2. Divide the result of step 1 by the integer divisor\n\n3. Round the result of the division to the precision of the currency\nusing `Money.round/1`\n\n4. Return two numbers: the result of the division and any remainder\nthat could not be applied given the precision of the currency.","title":"Arguments - Money.split/2","ref":"Money.html#split/2-arguments"},{"type":"function","doc":"Money.split Money.new(123.5, :JPY), 3\n    {¥41, ¥1}\n\n    Money.split Money.new(123.4, :JPY), 3\n    {¥41, ¥0}\n\n    Money.split Money.new(123.7, :USD), 9\n    {$13.74, $0.04}","title":"Examples - Money.split/2","ref":"Money.html#split/2-examples"},{"type":"function","doc":"Subtract one `Money` value struct from another.","title":"Money.sub/2","ref":"Money.html#sub/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`","title":"Options - Money.sub/2","ref":"Money.html#sub/2-options"},{"type":"function","doc":"* `{:ok, money}` or\n\n* `{:error, reason}`","title":"Returns - Money.sub/2","ref":"Money.html#sub/2-returns"},{"type":"function","doc":"iex> Money.sub Money.new(:USD, 200), Money.new(:USD, 100)\n    {:ok, Money.new(:USD, 100)}","title":"Example - Money.sub/2","ref":"Money.html#sub/2-example"},{"type":"function","doc":"Subtract one `Money` value struct from another and raise on error.\n\nReturns either `{:ok, money}` or `{:error, reason}`.","title":"Money.sub!/2","ref":"Money.html#sub!/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`","title":"Arguments - Money.sub!/2","ref":"Money.html#sub!/2-arguments"},{"type":"function","doc":"* a `t:Money.t/0` struct or\n\n* raises an exception","title":"Returns - Money.sub!/2","ref":"Money.html#sub!/2-returns"},{"type":"function","doc":"iex> Money.sub! Money.new(:USD, 200), Money.new(:USD, 100)\n    Money.new(:USD, \"100\")\n\n    Money.sub! Money.new(:USD, 200), Money.new(:CAD, 500)\n    ** (ArgumentError) Cannot subtract monies with different currencies. Received :USD and :CAD.","title":"Examples - Money.sub!/2","ref":"Money.html#sub!/2-examples"},{"type":"function","doc":"Sum a list of monies that may be in different\ncurrencies.","title":"Money.sum/2","ref":"Money.html#sum/2"},{"type":"function","doc":"* `money_list` is a list of any valid `t:Money.t/0` types returned\n  by `Money.new/2`.\n\n* `rates` is a map of exchange rates. The default is the rates\n  returned by `Money.ExchangeRates.latest_rates/0`. If the\n  exchange rates retriever is not running, then the default is\n  `%{}`.","title":"Arguments - Money.sum/2","ref":"Money.html#sum/2-arguments"},{"type":"function","doc":"* `{:ok, money}` representing the sum of the maybe\n  converted money amounts. The currency of the sum is\n  the currency of the first `Money` in the `money_list`.\n\n* `{:error, {exception, reason}}` describing an error.","title":"Returns - Money.sum/2","ref":"Money.html#sum/2-returns"},{"type":"function","doc":"iex> Money.sum([Money.new(:USD, 100), Money.new(:USD, 200), Money.new(:USD, 50)])\n    {:ok, Money.new(:USD, 350)}\n\n    iex> Money.sum([Money.new(:USD, 100), Money.new(:USD, 200), Money.new(:AUD, 50)], %{})\n    {:error,\n     {Money.ExchangeRateError, \"No exchange rate is available for currency :AUD\"}}\n\n    iex> rates = %{AUD: Decimal.new(2), USD: Decimal.new(1)}\n    iex> Money.sum [Money.new(:USD, 100), Money.new(:USD, 200), Money.new(:AUD, 50)], rates\n    {:ok, Money.from_float(:USD, 325.0)}","title":"Examples - Money.sum/2","ref":"Money.html#sum/2-examples"},{"type":"function","doc":"Convert `money` from one currency to another.","title":"Money.to_currency/3","ref":"Money.html#to_currency/3"},{"type":"function","doc":"* `money` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2`.\n\n* `to_currency` is a valid currency code into which the `money` is converted.\n\n* `rates` is a `Map` of currency rates where the map key is an upcased\n  atom or string and the value is a Decimal conversion factor.  The default is the\n  latest available exchange rates returned from `Money.ExchangeRates.latest_rates/0`.","title":"Arguments - Money.to_currency/3","ref":"Money.html#to_currency/3-arguments"},{"type":"function","doc":"To convert a `Money` to a currency defined by a locale,\n`Cldr.Currency.currency_from_locale/1` can be called with\na `t:Cldr.LanguageTag.t/0` parameter. It will return\nthe currency configured for that locale.","title":"Converting to a currency defined in a locale - Money.to_currency/3","ref":"Money.html#to_currency/3-converting-to-a-currency-defined-in-a-locale"},{"type":"function","doc":"iex> Money.to_currency(Money.new(:USD, 100), :AUD,\n    ...>   %{USD: Decimal.new(1), AUD: Decimal.from_float(0.7345)})\n    {:ok, Money.new(:AUD, \"73.4500\")}\n\n    iex> Money.to_currency(Money.new(\"USD\", 100), \"AUD\",\n    ...>   %{\"USD\" => Decimal.new(1), \"AUD\" => Decimal.from_float(0.7345)})\n    {:ok, Money.new(:AUD, \"73.4500\")}\n\n    iex> Money.to_currency(Money.new(:USD, 100), :AUDD,\n    ...>   %{USD: Decimal.new(1), AUD: Decimal.from_float(0.7345)})\n    {:error, {Cldr.UnknownCurrencyError, \"The currency :AUDD is invalid\"}}\n\n    iex> Money.to_currency(Money.new(:USD, 100), :CHF,\n    ...>   %{USD: Decimal.new(1), AUD: Decimal.from_float(0.7345)})\n    {:error, {Money.ExchangeRateError,\n      \"No exchange rate is available for currency :CHF\"}}","title":"Examples - Money.to_currency/3","ref":"Money.html#to_currency/3-examples"},{"type":"function","doc":"Convert `money` from one currency to another or raises on error.","title":"Money.to_currency!/3","ref":"Money.html#to_currency!/3"},{"type":"function","doc":"* `money` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2`.\n\n* `to_currency` is a valid currency code into which the `money` is converted.\n\n* `rates` is a `Map` of currency rates where the map key is an upcased\n  atom or string and the value is a Decimal conversion factor.  The default is the\n  latest available exchange rates returned from `Money.ExchangeRates.latest_rates/0`.","title":"Arguments - Money.to_currency!/3","ref":"Money.html#to_currency!/3-arguments"},{"type":"function","doc":"iex> Money.to_currency! Money.new(:USD, 100), :AUD,\n    ...>   %{USD: Decimal.new(1), AUD: Decimal.from_float(0.7345)}\n    Money.new(:AUD, \"73.4500\")\n\n    iex> Money.to_currency! Money.new(\"USD\", 100), \"AUD\",\n    ...>   %{\"USD\" => Decimal.new(1), \"AUD\" => Decimal.from_float(0.7345)}\n    Money.new(:AUD, \"73.4500\")\n\n    => Money.to_currency! Money.new(:USD, 100), :ZZZ,\n         %{USD: Decimal.new(1), AUD: Decimal.from_float(0.7345)}\n    ** (Cldr.UnknownCurrencyError) Currency :ZZZ is not known","title":"Examples - Money.to_currency!/3","ref":"Money.html#to_currency!/3-examples"},{"type":"function","doc":"Returns the currecny code of a `Money` type\nas an `atom`.","title":"Money.to_currency_code/1","ref":"Money.html#to_currency_code/1"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`.","title":"Arguments - Money.to_currency_code/1","ref":"Money.html#to_currency_code/1-arguments"},{"type":"function","doc":"* the currency code as an `t:atom`.","title":"Returns - Money.to_currency_code/1","ref":"Money.html#to_currency_code/1-returns"},{"type":"function","doc":"iex> m = Money.new(\"USD\", 100)\n    iex> Money.to_currency_code(m)\n    :USD","title":"Example - Money.to_currency_code/1","ref":"Money.html#to_currency_code/1-example"},{"type":"function","doc":"Returns the amount part of a `Money` type as a `Decimal`","title":"Money.to_decimal/1","ref":"Money.html#to_decimal/1"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`","title":"Arguments - Money.to_decimal/1","ref":"Money.html#to_decimal/1-arguments"},{"type":"function","doc":"* a `Decimal.t`","title":"Returns - Money.to_decimal/1","ref":"Money.html#to_decimal/1-returns"},{"type":"function","doc":"iex> m = Money.new(\"USD\", 100)\n    iex> Money.to_decimal(m)\n    Decimal.new(100)","title":"Example - Money.to_decimal/1","ref":"Money.html#to_decimal/1-example"},{"type":"function","doc":"Returns a tuple comprising the currency code, integer amount,\nexponent and remainder.\n\nSome services require submission of money items as an integer\nwith an implied exponent that is appropriate to the currency.\n\nRather than return only the integer, `Money.to_integer_exp`\nreturns the currency code, integer, exponent and remainder.\nThe remainder is included because to return an integer\nmoney with an implied exponent the `Money` has to be rounded\npotentially leaving a remainder.","title":"Money.to_integer_exp/2","ref":"Money.html#to_integer_exp/2"},{"type":"function","doc":"* `money` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2`.","title":"Options - Money.to_integer_exp/2","ref":"Money.html#to_integer_exp/2-options"},{"type":"function","doc":"* Since the returned integer is expected to have the implied fractional\ndigits the `Money` needs to be rounded which is what this function does.","title":"Notes - Money.to_integer_exp/2","ref":"Money.html#to_integer_exp/2-notes"},{"type":"function","doc":"iex> m = Money.new(:USD, \"200.012356\")\n    Money.new(:USD, \"200.012356\")\n    iex> Money.to_integer_exp(m)\n    {:USD, 20001, -2, Money.new(:USD, \"0.002356\")}\n\n    iex> m = Money.new(:USD, \"200.00\")\n    Money.new(:USD, \"200.00\")\n    iex> Money.to_integer_exp(m)\n    {:USD, 20000, -2, Money.new(:USD, \"0.00\")}","title":"Example - Money.to_integer_exp/2","ref":"Money.html#to_integer_exp/2-example"},{"type":"function","doc":"Returns a formatted string representation of a `t:Money.t/0`.\n\nFormatting is performed according to the rules defined by CLDR. See\n`Cldr.Number.to_string/2` for formatting options.  The default is to format\nas a currency which applies the appropriate rounding and fractional digits\nfor the currency.","title":"Money.to_string/2","ref":"Money.html#to_string/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`\n\n* `options` is a keyword list of options or a `%Cldr.Number.Format.Options{}` struct","title":"Arguments - Money.to_string/2","ref":"Money.html#to_string/2-arguments"},{"type":"function","doc":"* `{:ok, string}` or\n\n* `{:error, reason}`","title":"Returns - Money.to_string/2","ref":"Money.html#to_string/2-returns"},{"type":"function","doc":"* `:backend` is any CLDR backend module.  The default is\n  `Money.default_backend()`.\n\n* `currency_symbol`: Allows overriding a currency symbol. The alternatives\n  are:\n  * `:iso` the ISO currency code will be used instead of the default\n    currency symbol.\n  * `:narrow` uses the narrow symbol defined for the locale. The same\n    narrow symbol can be defined for more than one currency and therefore this\n    should be used with care. If no narrow symbol is defined, the standard\n    symbol is used.\n  * `:symbol` uses the standard symbol defined in CLDR. A symbol is unique\n    for each currency and can be safely used.\n  * \"string\" uses `string` as the currency symbol\n  * `:standard` (the default and recommended) uses the CLDR-defined symbol\n    based upon the currency format for the locale.\n\n* `:no_fraction_if_integer` is a boolean which, if `true`, will set `:fractional_digits`\n  to `0` if the money value is an integer value.\n\n* Any other options are passed to `Cldr.Number.to_string/3`","title":"Options - Money.to_string/2","ref":"Money.html#to_string/2-options"},{"type":"function","doc":"iex> Money.to_string Money.new(:USD, 1234)\n    {:ok, \"$1,234.00\"}\n\n    iex> Money.to_string Money.new(:USD, 1234), no_fraction_if_integer: true\n    {:ok, \"$1,234\"}\n\n    iex> Money.to_string Money.new(:JPY, 1234)\n    {:ok, \"¥1,234\"}\n\n    iex> Money.to_string Money.new(:THB, 1234)\n    {:ok, \"THB 1,234.00\"}\n\n    iex> Money.to_string Money.new(:THB, 1234, fractional_digits: 4)\n    {:ok, \"THB 1,234.0000\"}\n\n    iex> Money.to_string Money.new(:USD, 1234), format: :long\n    {:ok, \"1,234 US dollars\"}","title":"Examples - Money.to_string/2","ref":"Money.html#to_string/2-examples"},{"type":"function","doc":"Returns a formatted string representation of a `t:Money.t/0` or raises if\nthere is an error.\n\nFormatting is performed according to the rules defined by CLDR. See\n`Cldr.Number.to_string!/2` for formatting options.  The default is to format\nas a currency which applies the appropriate rounding and fractional digits\nfor the currency.","title":"Money.to_string!/2","ref":"Money.html#to_string!/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`\n\n* `options` is a keyword list of options or a `%Cldr.Number.Format.Options{}` struct","title":"Arguments - Money.to_string!/2","ref":"Money.html#to_string!/2-arguments"},{"type":"function","doc":"* `:backend` is any CLDR backend module.  The default is\n  `Money.default_backend()`.\n\n* Any other options are passed to `Cldr.Number.to_string/3`","title":"Options - Money.to_string!/2","ref":"Money.html#to_string!/2-options"},{"type":"function","doc":"iex> Money.to_string! Money.new(:USD, 1234)\n    \"$1,234.00\"\n\n    iex> Money.to_string! Money.new(:JPY, 1234)\n    \"¥1,234\"\n\n    iex> Money.to_string! Money.new(:THB, 1234)\n    \"THB 1,234.00\"\n\n    iex> Money.to_string! Money.new(:USD, 1234), format: :long\n    \"1,234 US dollars\"","title":"Examples - Money.to_string!/2","ref":"Money.html#to_string!/2-examples"},{"type":"function","doc":"Return a zero amount `t:Money.t/0` in the given currency.","title":"Money.zero/2","ref":"Money.html#zero/2"},{"type":"function","doc":"* `money_or_currency` is either a `t:Money.t/0` or\n  a currency code.\n\n* `options` is a keyword list of options passed\n  to `Money.new/3`. The default is `[]`.","title":"Arguments - Money.zero/2","ref":"Money.html#zero/2-arguments"},{"type":"function","doc":"iex> Money.zero(:USD)\n    Money.new(:USD, \"0\")\n\n    iex> money = Money.new(:USD, 200)\n    iex> Money.zero(money)\n    Money.new(:USD, \"0\")\n\n    iex> Money.zero :ZZZ\n    {:error, {Cldr.UnknownCurrencyError, \"The currency :ZZZ is invalid\"}}","title":"Example - Money.zero/2","ref":"Money.html#zero/2-example"},{"type":"function","doc":"Returns a boolean indicating if `t:Money.t/0`\nhas a zero value.","title":"Money.zero?/1","ref":"Money.html#zero?/1"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`","title":"Arguments - Money.zero?/1","ref":"Money.html#zero?/1-arguments"},{"type":"function","doc":"iex> Money.zero?(Money.new(:USD, 0))\n    true\n\n    iex> Money.zero?(Money.new(:USD, 1))\n    false\n\n    iex> Money.zero?(Money.new(:USD, -1))\n    false","title":"Example - Money.zero?/1","ref":"Money.html#zero?/1-example"},{"type":"type","doc":"An amount can be expressed as a float, an integer,\na Decimal or a string (which is converted to a Decimal)","title":"Money.amount/0","ref":"Money.html#t:amount/0"},{"type":"type","doc":"A currency code is an ISO 4217 code expressed\nas an atom or binary or an ISO 24165 Digital\nToken ID or Digital Token short name.","title":"Money.currency_code/0","ref":"Money.html#t:currency_code/0"},{"type":"type","doc":"Money is composed of an atom representation of an ISO4217 currency code and\na `Decimal` representation of an amount.","title":"Money.t/0","ref":"Money.html#t:t/0"},{"type":"module","doc":"","title":"Money.Application","ref":"Money.Application.html"},{"type":"function","doc":"","title":"Money.Application.start/2","ref":"Money.Application.html#start/2"},{"type":"module","doc":"Provides the core functions to retrieve and manage\nthe CLDR data that supports formatting and localisation.\n\nIt provides the core functions to access formatted\nCLDR data, set and retrieve a current locale and validate\ncertain core data types such as locales, currencies and\nterritories.","title":"Money.Cldr","ref":"Money.Cldr.html"},{"type":"function","doc":"","title":"Money.Cldr.available_locale_name?/1","ref":"Money.Cldr.html#available_locale_name?/1"},{"type":"function","doc":"Returns the default `locale`.","title":"Money.Cldr.default_locale/0","ref":"Money.Cldr.html#default_locale/0"},{"type":"function","doc":"iex> Money.Cldr.default_locale()\n    %Cldr.LanguageTag{\n      backend: Money.Cldr,\n      canonical_locale_name: \"en-001\",\n      cldr_locale_name: :\"en-001\",\n      language_subtags: [],\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en-001\",\n      script: :Latn,\n      territory: :\"001\",\n      transform: %{},\n      language_variants: []\n    }","title":"Example - Money.Cldr.default_locale/0","ref":"Money.Cldr.html#default_locale/0-example"},{"type":"function","doc":"Returns the default territory when a locale\ndoes not specify one and none can be inferred.","title":"Money.Cldr.default_territory/0","ref":"Money.Cldr.html#default_territory/0"},{"type":"function","doc":"iex> Money.Cldr.default_territory()\n    :\"001\"","title":"Example - Money.Cldr.default_territory/0","ref":"Money.Cldr.html#default_territory/0-example"},{"type":"function","doc":"Add locale-specific ellipsis to a string.","title":"Money.Cldr.ellipsis/2","ref":"Money.Cldr.html#ellipsis/2"},{"type":"function","doc":"* `string` is any `String.t` or a 2-element list\n  of `String.t` between which the ellipsis is inserted.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.ellipsis/2","ref":"Money.Cldr.html#ellipsis/2-arguments"},{"type":"function","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/0`.\n\n* `:location` determines where to place the ellipsis. The options are\n  `:after` (the default for a single string argument), `:between`\n  (the default and only valid location for an argument that is a list\n  of two strings) and `:before`.\n\n* `:format` formats based upon whether the ellipsis\n  is inserted between words or sentences. The valid options are\n  `:word` or `:sentence`. The default is `:sentence`.","title":"Options - Money.Cldr.ellipsis/2","ref":"Money.Cldr.html#ellipsis/2-options"},{"type":"function","doc":"iex> Money.Cldr.ellipsis(\"And furthermore\")\n    \"And furthermore…\"\n\n    iex> Money.Cldr.ellipsis([\"And furthermore\", \"there is much to be done\"], locale: :ja)\n    \"And furthermore…there is much to be done\"\n\n    iex> Money.Cldr.ellipsis(\"And furthermore\", format: :word)\n    \"And furthermore …\"\n\n    iex> Money.Cldr.ellipsis([\"And furthermore\", \"there is much to be done\"], locale: :ja, format: :word)\n    \"And furthermore … there is much to be done\"","title":"Examples - Money.Cldr.ellipsis/2","ref":"Money.Cldr.html#ellipsis/2-examples"},{"type":"function","doc":"Return the current locale to be used for `Cldr` functions that\ntake an optional locale parameter for which a locale is not supplied.","title":"Money.Cldr.get_locale/0","ref":"Money.Cldr.html#get_locale/0"},{"type":"function","doc":"iex> Money.Cldr.put_locale(\"pl\")\n    iex> Money.Cldr.get_locale()\n    %Cldr.LanguageTag{\n       backend: Elixir.Money.Cldr,\n       canonical_locale_name: \"pl\",\n       cldr_locale_name: :pl,\n       extensions: %{},\n       language: \"pl\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :pl,\n       territory: :PL,\n       requested_locale_name: \"pl\",\n       script: :Latn,\n       transform: %{},\n       language_variants: []\n     }","title":"Example - Money.Cldr.get_locale/0","ref":"Money.Cldr.html#get_locale/0-example"},{"type":"function","doc":"","title":"Money.Cldr.known_calendars/0","ref":"Money.Cldr.html#known_calendars/0"},{"type":"function","doc":"","title":"Money.Cldr.known_currencies/0","ref":"Money.Cldr.html#known_currencies/0"},{"type":"function","doc":"Returns either the Gettext `locale_name` in Cldr format or\n`false` based upon whether the locale name is configured in\n`Gettext`.","title":"Money.Cldr.known_gettext_locale_name/1","ref":"Money.Cldr.html#known_gettext_locale_name/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_gettext_locale_names/0`","title":"Arguments - Money.Cldr.known_gettext_locale_name/1","ref":"Money.Cldr.html#known_gettext_locale_name/1-arguments"},{"type":"function","doc":"iex> Money.Cldr.known_gettext_locale_name(\"en\")\n    \"en\"\n\n    iex> Money.Cldr.known_gettext_locale_name(\"en-SA\")\n    false","title":"Examples - Money.Cldr.known_gettext_locale_name/1","ref":"Money.Cldr.html#known_gettext_locale_name/1-examples"},{"type":"function","doc":"Returns a boolean indicating if the specified locale\nname is configured and available in Gettext.","title":"Money.Cldr.known_gettext_locale_name?/1","ref":"Money.Cldr.html#known_gettext_locale_name?/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`","title":"Arguments - Money.Cldr.known_gettext_locale_name?/1","ref":"Money.Cldr.html#known_gettext_locale_name?/1-arguments"},{"type":"function","doc":"iex> Money.Cldr.known_gettext_locale_name?(\"en\")\n    true\n\n    iex> Money.Cldr.known_gettext_locale_name?(\"!!\")\n    false","title":"Examples - Money.Cldr.known_gettext_locale_name?/1","ref":"Money.Cldr.html#known_gettext_locale_name?/1-examples"},{"type":"function","doc":"Returns a list of Gettext locale names but in CLDR format with\nunderscore replaced by hyphen in order to facilitate comparisons\nwith `Cldr` locale names.","title":"Money.Cldr.known_gettext_locale_names/0","ref":"Money.Cldr.html#known_gettext_locale_names/0"},{"type":"function","doc":"Returns either the `locale_name` or `false` based upon\nwhether the locale name is configured in `Cldr`.\n\nThis is helpful when building a list of `or` expressions\nto return the first known locale name from a list.","title":"Money.Cldr.known_locale_name/1","ref":"Money.Cldr.html#known_locale_name/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`","title":"Arguments - Money.Cldr.known_locale_name/1","ref":"Money.Cldr.html#known_locale_name/1-arguments"},{"type":"function","doc":"iex> Money.Cldr.known_locale_name(:\"en-AU\")\n    :\"en-AU\"\n\n    iex> Money.Cldr.known_locale_name(:\"en-SA\")\n    false","title":"Examples - Money.Cldr.known_locale_name/1","ref":"Money.Cldr.html#known_locale_name/1-examples"},{"type":"function","doc":"Returns a boolean indicating if the specified locale\nname is configured and available in Cldr.","title":"Money.Cldr.known_locale_name?/1","ref":"Money.Cldr.html#known_locale_name?/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by `Money.Cldr.known_locale_names/0`","title":"Arguments - Money.Cldr.known_locale_name?/1","ref":"Money.Cldr.html#known_locale_name?/1-arguments"},{"type":"function","doc":"iex> Money.Cldr.known_locale_name?(:en)\n    true\n\n    iex> Money.Cldr.known_locale_name?(:\"!!\")\n    false","title":"Examples - Money.Cldr.known_locale_name?/1","ref":"Money.Cldr.html#known_locale_name?/1-examples"},{"type":"function","doc":"Returns a list of the known locale names.\n\nKnown locales are those locales which\nare the subset of all CLDR locales that\nhave been configured for use either\nin this module or in `Gettext`.","title":"Money.Cldr.known_locale_names/0","ref":"Money.Cldr.html#known_locale_names/0"},{"type":"function","doc":"Returns a list of atoms representing the number systems types known to `Cldr`.","title":"Money.Cldr.known_number_system_types/0","ref":"Money.Cldr.html#known_number_system_types/0"},{"type":"function","doc":"iex> Money.Cldr.known_number_system_types()\n    [:default, :finance, :native, :traditional]","title":"Example - Money.Cldr.known_number_system_types/0","ref":"Money.Cldr.html#known_number_system_types/0-example"},{"type":"function","doc":"","title":"Money.Cldr.known_number_systems/0","ref":"Money.Cldr.html#known_number_systems/0"},{"type":"function","doc":"Returns either the RBNF `locale_name` or `false` based upon\nwhether the locale name is configured in `Cldr`\nand has RBNF rules defined.","title":"Money.Cldr.known_rbnf_locale_name/1","ref":"Money.Cldr.html#known_rbnf_locale_name/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`","title":"Arguments - Money.Cldr.known_rbnf_locale_name/1","ref":"Money.Cldr.html#known_rbnf_locale_name/1-arguments"},{"type":"function","doc":"iex> Money.Cldr.known_rbnf_locale_name(:en)\n    :en\n\n    iex> Money.Cldr.known_rbnf_locale_name(:\"en-SA\")\n    false","title":"Examples - Money.Cldr.known_rbnf_locale_name/1","ref":"Money.Cldr.html#known_rbnf_locale_name/1-examples"},{"type":"function","doc":"Returns a boolean indicating if the specified locale\nname is configured and available in Cldr and supports\nrules based number formats (RBNF).","title":"Money.Cldr.known_rbnf_locale_name?/1","ref":"Money.Cldr.html#known_rbnf_locale_name?/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by `Money.Cldr.known_locale_names/0`","title":"Arguments - Money.Cldr.known_rbnf_locale_name?/1","ref":"Money.Cldr.html#known_rbnf_locale_name?/1-arguments"},{"type":"function","doc":"iex> Money.Cldr.known_rbnf_locale_name?(:en)\n    true\n\n    iex> Money.Cldr.known_rbnf_locale_name?(:\"!!\")\n    false","title":"Examples - Money.Cldr.known_rbnf_locale_name?/1","ref":"Money.Cldr.html#known_rbnf_locale_name?/1-examples"},{"type":"function","doc":"Returns a list of locale names which have rules-based number\nformats (RBNF).","title":"Money.Cldr.known_rbnf_locale_names/0","ref":"Money.Cldr.html#known_rbnf_locale_names/0"},{"type":"function","doc":"","title":"Money.Cldr.known_territories/0","ref":"Money.Cldr.html#known_territories/0"},{"type":"function","doc":"Normalizes a string by applying transliteration\nof common symbols in numbers, currencies and dates","title":"Money.Cldr.normalize_lenient_parse/3","ref":"Money.Cldr.html#normalize_lenient_parse/3"},{"type":"function","doc":"Set the current process's Gettext locale from a\n`t:Cldr.LanguageTag`.","title":"Money.Cldr.put_gettext_locale/1","ref":"Money.Cldr.html#put_gettext_locale/1"},{"type":"function","doc":"* `locale` is a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.","title":"Arguments - Money.Cldr.put_gettext_locale/1","ref":"Money.Cldr.html#put_gettext_locale/1-arguments"},{"type":"function","doc":"* `{:ok, gettext_locale_name}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.put_gettext_locale/1","ref":"Money.Cldr.html#put_gettext_locale/1-returns"},{"type":"function","doc":"1. If the `locale.gettext_locale_name` is `nil` then an error\n   is returned.\n\n2. The `gettext` locale for the `gettext_backend` configured for the\n   CLDR backend defined by the `t:Cldr.LanguageTag` is set.","title":"Behaviour - Money.Cldr.put_gettext_locale/1","ref":"Money.Cldr.html#put_gettext_locale/1-behaviour"},{"type":"function","doc":"iex> import Cldr.LanguageTag.Sigil\n    iex> Money.Cldr.put_gettext_locale(~l\"en\")\n    {:ok, \"en\"}\n\n    iex> import Cldr.LanguageTag.Sigil\n    iex> Money.Cldr.put_gettext_locale(~l\"de\")\n    {\n      :error,\n      {\n        Cldr.UnknownLocaleError,\n        \"Locale TestBackend.Cldr.Locale.new!(\\\"de-DE\\\") does not map to a known gettext locale name\"\n      }\n    }","title":"Examples - Money.Cldr.put_gettext_locale/1","ref":"Money.Cldr.html#put_gettext_locale/1-examples"},{"type":"function","doc":"Set the current locale to be used for `Cldr` functions that\ntake an optional locale parameter for which a locale is not supplied.","title":"Money.Cldr.put_locale/1","ref":"Money.Cldr.html#put_locale/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by `Money.Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag` struct returned by `Money.Cldr.Locale.new!/1`\n\nSee [rfc5646](https://tools.ietf.org/html/rfc5646) for the specification\nof a language tag.","title":"Arguments - Money.Cldr.put_locale/1","ref":"Money.Cldr.html#put_locale/1-arguments"},{"type":"function","doc":"iex> Money.Cldr.put_locale(\"en\")\n    {:ok,\n     %Cldr.LanguageTag{\n       backend: Money.Cldr,\n       canonical_locale_name: \"en\",\n       cldr_locale_name: :en,\n       language_subtags: [],\n       extensions: %{},\n       gettext_locale_name: \"en\",\n       language: \"en\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :en,\n       requested_locale_name: \"en\",\n       script: :Latn,\n       territory: :US,\n       transform: %{},\n       language_variants: []\n     }}\n\n    iex> Money.Cldr.put_locale(\"invalid-locale!\")\n    {:error, {Cldr.LanguageTag.ParseError,\n      \"Expected a BCP47 language tag. Could not parse the remaining \\\"!\\\" starting at position 15\"}}","title":"Examples - Money.Cldr.put_locale/1","ref":"Money.Cldr.html#put_locale/1-examples"},{"type":"function","doc":"Add locale-specific quotation marks around a string.","title":"Money.Cldr.quote/2","ref":"Money.Cldr.html#quote/2"},{"type":"function","doc":"* `string` is any valid Elixir string\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.quote/2","ref":"Money.Cldr.html#quote/2-arguments"},{"type":"function","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/0`","title":"Options - Money.Cldr.quote/2","ref":"Money.Cldr.html#quote/2-options"},{"type":"function","doc":"iex> Money.Cldr.quote(\"Quoted String\")\n    \"“Quoted String”\"\n\n    iex> Money.Cldr.quote(\"Quoted String\", locale: :ja)\n    \"「Quoted String」\"","title":"Examples - Money.Cldr.quote/2","ref":"Money.Cldr.html#quote/2-examples"},{"type":"function","doc":"Returns a list of the locales names that are configured,\nbut not known in CLDR.\n\nSince there is a compile-time exception raised if there are\nany unknown locales this function should always\nreturn an empty list.","title":"Money.Cldr.unknown_locale_names/0","ref":"Money.Cldr.html#unknown_locale_names/0"},{"type":"function","doc":"","title":"Money.Cldr.validate_calendar/1","ref":"Money.Cldr.html#validate_calendar/1"},{"type":"function","doc":"","title":"Money.Cldr.validate_currency/1","ref":"Money.Cldr.html#validate_currency/1"},{"type":"function","doc":"Normalise and validate a locale name.","title":"Money.Cldr.validate_locale/1","ref":"Money.Cldr.html#validate_locale/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `Money.Cldr.Locale.new!/1`","title":"Arguments - Money.Cldr.validate_locale/1","ref":"Money.Cldr.html#validate_locale/1-arguments"},{"type":"function","doc":"* `{:ok, language_tag}`\n\n* `{:error, reason}`","title":"Returns - Money.Cldr.validate_locale/1","ref":"Money.Cldr.html#validate_locale/1-returns"},{"type":"function","doc":"See [rfc5646](https://tools.ietf.org/html/rfc5646) for the specification\nof a language tag.","title":"Notes - Money.Cldr.validate_locale/1","ref":"Money.Cldr.html#validate_locale/1-notes"},{"type":"function","doc":"iex> Money.Cldr.validate_locale(:en)\n    {:ok,\n    %Cldr.LanguageTag{\n      backend: Money.Cldr,\n      canonical_locale_name: \"en\",\n      cldr_locale_name: :en,\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en\",\n      script: :Latn,\n      territory: :US,\n      transform: %{},\n      language_variants: []\n    }}\n\n\n    iex> Money.Cldr.validate_locale Money.Cldr.default_locale()\n    {:ok,\n    %Cldr.LanguageTag{\n      backend: Money.Cldr,\n      canonical_locale_name: \"en-001\",\n      cldr_locale_name: :\"en-001\",\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en-001\",\n      script: :Latn,\n      territory: :\"001\",\n      transform: %{},\n      language_variants: []\n    }}\n\n    iex> Money.Cldr.validate_locale(\"zzz\")\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}","title":"Examples - Money.Cldr.validate_locale/1","ref":"Money.Cldr.html#validate_locale/1-examples"},{"type":"function","doc":"","title":"Money.Cldr.validate_number_system/1","ref":"Money.Cldr.html#validate_number_system/1"},{"type":"function","doc":"Normalise and validate a number system type.","title":"Money.Cldr.validate_number_system_type/1","ref":"Money.Cldr.html#validate_number_system_type/1"},{"type":"function","doc":"* `number_system_type` is any number system type returned by\n  `Cldr.known_number_system_types/1`","title":"Arguments - Money.Cldr.validate_number_system_type/1","ref":"Money.Cldr.html#validate_number_system_type/1-arguments"},{"type":"function","doc":"* `{:ok, normalized_number_system_type}` or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Cldr.validate_number_system_type/1","ref":"Money.Cldr.html#validate_number_system_type/1-returns"},{"type":"function","doc":"iex> Money.Cldr.validate_number_system_type(:default)\n    {:ok, :default}\n\n    iex> Money.Cldr.validate_number_system_type(:traditional)\n    {:ok, :traditional}\n\n    iex> Money.Cldr.validate_number_system_type(:latn)\n    {\n      :error,\n      {Cldr.UnknownNumberSystemTypeError, \"The number system type :latn is unknown\"}\n    }\n\n    iex> Money.Cldr.validate_number_system_type(\"bork\")\n    {\n      :error,\n      {Cldr.UnknownNumberSystemTypeError, \"The number system type \\\"bork\\\" is invalid\"}\n    }","title":"Examples - Money.Cldr.validate_number_system_type/1","ref":"Money.Cldr.html#validate_number_system_type/1-examples"},{"type":"function","doc":"","title":"Money.Cldr.validate_territory/1","ref":"Money.Cldr.html#validate_territory/1"},{"type":"function","doc":"Execute a function with a locale ensuring that the\ncurrent locale is restored after the function.","title":"Money.Cldr.with_locale/2","ref":"Money.Cldr.html#with_locale/2"},{"type":"function","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`.\n\n* `fun` is any 0-arity function or function capture.","title":"Arguments - Money.Cldr.with_locale/2","ref":"Money.Cldr.html#with_locale/2-arguments"},{"type":"function","doc":"* The value returned by the function `fun/0` or\n\n* `{:error, {exception, reason}}` if the locale is invalid or\n\n* raises an exception if the current locale cannot be\n  identified.","title":"Returns - Money.Cldr.with_locale/2","ref":"Money.Cldr.html#with_locale/2-returns"},{"type":"module","doc":"Parses HTTP `Accept-Language` header values as defined in\n[rfc2616](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4).\n\nThe Accept-Language request-header field is similar to Accept, but restricts\nthe set of natural languages that are preferred as a response to the request.\nLanguage tags function are provided in `Cldr.LanguageTag`.\n\nThe format of an `Accept-Language` header is as follows in `ABNF` format:\n\n       Accept-Language = \"Accept-Language\" \":\"\n                         1#( language-range [ \";\" \"q\" \"=\" qvalue ] )\n       language-range  = ( ( 1*8ALPHA *( \"-\" 1*8ALPHA ) ) | \"*\" )\n\nEach language-range MAY be given an associated quality value which represents an\nestimate of the user's preference for the languages specified by that range. The\nquality value defaults to \"q=1\". For example,\n\n       Accept-Language: da, en-gb;q=0.8, en;q=0.7\n\nwould mean: \"I prefer Danish, but will accept British English and other types of English.\"","title":"Money.Cldr.AcceptLanguage","ref":"Money.Cldr.AcceptLanguage.html"},{"type":"function","doc":"Parse an `Accept-Language` string and return the best match for\na configured `Cldr` locale.","title":"Money.Cldr.AcceptLanguage.best_match/1","ref":"Money.Cldr.AcceptLanguage.html#best_match/1"},{"type":"function","doc":"* `accept_language` is a string representing an accept language header","title":"Arguments - Money.Cldr.AcceptLanguage.best_match/1","ref":"Money.Cldr.AcceptLanguage.html#best_match/1-arguments"},{"type":"function","doc":"* `{:ok, language_tag}` or\n\n* `{:error, reason}`","title":"Returns - Money.Cldr.AcceptLanguage.best_match/1","ref":"Money.Cldr.AcceptLanguage.html#best_match/1-returns"},{"type":"function","doc":"iex> Money.Cldr.AcceptLanguage.best_match(\"da;q=0.1,zh-TW;q=0.3\", TestBackend.Cldr)\n    {:ok,\n     %Cldr.LanguageTag{\n       backend: TestBackend.Cldr,\n       canonical_locale_name: \"zh-TW\",\n       cldr_locale_name: :\"zh-Hant\",\n       language_subtags: [],\n       extensions: %{},\n       gettext_locale_name: nil,\n       language: \"zh\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :\"zh-Hant\",\n       requested_locale_name: \"zh-TW\",\n       script: :Hant,\n       territory: :TW,\n       transform: %{},\n       language_variants: []\n     }}\n\n    iex> Money.Cldr.AcceptLanguage.best_match(\"da;q=0.1,zh-TW;q=0.3\", TestBackend.Cldr)\n    {:ok,\n     %Cldr.LanguageTag{\n       backend: TestBackend.Cldr,\n       canonical_locale_name: \"zh-TW\",\n       cldr_locale_name: :\"zh-Hant\",\n       language_subtags: [],\n       extensions: %{},\n       gettext_locale_name: nil,\n       language: \"zh\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :\"zh-Hant\",\n       requested_locale_name: \"zh-TW\",\n       script: :Hant,\n       territory: :TW,\n       transform: %{},\n       language_variants: []\n     }}\n\n    iex> Money.Cldr.AcceptLanguage.best_match(\"xx,yy;q=0.3\")\n    {:error,\n     {Cldr.NoMatchingLocale,\n      \"No configured locale could be matched to \\\"xx,yy;q=0.3\\\"\"}}\n\n    iex> Money.Cldr.AcceptLanguage.best_match(\"invalid_tag\")\n    {:error, {Cldr.LanguageTag.ParseError,\n      \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}","title":"Examples - Money.Cldr.AcceptLanguage.best_match/1","ref":"Money.Cldr.AcceptLanguage.html#best_match/1-examples"},{"type":"function","doc":"Parses an `Accept-Language` header value in its string\nor tokenized form to return a tuple of the form\n`{:ok, [{quality, %Cldr.LanguageTag{}}, ...]}` sorted by quality.","title":"Money.Cldr.AcceptLanguage.parse/1","ref":"Money.Cldr.AcceptLanguage.html#parse/1"},{"type":"function","doc":"* `accept-language` is any string in the format defined by\n  [rfc2616](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4)\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","title":"Arguments - Money.Cldr.AcceptLanguage.parse/1","ref":"Money.Cldr.AcceptLanguage.html#parse/1-arguments"},{"type":"function","doc":"* `{:ok, [{quality, language_tag}, ...]}` or\n\n* `{:error, {Cldr.AcceptLanguageError, String.t}}`\n\nIf at least one valid language tag is found but errors are also\ndetected on one more more tags, an `{ok, list}` tuple is returned\nwith an error tuple for each invalid tag added at the end of the list.","title":"Returns - Money.Cldr.AcceptLanguage.parse/1","ref":"Money.Cldr.AcceptLanguage.html#parse/1-returns"},{"type":"function","doc":"iex> Cldr.AcceptLanguage.parse(\"da,zh-TW;q=0.3\", TestBackend.Cldr)\n    {:ok,\n     [\n       {1.0,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"da\",\n          cldr_locale_name: :da,\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"da\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :da,\n          requested_locale_name: \"da\",\n          script: :Latn,\n          territory: :DK,\n          transform: %{},\n          language_variants: []\n        }},\n       {0.3,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"zh-TW\",\n          cldr_locale_name: :\"zh-Hant\",\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"zh\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :\"zh-Hant\",\n          requested_locale_name: \"zh-TW\",\n          script: :Hant,\n          territory: :TW,\n          transform: %{},\n          language_variants: []\n        }}\n     ]}\n\n    iex> Money.Cldr.AcceptLanguage.parse(\"invalid_tag\")\n    {:error,\n     {Cldr.LanguageTag.ParseError,\n      \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}\n\n    iex> Money.Cldr.AcceptLanguage.parse(\"da,zh-TW;q=0.3,invalid_tag\")\n    {:ok,\n     [\n       {1.0,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"da\",\n          cldr_locale_name: :da,\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"da\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :da,\n          requested_locale_name: \"da\",\n          script: :Latn,\n          territory: :DK,\n          transform: %{},\n          language_variants: []\n        }},\n       {0.3,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"zh-TW\",\n          cldr_locale_name: :\"zh-Hant\",\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"zh\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :\"zh-Hant\",\n          requested_locale_name: \"zh-TW\",\n          script: :Hant,\n          territory: :TW,\n          transform: %{},\n          language_variants: []\n        }},\n       {:error,\n        {Cldr.LanguageTag.ParseError,\n         \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}\n     ]}","title":"Example - Money.Cldr.AcceptLanguage.parse/1","ref":"Money.Cldr.AcceptLanguage.html#parse/1-example"},{"type":"function","doc":"Parses an `Accept-Language` header value in its string\nor tokenized form to produce a list of tuples of the form\n`[{quality, %Cldr.LanguageTag{}}, ...]` sorted by quality\nin descending order.","title":"Money.Cldr.AcceptLanguage.parse!/1","ref":"Money.Cldr.AcceptLanguage.html#parse!/1"},{"type":"function","doc":"* `accept-language` is any string in the format defined by [rfc2616](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4)","title":"Arguments - Money.Cldr.AcceptLanguage.parse!/1","ref":"Money.Cldr.AcceptLanguage.html#parse!/1-arguments"},{"type":"function","doc":"* `{:ok, [{quality, language_tag}, ...]}` or\n\n* raises a `Cldr.AcceptLanguageError` exception\n\nIf at least one valid language tag is found but errors are also\ndetected on one more more tags, an `{ok, list}` tuple is returned\nwith an error tuple for each invalid tag added at the end of the list.","title":"Returns - Money.Cldr.AcceptLanguage.parse!/1","ref":"Money.Cldr.AcceptLanguage.html#parse!/1-returns"},{"type":"function","doc":"iex> Money.Cldr.AcceptLanguage.parse!(\"da,zh-TW;q=0.3\")\n    [\n      {1.0,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"da\",\n         cldr_locale_name: :da,\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"da\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :da,\n         requested_locale_name: \"da\",\n         script: :Latn,\n         territory: :DK,\n         transform: %{},\n         language_variants: []\n       }},\n      {0.3,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"zh-TW\",\n         cldr_locale_name: :\"zh-Hant\",\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"zh\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :\"zh-Hant\",\n         requested_locale_name: \"zh-TW\",\n         script: :Hant,\n         territory: :TW,\n         transform: %{},\n         language_variants: []\n       }}\n    ]\n\n    Money.Cldr.AcceptLanguage.parse! \"invalid_tag\"\n    ** (Cldr.AcceptLanguageError) \"Expected a BCP47 language tag. Could not parse the remaining \"g\" starting at position 11\n        (ex_cldr) lib/cldr/accept_language.ex:304: Cldr.AcceptLanguage.parse!/1\n\n    iex> Money.Cldr.AcceptLanguage.parse!(\"da,zh-TW;q=0.3,invalid_tag\")\n    [\n      {1.0,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"da\",\n         cldr_locale_name: :da,\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"da\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :da,\n         requested_locale_name: \"da\",\n         script: :Latn,\n         territory: :DK,\n         transform: %{},\n         language_variants: []\n       }},\n      {0.3,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"zh-TW\",\n         cldr_locale_name: :\"zh-Hant\",\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"zh\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :\"zh-Hant\",\n         requested_locale_name: \"zh-TW\",\n         script: :Hant,\n         territory: :TW,\n         transform: %{},\n         language_variants: []\n       }},\n      {:error,\n       {Cldr.LanguageTag.ParseError,\n        \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}\n    ]","title":"Example - Money.Cldr.AcceptLanguage.parse!/1","ref":"Money.Cldr.AcceptLanguage.html#parse!/1-example"},{"type":"module","doc":"","title":"Money.Cldr.Currency","ref":"Money.Cldr.Currency.html"},{"type":"function","doc":"Returns a map of the metadata for all currencies for\na given locale.","title":"Money.Cldr.Currency.currencies_for_locale/3","ref":"Money.Cldr.Currency.html#currencies_for_locale/3"},{"type":"function","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `MyApp.Cldr.Locale.new!/1`\n\n* `currency_status` is `:all`, `:current`, `:historic`,\n  `unannotated` or `:tender`; or a list of one or more status.\n  The default is `:all`. See `Cldr.Currency.currency_filter/2`.","title":"Arguments - Money.Cldr.Currency.currencies_for_locale/3","ref":"Money.Cldr.Currency.html#currencies_for_locale/3-arguments"},{"type":"function","doc":"* `{:ok, currency_map}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.Currency.currencies_for_locale/3","ref":"Money.Cldr.Currency.html#currencies_for_locale/3-returns"},{"type":"function","doc":"MyApp.Cldr.Currency.currencies_for_locale(\"en\")\n  => {:ok,\n   %{\n     FJD: %Cldr.Currency{\n       cash_digits: 2,\n       cash_rounding: 0,\n       code: \"FJD\",\n       count: %{one: \"Fijian dollar\", other: \"Fijian dollars\"},\n       digits: 2,\n       from: nil,\n       iso_digits: 2,\n       name: \"Fijian Dollar\",\n       narrow_symbol: \"$\",\n       rounding: 0,\n       symbol: \"FJD\",\n       tender: true,\n       to: nil\n     },\n     SUR: %Cldr.Currency{\n       cash_digits: 2,\n       cash_rounding: 0,\n       code: \"SUR\",\n       count: %{one: \"Soviet rouble\", other: \"Soviet roubles\"},\n       digits: 2,\n       from: nil,\n       iso_digits: nil,\n       name: \"Soviet Rouble\",\n       narrow_symbol: nil,\n       rounding: 0,\n       symbol: \"SUR\",\n       tender: true,\n       to: nil\n     },\n     ...\n    }}","title":"Example - Money.Cldr.Currency.currencies_for_locale/3","ref":"Money.Cldr.Currency.html#currencies_for_locale/3-example"},{"type":"function","doc":"Returns a map of the metadata for all currencies for\na given locale and raises on error.","title":"Money.Cldr.Currency.currencies_for_locale!/3","ref":"Money.Cldr.Currency.html#currencies_for_locale!/3"},{"type":"function","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `MyApp.Cldr.Locale.new!/1`\n\n* `currency_status` is `:all`, `:current`, `:historic`,\n  `unannotated` or `:tender`; or a list of one or more status.\n  The default is `:all`. See `Cldr.Currency.currency_filter/2`.","title":"Arguments - Money.Cldr.Currency.currencies_for_locale!/3","ref":"Money.Cldr.Currency.html#currencies_for_locale!/3-arguments"},{"type":"function","doc":"* `{:ok, currency_map}` or\n\n* raises an exception","title":"Returns - Money.Cldr.Currency.currencies_for_locale!/3","ref":"Money.Cldr.Currency.html#currencies_for_locale!/3-returns"},{"type":"function","doc":"MyApp.Cldr.Currency.currencies_for_locale!(\"en\")\n  => %{\n    FJD: %Cldr.Currency{\n      cash_digits: 2,\n      cash_rounding: 0,\n      code: \"FJD\",\n      count: %{one: \"Fijian dollar\", other: \"Fijian dollars\"},\n      digits: 2,\n      from: nil,\n      iso_digits: 2,\n      name: \"Fijian Dollar\",\n      narrow_symbol: \"$\",\n      rounding: 0,\n      symbol: \"FJD\",\n      tender: true,\n      to: nil\n    },\n    SUR: %Cldr.Currency{\n      cash_digits: 2,\n      cash_rounding: 0,\n      code: \"SUR\",\n      count: %{one: \"Soviet rouble\", other: \"Soviet roubles\"},\n      digits: 2,\n      from: nil,\n      iso_digits: nil,\n      name: \"Soviet Rouble\",\n      narrow_symbol: nil,\n      rounding: 0,\n      symbol: \"SUR\",\n      tender: true,\n      to: nil\n    },\n    ...\n   }","title":"Example - Money.Cldr.Currency.currencies_for_locale!/3","ref":"Money.Cldr.Currency.html#currencies_for_locale!/3-example"},{"type":"function","doc":"Returns the currency metadata for the requested currency code.","title":"Money.Cldr.Currency.currency_for_code/2","ref":"Money.Cldr.Currency.html#currency_for_code/2"},{"type":"function","doc":"* `currency_or_currency_code` is a `binary` or `atom` representation\n   of an ISO 4217 currency code, or a `%Cldr.Currency{}` struct.","title":"Arguments - Money.Cldr.Currency.currency_for_code/2","ref":"Money.Cldr.Currency.html#currency_for_code/2-arguments"},{"type":"function","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`","title":"Options - Money.Cldr.Currency.currency_for_code/2","ref":"Money.Cldr.Currency.html#currency_for_code/2-options"},{"type":"function","doc":"* A `{:ok, currency}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.Currency.currency_for_code/2","ref":"Money.Cldr.Currency.html#currency_for_code/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Currency.currency_for_code(\"AUD\")\n    {:ok,\n      %Cldr.Currency{\n        cash_digits: 2,\n        cash_rounding: 0,\n        code: \"AUD\",\n        count: %{one: \"Australian dollar\", other: \"Australian dollars\"},\n        digits: 2,\n        iso_digits: 2,\n        name: \"Australian Dollar\",\n        narrow_symbol: \"$\",\n        rounding: 0,\n        symbol: \"A$\",\n        tender: true\n    }}\n\n    iex> Money.Cldr.Currency.currency_for_code(\"THB\")\n    {:ok,\n      %Cldr.Currency{\n        cash_digits: 2,\n        cash_rounding: 0,\n        code: \"THB\",\n        count: %{one: \"Thai baht\", other: \"Thai baht\"},\n        digits: 2,\n        iso_digits: 2,\n        name: \"Thai Baht\",\n        narrow_symbol: \"฿\",\n        rounding: 0,\n        symbol: \"THB\",\n        tender: true\n    }}","title":"Examples - Money.Cldr.Currency.currency_for_code/2","ref":"Money.Cldr.Currency.html#currency_for_code/2-examples"},{"type":"function","doc":"Returns the currency metadata for the requested currency code.","title":"Money.Cldr.Currency.currency_for_code!/2","ref":"Money.Cldr.Currency.html#currency_for_code!/2"},{"type":"function","doc":"* `currency_or_currency_code` is a `binary` or `atom` representation\n   of an ISO 4217 currency code, or a `%Cldr.Currency{}` struct.","title":"Arguments - Money.Cldr.Currency.currency_for_code!/2","ref":"Money.Cldr.Currency.html#currency_for_code!/2-arguments"},{"type":"function","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`","title":"Options - Money.Cldr.Currency.currency_for_code!/2","ref":"Money.Cldr.Currency.html#currency_for_code!/2-options"},{"type":"function","doc":"* A `t:Cldr.Current.t/0` or\n\n* raises an exception","title":"Returns - Money.Cldr.Currency.currency_for_code!/2","ref":"Money.Cldr.Currency.html#currency_for_code!/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Currency.currency_for_code!(\"AUD\")\n    %Cldr.Currency{\n      cash_digits: 2,\n      cash_rounding: 0,\n      code: \"AUD\",\n      count: %{one: \"Australian dollar\", other: \"Australian dollars\"},\n      digits: 2,\n      iso_digits: 2,\n      name: \"Australian Dollar\",\n      narrow_symbol: \"$\",\n      rounding: 0,\n      symbol: \"A$\",\n      tender: true\n    }\n\n    iex> Money.Cldr.Currency.currency_for_code!(\"THB\")\n    %Cldr.Currency{\n      cash_digits: 2,\n      cash_rounding: 0,\n      code: \"THB\",\n      count: %{one: \"Thai baht\", other: \"Thai baht\"},\n      digits: 2,\n      iso_digits: 2,\n      name: \"Thai Baht\",\n      narrow_symbol: \"฿\",\n      rounding: 0,\n      symbol: \"THB\",\n      tender: true\n    }","title":"Examples - Money.Cldr.Currency.currency_for_code!/2","ref":"Money.Cldr.Currency.html#currency_for_code!/2-examples"},{"type":"function","doc":"Returns the effective currency for a given locale","title":"Money.Cldr.Currency.currency_from_locale/1","ref":"Money.Cldr.Currency.html#currency_from_locale/1"},{"type":"function","doc":"* `locale` is a `Cldr.LanguageTag` struct returned by\n  `Cldr.Locale.new!/2`","title":"Arguments - Money.Cldr.Currency.currency_from_locale/1","ref":"Money.Cldr.Currency.html#currency_from_locale/1-arguments"},{"type":"function","doc":"* A ISO 4217 currency code as an upcased atom","title":"Returns - Money.Cldr.Currency.currency_from_locale/1","ref":"Money.Cldr.Currency.html#currency_from_locale/1-returns"},{"type":"function","doc":"iex> {:ok, locale} = Money.Cldr.validate_locale(\"en\")\n    iex> Money.Cldr.Currency.currency_from_locale locale\n    :USD\n\n    iex> {:ok, locale} = Money.Cldr.validate_locale(\"en-AU\")\n    iex> Money.Cldr.Currency.currency_from_locale locale\n    :AUD\n\n    iex> Money.Cldr.Currency.currency_from_locale(\"en-GB\")\n    :GBP","title":"Examples - Money.Cldr.Currency.currency_from_locale/1","ref":"Money.Cldr.Currency.html#currency_from_locale/1-examples"},{"type":"function","doc":"Returns a list of historic and the current\ncurrency for a given locale.","title":"Money.Cldr.Currency.currency_history_for_locale/1","ref":"Money.Cldr.Currency.html#currency_history_for_locale/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `MyApp.Cldr.Locale.new!/1`","title":"Arguments - Money.Cldr.Currency.currency_history_for_locale/1","ref":"Money.Cldr.Currency.html#currency_history_for_locale/1-arguments"},{"type":"function","doc":"iex> MyApp.Cldr.Currency.currency_history_for_locale(\"en\")\n    {:ok,\n        %{\n        USD: %{from: ~D[1792-01-01], to: nil},\n        USN: %{tender: false},\n        USS: %{from: nil, tender: false, to: ~D[2014-03-01]}\n      }\n    }","title":"Example - Money.Cldr.Currency.currency_history_for_locale/1","ref":"Money.Cldr.Currency.html#currency_history_for_locale/1-example"},{"type":"function","doc":"Returns a map that matches a currency string to a\ncurrency code.\n\nA currency string is a localised name or symbol\nrepresenting a currency in a locale-specific manner.","title":"Money.Cldr.Currency.currency_strings/3","ref":"Money.Cldr.Currency.html#currency_strings/3"},{"type":"function","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `MyApp.Cldr.Locale.new!/1`\n\n* `currency_status` is `:all`, `:current`, `:historic`,\n  `unannotated` or `:tender`; or a list of one or more status.\n  The default is `:all`. See `Cldr.Currency.currency_filter/2`.","title":"Arguments - Money.Cldr.Currency.currency_strings/3","ref":"Money.Cldr.Currency.html#currency_strings/3-arguments"},{"type":"function","doc":"* `{:ok, currency_string_map}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.Currency.currency_strings/3","ref":"Money.Cldr.Currency.html#currency_strings/3-returns"},{"type":"function","doc":"MyApp.Cldr.Currency.currency_strings(\"en\")\n    => {:ok,\n     %{\n       \"mexican silver pesos\" => :MXP,\n       \"sudanese dinar\" => :SDD,\n       \"bad\" => :BAD,\n       \"rsd\" => :RSD,\n       \"swazi lilangeni\" => :SZL,\n       \"zairean new zaire\" => :ZRN,\n       \"guyanaese dollars\" => :GYD,\n       \"equatorial guinean ekwele\" => :GQE,\n       ...\n      }}","title":"Example - Money.Cldr.Currency.currency_strings/3","ref":"Money.Cldr.Currency.html#currency_strings/3-example"},{"type":"function","doc":"Returns a map that matches a currency string to a\ncurrency code or raises an exception.\n\nA currency string is a localised name or symbol\nrepresenting a currency in a locale-specific manner.","title":"Money.Cldr.Currency.currency_strings!/3","ref":"Money.Cldr.Currency.html#currency_strings!/3"},{"type":"function","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `MyApp.Cldr.Locale.new!/1`\n\n* `currency_status` is `:all`, `:current`, `:historic`,\n  `unannotated` or `:tender`; or a list of one or more status.\n  The default is `:all`. See `Cldr.Currency.currency_filter/2`.","title":"Arguments - Money.Cldr.Currency.currency_strings!/3","ref":"Money.Cldr.Currency.html#currency_strings!/3-arguments"},{"type":"function","doc":"* `{:ok, currency_string_map}` or\n\n* raises an exception","title":"Returns - Money.Cldr.Currency.currency_strings!/3","ref":"Money.Cldr.Currency.html#currency_strings!/3-returns"},{"type":"function","doc":"MyApp.Cldr.Currency.currency_strings!(\"en\")\n    => %{\n      \"mexican silver pesos\" => :MXP,\n      \"sudanese dinar\" => :SDD,\n      \"bad\" => :BAD,\n      \"rsd\" => :RSD,\n      \"swazi lilangeni\" => :SZL,\n      \"zairean new zaire\" => :ZRN,\n      \"guyanaese dollars\" => :GYD,\n      \"equatorial guinean ekwele\" => :GQE,\n      ...\n     }","title":"Example - Money.Cldr.Currency.currency_strings!/3","ref":"Money.Cldr.Currency.html#currency_strings!/3-example"},{"type":"function","doc":"Returns the current currency for a given locale.\n\nThis function does not consider the `U` extenion\nparameters `cu` or `rg`. It is recommended to us\n`Cldr.Currency.currency_from_locale/1` in most\ncircumstances.","title":"Money.Cldr.Currency.current_currency_from_locale/1","ref":"Money.Cldr.Currency.html#current_currency_from_locale/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `MyApp.Cldr.Locale.new!/1`","title":"Arguments - Money.Cldr.Currency.current_currency_from_locale/1","ref":"Money.Cldr.Currency.html#current_currency_from_locale/1-arguments"},{"type":"function","doc":"iex> MyApp.Cldr.Currency.current_currency_from_locale(\"en\")\n    :USD\n\n    iex> MyApp.Cldr.Currency.current_currency_from_locale(\"en-AU\")\n    :AUD","title":"Example - Money.Cldr.Currency.current_currency_from_locale/1","ref":"Money.Cldr.Currency.html#current_currency_from_locale/1-example"},{"type":"function","doc":"Returns a mapping from a territory code to its\ncurrent currency code.\n\nIf a territory has no current currency (like\nAntartica, territory code `:AQ`) then no\nmapping is returned for that territory.","title":"Money.Cldr.Currency.current_territory_currencies/0","ref":"Money.Cldr.Currency.html#current_territory_currencies/0"},{"type":"function","doc":"* A map of `{territory_code => Cldr.Currency.t}`","title":"Returns - Money.Cldr.Currency.current_territory_currencies/0","ref":"Money.Cldr.Currency.html#current_territory_currencies/0-returns"},{"type":"function","doc":"iex> Money.Cldr.Currency.current_territory_currencies()","title":"Example - Money.Cldr.Currency.current_territory_currencies/0","ref":"Money.Cldr.Currency.html#current_territory_currencies/0-example"},{"type":"function","doc":"","title":"Money.Cldr.Currency.known_currencies/0","ref":"Money.Cldr.Currency.html#known_currencies/0"},{"type":"function","doc":"","title":"Money.Cldr.Currency.known_currency?/1","ref":"Money.Cldr.Currency.html#known_currency?/1"},{"type":"function","doc":"Returns a 2-tuple indicating if the supplied currency code is known.","title":"Money.Cldr.Currency.known_currency_code/1","ref":"Money.Cldr.Currency.html#known_currency_code/1"},{"type":"function","doc":"* `currency_code` is a `binary` or `atom` representing an ISO4217\n  currency code","title":"Arguments - Money.Cldr.Currency.known_currency_code/1","ref":"Money.Cldr.Currency.html#known_currency_code/1-arguments"},{"type":"function","doc":"* `{:ok, currency_code}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.Currency.known_currency_code/1","ref":"Money.Cldr.Currency.html#known_currency_code/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Currency.known_currency_code(\"AUD\")\n    {:ok, :AUD}\n\n    iex> Money.Cldr.Currency.known_currency_code(\"GGG\")\n    {:error, {Cldr.UnknownCurrencyError, \"The currency \\\"GGG\\\" is invalid\"}}","title":"Examples - Money.Cldr.Currency.known_currency_code/1","ref":"Money.Cldr.Currency.html#known_currency_code/1-examples"},{"type":"function","doc":"Returns a boolean indicating if the supplied currency code is known.","title":"Money.Cldr.Currency.known_currency_code?/1","ref":"Money.Cldr.Currency.html#known_currency_code?/1"},{"type":"function","doc":"* `currency_code` is a `binary` or `atom` representing an ISO4217\n  currency code","title":"Arguments - Money.Cldr.Currency.known_currency_code?/1","ref":"Money.Cldr.Currency.html#known_currency_code?/1-arguments"},{"type":"function","doc":"* `true` or `false`","title":"Returns - Money.Cldr.Currency.known_currency_code?/1","ref":"Money.Cldr.Currency.html#known_currency_code?/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Currency.known_currency_code?(\"AUD\")\n    true\n\n    iex> Money.Cldr.Currency.known_currency_code?(\"GGG\")\n    false\n\n    iex> Money.Cldr.Currency.known_currency_code?(:XCV)\n    false","title":"Examples - Money.Cldr.Currency.known_currency_code?/1","ref":"Money.Cldr.Currency.html#known_currency_code?/1-examples"},{"type":"function","doc":"Returns a list of all known currency codes.","title":"Money.Cldr.Currency.known_currency_codes/0","ref":"Money.Cldr.Currency.html#known_currency_codes/0"},{"type":"function","doc":"iex> Money.Cldr.Currency.known_currency_codes()","title":"Example - Money.Cldr.Currency.known_currency_codes/0","ref":"Money.Cldr.Currency.html#known_currency_codes/0-example"},{"type":"function","doc":"Returns a `Currency` struct created from the arguments.","title":"Money.Cldr.Currency.new/2","ref":"Money.Cldr.Currency.html#new/2"},{"type":"function","doc":"* `currency` is a private use currency code in a format defined by\n  [ISO4217](https://en.wikipedia.org/wiki/ISO_4217)\n  which is `X` followed by two alphanumeric characters.\n\n* `options` is a map of options representing the optional elements of\n  the `Cldr.Currency.t` struct.","title":"Arguments - Money.Cldr.Currency.new/2","ref":"Money.Cldr.Currency.html#new/2-arguments"},{"type":"function","doc":"* `:name` is the name of the currency. Required.\n* `:digits` is the precision of the currency. Required.\n* `:symbol` is the currency symbol. Optional.\n* `:narrow_symbol` is an alternative narrow symbol. Optional.\n* `:round_nearest` is the rounding precision such as `0.05`. Optional.\n* `:alt_code` is an alternative currency code for application use.\n* `:cash_digits` is the precision of the currency when used as cash. Optional.\n* `:cash_rounding_nearest` is the rounding precision when used as cash\n  such as `0.05`. Optional.","title":"Options - Money.Cldr.Currency.new/2","ref":"Money.Cldr.Currency.html#new/2-options"},{"type":"function","doc":"* `{:ok, Cldr.Currency.t}` or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Cldr.Currency.new/2","ref":"Money.Cldr.Currency.html#new/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Currency.new(:XAE, name: \"Custom Name\", digits: 0)\n    {:ok,\n     %Cldr.Currency{\n       alt_code: :XAE,\n       cash_digits: 0,\n       cash_rounding: nil,\n       code: :XAE,\n       count: %{other: \"Custom Name\"},\n       digits: 0,\n       from: nil,\n       iso_digits: 0,\n       name: \"Custom Name\",\n       narrow_symbol: nil,\n       rounding: 0,\n       symbol: \"XAE\",\n       tender: false,\n       to: nil\n     }}\n    iex> MyApp.Cldr.Currency.new(:XAH, name: \"Custom Name\")\n    {:error, \"Required options are missing. Required options are [:name, :digits]\"}\n    iex> Money.Cldr.Currency.new(:XAE, name: \"XAE\", digits: 0)\n    {:error, {Cldr.CurrencyAlreadyDefined, \"Currency :XAE is already defined.\"}}","title":"Example - Money.Cldr.Currency.new/2","ref":"Money.Cldr.Currency.html#new/2-example"},{"type":"function","doc":"Returns the appropriate currency display name for the `currency`, based\non the plural rules in effect for the `locale`.","title":"Money.Cldr.Currency.pluralize/3","ref":"Money.Cldr.Currency.html#pluralize/3"},{"type":"function","doc":"* `number` is an integer, float or `Decimal`\n\n* `currency` is any currency returned by `Cldr.Currency.known_currencies/0`\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.Currency.pluralize/3","ref":"Money.Cldr.Currency.html#pluralize/3-arguments"},{"type":"function","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `MyApp.Cldr.Locale.new!/1`. The\n  default is `Money.Cldr.get_locale/0`","title":"Options - Money.Cldr.Currency.pluralize/3","ref":"Money.Cldr.Currency.html#pluralize/3-options"},{"type":"function","doc":"* `{:ok, plural_string}` or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Cldr.Currency.pluralize/3","ref":"Money.Cldr.Currency.html#pluralize/3-returns"},{"type":"function","doc":"iex> Money.Cldr.Currency.pluralize(1, :USD)\n    {:ok, \"US dollar\"}\n\n    iex> Money.Cldr.Currency.pluralize(3, :USD)\n    {:ok, \"US dollars\"}\n\n    iex> Money.Cldr.Currency.pluralize(12, :USD, locale: \"zh\")\n    {:ok, \"美元\"}\n\n    iex> Money.Cldr.Currency.pluralize(12, :USD, locale: \"fr\")\n    {:ok, \"dollars des États-Unis\"}\n\n    iex> Money.Cldr.Currency.pluralize(1, :USD, locale: \"fr\")\n    {:ok, \"dollar des États-Unis\"}","title":"Examples - Money.Cldr.Currency.pluralize/3","ref":"Money.Cldr.Currency.html#pluralize/3-examples"},{"type":"function","doc":"Returns the strings associated with a currency\nin a given locale.","title":"Money.Cldr.Currency.strings_for_currency/2","ref":"Money.Cldr.Currency.html#strings_for_currency/2"},{"type":"function","doc":"* `currency` is an ISO4217 currency code\n\n* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `MyApp.Cldr.Locale.new!/1`","title":"Arguments - Money.Cldr.Currency.strings_for_currency/2","ref":"Money.Cldr.Currency.html#strings_for_currency/2-arguments"},{"type":"function","doc":"* A list of strings or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.Currency.strings_for_currency/2","ref":"Money.Cldr.Currency.html#strings_for_currency/2-returns"},{"type":"function","doc":"iex> MyApp.Cldr.Currency.strings_for_currency(:AUD, \"en\")\n    ...> |> Enum.sort()\n    [\"a$\", \"aud\", \"australian dollar\", \"australian dollars\"]","title":"Example - Money.Cldr.Currency.strings_for_currency/2","ref":"Money.Cldr.Currency.html#strings_for_currency/2-example"},{"type":"module","doc":"Backend module that provides functions\nto define new locales and display human-readable\nlocale names for presentation purposes.","title":"Money.Cldr.Locale","ref":"Money.Cldr.Locale.html"},{"type":"function","doc":"Returns the list of fallback locale names, starting\nwith the provided locale name.\n\nFallbacks are a list of locate names which can\nbe used to resolve translation or other localization\ndata if such localised data does not exist for\nthis specific locale..","title":"Money.Cldr.Locale.fallback_locale_names/1","ref":"Money.Cldr.Locale.html#fallback_locale_names/1"},{"type":"function","doc":"* `locale_name` is any locale name returned by\n  `Money.Cldr.known_locale_names/0`","title":"Arguments - Money.Cldr.Locale.fallback_locale_names/1","ref":"Money.Cldr.Locale.html#fallback_locale_names/1-arguments"},{"type":"function","doc":"* `{:ok, list_of_locale_names}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.Locale.fallback_locale_names/1","ref":"Money.Cldr.Locale.html#fallback_locale_names/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Locale.fallback_locale_names(:\"fr-CA\")\n    {:ok, [:\"fr-CA\", :fr, :und]}\n\n    # Fallbacks are typically formed by progressively\n    # stripping variant, territory and script from the\n    # given locale name. But not always - there are\n    # certain fallbacks that take a different path.\n\n    iex> Money.Cldr.Locale.fallback_locale_names(:nb)\n    {:ok, [:nb, :no, :und]}","title":"Examples - Money.Cldr.Locale.fallback_locale_names/1","ref":"Money.Cldr.Locale.html#fallback_locale_names/1-examples"},{"type":"function","doc":"Returns the list of fallback locales, starting\nwith the provided locale name.\n\nFallbacks are a list of locate names which can\nbe used to resolve translation or other localization\ndata if such localised data does not exist for\nthis specific locale.","title":"Money.Cldr.Locale.fallback_locales/1","ref":"Money.Cldr.Locale.html#fallback_locales/1"},{"type":"function","doc":"* `locale_name` is any locale name returned by\n  `Money.Cldr.known_locale_names/0`","title":"Arguments - Money.Cldr.Locale.fallback_locales/1","ref":"Money.Cldr.Locale.html#fallback_locales/1-arguments"},{"type":"function","doc":"* `{:ok, list_of_locales}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.Locale.fallback_locales/1","ref":"Money.Cldr.Locale.html#fallback_locales/1-returns"},{"type":"function","doc":"Money.Cldr.Locale.fallback_locales(:\"fr-CA\")\n    => {:ok,\n         [#Cldr.LanguageTag , #Cldr.LanguageTag ,\n          #Cldr.LanguageTag ]}\n\n    # Fallbacks are typically formed by progressively\n    # stripping variant, territory and script from the\n    # given locale name. But not always - there are\n    # certain fallbacks that take a different path.\n\n    Money.Cldr.Locale.fallback_locales(:nb))\n    => {:ok,\n         [#Cldr.LanguageTag , #Cldr.LanguageTag ,\n          #Cldr.LanguageTag ]}","title":"Examples - Money.Cldr.Locale.fallback_locales/1","ref":"Money.Cldr.Locale.html#fallback_locales/1-examples"},{"type":"function","doc":"Returns the \"best fit\" locale for a given territory.\n\nUsing the population percentage data from CLDR, the\nlanguage most commonly spoken in the given territory\nis used to form a locale name which is then validated\nagainst the given backend.\n\nFirst a territory-specific locale is validated and if\nthat fails, the base language only is validate.\n\nFor example, if the territory is `AU` then then the\nlanguage most spoken is \"en\". First, the locale \"en-AU\"\nis validated and if that fails, \"en\" is validated.","title":"Money.Cldr.Locale.locale_for_territory/1","ref":"Money.Cldr.Locale.html#locale_for_territory/1"},{"type":"function","doc":"* `territory` is any ISO 3166 Alpha-2 territory\n  code that can be validated by `Cldr.validate_territory/1`","title":"Arguments - Money.Cldr.Locale.locale_for_territory/1","ref":"Money.Cldr.Locale.html#locale_for_territory/1-arguments"},{"type":"function","doc":"* `{:ok, language_tag}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.Locale.locale_for_territory/1","ref":"Money.Cldr.Locale.html#locale_for_territory/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Locale.locale_for_territory(:AU)\n  Elixir.Money.Cldr.validate_locale(:\"en-AU\")\n\n  iex> Money.Cldr.Locale.locale_for_territory(:US)\n  Elixir.Money.Cldr.validate_locale(:\"en-US\")\n\n  iex> Money.Cldr.Locale.locale_for_territory(:ZZ)\n  {:error, {Cldr.UnknownTerritoryError, \"The territory :ZZ is unknown\"}}","title":"Examples - Money.Cldr.Locale.locale_for_territory/1","ref":"Money.Cldr.Locale.html#locale_for_territory/1-examples"},{"type":"function","doc":"Returns a \"best fit\" locale for a host name.","title":"Money.Cldr.Locale.locale_from_host/2","ref":"Money.Cldr.Locale.html#locale_from_host/2"},{"type":"function","doc":"* `host` is any valid host name\n\n* `options` is a keyword list of options. The default\n  is `[]`.","title":"Arguments - Money.Cldr.Locale.locale_from_host/2","ref":"Money.Cldr.Locale.html#locale_from_host/2-arguments"},{"type":"function","doc":"* `:tlds` is a list of territory codes as upper-cased\n  atoms that are to be considered as top-level domains.\n  See `Cldr.Locale.locale_from_host/2` for the default\n  list.","title":"Options - Money.Cldr.Locale.locale_from_host/2","ref":"Money.Cldr.Locale.html#locale_from_host/2-options"},{"type":"function","doc":"* `{:ok, langauge_tag}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.Locale.locale_from_host/2","ref":"Money.Cldr.Locale.html#locale_from_host/2-returns"},{"type":"function","doc":"Certain top-level domains have become associated with content\nunderlated to the territory for who the domain is registered.\nTherefore Google (and perhaps others) do not associate these\nTLDs as belonging to the territory but rather are considered\ngeneric top-level domain names.","title":"Notes - Money.Cldr.Locale.locale_from_host/2","ref":"Money.Cldr.Locale.html#locale_from_host/2-notes"},{"type":"function","doc":"iex> Money.Cldr.Locale.locale_from_host \"a.b.com.au\"\n    Elixir.Money.Cldr.validate_locale(:\"en-AU\")\n\n    iex> Money.Cldr.Locale.locale_from_host(\"a.b.com.tv\")\n    {:error,\n     {Cldr.UnknownLocaleError, \"No locale was identified for territory \\\"tv\\\"\"}}\n\n    iex> Money.Cldr.Locale.locale_from_host(\"a.b.com\")\n    {:error,\n     {Cldr.UnknownLocaleError, \"No locale was identified for territory \\\"com\\\"\"}}","title":"Examples - Money.Cldr.Locale.locale_from_host/2","ref":"Money.Cldr.Locale.html#locale_from_host/2-examples"},{"type":"function","doc":"","title":"Money.Cldr.Locale.new/1","ref":"Money.Cldr.Locale.html#new/1"},{"type":"function","doc":"","title":"Money.Cldr.Locale.new!/1","ref":"Money.Cldr.Locale.html#new!/1"},{"type":"function","doc":"Returns the script direction for a locale.","title":"Money.Cldr.Locale.script_direction_from_locale/1","ref":"Money.Cldr.Locale.html#script_direction_from_locale/1"},{"type":"function","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`\n  or any `locale_name` returned by `Cldr.known_locale_names/1`.","title":"Arguments - Money.Cldr.Locale.script_direction_from_locale/1","ref":"Money.Cldr.Locale.html#script_direction_from_locale/1-arguments"},{"type":"function","doc":"* The script direction which is either `:ltr` (for left-to-right\n  scripts) or `:rtl` (for right-to-left scripts).","title":"Returns - Money.Cldr.Locale.script_direction_from_locale/1","ref":"Money.Cldr.Locale.html#script_direction_from_locale/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Locale.script_direction_from_locale \"en-US\"\n    :ltr\n\n    iex> Money.Cldr.Locale.script_direction_from_locale :ar\n    :rtl","title":"Examples - Money.Cldr.Locale.script_direction_from_locale/1","ref":"Money.Cldr.Locale.html#script_direction_from_locale/1-examples"},{"type":"function","doc":"Returns the last segment of a host that might\nbe a territory.","title":"Money.Cldr.Locale.territory_from_host/1","ref":"Money.Cldr.Locale.html#territory_from_host/1"},{"type":"function","doc":"* `host` is any valid host name","title":"Arguments - Money.Cldr.Locale.territory_from_host/1","ref":"Money.Cldr.Locale.html#territory_from_host/1-arguments"},{"type":"function","doc":"* `{:ok, territory}` or\n\n* `{:error, {exception, reason}}`","title":"Returns - Money.Cldr.Locale.territory_from_host/1","ref":"Money.Cldr.Locale.html#territory_from_host/1-returns"},{"type":"function","doc":"iex> Cldr.Locale.territory_from_host(\"a.b.com.au\")\n    {:ok, :AU}\n\n    iex> Cldr.Locale.territory_from_host(\"a.b.com\")\n    {:error,\n     {Cldr.UnknownLocaleError, \"No locale was identified for territory \\\"com\\\"\"}}","title":"Examples - Money.Cldr.Locale.territory_from_host/1","ref":"Money.Cldr.Locale.html#territory_from_host/1-examples"},{"type":"function","doc":"Returns the territory from a language tag or\nlocale name.","title":"Money.Cldr.Locale.territory_from_locale/1","ref":"Money.Cldr.Locale.html#territory_from_locale/1"},{"type":"function","doc":"* `locale` is any language tag returned by\n  `Money.Cldr.Locale.new/1`\n  or a locale name in the list returned by\n  `Money.Cldr.known_locale_names/0`","title":"Arguments - Money.Cldr.Locale.territory_from_locale/1","ref":"Money.Cldr.Locale.html#territory_from_locale/1-arguments"},{"type":"function","doc":"* A territory code as an atom","title":"Returns - Money.Cldr.Locale.territory_from_locale/1","ref":"Money.Cldr.Locale.html#territory_from_locale/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Locale.territory_from_locale \"en-US\"\n    :US\n\n    iex> Money.Cldr.Locale.territory_from_locale \"en-US-u-rg-GBzzzz\"\n    :GB","title":"Examples - Money.Cldr.Locale.territory_from_locale/1","ref":"Money.Cldr.Locale.html#territory_from_locale/1-examples"},{"type":"function","doc":"Returns the time zone from a language tag or\nlocale name.","title":"Money.Cldr.Locale.timezone_from_locale/1","ref":"Money.Cldr.Locale.html#timezone_from_locale/1"},{"type":"function","doc":"* `locale` is any language tag returned by\n  `Money.Cldr.Locale.new/1`\n  or a locale name in the list returned by\n  `Money.Cldr.known_locale_names/0`","title":"Arguments - Money.Cldr.Locale.timezone_from_locale/1","ref":"Money.Cldr.Locale.html#timezone_from_locale/1-arguments"},{"type":"function","doc":"* A time zone ID as a string or\n\n* `:error` if no time zone can be determined","title":"Returns - Money.Cldr.Locale.timezone_from_locale/1","ref":"Money.Cldr.Locale.html#timezone_from_locale/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Locale.timezone_from_locale \"en-US-u-tz-ausyd\"\n    \"Australia/Sydney\"","title":"Examples - Money.Cldr.Locale.timezone_from_locale/1","ref":"Money.Cldr.Locale.html#timezone_from_locale/1-examples"},{"type":"module","doc":"A backend module for Money.\n\nThis module provides the same api as the Money\nmodule however:\n\n* It matches the standard behaviour of other\n`ex_cldr` based libraries in maintaining the\nmain public API on the backend module\n\n* It does not require the `:backend` option to\nbe provided since that is implied through the\nuse of the backend module.\n\nAll the functions in this module delegate to\nthe functions in `Money`.","title":"Money.Cldr.Money","ref":"Money.Cldr.Money.html"},{"type":"function","doc":"The absolute value of a `Money` amount.\nReturns a `Money` type with a positive sign for the amount.","title":"Money.Cldr.Money.abs/1","ref":"Money.Cldr.Money.html#abs/1"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`","title":"Arguments - Money.Cldr.Money.abs/1","ref":"Money.Cldr.Money.html#abs/1-arguments"},{"type":"function","doc":"* a `t:Money.t/0`","title":"Returns - Money.Cldr.Money.abs/1","ref":"Money.Cldr.Money.html#abs/1-returns"},{"type":"function","doc":"iex> m = Money.Cldr.Money.new(\"USD\", -100)\n    iex> Money.Cldr.Money.abs(m)\n    Money.new(:USD, \"100\")","title":"Example - Money.Cldr.Money.abs/1","ref":"Money.Cldr.Money.html#abs/1-example"},{"type":"function","doc":"Add two `Money` values.","title":"Money.Cldr.Money.add/2","ref":"Money.Cldr.Money.html#add/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`","title":"Arguments - Money.Cldr.Money.add/2","ref":"Money.Cldr.Money.html#add/2-arguments"},{"type":"function","doc":"* `{:ok, money}` or\n\n* `{:error, reason}`","title":"Returns - Money.Cldr.Money.add/2","ref":"Money.Cldr.Money.html#add/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.add Money.new(:USD, 200), Money.new(:USD, 100)\n    {:ok, Money.new(:USD, 300)}\n\n    iex> Money.Cldr.Money.add Money.new(:USD, 200), Money.new(:AUD, 100)\n    {:error, {ArgumentError, \"Cannot add monies with different currencies. \" <>\n      \"Received :USD and :AUD.\"}}","title":"Example - Money.Cldr.Money.add/2","ref":"Money.Cldr.Money.html#add/2-example"},{"type":"function","doc":"Add two `Money` values and raise on error.","title":"Money.Cldr.Money.add!/2","ref":"Money.Cldr.Money.html#add!/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`","title":"Arguments - Money.Cldr.Money.add!/2","ref":"Money.Cldr.Money.html#add!/2-arguments"},{"type":"function","doc":"* `{:ok, money}` or\n\n* raises an exception","title":"Returns - Money.Cldr.Money.add!/2","ref":"Money.Cldr.Money.html#add!/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.add! Money.new(:USD, 200), Money.new(:USD, 100)\n    Money.new(:USD, \"300\")\n\n    Money.Cldr.Money.add! Money.new(:USD, 200), Money.new(:CAD, 500)\n    ** (ArgumentError) Cannot add two `t:Money.t/0` with different currencies. Received :USD and :CAD.","title":"Examples - Money.Cldr.Money.add!/2","ref":"Money.Cldr.Money.html#add!/2-examples"},{"type":"function","doc":"Compares two `Money` values numerically. If the first number is greater\nthan the second #Integer<1> is returned, if less than Integer<-1> is\nreturned. Otherwise, if both numbers are equal Integer<0> is returned.","title":"Money.Cldr.Money.cmp/2","ref":"Money.Cldr.Money.html#cmp/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`.","title":"Arguments - Money.Cldr.Money.cmp/2","ref":"Money.Cldr.Money.html#cmp/2-arguments"},{"type":"function","doc":"*  `-1` | `0` | `1` or\n\n* `{:error, {module(), String.t}}`","title":"Returns - Money.Cldr.Money.cmp/2","ref":"Money.Cldr.Money.html#cmp/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.cmp Money.new(:USD, 200), Money.new(:USD, 100)\n    1\n\n    iex> Money.Cldr.Money.cmp Money.new(:USD, 200), Money.new(:USD, 200)\n    0\n\n    iex> Money.Cldr.Money.cmp Money.new(:USD, 200), Money.new(:USD, 500)\n    -1\n\n    iex> Money.Cldr.Money.cmp Money.new(:USD, 200), Money.new(:CAD, 500)\n    {:error,\n     {ArgumentError,\n      \"Cannot compare monies with different currencies. Received :USD and :CAD.\"}}","title":"Examples - Money.Cldr.Money.cmp/2","ref":"Money.Cldr.Money.html#cmp/2-examples"},{"type":"function","doc":"Compares two `Money` values numerically and raises on error.","title":"Money.Cldr.Money.cmp!/2","ref":"Money.Cldr.Money.html#cmp!/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`.","title":"Arguments - Money.Cldr.Money.cmp!/2","ref":"Money.Cldr.Money.html#cmp!/2-arguments"},{"type":"function","doc":"*  `-1` | `0` | `1` or\n\n* raises an exception.","title":"Returns - Money.Cldr.Money.cmp!/2","ref":"Money.Cldr.Money.html#cmp!/2-returns"},{"type":"function","doc":"Money.Cldr.Money.cmp! Money.new(:USD, 200), Money.new(:CAD, 500)\n    ** (ArgumentError) Cannot compare monies with different currencies. Received :USD and :CAD.","title":"Examples - Money.Cldr.Money.cmp!/2","ref":"Money.Cldr.Money.html#cmp!/2-examples"},{"type":"function","doc":"Compares two `Money` values numerically. If the first number is greater\nthan the second :gt is returned, if less than :lt is returned, if both\nnumbers are equal :eq is returned.","title":"Money.Cldr.Money.compare/2","ref":"Money.Cldr.Money.html#compare/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`.","title":"Arguments - Money.Cldr.Money.compare/2","ref":"Money.Cldr.Money.html#compare/2-arguments"},{"type":"function","doc":"*  `:gt` | `:eq` | `:lt` or\n\n* `{:error, {module(), String.t}}`.","title":"Returns - Money.Cldr.Money.compare/2","ref":"Money.Cldr.Money.html#compare/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.compare Money.new(:USD, 200), Money.new(:USD, 100)\n    :gt\n\n    iex> Money.Cldr.Money.compare Money.new(:USD, 200), Money.new(:USD, 200)\n    :eq\n\n    iex> Money.Cldr.Money.compare Money.new(:USD, 200), Money.new(:USD, 500)\n    :lt\n\n    iex> Money.Cldr.Money.compare Money.new(:USD, 200), Money.new(:CAD, 500)\n    {:error,\n     {ArgumentError,\n      \"Cannot compare monies with different currencies. Received :USD and :CAD.\"}}","title":"Examples - Money.Cldr.Money.compare/2","ref":"Money.Cldr.Money.html#compare/2-examples"},{"type":"function","doc":"Compares two `Money` values numerically and raises on error.","title":"Money.Cldr.Money.compare!/2","ref":"Money.Cldr.Money.html#compare!/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`.","title":"Arguments - Money.Cldr.Money.compare!/2","ref":"Money.Cldr.Money.html#compare!/2-arguments"},{"type":"function","doc":"*  `:gt` | `:eq` | `:lt` or\n\n* raises an exception.","title":"Returns - Money.Cldr.Money.compare!/2","ref":"Money.Cldr.Money.html#compare!/2-returns"},{"type":"function","doc":"Money.Cldr.Money.compare! Money.new(:USD, 200), Money.new(:CAD, 500)\n    ** (ArgumentError) Cannot compare monies with different currencies. Received :USD and :CAD.","title":"Examples - Money.Cldr.Money.compare!/2","ref":"Money.Cldr.Money.html#compare!/2-examples"},{"type":"function","doc":"Returns the effective cross-rate to convert from one currency\nto another.","title":"Money.Cldr.Money.cross_rate/3","ref":"Money.Cldr.Money.html#cross_rate/3"},{"type":"function","doc":"* `from` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2` or a valid\n   currency code\n\n* `to_currency` is a valid currency code into which the `money` is converted\n\n* `rates` is a `Map` of currency rates where the map key is an upcased\n  atom or string and the value is a Decimal conversion factor.  The default is the\n  latest available exchange rates returned from `Money.ExchangeRates.latest_rates()`","title":"Arguments - Money.Cldr.Money.cross_rate/3","ref":"Money.Cldr.Money.html#cross_rate/3-arguments"},{"type":"function","doc":"Money.Cldr.Money.cross_rate(Money.new(:USD, 100), :AUD, %{USD: Decimal.new(1), AUD: Decimal.new(\"0.7345\")})\n    {:ok, Decimal.new(\"0.7345\")}\n\n    Money.Cldr.Money.cross_rate Money.new(:USD, 100), :ZZZ, %{USD: Decimal.new(1), AUD: Decimal.new(0.7345)}\n    ** (Cldr.UnknownCurrencyError) Currency :ZZZ is not known","title":"Examples - Money.Cldr.Money.cross_rate/3","ref":"Money.Cldr.Money.html#cross_rate/3-examples"},{"type":"function","doc":"Returns the effective cross-rate to convert from one currency\nto another.","title":"Money.Cldr.Money.cross_rate!/3","ref":"Money.Cldr.Money.html#cross_rate!/3"},{"type":"function","doc":"* `from` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2` or a valid\n   currency code\n\n* `to_currency` is a valid currency code into which the `money` is converted\n\n* `rates` is a `Map` of currency rates where the map key is an upcased\n  atom or string and the value is a Decimal conversion factor.  The default is the\n  latest available exchange rates returned from `Money.ExchangeRates.latest_rates()`","title":"Arguments - Money.Cldr.Money.cross_rate!/3","ref":"Money.Cldr.Money.html#cross_rate!/3-arguments"},{"type":"function","doc":"iex> Money.Cldr.Money.cross_rate!(Money.new(:USD, 100), :AUD, %{USD: Decimal.new(1), AUD: Decimal.new(\"0.7345\")})\n    Decimal.new(\"0.7345\")\n\n    iex> Money.Cldr.Money.cross_rate!(:USD, :AUD, %{USD: Decimal.new(1), AUD: Decimal.new(\"0.7345\")})\n    Decimal.new(\"0.7345\")\n\n    Money.Cldr.Money.cross_rate Money.new(:USD, 100), :ZZZ, %{USD: Decimal.new(1), AUD: Decimal.new(\"0.7345\")}\n    ** (Cldr.UnknownCurrencyError) Currency :ZZZ is not known","title":"Examples - Money.Cldr.Money.cross_rate!/3","ref":"Money.Cldr.Money.html#cross_rate!/3-examples"},{"type":"function","doc":"Divide a `Money` value by a number.","title":"Money.Cldr.Money.div/2","ref":"Money.Cldr.Money.html#div/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` types returned.\n  by `Money.new/2`\n\n* `number` is an integer, float or `t:Decimal.t/0`.\n\n> Note that dividing one `t:Money.t/0` by another is not supported.","title":"Arguments - Money.Cldr.Money.div/2","ref":"Money.Cldr.Money.html#div/2-arguments"},{"type":"function","doc":"* `{:ok, money}` or\n\n* `{:error, reason}`","title":"Returns - Money.Cldr.Money.div/2","ref":"Money.Cldr.Money.html#div/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.div Money.new(:USD, 200), 2\n    {:ok, Money.new(:USD, 100)}\n\n    iex> Money.Cldr.Money.div(Money.new(:USD, 200), \"xx\")\n    {:error, {ArgumentError, \"Cannot divide money by \\\"xx\\\"\"}}","title":"Example - Money.Cldr.Money.div/2","ref":"Money.Cldr.Money.html#div/2-example"},{"type":"function","doc":"Divide a `Money` value by a number and raise on error.","title":"Money.Cldr.Money.div!/2","ref":"Money.Cldr.Money.html#div!/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` types returned\n  by `Money.new/2`\n\n* `number` is an integer, float or `t:Decimal.t/0`","title":"Arguments - Money.Cldr.Money.div!/2","ref":"Money.Cldr.Money.html#div!/2-arguments"},{"type":"function","doc":"* a `t:Money.t/0` struct or\n\n* raises an exception","title":"Returns - Money.Cldr.Money.div!/2","ref":"Money.Cldr.Money.html#div!/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.div Money.new(:USD, 200), 2\n    {:ok, Money.new(:USD, 100)}\n\n    Money.Cldr.Money.div(Money.new(:USD, 200), \"xx\")\n    ** (ArgumentError) \"Cannot divide money by \\\"xx\\\"\"]}}","title":"Examples - Money.Cldr.Money.div!/2","ref":"Money.Cldr.Money.html#div!/2-examples"},{"type":"function","doc":"Returns a boolean indicating if two `Money` values are equal","title":"Money.Cldr.Money.equal?/2","ref":"Money.Cldr.Money.html#equal?/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`","title":"Arguments - Money.Cldr.Money.equal?/2","ref":"Money.Cldr.Money.html#equal?/2-arguments"},{"type":"function","doc":"* `true` or `false`","title":"Returns - Money.Cldr.Money.equal?/2","ref":"Money.Cldr.Money.html#equal?/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.equal? Money.new(:USD, 200), Money.new(:USD, 200)\n    true\n\n    iex> Money.Cldr.Money.equal? Money.new(:USD, 200), Money.new(:USD, 100)\n    false","title":"Example - Money.Cldr.Money.equal?/2","ref":"Money.Cldr.Money.html#equal?/2-example"},{"type":"function","doc":"Returns a `t:Money.t/0` struct from a currency code and a float amount, or\nan error tuple of the form `{:error, {exception, message}}`.\n\nFloats are fraught with danger in computer arithmetic due to the\nunexpected loss of precision during rounding. The IEEE754 standard\nindicates that a number with a precision of 16 digits should\nround-trip convert without loss of fidelity. This function supports\nnumbers with a precision up to 15 digits and will error if the\nprovided amount is outside that range.\n\n**Note** that `Money` cannot detect lack of precision or rounding errors\nintroduced upstream. This function therefore should be used with\ngreat care and its use should be considered potentially harmful.","title":"Money.Cldr.Money.from_float/3","ref":"Money.Cldr.Money.html#from_float/3"},{"type":"function","doc":"* `currency_code` is an [ISO4217](https://en.wikipedia.org/wiki/ISO_4217)\n  binary or atom currency code or an\n  [ISO 24165](https://www.iso.org/standard/80601.html) token identifier or shortname.\n\n* `amount` is a float","title":"Arguments - Money.Cldr.Money.from_float/3","ref":"Money.Cldr.Money.html#from_float/3-arguments"},{"type":"function","doc":"iex> Money.Cldr.Money.from_float 1.23456, :USD\n    Money.new(:USD, \"1.23456\")\n\n    iex> Money.Cldr.Money.from_float 1.234567890987656, :USD\n    {:error,\n      {Money.InvalidAmountError,\n        \"The precision of the float 1.234567890987656 is \" <>\n        \"greater than 15 which could lead to unexpected results. \" <>\n        \"Reduce the precision or call Money.new/2 with a Decimal or String amount\"}}","title":"Examples - Money.Cldr.Money.from_float/3","ref":"Money.Cldr.Money.html#from_float/3-examples"},{"type":"function","doc":"Returns a `t:Money.t/0` struct from a currency code and a float amount, or\nraises an exception if the currency code is invalid.\n\nSee `Money.from_float/2` for further information.\n\n**Note** that `Money` cannot detect lack of precision or rounding errors\nintroduced upstream. This function therefore should be used with\ngreat care and its use should be considered potentially harmful.","title":"Money.Cldr.Money.from_float!/3","ref":"Money.Cldr.Money.html#from_float!/3"},{"type":"function","doc":"* `currency_code` is an ISO4217 three-character upcased binary or atom\n\n* `amount` is a float\n\n* `options` is a keyword list of options passed\n  to `Money.new/3`. The default is `[]`.","title":"Arguments - Money.Cldr.Money.from_float!/3","ref":"Money.Cldr.Money.html#from_float!/3-arguments"},{"type":"function","doc":"iex> Money.Cldr.Money.from_float!(:USD, 1.234)\n    Money.new(:USD, \"1.234\")\n\n    Money.from_float!(:USD, 1.234567890987654)\n    #=> ** (Money.InvalidAmountError) The precision of the float 1.234567890987654 is greater than 15 which could lead to unexpected results. Reduce the precision or call Money.new/2 with a Decimal or String amount\n        (ex_money) lib/money.ex:293: Money.from_float!/2","title":"Examples - Money.Cldr.Money.from_float!/3","ref":"Money.Cldr.Money.html#from_float!/3-examples"},{"type":"function","doc":"Convert an integer representation of money into a `Money` struct.\n\nThis is the inverse operation of `Money.to_integer_exp/1`. Note\nthat the ISO definition of currency digits (subunit) is *always*\nused.  This is, in some cases like the Colombian Peso (COP)\ndifferent to the CLDR definition.","title":"Money.Cldr.Money.from_integer/3","ref":"Money.Cldr.Money.html#from_integer/3"},{"type":"function","doc":"* `integer` is an integer representation of a mooney item including\n  any decimal digits.  ie. 20000 would interpreted to mean $200.00\n\n* `currency` is the currency code for the `integer`.  The assumed\n  decimal places is derived from the currency code.","title":"Options - Money.Cldr.Money.from_integer/3","ref":"Money.Cldr.Money.html#from_integer/3-options"},{"type":"function","doc":"* A `Money` struct or\n\n* `{:error, {Cldr.UnknownCurrencyError, message}}`","title":"Returns - Money.Cldr.Money.from_integer/3","ref":"Money.Cldr.Money.html#from_integer/3-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.from_integer(20000, :USD)\n    Money.new(:USD, \"200.00\")\n\n    iex> Money.Cldr.Money.from_integer(200, :JPY)\n    Money.new(:JPY, \"200\")\n\n    iex> Money.Cldr.Money.from_integer(20012, :USD)\n    Money.new(:USD, \"200.12\")\n\n    iex> Money.Cldr.Money.from_integer(20012, :COP)\n    Money.new(:COP, \"200.12\")","title":"Examples - Money.Cldr.Money.from_integer/3","ref":"Money.Cldr.Money.html#from_integer/3-examples"},{"type":"function","doc":"","title":"Money.Cldr.Money.known_currencies/0","ref":"Money.Cldr.Money.html#known_currencies/0"},{"type":"function","doc":"","title":"Money.Cldr.Money.known_current_currencies/0","ref":"Money.Cldr.Money.html#known_current_currencies/0"},{"type":"function","doc":"","title":"Money.Cldr.Money.known_historic_currencies/0","ref":"Money.Cldr.Money.html#known_historic_currencies/0"},{"type":"function","doc":"","title":"Money.Cldr.Money.known_tender_currencies/0","ref":"Money.Cldr.Money.html#known_tender_currencies/0"},{"type":"function","doc":"Multiply a `Money` value by a number.","title":"Money.Cldr.Money.mult/2","ref":"Money.Cldr.Money.html#mult/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`.\n\n* `number` is an integer, float or `t:Decimal.t/0`.\n\n> Note that multipling one `t:Money.t/0` by another is not supported.","title":"Arguments - Money.Cldr.Money.mult/2","ref":"Money.Cldr.Money.html#mult/2-arguments"},{"type":"function","doc":"* `{:ok, money}` or\n\n* `{:error, reason}`","title":"Returns - Money.Cldr.Money.mult/2","ref":"Money.Cldr.Money.html#mult/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.mult(Money.new(:USD, 200), 2)\n    {:ok, Money.new(:USD, 400)}\n\n    iex> Money.Cldr.Money.mult(Money.new(:USD, 200), \"xx\")\n    {:error, {ArgumentError, \"Cannot multiply money by \\\"xx\\\"\"}}","title":"Example - Money.Cldr.Money.mult/2","ref":"Money.Cldr.Money.html#mult/2-example"},{"type":"function","doc":"Multiply a `Money` value by a number and raise on error.","title":"Money.Cldr.Money.mult!/2","ref":"Money.Cldr.Money.html#mult!/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` types returned\n  by `Money.new/2`.\n\n* `number` is an integer, float or `Decimal.t`","title":"Arguments - Money.Cldr.Money.mult!/2","ref":"Money.Cldr.Money.html#mult!/2-arguments"},{"type":"function","doc":"* a `t:Money.t/0` or\n\n* raises an exception","title":"Returns - Money.Cldr.Money.mult!/2","ref":"Money.Cldr.Money.html#mult!/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.mult!(Money.new(:USD, 200), 2)\n    Money.new(:USD, \"400\")\n\n    Money.Cldr.Money.mult!(Money.new(:USD, 200), :invalid)\n    ** (ArgumentError) Cannot multiply money by :invalid","title":"Examples - Money.Cldr.Money.mult!/2","ref":"Money.Cldr.Money.html#mult!/2-examples"},{"type":"function","doc":"Returns a `t:Money.t/0` struct from a currency code and a currency amount or\nan error tuple of the form `{:error, {exception, message}}`.","title":"Money.Cldr.Money.new/3","ref":"Money.Cldr.Money.html#new/3"},{"type":"function","doc":"* `currency_code` is an [ISO4217](https://en.wikipedia.org/wiki/ISO_4217)\n  binary or atom currency code or an\n  [ISO 24165](https://www.iso.org/standard/80601.html) token identifier or shortname.\n\n* `amount` is an integer, string or Decimal","title":"Arguments - Money.Cldr.Money.new/3","ref":"Money.Cldr.Money.html#new/3-arguments"},{"type":"function","doc":"`:locale` is any known locale.  The locale is used to normalize any\nbinary (String) amounts to a form that can be consumed by `Decimal.new/1`.\nThis consists of removing any localised grouping characters and replacing\nthe localised decimal separator with a \".\".\n\nNote that the `currency_code` and `amount` arguments can be supplied in\neither order,","title":"Options - Money.Cldr.Money.new/3","ref":"Money.Cldr.Money.html#new/3-options"},{"type":"function","doc":"iex> Money.Cldr.Money.new(:USD, 100)\n    Money.new(:USD, \"100\")\n\n    iex> Money.Cldr.Money.new(100, :USD)\n    Money.new(:USD, \"100\")\n\n    iex> Money.Cldr.Money.new(\"USD\", 100)\n    Money.new(:USD, \"100\")\n\n    iex> Money.Cldr.Money.new(\"thb\", 500)\n    Money.new(:THB, \"500\")\n\n    iex> Money.Cldr.Money.new(\"EUR\", Decimal.new(100))\n    Money.new(:EUR, \"100\")\n\n    iex> Money.Cldr.Money.new(:EUR, \"100.30\")\n    Money.new(:EUR, \"100.30\")\n\n    iex> Money.Cldr.Money.new(:XYZZ, 100)\n    {:error, {Money.UnknownCurrencyError, \"The currency :XYZZ is invalid\"}}\n\n    iex> Money.Cldr.Money.new(\"1.000,99\", :EUR, locale: \"de\")\n    Money.new(:EUR, \"1000.99\")\n\n    iex> Money.Cldr.Money.new 123.445, :USD\n    {:error,\n     {Money.InvalidAmountError,\n      \"Float amounts are not supported in new/2 due to potenial \" <>\n      \"rounding and precision issues.  If absolutely required, \" <>\n      \"use Money.from_float/2\"}}","title":"Examples - Money.Cldr.Money.new/3","ref":"Money.Cldr.Money.html#new/3-examples"},{"type":"function","doc":"Returns a `t:Money.t/0` struct from a currency code and a currency amount. Raises an\nexception if the current code is invalid.","title":"Money.Cldr.Money.new!/3","ref":"Money.Cldr.Money.html#new!/3"},{"type":"function","doc":"* `currency_code` is an ISO4217 three-character upcased binary or atom\n\n* `amount` is an integer, float or Decimal","title":"Arguments - Money.Cldr.Money.new!/3","ref":"Money.Cldr.Money.html#new!/3-arguments"},{"type":"function","doc":"Money.new!(:XYZZ, 100)\n    ** (Money.UnknownCurrencyError) Currency :XYZZ is not known\n      (ex_money) lib/money.ex:177: Money.new!/2","title":"Examples - Money.Cldr.Money.new!/3","ref":"Money.Cldr.Money.html#new!/3-examples"},{"type":"function","doc":"Normalizes the underlying `Decimal` amount on the\ngiven `t:Money.t/0`.\n\nThis will normalize the coefficient and exponent of the\ndecimal amount in a standard way that may aid in\nnative comparison of `t:Money.t/0` items.","title":"Money.Cldr.Money.normalize/1","ref":"Money.Cldr.Money.html#normalize/1"},{"type":"function","doc":"iex> x = %Money{currency: :USD, amount: %Decimal{sign: 1, coef: 42, exp: 0}}\n    Money.new(:USD, \"42\")\n    iex> y = %Money{currency: :USD, amount: %Decimal{sign: 1, coef: 4200000000, exp: -8}}\n    Money.new(:USD, \"42.00000000\")\n    iex> x == y\n    false\n    iex> y = Money.normalize(x)\n    Money.new(:USD, \"42\")\n    iex> x == y\n    true","title":"Example - Money.Cldr.Money.normalize/1","ref":"Money.Cldr.Money.html#normalize/1-example"},{"type":"function","doc":"Parse a string and return a `t:Money.t/0` or an error.\n\nThe string to be parsed is required to have a currency\ncode and an amount.  The currency code may be placed\nbefore the amount or after, but not both.\n\nParsing is strict.  Additional text surrounding the\ncurrency code and amount will cause the parse to\nfail.","title":"Money.Cldr.Money.parse/2","ref":"Money.Cldr.Money.html#parse/2"},{"type":"function","doc":"* `string` is a string to be parsed\n\n* `options` is a keyword list of options that is\n  passed to `Money.new/3` with the exception of\n  the options listed below","title":"Arguments - Money.Cldr.Money.parse/2","ref":"Money.Cldr.Money.html#parse/2-arguments"},{"type":"function","doc":"* `backend` is any module() that includes `use Cldr` and therefore\n  is a `Cldr` backend module(). The default is `Money.default_backend()`\n\n* `locale_name` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is ` .get_locale()`\n\n* `currency_filter` is an `atom` or list of `atoms` representing the\n  currency types to be considered for a match. If a list of\n  atoms is given, the currency must meet all criteria for\n  it to be considered.\n\n  * `:all`, the default, considers all currencies\n\n  * `:current` considers those currencies that have a `:to`\n    date of nil and which also is a known ISO4217 currency\n\n  * `:historic` is the opposite of `:current`\n\n  * `:tender` considers currencies that are legal tender\n\n  * `:unannotated` considers currencies that don't have\n    \"(some string)\" in their names.  These are usually\n    financial instruments.\n\n* `fuzzy` is a float greater than `0.0` and less than or\n  equal to `1.0` which is used as input to the\n  `String.jaro_distance/2` to determine is the provided\n  currency string is *close enough* to a known currency\n  string for it to identify definitively a currency code.\n  It is recommended to use numbers greater than `0.8` in\n  order to reduce false positives.\n\n* `:default_currency` is any valid currency code or `false`\n  that will used if no currency code, symbol or description is\n  indentified in the parsed string. The default is `nil`\n  which means that the default currency associated with\n  the `:locale` option will be used. If `false` then the\n  currency assocated with the `:locale` option will not be\n  used and an error will be returned if there is no currency\n  in the string being parsed.","title":"Options - Money.Cldr.Money.parse/2","ref":"Money.Cldr.Money.html#parse/2-options"},{"type":"function","doc":"* a `t:Money.t/0` if parsing is successful or\n\n* `{:error, {exception, reason}}` if an error is\n  detected.","title":"Returns - Money.Cldr.Money.parse/2","ref":"Money.Cldr.Money.html#parse/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.parse(\"USD 100\")\n    Money.new(:USD, \"100\")\n\n    iex> Money.Cldr.Money.parse \"USD 100,00\", locale: \"de\"\n    Money.new(:USD, \"100.00\")\n\n    iex> Money.Cldr.Money.parse(\"100 USD\")\n    Money.new(:USD, \"100\")\n\n    iex> Money.Cldr.Money.parse(\"100 eurosports\", fuzzy: 0.8)\n    Money.new(:EUR, \"100\")\n\n    iex> Money.Cldr.Money.parse(\"100 eurosports\", fuzzy: 0.9)\n    {:error,\n      {Money.UnknownCurrencyError, \"The currency \\\"eurosports\\\" is unknown or not supported\"}}\n\n    iex> Money.Cldr.Money.parse(\"100 afghan afghanis\")\n    Money.new(:AFN, \"100\")\n\n    iex> Money.Cldr.Money.parse(\"100\", default_currency: false)\n    {:error,\n      {Money.Invalid, \"A currency code, symbol or description must be specified but was not found in \\\"100\\\"\"}}\n\n    iex> Money.Cldr.Money.parse(\"USD 100 with trailing text\")\n    {:error,\n      {Money.ParseError, \"Could not parse \\\"USD 100 with trailing text\\\".\"}}","title":"Examples - Money.Cldr.Money.parse/2","ref":"Money.Cldr.Money.html#parse/2-examples"},{"type":"function","doc":"Set the fractional part of a `Money`.","title":"Money.Cldr.Money.put_fraction/2","ref":"Money.Cldr.Money.html#put_fraction/2"},{"type":"function","doc":"* `money` is a ``t:Money.t/0`` struct\n\n* `fraction` is an integer amount that will be set\n  as the fraction of the `money`","title":"Arguments - Money.Cldr.Money.put_fraction/2","ref":"Money.Cldr.Money.html#put_fraction/2-arguments"},{"type":"function","doc":"The fraction can only be set if it matches the number of\ndecimal digits for the currency associated with the `money`.\nTherefore, for a currency with 2 decimal digits, the\nmaximum for `fraction` is `99`.","title":"Notes - Money.Cldr.Money.put_fraction/2","ref":"Money.Cldr.Money.html#put_fraction/2-notes"},{"type":"function","doc":"iex> Money.Cldr.Money.put_fraction Money.new(:USD, \"2.49\"), 99\n    Money.new(:USD, \"2.99\")\n\n    iex> Money.Cldr.Money.put_fraction Money.new(:USD, \"2.49\"), 0\n    Money.new(:USD, \"2.0\")\n\n    iex> Money.Cldr.Money.put_fraction Money.new(:USD, \"2.49\"), 999\n    {:error,\n     {Money.InvalidAmountError, \"Rounding up to 999 is invalid for currency :USD\"}}","title":"Examples - Money.Cldr.Money.put_fraction/2","ref":"Money.Cldr.Money.html#put_fraction/2-examples"},{"type":"function","doc":"","title":"Money.Cldr.Money.reduce/1","ref":"Money.Cldr.Money.html#reduce/1"},{"type":"function","doc":"Round a `Money` value into the acceptable range for the requested currency.","title":"Money.Cldr.Money.round/2","ref":"Money.Cldr.Money.html#round/2"},{"type":"function","doc":"* `money` is a `t:Money.t/0` struct.\n\n* `options` is a keyword list of options.","title":"Arguments - Money.Cldr.Money.round/2","ref":"Money.Cldr.Money.html#round/2-arguments"},{"type":"function","doc":"* `:rounding_mode` that defines how the number will be rounded.  See\n    `Decimal.Context`.  The default is `:half_even` which is also known\n    as \"banker's rounding\".\n\n  * `:currency_digits` which determines the rounding increment.\n    The valid options are `:cash`, `:accounting` and `:iso` or\n    an integer value representing the rounding factor.  The\n    default is `:iso`.","title":"Options - Money.Cldr.Money.round/2","ref":"Money.Cldr.Money.html#round/2-options"},{"type":"function","doc":"There are two kinds of rounding applied:\n\n1. Round to the appropriate number of fractional digits.\n\n3. Apply an appropriate rounding increment.  Most currencies\n   round to the same precision as the number of decimal digits, but some\n   such as `:CHF` round to a minimum such as `0.05` when its a cash\n   amount. The rounding increment is applied when the option\n   `:currency_digits` is set to `:cash`.","title":"Notes - Money.Cldr.Money.round/2","ref":"Money.Cldr.Money.html#round/2-notes"},{"type":"function","doc":"iex> Money.Cldr.Money.round Money.new(\"123.73\", :CHF), currency_digits: :cash\n    Money.new(:CHF, \"123.75\")\n\n    iex> Money.Cldr.Money.round Money.new(\"123.73\", :CHF), currency_digits: 0\n    Money.new(:CHF, \"124\")\n\n    iex> Money.Cldr.Money.round Money.new(\"123.7456\", :CHF)\n    Money.new(:CHF, \"123.75\")\n\n    iex> Money.Cldr.Money.round Money.new(\"123.7456\", :JPY)\n    Money.new(:JPY, \"124\")","title":"Examples - Money.Cldr.Money.round/2","ref":"Money.Cldr.Money.html#round/2-examples"},{"type":"function","doc":"Split a `Money` value into a number of parts maintaining the currency's\nprecision and rounding and ensuring that the parts sum to the original\namount.","title":"Money.Cldr.Money.split/2","ref":"Money.Cldr.Money.html#split/2"},{"type":"function","doc":"* `money` is any `t:Money.t/0` struct\n\n* `parts` is an integer number of parts into which the `money` is split\n\nReturns a tuple `{dividend, remainder}` as the function result\nderived as follows:\n\n1. Round the money amount to the required currency precision using\n`Money.round/1`.\n\n2. Divide the result of step 1 by the integer divisor.\n\n3. Round the result of the division to the precision of the currency\nusing `Money.round/1`.\n\n4. Return two numbers: the result of the division and any remainder\nthat could not be applied given the precision of the currency.","title":"Arguments - Money.Cldr.Money.split/2","ref":"Money.Cldr.Money.html#split/2-arguments"},{"type":"function","doc":"Money.Cldr.Money.split Money.new(123.5, :JPY), 3\n    {¥41, ¥1}\n\n    Money.Cldr.Money.split Money.new(123.4, :JPY), 3\n    {¥41, ¥0}\n\n    Money.Cldr.Money.split Money.new(123.7, :USD), 9\n    {$13.74, $0.04}","title":"Examples - Money.Cldr.Money.split/2","ref":"Money.Cldr.Money.html#split/2-examples"},{"type":"function","doc":"Subtract one `Money` value struct from another.","title":"Money.Cldr.Money.sub/2","ref":"Money.Cldr.Money.html#sub/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`.","title":"Options - Money.Cldr.Money.sub/2","ref":"Money.Cldr.Money.html#sub/2-options"},{"type":"function","doc":"* `{:ok, money}` or\n\n* `{:error, reason}`.","title":"Returns - Money.Cldr.Money.sub/2","ref":"Money.Cldr.Money.html#sub/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.sub Money.new(:USD, 200), Money.new(:USD, 100)\n    {:ok, Money.new(:USD, 100)}","title":"Example - Money.Cldr.Money.sub/2","ref":"Money.Cldr.Money.html#sub/2-example"},{"type":"function","doc":"Subtract one `Money` value struct from another and raise on error.\n\nReturns either `{:ok, money}` or `{:error, reason}`.","title":"Money.Cldr.Money.sub!/2","ref":"Money.Cldr.Money.html#sub!/2"},{"type":"function","doc":"* `money_1` and `money_2` are any valid `t:Money.t/0` types returned\n  by `Money.new/2`.","title":"Arguments - Money.Cldr.Money.sub!/2","ref":"Money.Cldr.Money.html#sub!/2-arguments"},{"type":"function","doc":"* a `t:Money.t/0` struct or\n\n* raises an exception","title":"Returns - Money.Cldr.Money.sub!/2","ref":"Money.Cldr.Money.html#sub!/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Money.sub! Money.new(:USD, 200), Money.new(:USD, 100)\n    Money.new(:USD, \"100\")\n\n    Money.Cldr.Money.sub! Money.new(:USD, 200), Money.new(:CAD, 500)\n    ** (ArgumentError) Cannot subtract monies with different currencies. Received :USD and :CAD.","title":"Examples - Money.Cldr.Money.sub!/2","ref":"Money.Cldr.Money.html#sub!/2-examples"},{"type":"function","doc":"Convert `money` from one currency to another.","title":"Money.Cldr.Money.to_currency/3","ref":"Money.Cldr.Money.html#to_currency/3"},{"type":"function","doc":"* `money` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2`\n\n* `to_currency` is a valid currency code into which the `money` is converted\n\n* `rates` is a `Map` of currency rates where the map key is an upcased\n  atom or string and the value is a Decimal conversion factor.  The default is the\n  latest available exchange rates returned from `Money.ExchangeRates.latest_rates()`","title":"Arguments - Money.Cldr.Money.to_currency/3","ref":"Money.Cldr.Money.html#to_currency/3-arguments"},{"type":"function","doc":"Money.Cldr.Money.to_currency(Money.new(:USD, 100), :AUD, %{USD: Decimal.new(1), AUD: Decimal.from_float(0.7345)})\n    {:ok, Money.new(:AUD, \"73.4500\")}\n\n    Money.Cldr.Money.to_currency(Money.new(\"USD\", 100), \"AUD\", %{\"USD\" => Decimal.new(1), \"AUD\" => Decimal.from_float(0.7345)})\n    {:ok, Money.new(:AUD, \"73.4500\")}\n\n    iex> Money.Cldr.Money.to_currency Money.new(:USD, 100), :AUDD, %{USD: Decimal.new(1), AUD: Decimal.from_float(0.7345)}\n    {:error, {Cldr.UnknownCurrencyError, \"The currency :AUDD is invalid\"}}\n\n    iex> Money.Cldr.Money.to_currency Money.new(:USD, 100), :CHF, %{USD: Decimal.new(1), AUD: Decimal.from_float(0.7345)}\n    {:error, {Money.ExchangeRateError, \"No exchange rate is available for currency :CHF\"}}","title":"Examples - Money.Cldr.Money.to_currency/3","ref":"Money.Cldr.Money.html#to_currency/3-examples"},{"type":"function","doc":"Convert `money` from one currency to another and raises on error","title":"Money.Cldr.Money.to_currency!/3","ref":"Money.Cldr.Money.html#to_currency!/3"},{"type":"function","doc":"* `money` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2`\n\n* `to_currency` is a valid currency code into which the `money` is converted\n\n* `rates` is a `Map` of currency rates where the map key is an upcased\n  atom or string and the value is a Decimal conversion factor.  The default is the\n  latest available exchange rates returned from `Money.ExchangeRates.latest_rates()`","title":"Arguments - Money.Cldr.Money.to_currency!/3","ref":"Money.Cldr.Money.html#to_currency!/3-arguments"},{"type":"function","doc":"iex> Money.Cldr.Money.to_currency! Money.new(:USD, 100), :AUD, %{USD: Decimal.new(1), AUD: Decimal.from_float(0.7345)}\n    Money.new(:AUD, \"73.4500\")\n\n    iex> Money.Cldr.Money.to_currency! Money.new(\"USD\", 100), \"AUD\", %{\"USD\" => Decimal.new(1), \"AUD\" => Decimal.from_float(0.7345)}\n    Money.new(:AUD, \"73.4500\")\n\n    Money.Cldr.Money.to_currency! Money.new(:USD, 100), :ZZZ, %{USD: Decimal.new(1), AUD: Decimal.from_float(0.7345)}\n    ** (Cldr.UnknownCurrencyError) Currency :ZZZ is not known","title":"Examples - Money.Cldr.Money.to_currency!/3","ref":"Money.Cldr.Money.html#to_currency!/3-examples"},{"type":"function","doc":"Returns the amount part of a `Money` type as a `Decimal`","title":"Money.Cldr.Money.to_decimal/1","ref":"Money.Cldr.Money.html#to_decimal/1"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`","title":"Arguments - Money.Cldr.Money.to_decimal/1","ref":"Money.Cldr.Money.html#to_decimal/1-arguments"},{"type":"function","doc":"* a `Decimal.t`","title":"Returns - Money.Cldr.Money.to_decimal/1","ref":"Money.Cldr.Money.html#to_decimal/1-returns"},{"type":"function","doc":"iex> m = Money.Cldr.Money.new(\"USD\", 100)\n    iex> Money.Cldr.Money.to_decimal(m)\n    Decimal.new(\"100\")","title":"Example - Money.Cldr.Money.to_decimal/1","ref":"Money.Cldr.Money.html#to_decimal/1-example"},{"type":"function","doc":"Returns a tuple comprising the currency code, integer amount,\nexponent and remainder\n\nSome services require submission of money items as an integer\nwith an implied exponent that is appropriate to the currency.\n\nRather than return only the integer, `Money.to_integer_exp`\nreturns the currency code, integer, exponent and remainder.\nThe remainder is included because to return an integer\nmoney with an implied exponent the `Money` has to be rounded\npotentially leaving a remainder.","title":"Money.Cldr.Money.to_integer_exp/1","ref":"Money.Cldr.Money.html#to_integer_exp/1"},{"type":"function","doc":"* `money` is any `t:Money.t/0` struct returned by `Cldr.Currency.new/2`","title":"Arguments - Money.Cldr.Money.to_integer_exp/1","ref":"Money.Cldr.Money.html#to_integer_exp/1-arguments"},{"type":"function","doc":"* Since the returned integer is expected to have the implied fractional\ndigits the `Money` needs to be rounded which is what this function does.","title":"Notes - Money.Cldr.Money.to_integer_exp/1","ref":"Money.Cldr.Money.html#to_integer_exp/1-notes"},{"type":"function","doc":"iex> m = Money.Cldr.Money.new(:USD, \"200.012356\")\n    Money.new(:USD, \"200.012356\")\n    iex> Money.Cldr.Money.to_integer_exp(m)\n    {:USD, 20001, -2, Money.new(:USD, \"0.002356\")}\n\n    iex> m = Money.Cldr.Money.new(:USD, \"200.00\")\n    Money.new(:USD, \"200.00\")\n    iex> Money.Cldr.Money.to_integer_exp(m)\n    {:USD, 20000, -2, Money.new(:USD, \"0.00\")}","title":"Example - Money.Cldr.Money.to_integer_exp/1","ref":"Money.Cldr.Money.html#to_integer_exp/1-example"},{"type":"function","doc":"Returns a formatted string representation of a `Money{}`.\n\nFormatting is performed according to the rules defined by CLDR. See\n`Cldr.Number.to_string/2` for formatting options.  The default is to format\nas a currency which applies the appropriate rounding and fractional digits\nfor the currency.","title":"Money.Cldr.Money.to_string/2","ref":"Money.Cldr.Money.html#to_string/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.Money.to_string/2","ref":"Money.Cldr.Money.html#to_string/2-arguments"},{"type":"function","doc":"* `{:ok, string}` or\n\n* `{:error, reason}`","title":"Returns - Money.Cldr.Money.to_string/2","ref":"Money.Cldr.Money.html#to_string/2-returns"},{"type":"function","doc":"* `:backend` is any CLDR backend module.  The default is\n  `Money.default_backend()`.\n\n* Any other options are passed to `Cldr.Number.to_string/3`","title":"Options - Money.Cldr.Money.to_string/2","ref":"Money.Cldr.Money.html#to_string/2-options"},{"type":"function","doc":"iex> Money.Cldr.Money.to_string Money.new(:USD, 1234)\n    {:ok, \"$1,234.00\"}\n\n    iex> Money.Cldr.Money.to_string Money.new(:JPY, 1234)\n    {:ok, \"¥1,234\"}\n\n    iex> Money.Cldr.Money.to_string Money.new(:THB, 1234)\n    {:ok, \"THB 1,234.00\"}\n\n    iex> Money.Cldr.Money.to_string Money.new(:USD, 1234), format: :long\n    {:ok, \"1,234 US dollars\"}","title":"Examples - Money.Cldr.Money.to_string/2","ref":"Money.Cldr.Money.html#to_string/2-examples"},{"type":"function","doc":"Returns a formatted string representation of a `t:Money.t/0` or raises if\nthere is an error.\n\nFormatting is performed according to the rules defined by CLDR. See\n`Cldr.Number.to_string!/2` for formatting options.  The default is to format\nas a currency which applies the appropriate rounding and fractional digits\nfor the currency.","title":"Money.Cldr.Money.to_string!/2","ref":"Money.Cldr.Money.html#to_string!/2"},{"type":"function","doc":"* `money` is any valid `t:Money.t/0` type returned\n  by `Money.new/2`\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.Money.to_string!/2","ref":"Money.Cldr.Money.html#to_string!/2-arguments"},{"type":"function","doc":"* `:backend` is any CLDR backend module.  The default is\n  `Money.default_backend()`.\n\n* Any other options are passed to `Cldr.Number.to_string/3`","title":"Options - Money.Cldr.Money.to_string!/2","ref":"Money.Cldr.Money.html#to_string!/2-options"},{"type":"function","doc":"iex> Money.Cldr.Money.to_string! Money.new(:USD, 1234)\n    \"$1,234.00\"\n\n    iex> Money.Cldr.Money.to_string! Money.new(:JPY, 1234)\n    \"¥1,234\"\n\n    iex> Money.Cldr.Money.to_string! Money.new(:THB, 1234)\n    \"THB 1,234.00\"\n\n    iex> Money.Cldr.Money.to_string! Money.new(:USD, 1234), format: :long\n    \"1,234 US dollars\"","title":"Examples - Money.Cldr.Money.to_string!/2","ref":"Money.Cldr.Money.html#to_string!/2-examples"},{"type":"function","doc":"","title":"Money.Cldr.Money.validate_currency/1","ref":"Money.Cldr.Money.html#validate_currency/1"},{"type":"function","doc":"Return a zero amount `t:Money` in the given currency.","title":"Money.Cldr.Money.zero/2","ref":"Money.Cldr.Money.html#zero/2"},{"type":"function","doc":"* `money_or_currency` is either a `t:Money` or\n  a currency code\n\n* `options` is a keyword list of options passed\n  to `Money.new/3`. The default is `[]`.","title":"Arguments - Money.Cldr.Money.zero/2","ref":"Money.Cldr.Money.html#zero/2-arguments"},{"type":"function","doc":"iex> Money.Cldr.Money.zero(:USD)\n    Money.new(:USD, \"0\")\n\n    iex> money = Money.new(:USD, 200)\n    iex> Money.Cldr.Money.zero(money)\n    Money.new(:USD, \"0\")\n\n    iex> Money.Cldr.Money.zero :ZZZ\n    {:error, {Cldr.UnknownCurrencyError, \"The currency :ZZZ is invalid\"}}","title":"Example - Money.Cldr.Money.zero/2","ref":"Money.Cldr.Money.html#zero/2-example"},{"type":"module","doc":"Formats numbers and currencies based upon CLDR's decimal formats specification.\n\nThe format specification is documentated in [Unicode TR35](http://unicode.org/reports/tr35/tr35-numbers.html#Number_Formats).\nThere are several classes of formatting including non-scientific, scientific,\nrules based (for spelling and ordinal formats), compact formats that display `1k`\nrather than `1,000` and so on.  See `Cldr.Number.to_string/2` for specific formatting\noptions.","title":"Money.Cldr.Number","ref":"Money.Cldr.Number.html"},{"type":"module","doc":"The following description applies to formats that do not use scientific\nnotation or significant digits:\n\n* If the number of actual integer digits exceeds the maximum integer digits,\n  then only the least significant digits are shown. For example, 1997 is\n  formatted as \"97\" if the maximum integer digits is set to 2.\n\n* If the number of actual integer digits is less than the minimum integer\n  digits, then leading zeros are added. For example, 1997 is formatted as\n  \"01997\" if the minimum integer digits is set to 5.\n\n* If the number of actual fraction digits exceeds the maximum fraction\n  digits, then half-even rounding it performed to the maximum fraction\n  digits. For example, 0.125 is formatted as \"0.12\" if the maximum fraction\n  digits is 2. This behavior can be changed by specifying a rounding\n  increment and a rounding mode.\n\n* If the number of actual fraction digits is less than the minimum fraction\n  digits, then trailing zeros are added. For example, 0.125 is formatted as\n  \"0.1250\" if the minimum fraction digits is set to 4.\n\n* Trailing fractional zeros are not displayed if they occur j positions after\n  the decimal, where j is less than the maximum fraction digits. For example,\n  0.10004 is formatted as \"0.1\" if the maximum fraction digits is four or\n  less.","title":"Non-Scientific Notation Formatting - Money.Cldr.Number","ref":"Money.Cldr.Number.html#module-non-scientific-notation-formatting"},{"type":"module","doc":"Numbers in scientific notation are expressed as the product of a mantissa and\na power of ten, for example, 1234 can be expressed as 1.234 x 10^3. The\nmantissa is typically in the half-open interval [1.0, 10.0) or sometimes\n[0.0, 1.0), but it need not be. In a pattern, the exponent character\nimmediately followed by one or more digit characters indicates scientific\nnotation. Example: \"0.###E0\" formats the number 1234 as \"1.234E3\".\n\n* The number of digit characters after the exponent character gives the\n  minimum exponent digit count. There is no maximum. Negative exponents are\n  formatted using the localized minus sign, not the prefix and suffix from\n  the pattern. This allows patterns such as \"0.###E0 m/s\". To prefix positive\n  exponents with a localized plus sign, specify '+' between the exponent and\n  the digits: \"0.###E+0\" will produce formats \"1E+1\", \"1E+0\", \"1E-1\", and so\n  on. (In localized patterns, use the localized plus sign rather than '+'.)\n\n* The minimum number of integer digits is achieved by adjusting the exponent.\n  Example: 0.00123 formatted with \"00.###E0\" yields \"12.3E-4\". This only\n  happens if there is no maximum number of integer digits. If there is a\n  maximum, then the minimum number of integer digits is fixed at one.\n\n* The maximum number of integer digits, if present, specifies the exponent\n  grouping. The most common use of this is to generate engineering notation,\n  in which the exponent is a multiple of three, for example, \"##0.###E0\". The\n  number 12345 is formatted using \"##0.####E0\" as \"12.345E3\".\n\n* When using scientific notation, the formatter controls the digit counts\n  using significant digits logic. The maximum number of significant digits\n  limits the total number of integer and fraction digits that will be shown\n  in the mantissa; it does not affect parsing. For example, 12345 formatted\n  with \"##0.##E0\" is \"12.3E3\". Exponential patterns may not contain grouping\n  separators.","title":"Scientific Notation Formatting - Money.Cldr.Number","ref":"Money.Cldr.Number.html#module-scientific-notation-formatting"},{"type":"module","doc":"There are two ways of controlling how many digits are shows: (a)\nsignificant digits counts, or (b) integer and fraction digit counts. Integer\nand fraction digit counts are described above. When a formatter is using\nsignificant digits counts, it uses however many integer and fraction digits\nare required to display the specified number of significant digits. It may\nignore min/max integer/fraction digits, or it may use them to the extent\npossible.","title":"Significant Digits - Money.Cldr.Number","ref":"Money.Cldr.Number.html#module-significant-digits"},{"type":"function","doc":"Parse a string locale-aware manner and return\na number.","title":"Money.Cldr.Number.parse/2","ref":"Money.Cldr.Number.html#parse/2"},{"type":"function","doc":"* `string` is any `String.t`\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.Number.parse/2","ref":"Money.Cldr.Number.html#parse/2-arguments"},{"type":"function","doc":"* `:number` is one of `:integer`, `:float`,\n  `:decimal` or `nil`. The default is `nil`\n  meaning that the type auto-detected as either\n  an `integer` or a `float`.\n\n* `:locale` is any locale returned by\n  `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag.t`. The default is\n  `Money.Cldr.get_locale/0`.","title":"Options - Money.Cldr.Number.parse/2","ref":"Money.Cldr.Number.html#parse/2-options"},{"type":"function","doc":"* A number of the requested or default type or\n\n* `{:error, {exception, error}}` if no number could be determined","title":"Returns - Money.Cldr.Number.parse/2","ref":"Money.Cldr.Number.html#parse/2-returns"},{"type":"function","doc":"This function parses a string to return a number but\nin a locale-aware manner. It will normalise grouping\ncharacters and decimal separators, different forms of\nthe `+` and `-` symbols that appear in Unicode and\nstrips any `_` characters that might be used for\nformatting in a string. It then parses the number\nusing the Elixir standard library functions.","title":"Notes - Money.Cldr.Number.parse/2","ref":"Money.Cldr.Number.html#parse/2-notes"},{"type":"function","doc":"iex> Money.Cldr.Number.parse(\"＋1.000,34\", locale: \"de\")\n    {:ok, 1000.34}\n\n    iex> Money.Cldr.Number.parse(\"-1_000_000.34\")\n    {:ok, -1000000.34}\n\n    iex> Money.Cldr.Number.parse(\"1.000\", locale: \"de\", number: :integer)\n    {:ok, 1000}\n\n    iex> Money.Cldr.Number.parse(\"＋1.000,34\", locale: \"de\", number: :integer)\n    {:error,\n      {Cldr.Number.ParseError,\n       \"The string \\\"＋1.000,34\\\" could not be parsed as a number\"}}","title":"Examples - Money.Cldr.Number.parse/2","ref":"Money.Cldr.Number.html#parse/2-examples"},{"type":"function","doc":"Resolve curencies from strings within\na list.","title":"Money.Cldr.Number.resolve_currencies/2","ref":"Money.Cldr.Number.html#resolve_currencies/2"},{"type":"function","doc":"* `list` is any list in which currency\n  names and symbols are expected\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.Number.resolve_currencies/2","ref":"Money.Cldr.Number.html#resolve_currencies/2-arguments"},{"type":"function","doc":"* `:locale` is any valid locale returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is `Money.Cldr.get_locale()`\n\n* `:only` is an `atom` or list of `atoms` representing the\n  currencies or currency types to be considered for a match.\n  The equates to a list of acceptable currencies for parsing.\n  See the notes below for currency types.\n\n* `:except` is an `atom` or list of `atoms` representing the\n  currencies or currency types to be not considered for a match.\n  This equates to a list of unacceptable currencies for parsing.\n  See the notes below for currency types.\n\n* `:fuzzy` is a float greater than `0.0` and less than or\n  equal to `1.0` which is used as input to\n  `String.jaro_distance/2` to determine is the provided\n  currency string is *close enough* to a known currency\n  string for it to identify definitively a currency code.\n  It is recommended to use numbers greater than `0.8` in\n  order to reduce false positives.","title":"Options - Money.Cldr.Number.resolve_currencies/2","ref":"Money.Cldr.Number.html#resolve_currencies/2-options"},{"type":"function","doc":"The `:only` and `:except` options accept a list of\ncurrency codes and/or currency types.  The following\ntypes are recognised.\n\nIf both `:only` and `:except` are specified,\nthe `:except` entries take priority - that means\nany entries in `:except` are removed from the `:only`\nentries.\n\n  * `:all`, the default, considers all currencies\n\n  * `:current` considers those currencies that have a `:to`\n    date of nil and which also is a known ISO4217 currency\n\n  * `:historic` is the opposite of `:current`\n\n  * `:tender` considers currencies that are legal tender\n\n  * `:unannotated` considers currencies that don't have\n    \"(some string)\" in their names.  These are usually\n    financial instruments.","title":"Notes - Money.Cldr.Number.resolve_currencies/2","ref":"Money.Cldr.Number.html#resolve_currencies/2-notes"},{"type":"function","doc":"iex> Money.Cldr.Number.scan(\"100 US dollars\")\n    ...> |> Money.Cldr.Number.resolve_currencies\n    [100, :USD]\n\n    iex> Money.Cldr.Number.scan(\"100 eurosports\")\n    ...> |> Money.Cldr.Number.resolve_currencies(fuzzy: 0.75)\n    [100, :EUR]\n\n    iex> Money.Cldr.Number.scan(\"100 dollars des États-Unis\")\n    ...> |> Money.Cldr.Number.resolve_currencies(locale: \"fr\")\n    [100, :USD]","title":"Examples - Money.Cldr.Number.resolve_currencies/2","ref":"Money.Cldr.Number.html#resolve_currencies/2-examples"},{"type":"function","doc":"Resolve a currency from a string","title":"Money.Cldr.Number.resolve_currency/2","ref":"Money.Cldr.Number.html#resolve_currency/2"},{"type":"function","doc":"* `list` is any list in which currency\n  names and symbols are expected\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.Number.resolve_currency/2","ref":"Money.Cldr.Number.html#resolve_currency/2-arguments"},{"type":"function","doc":"* `:locale` is any valid locale returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is `Money.Cldr.get_locale()`\n\n* `:only` is an `atom` or list of `atoms` representing the\n  currencies or currency types to be considered for a match.\n  The equates to a list of acceptable currencies for parsing.\n  See the notes below for currency types.\n\n* `:except` is an `atom` or list of `atoms` representing the\n  currencies or currency types to be not considered for a match.\n  This equates to a list of unacceptable currencies for parsing.\n  See the notes below for currency types.\n\n* `:fuzzy` is a float greater than `0.0` and less than or\n  equal to `1.0` which is used as input to\n  `String.jaro_distance/2` to determine is the provided\n  currency string is *close enough* to a known currency\n  string for it to identify definitively a currency code.\n  It is recommended to use numbers greater than `0.8` in\n  order to reduce false positives.","title":"Options - Money.Cldr.Number.resolve_currency/2","ref":"Money.Cldr.Number.html#resolve_currency/2-options"},{"type":"function","doc":"* An ISO4217 currency code as an atom or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Cldr.Number.resolve_currency/2","ref":"Money.Cldr.Number.html#resolve_currency/2-returns"},{"type":"function","doc":"The `:only` and `:except` options accept a list of\ncurrency codes and/or currency types.  The following\ntypes are recognised.\n\nIf both `:only` and `:except` are specified,\nthe `:except` entries take priority - that means\nany entries in `:except` are removed from the `:only`\nentries.\n\n  * `:all`, the default, considers all currencies\n\n  * `:current` considers those currencies that have a `:to`\n    date of nil and which also is a known ISO4217 currency\n\n  * `:historic` is the opposite of `:current`\n\n  * `:tender` considers currencies that are legal tender\n\n  * `:unannotated` considers currencies that don't have\n    \"(some string)\" in their names.  These are usually\n    financial instruments.","title":"Notes - Money.Cldr.Number.resolve_currency/2","ref":"Money.Cldr.Number.html#resolve_currency/2-notes"},{"type":"function","doc":"iex> Money.Cldr.Number.resolve_currency(\"US dollars\")\n    [:USD]\n\n    iex> Money.Cldr.Number.resolve_currency(\"100 eurosports\", fuzzy: 0.75)\n    [:EUR]\n\n    iex> Money.Cldr.Number.resolve_currency(\"dollars des États-Unis\", locale: \"fr\")\n    [:USD]\n\n    iex> Money.Cldr.Number.resolve_currency(\"not a known currency\", locale: \"fr\")\n    {:error,\n     {Cldr.UnknownCurrencyError,\n      \"The currency \\\"not a known currency\\\" is unknown or not supported\"}}","title":"Examples - Money.Cldr.Number.resolve_currency/2","ref":"Money.Cldr.Number.html#resolve_currency/2-examples"},{"type":"function","doc":"Resolve and tokenize percent or permille\nfrom the beginning and/or the end of a string","title":"Money.Cldr.Number.resolve_per/2","ref":"Money.Cldr.Number.html#resolve_per/2"},{"type":"function","doc":"* `list` is any list in which percent\n  and permille symbols are expected\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.Number.resolve_per/2","ref":"Money.Cldr.Number.html#resolve_per/2-arguments"},{"type":"function","doc":"* `:locale` is any valid locale returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is `options[:backend].get_locale()`","title":"Options - Money.Cldr.Number.resolve_per/2","ref":"Money.Cldr.Number.html#resolve_per/2-options"},{"type":"function","doc":"* An `:percent` or `permille` or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Cldr.Number.resolve_per/2","ref":"Money.Cldr.Number.html#resolve_per/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Number.resolve_per \"11%\"\n    [\"11\", :percent]\n\n    iex> Money.Cldr.Number.resolve_per \"% of linguists\"\n    [:percent, \" of linguists\"]\n\n    iex> Money.Cldr.Number.resolve_per \"% of linguists %\"\n    [:percent, \" of linguists \", :percent]","title":"Examples - Money.Cldr.Number.resolve_per/2","ref":"Money.Cldr.Number.html#resolve_per/2-examples"},{"type":"function","doc":"Resolve and tokenize percent and permille\nsybols from strings within a list.\n\nPercent and permille symbols can be identified\nat the beginning and/or the end of a string.","title":"Money.Cldr.Number.resolve_pers/2","ref":"Money.Cldr.Number.html#resolve_pers/2"},{"type":"function","doc":"* `list` is any list in which percent and\n  permille symbols are expected\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.Number.resolve_pers/2","ref":"Money.Cldr.Number.html#resolve_pers/2-arguments"},{"type":"function","doc":"* `:locale` is any valid locale returned by `Cldr.known_locale_names/1`\n  or a `t:Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is `options[:backend].get_locale()`","title":"Options - Money.Cldr.Number.resolve_pers/2","ref":"Money.Cldr.Number.html#resolve_pers/2-options"},{"type":"function","doc":"iex> Money.Cldr.Number.scan(\"100%\")\n    ...> |> Money.Cldr.Number.resolve_pers()\n    [100, :percent]","title":"Examples - Money.Cldr.Number.resolve_pers/2","ref":"Money.Cldr.Number.html#resolve_pers/2-examples"},{"type":"function","doc":"Scans a string locale-aware manner and returns\na list of strings and numbers.","title":"Money.Cldr.Number.scan/2","ref":"Money.Cldr.Number.html#scan/2"},{"type":"function","doc":"* `string` is any `String.t`\n\n* `options` is a keyword list of options","title":"Arguments - Money.Cldr.Number.scan/2","ref":"Money.Cldr.Number.html#scan/2-arguments"},{"type":"function","doc":"* `:number` is one of `:integer`, `:float`,\n  `:decimal` or `nil`. The default is `nil`\n  meaning that the type auto-detected as either\n  an `integer` or a `float`.\n\n* `:locale` is any locale returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag.t`. The default is `Money.Cldr.get_locale/0`.","title":"Options - Money.Cldr.Number.scan/2","ref":"Money.Cldr.Number.html#scan/2-options"},{"type":"function","doc":"* A list of strings and numbers","title":"Returns - Money.Cldr.Number.scan/2","ref":"Money.Cldr.Number.html#scan/2-returns"},{"type":"function","doc":"Number parsing is performed by `Cldr.Number.Parser.parse/2`\nand any options provided are passed to that function.","title":"Notes - Money.Cldr.Number.scan/2","ref":"Money.Cldr.Number.html#scan/2-notes"},{"type":"function","doc":"iex> Money.Cldr.Number.scan(\"£1_000_000.34\")\n    [\"£\", 1000000.34]\n\n    iex> Money.Cldr.Number.scan(\"I want £1_000_000 dollars\")\n    [\"I want £\", 1000000, \" dollars\"]\n\n    iex> Money.Cldr.Number.scan(\"The prize is 23\")\n    [\"The prize is \", 23]\n\n    iex> Money.Cldr.Number.scan(\"The lottery number is 23 for the next draw\")\n    [\"The lottery number is \", 23, \" for the next draw\"]\n\n    iex> Money.Cldr.Number.scan(\"The loss is -1.000 euros\", locale: \"de\", number: :integer)\n    [\"The loss is \", -1000, \" euros\"]","title":"Examples - Money.Cldr.Number.scan/2","ref":"Money.Cldr.Number.html#scan/2-examples"},{"type":"function","doc":"Formats a number and applies the `:approximately` format for\na locale and number system.","title":"Money.Cldr.Number.to_approx_string/2","ref":"Money.Cldr.Number.html#to_approx_string/2"},{"type":"function","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `options` is a keyword list defining how the number is to be formatted.\n  See `Cldr.Number.to_string/3` for a description of the available\n  options.","title":"Arguments - Money.Cldr.Number.to_approx_string/2","ref":"Money.Cldr.Number.html#to_approx_string/2-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.to_approx_string 1234\n    {:ok, \"~1,234\"}","title":"Example - Money.Cldr.Number.to_approx_string/2","ref":"Money.Cldr.Number.html#to_approx_string/2-example"},{"type":"function","doc":"Formats a number and applies the `:at_least` format for\na locale and number system.","title":"Money.Cldr.Number.to_at_least_string/2","ref":"Money.Cldr.Number.html#to_at_least_string/2"},{"type":"function","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `options` is a keyword list defining how the number is to be formatted.\n  See `Money.Cldr.Number.to_string/2` for a description of the available\n  options.","title":"Arguments - Money.Cldr.Number.to_at_least_string/2","ref":"Money.Cldr.Number.html#to_at_least_string/2-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.to_at_least_string 1234\n    {:ok, \"1,234+\"}","title":"Example - Money.Cldr.Number.to_at_least_string/2","ref":"Money.Cldr.Number.html#to_at_least_string/2-example"},{"type":"function","doc":"Formats a number and applies the `:at_most` format for\na locale and number system.","title":"Money.Cldr.Number.to_at_most_string/2","ref":"Money.Cldr.Number.html#to_at_most_string/2"},{"type":"function","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `options` is a keyword list defining how the number is to be formatted.\n  See `Cldr.Number.to_string/3` for a description of the available\n  options.","title":"Arguments - Money.Cldr.Number.to_at_most_string/2","ref":"Money.Cldr.Number.html#to_at_most_string/2-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.to_at_most_string 1234\n    {:ok, \"≤1,234\"}","title":"Example - Money.Cldr.Number.to_at_most_string/2","ref":"Money.Cldr.Number.html#to_at_most_string/2-example"},{"type":"function","doc":"Formats the first and last numbers of a range and applies\nthe `:range` format for a locale and number system.","title":"Money.Cldr.Number.to_range_string/2","ref":"Money.Cldr.Number.html#to_range_string/2"},{"type":"function","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `options` is a keyword list defining how the number is to be formatted.\n  See `Cldr.Number.to_string/3` for a description of the available\n  options.","title":"Arguments - Money.Cldr.Number.to_range_string/2","ref":"Money.Cldr.Number.html#to_range_string/2-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.to_range_string 1234..5678\n    {:ok, \"1,234–5,678\"}","title":"Example - Money.Cldr.Number.to_range_string/2","ref":"Money.Cldr.Number.html#to_range_string/2-example"},{"type":"function","doc":"Returns a number formatted into a string according to a format pattern and options.","title":"Money.Cldr.Number.to_string/2","ref":"Money.Cldr.Number.html#to_string/2"},{"type":"function","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `options` is a keyword list defining how the number is to be formatted.","title":"Arguments - Money.Cldr.Number.to_string/2","ref":"Money.Cldr.Number.html#to_string/2-arguments"},{"type":"function","doc":"* `format`: the format style or a format string defining how the number is\n  formatted. See `Cldr.Number.Format` for how format strings can be constructed.\n  See `Cldr.Number.Format.format_styles_for/3` to return available format styles\n  for a locale. The default `format` is `:standard`.\n\n* If `:format` is set to `:long` or `:short` then the formatting depends on\n  whether `:currency` is specified. If not specified then the number is\n  formatted as `:decimal_long` or `:decimal_short`. If `:currency` is\n  specified the number is formatted as `:currency_long` or\n  `:currency_short` and `:fractional_digits` is set to 0 as a default.\n\n* `:format` may also be a format defined by CLDR's Rules Based Number\n  Formats (RBNF).  Further information is found in the module `Cldr.Rbnf`.\n  The most commonly used formats in this category are to spell out the\n  number in a the locales language.  The applicable formats are `:spellout`,\n  `:spellout_year`, `:ordinal`.  A number can also be formatted as roman\n  numbers by using the format `:roman` or `:roman_lower`.\n\n* `currency`: is the currency for which the number is formatted. For\n  available currencies see `Cldr.Currency.known_currencies/0`. This option\n  is required if `:format` is set to `:currency`.  If `currency` is set\n  and no `:format` is set, `:format` will be set to `:currency` as well.\n\n* `currency_symbol`: Allows overriding a currency symbol. The alternatives\n  are:\n  * `:iso` the ISO currency code will be used instead of the default\n    currency symbol.\n  * `:narrow` uses the narrow symbol defined for the locale. The same\n    narrow symbol can be defined for more than one currency and therefore this\n    should be used with care. If no narrow symbol is defined, the standard\n    symbol is used.\n  * `:symbol` uses the standard symbol defined in CLDR. A symbol is unique\n    for each currency and can be safely used.\n  * \"string\" uses `string` as the currency symbol\n  * `:standard` (the default and recommended) uses the CLDR-defined symbol\n    based upon the currency format for the locale.\n\n* `:cash`: a boolean which indicates whether a number being formatted as a\n  `:currency` is to be considered a cash value or not. Currencies can be\n  rounded differently depending on whether `:cash` is `true` or `false`.\n  *This option is deprecated in favour of `currency_digits: :cash`.\n\n* `:currency_digits` indicates which of the rounding and digits should be\n  used. The options are `:accounting` which is the default, `:cash` or\n  `:iso`\n\n* `:rounding_mode`: determines how a number is rounded to meet the precision\n  of the format requested. The available rounding modes are `:down`,\n  :half_up, :half_even, :ceiling, :floor, :half_down, :up. The default is\n  `:half_even`.\n\n* `:number_system`: determines which of the number systems for a locale\n  should be used to define the separators and digits for the formatted\n  number. If `number_system` is an `atom` then `number_system` is\n  interpreted as a number system. If the `:number_system` is\n  `binary` then it is interpreted as a number system name. See\n  `Cldr.Number.System.number_system_names_for/2`. The default is `:default`.\n\n* `:locale`: determines the locale in which the number is formatted. See\n  `Cldr.known_locale_names/0`. The default is`Cldr.get_locale/0` which is the\n  locale currently in affect for this `Process` and which is set by\n  `Cldr.put_locale/1`.\n\n* If `:fractional_digits` is set to a positive integer value then the number\n  will be rounded to that number of digits and displayed accordingly - overriding\n  settings that would be applied by default.  For example, currencies have\n  fractional digits defined reflecting each currencies minor unit.  Setting\n  `:fractional_digits` will override that setting.\n\n* If `:maximum_integer_digits` is set to a positive integer value then the\n  number is left truncated before formatting. For example if the number `1234`\n  is formatted with the option `maximum_integer_digits: 2`, the number is\n  truncated to `34` and formatted.\n\n* If `:round_nearest` is set to a positive integer value then the number\n  will be rounded to nearest increment of that value - overriding\n  settings that would be applied by default.\n\n* `:minimum_grouping_digits` overrides the CLDR definition of minimum grouping\n  digits. For example in the locale `es` the number `1234` is formatted by default\n  as `1345` because the locale defines the `minimium_grouping_digits` as `2`. If\n  `minimum_grouping_digits: 1` is set as an option the number is formatting as\n  `1.345`. The `:minimum_grouping_digits` is added to the grouping defined by\n  the number format.  If the sum of these two digits is greater than the number\n  of digits in the integer (or fractional) part of the number then no grouping\n  is performed.\n\n* `:wrapper` is a 2-arity function that will be called for each number component\n  with parameters `string` and `tag` where `tag` is one of `:number`,\n  `:currency_symbol`, `:currency_space`, `:literal`, `:quote`, `:percent`,\n  `:permille`, `:minus` or `:plus`. The function must return a string. The\n  function can be used to wrap format elements in HTML or other tags.","title":"Options - Money.Cldr.Number.to_string/2","ref":"Money.Cldr.Number.html#to_string/2-options"},{"type":"function","doc":"A locale identifier can specify options that affect number formatting.\nThese options are:\n\n* `nu`: defines the number system to be used if none is specified by the `:number_system`\n  option to `to_string/2`\n\nThis key is part of the [u extension](https://unicode.org/reports/tr35/#u_Extension) and\nthat document should be consulted for details on how to construct a locale identifier with these\nextensions.","title":"Locale extensions affecting formatting - Money.Cldr.Number.to_string/2","ref":"Money.Cldr.Number.html#to_string/2-locale-extensions-affecting-formatting"},{"type":"function","doc":"Wrapping elements is particularly useful when formatting a number with a\ncurrency symbol and the requirement is to have different HTML formatting\napplied to the symbol than the number.  For example:\n\n    iex> Cldr.Number.to_string(100, format: :currency, currency: :USD, wrapper: fn\n    ...>   string, :currency_symbol -> \" \" <> string <> \" \"\n    ...>   string, :number -> \" \" <> string <> \" \"\n    ...>   string, :currency_space -> \" \" <> string <> \" \"\n    ...>   string, _other -> string\n    ...> end)\n    {:ok, \" $  100.00 \"}\n\nIt is also possible and recommended to use the `Phoenix.HTML.Tag.content_tag/3`\nfunction if wrapping HTML tags since these will ensure HTML entities are\ncorrectly encoded.  For example:\n\n    iex> Cldr.Number.to_string(100, format: :currency, currency: :USD, wrapper: fn\n    ...>   string, :currency_symbol -> Phoenix.HTML.Tag.content_tag(:span, string, class: \"symbol\")\n    ...>   string, :number -> Phoenix.HTML.Tag.content_tag(:span, string, class: \"number\")\n    ...>   string, :currency_space -> Phoenix.HTML.Tag.content_tag(:span, string)\n    ...>   string, _other -> string\n    ...> end)\n    {:ok, \" $  100.00 \"}\n\nWhen formatting a number the format is parsed into format elements that might include\na currency symbol, a literal string, inserted text between a currency symbol and the\ncurrency amount, a percent sign, the number itself and several other elements.  In\nsome cases it is helpful to be apply specific formatting to each element.\nThis can be achieved by specifying a `:wrapper` option. This option takes a 2-arity\nfunction as an argument. For each element of the format the wrapper function is called\nwith two parameters:  the format element as a string and an atom representing the\nelement type. The wrapper function is required to return a string that is then\ninserted in the final formatted number.","title":"Wrapping format elements - Money.Cldr.Number.to_string/2","ref":"Money.Cldr.Number.html#to_string/2-wrapping-format-elements"},{"type":"function","doc":"* `{:ok, string}` or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Cldr.Number.to_string/2","ref":"Money.Cldr.Number.html#to_string/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Number.to_string 12345\n    {:ok, \"12,345\"}\n\n    iex> Money.Cldr.Number.to_string 12345, locale: \"fr\"\n    {:ok, \"12 345\"}\n\n    iex> Money.Cldr.Number.to_string 1345.32, currency: :EUR, locale: \"es\", minimum_grouping_digits: 1\n    {:ok, \"1.345,32 €\"}\n\n    iex> Money.Cldr.Number.to_string 1345.32, currency: :EUR, locale: \"es\"\n    {:ok, \"1345,32 €\"}\n\n    iex> Money.Cldr.Number.to_string 12345, locale: \"fr\", currency: \"USD\"\n    {:ok, \"12 345,00 $US\"}\n\n    iex> Money.Cldr.Number.to_string 12345, format: \"#E0\"\n    {:ok, \"1.2345E4\"}\n\n    iex> Money.Cldr.Number.to_string 12345, format: :accounting, currency: \"THB\"\n    {:ok, \"THB 12,345.00\"}\n\n    iex> Money.Cldr.Number.to_string -12345, format: :accounting, currency: \"THB\"\n    {:ok, \"(THB 12,345.00)\"}\n\n    iex> Money.Cldr.Number.to_string 12345, format: :accounting, currency: \"THB\",\n    ...> locale: \"th\"\n    {:ok, \"฿12,345.00\"}\n\n    iex> Money.Cldr.Number.to_string 12345, format: :accounting, currency: \"THB\",\n    ...> locale: \"th\", number_system: :native\n    {:ok, \"฿๑๒,๓๔๕.๐๐\"}\n\n    iex> Money.Cldr.Number.to_string 1244.30, format: :long\n    {:ok, \"1 thousand\"}\n\n    iex> Money.Cldr.Number.to_string 1244.30, format: :long, currency: \"USD\"\n    {:ok, \"1,244 US dollars\"}\n\n    iex> Money.Cldr.Number.to_string 1244.30, format: :short\n    {:ok, \"1K\"}\n\n    iex> Money.Cldr.Number.to_string 1244.30, format: :short, currency: \"EUR\"\n    {:ok, \"€1K\"}\n\n    iex> Money.Cldr.Number.to_string 1234, format: :spellout\n    {:ok, \"one thousand two hundred thirty-four\"}\n\n    iex> Money.Cldr.Number.to_string 1234, format: :spellout_verbose\n    {:ok, \"one thousand two hundred and thirty-four\"}\n\n    iex> Money.Cldr.Number.to_string 1989, format: :spellout_year\n    {:ok, \"nineteen eighty-nine\"}\n\n    iex> Money.Cldr.Number.to_string 123, format: :ordinal\n    {:ok, \"123rd\"}\n\n    iex> Money.Cldr.Number.to_string 123, format: :roman\n    {:ok, \"CXXIII\"}\n\n    iex> Money.Cldr.Number.to_string 123, locale: \"th-u-nu-thai\"\n    {:ok, \"๑๒๓\"}","title":"Examples - Money.Cldr.Number.to_string/2","ref":"Money.Cldr.Number.html#to_string/2-examples"},{"type":"function","doc":"An error tuple `{:error, reason}` will be returned if an error is detected.\nThe two most likely causes of an error return are:\n\n  * A format cannot be compiled. In this case the error tuple will look like:\n\n```\n    iex> Money.Cldr.Number.to_string(12345, format: \"0#\")\n    {:error, {Cldr.FormatCompileError,\n      \"Decimal format compiler: syntax error before: \\\"#\\\"\"}}\n```\n\n  * The format style requested is not defined for the `locale` and\n    `number_system`. This happens typically when the number system is\n    `:algorithmic` rather than the more common `:numeric`. In this case the error\n    return looks like:\n\n```\n    iex> Money.Cldr.Number.to_string(1234, locale: \"he\", number_system: \"hebr\", format: :percent)\n    {:error, {Cldr.UnknownFormatError,\n      \"The locale :he with number system :hebr does not define a format :percent\"}}\n```","title":"Errors - Money.Cldr.Number.to_string/2","ref":"Money.Cldr.Number.html#to_string/2-errors"},{"type":"function","doc":"Same as the execution of `to_string/2` but raises an exception if an error would be\nreturned.","title":"Money.Cldr.Number.to_string!/2","ref":"Money.Cldr.Number.html#to_string!/2"},{"type":"function","doc":"* `number` is an integer, float or Decimal to be formatted\n\n* `options` is a keyword list defining how the number is to be formatted. See\n  `Money.Cldr.Number.to_string/2`","title":"Arguments - Money.Cldr.Number.to_string!/2","ref":"Money.Cldr.Number.html#to_string!/2-arguments"},{"type":"function","doc":"* a formatted number as a string or\n\n* raises an exception","title":"Returns - Money.Cldr.Number.to_string!/2","ref":"Money.Cldr.Number.html#to_string!/2-returns"},{"type":"function","doc":"iex> Money.Cldr.Number.to_string! 12345\n    \"12,345\"\n\n    iex> Money.Cldr.Number.to_string! 12345, locale: \"fr\"\n    \"12 345\"","title":"Examples - Money.Cldr.Number.to_string!/2","ref":"Money.Cldr.Number.html#to_string!/2-examples"},{"type":"function","doc":"Return a valid number system from a provided locale and number\nsystem name or type.\n\nThe number system or number system type must be valid for the\ngiven locale.  If a number system type is provided, the\nunderlying number system is returned.","title":"Money.Cldr.Number.validate_number_system/2","ref":"Money.Cldr.Number.html#validate_number_system/2"},{"type":"function","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n\n* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`","title":"Arguments - Money.Cldr.Number.validate_number_system/2","ref":"Money.Cldr.Number.html#validate_number_system/2-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.validate_number_system \"en\", :latn\n    {:ok, :latn}\n\n    iex> Money.Cldr.Number.validate_number_system \"en\", :default\n    {:ok, :latn}\n\n    iex> Money.Cldr.Number.validate_number_system \"en\", :unknown\n    {:error,\n     {Cldr.UnknownNumberSystemError, \"The number system :unknown is unknown\"}}\n\n    iex> Money.Cldr.Number.validate_number_system \"zz\", :default\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zz\\\" is invalid\"}}","title":"Examples - Money.Cldr.Number.validate_number_system/2","ref":"Money.Cldr.Number.html#validate_number_system/2-examples"},{"type":"module","doc":"Implements cardinal plural rules for numbers.","title":"Money.Cldr.Number.Cardinal","ref":"Money.Cldr.Number.Cardinal.html"},{"type":"function","doc":"The locale names for which plural rules are defined.","title":"Money.Cldr.Number.Cardinal.available_locale_names/0","ref":"Money.Cldr.Number.Cardinal.html#available_locale_names/0"},{"type":"function","doc":"The configured locales for which plural rules are defined.\n\nReturns the intersection of `Money.Cldr.known_locale_names/0` and\nthe locales for which Cardinal plural rules are defined.\n\nThere are many `Cldr` locales which don't have their own plural\nrules so this list is the intersection of `Cldr`'s configured\nlocales and those that have rules.","title":"Money.Cldr.Number.Cardinal.known_locale_names/0","ref":"Money.Cldr.Number.Cardinal.html#known_locale_names/0"},{"type":"function","doc":"Return the plural key for a given number in a given locale\n\nReturns which plural key (`:zero`, `:one`, `:two`, `:few`,\n`:many` or `:other`) a given number fits into within the\ncontext of a given locale.\n\nNote that these key names should not be interpreted\nliterally.  For example, the key returned from\n`Cldr.Number.Ordinal.plural_rule(0, \"en\")` is actually\n`:other`, not `:zero`.\n\nThis key can then be used to format a number, date, time, unit,\nlist or other content in a plural-sensitive way.","title":"Money.Cldr.Number.Cardinal.plural_rule/3","ref":"Money.Cldr.Number.Cardinal.html#plural_rule/3"},{"type":"function","doc":"* `number` is any `integer`, `float` or `Decimal`\n\n* `locale` is any locale returned by `Cldr.Locale.new!/2` or any\n  `locale_name` returned by `Money.Cldr.known_locale_names/0`\n\n* `rounding` is one of `[:down, :up, :ceiling, :floor, :half_even, :half_up, :half_down]`.  The\n  default is `:half_even`.","title":"Arguments - Money.Cldr.Number.Cardinal.plural_rule/3","ref":"Money.Cldr.Number.Cardinal.html#plural_rule/3-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.Cardinal.plural_rule 0, \"fr\"\n    :one\n\n    iex> Money.Cldr.Number.Cardinal.plural_rule 0, \"en\"\n    :other","title":"Examples - Money.Cldr.Number.Cardinal.plural_rule/3","ref":"Money.Cldr.Number.Cardinal.html#plural_rule/3-examples"},{"type":"function","doc":"Returns all the plural rules defined in CLDR.","title":"Money.Cldr.Number.Cardinal.plural_rules/0","ref":"Money.Cldr.Number.Cardinal.html#plural_rules/0"},{"type":"function","doc":"Return the plural rules for a locale.","title":"Money.Cldr.Number.Cardinal.plural_rules_for/1","ref":"Money.Cldr.Number.Cardinal.html#plural_rules_for/1"},{"type":"function","doc":"* `locale` is any locale returned by `Money.Cldr.Locale.new!/1` or any\n  `locale_name` returned by `Money.Cldr.known_locale_names/0`\n\nThe rules are returned in AST form after parsing.","title":"Arguments - Money.Cldr.Number.Cardinal.plural_rules_for/1","ref":"Money.Cldr.Number.Cardinal.html#plural_rules_for/1-arguments"},{"type":"function","doc":"Pluralize a number using cardinal plural rules\nand a substitution map.","title":"Money.Cldr.Number.Cardinal.pluralize/3","ref":"Money.Cldr.Number.Cardinal.html#pluralize/3"},{"type":"function","doc":"* `number` is an integer, float or Decimal\n\n* `locale` is any locale returned by `Money.Cldr.Locale.new!/1` or any\n  `locale_name` returned by `Money.Cldr.known_locale_names/0`\n\n* `substitutions` is a map that maps plural keys to a string.\n  The valid substitution keys are `:zero`, `:one`, `:two`,\n  `:few`, `:many` and `:other`.\n\nSee also `Money.Cldr.Number.Cardinal.Cardinal.plural_rule/3`.","title":"Arguments - Money.Cldr.Number.Cardinal.pluralize/3","ref":"Money.Cldr.Number.Cardinal.html#pluralize/3-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.Cardinal.pluralize 1, \"en\", %{one: \"one\"}\n    \"one\"\n\n    iex> Money.Cldr.Number.Cardinal.pluralize 2, \"en\", %{one: \"one\"}\n    nil\n\n    iex> Money.Cldr.Number.Cardinal.pluralize 2, \"en\", %{one: \"one\", two: \"two\", other: \"other\"}\n    \"other\"\n\n    iex> Money.Cldr.Number.Cardinal.pluralize 22, \"en\", %{one: \"one\", two: \"two\", other: \"other\"}\n    \"other\"\n\n    iex> Money.Cldr.Number.Cardinal.pluralize Decimal.new(1), \"en\", %{one: \"one\"}\n    \"one\"\n\n    iex> Money.Cldr.Number.Cardinal.pluralize Decimal.new(2), \"en\", %{one: \"one\"}\n    nil\n\n    iex> Money.Cldr.Number.Cardinal.pluralize Decimal.new(2), \"en\", %{one: \"one\", two: \"two\"}\n    nil\n\n    iex> Money.Cldr.Number.Cardinal.pluralize 1..10, \"ar\", %{one: \"one\", few: \"few\", other: \"other\"}\n    \"few\"\n\n    iex> Money.Cldr.Number.Cardinal.pluralize 1..10, \"en\", %{one: \"one\", few: \"few\", other: \"other\"}\n    \"other\"","title":"Examples - Money.Cldr.Number.Cardinal.pluralize/3","ref":"Money.Cldr.Number.Cardinal.html#pluralize/3-examples"},{"type":"module","doc":"Functions to manage the collection of number patterns defined in Cldr.\n\nNumber patterns affect how numbers are interpreted in a localized context.\nHere are some examples, based on the French locale. The \".\" shows where the\ndecimal point should go. The \",\" shows where the thousands separator should\ngo. A \"0\" indicates zero-padding: if the number is too short, a zero (in the\nlocale's numeric set) will go there. A \"#\" indicates no padding: if the\nnumber is too short, nothing goes there. A \"¤\" shows where the currency sign\nwill go. The following illustrates the effects of different patterns for the\nFrench locale, with the number \"1234.567\". Notice how the pattern characters\n',' and '.' are replaced by the characters appropriate for the locale.","title":"Money.Cldr.Number.Format","ref":"Money.Cldr.Number.Format.html"},{"type":"module","doc":"| Pattern\t      | Currency\t      | Text        |\n| ------------- | :-------------: | ----------: |\n| #,##0.##\t    | n/a\t            | 1 234,57    |\n| #,##0.###\t    | n/a\t            | 1 234,567   |\n| ###0.#####\t  | n/a\t            | 1234,567    |\n| ###0.0000#\t  | n/a\t            | 1234,5670   |\n| 00000.0000\t  | n/a\t            | 01234,5670  |\n| #,##0.00 ¤\t  | EUR\t            | 1 234,57 €  |\n\nThe number of # placeholder characters before the decimal do not matter,\nsince no limit is placed on the maximum number of digits. There should,\nhowever, be at least one zero some place in the pattern. In currency formats,\nthe number of digits after the decimal also do not matter, since the\ninformation in the supplemental data (see Supplemental Currency Data) is used\nto override the number of decimal places — and the rounding — according to\nthe currency that is being formatted. That can be seen in the above chart,\nwith the difference between Yen and Euro formatting.\n\nDetails of the number formats are described in the\n[Unicode documentation](http://unicode.org/reports/tr35/tr35-numbers.html#Number_Format_Patterns)","title":"Number Pattern Examples - Money.Cldr.Number.Format","ref":"Money.Cldr.Number.Format.html#module-number-pattern-examples"},{"type":"function","doc":"Returns the decimal formats defined for a given locale.","title":"Money.Cldr.Number.Format.all_formats_for/1","ref":"Money.Cldr.Number.Format.html#all_formats_for/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by\n  `Money.Cldr.Locale.new!/1`. The default\n  is `Money.Cldr.get_locale/0`.","title":"Arguments - Money.Cldr.Number.Format.all_formats_for/1","ref":"Money.Cldr.Number.Format.html#all_formats_for/1-arguments"},{"type":"function","doc":"* `{:ok, map}` where map is a map of decimal formats\n  keyed by number system or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Cldr.Number.Format.all_formats_for/1","ref":"Money.Cldr.Number.Format.html#all_formats_for/1-returns"},{"type":"function","doc":"Returns the decimal formats defined for a given locale.","title":"Money.Cldr.Number.Format.all_formats_for!/1","ref":"Money.Cldr.Number.Format.html#all_formats_for!/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by\n  `Money.Cldr.Locale.new!/1`. The default\n  is `Money.Cldr.get_locale/0`.","title":"Arguments - Money.Cldr.Number.Format.all_formats_for!/1","ref":"Money.Cldr.Number.Format.html#all_formats_for!/1-arguments"},{"type":"function","doc":"* `{:ok, map}` where map is a map of decimal formats\n  keyed by number system or\n\n* raises an exception.\n\nSee `Money.Cldr.Number.Format.Number.Format.all_formats_for/1` for further information.","title":"Returns - Money.Cldr.Number.Format.all_formats_for!/1","ref":"Money.Cldr.Number.Format.html#all_formats_for!/1-returns"},{"type":"function","doc":"Returns the currency space for a given locale and\nnumber system.","title":"Money.Cldr.Number.Format.currency_spacing/2","ref":"Money.Cldr.Number.Format.html#currency_spacing/2"},{"type":"function","doc":"Returns the list of decimal formats in the configured locales including\nthe list of locales configured for precompilation in `config.exs`.\n\nThis function exists to allow the decimal formatter\nto precompile all the known formats at compile time.","title":"Money.Cldr.Number.Format.decimal_format_list/0","ref":"Money.Cldr.Number.Format.html#decimal_format_list/0"},{"type":"function","doc":"#=> Money.Cldr.Number.Format.Format.decimal_format_list\n    [\"#\", \"#,##,##0%\",\n    \"#,##,##0.###\", \"#,##,##0.00¤\", \"#,##,##0.00¤;(#,##,##0.00¤)\",\n    \"#,##,##0 %\", \"#,##0%\", \"#,##0.###\", \"#,##0.00 ¤\",\n    \"#,##0.00 ¤;(#,##0.00 ¤)\", \"#,##0.00¤\", \"#,##0.00¤;(#,##0.00¤)\",\n    \"#,##0 %\", \"#0%\", \"#0.######\", \"#0.00 ¤\", \"#E0\", \"%#,##0\", \"% #,##0\",\n    \"0\", \"0.000000E+000\", \"0000 M ¤\", \"0000¤\", \"000G ¤\", \"000K ¤\", \"000M ¤\",\n    \"000T ¤\", \"000mM ¤\", \"000m ¤\", \"000 Bio'.' ¤\", \"000 Bln ¤\", \"000 Bn ¤\",\n    \"000 B ¤\", \"000 E ¤\", \"000 K ¤\", \"000 MRD ¤\", \"000 Md ¤\", \"000 Mio'.' ¤\",\n    \"000 Mio ¤\", \"000 Mld ¤\", \"000 Mln ¤\", \"000 Mn ¤\", \"000 Mrd'.' ¤\",\n    \"000 Mrd ¤\", \"000 Mr ¤\", \"000 M ¤\", \"000 NT ¤\", \"000 N ¤\", \"000 Tn ¤\",\n    \"000 Tr ¤\", ...]","title":"Example - Money.Cldr.Number.Format.decimal_format_list/0","ref":"Money.Cldr.Number.Format.html#decimal_format_list/0-example"},{"type":"function","doc":"Returns the list of decimal formats for a configured locale.","title":"Money.Cldr.Number.Format.decimal_format_list_for/1","ref":"Money.Cldr.Number.Format.html#decimal_format_list_for/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by\n  `Money.Cldr.Locale.new!/1`. The default\n  is `Money.Cldr.get_locale/0`.\n\nThis function exists to allow the decimal formatter to precompile all\nthe known formats at compile time. Its use is not otherwise recommended.","title":"Arguments - Money.Cldr.Number.Format.decimal_format_list_for/1","ref":"Money.Cldr.Number.Format.html#decimal_format_list_for/1-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.Format.decimal_format_list_for(:en)\n    {:ok, [\"#,##0%\", \"#,##0.###\", \"#,##0.00\", \"#,##0.00;(#,##0.00)\",\"#E0\",\n     \"0 billion\", \"0 million\", \"0 thousand\",\n     \"0 trillion\", \"00 billion\", \"00 million\", \"00 thousand\", \"00 trillion\",\n     \"000 billion\", \"000 million\", \"000 thousand\", \"000 trillion\", \"000B\", \"000K\",\n     \"000M\", \"000T\", \"00B\", \"00K\", \"00M\", \"00T\", \"0B\", \"0K\", \"0M\", \"0T\",\n     \"¤#,##0.00\", \"¤#,##0.00;(¤#,##0.00)\", \"¤000B\", \"¤000K\", \"¤000M\",\n     \"¤000T\", \"¤00B\", \"¤00K\", \"¤00M\", \"¤00T\", \"¤0B\", \"¤0K\", \"¤0M\", \"¤0T\",\n     \"¤ #,##0.00\", \"¤ #,##0.00;(¤ #,##0.00)\", \"¤ 000B\", \"¤ 000K\", \"¤ 000M\",\n     \"¤ 000T\", \"¤ 00B\", \"¤ 00K\", \"¤ 00M\", \"¤ 00T\", \"¤ 0B\", \"¤ 0K\", \"¤ 0M\", \"¤ 0T\"]}","title":"Example - Money.Cldr.Number.Format.decimal_format_list_for/1","ref":"Money.Cldr.Number.Format.html#decimal_format_list_for/1-example"},{"type":"function","doc":"Returns the default grouping for a locale as a map.","title":"Money.Cldr.Number.Format.default_grouping_for/1","ref":"Money.Cldr.Number.Format.html#default_grouping_for/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by\n  `Money.Cldr.Locale.new!/1`. The default\n  is `Money.Cldr.get_locale/0`.","title":"Arguments - Money.Cldr.Number.Format.default_grouping_for/1","ref":"Money.Cldr.Number.Format.html#default_grouping_for/1-arguments"},{"type":"function","doc":"* `{:ok, grouping}` or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Cldr.Number.Format.default_grouping_for/1","ref":"Money.Cldr.Number.Format.html#default_grouping_for/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Number.Format.default_grouping_for(:en)\n    {:ok, %{fraction: %{first: 0, rest: 0}, integer: %{first: 3, rest: 3}}}","title":"Examples - Money.Cldr.Number.Format.default_grouping_for/1","ref":"Money.Cldr.Number.Format.html#default_grouping_for/1-examples"},{"type":"function","doc":"Returns the default grouping for a locale\nor raises on error.","title":"Money.Cldr.Number.Format.default_grouping_for!/1","ref":"Money.Cldr.Number.Format.html#default_grouping_for!/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by\n  `Money.Cldr.Locale.new!/1`. The default\n  is `Money.Cldr.get_locale/0`.","title":"Arguments - Money.Cldr.Number.Format.default_grouping_for!/1","ref":"Money.Cldr.Number.Format.html#default_grouping_for!/1-arguments"},{"type":"function","doc":"* `grouping` as a map or\n\n* raises an exception.","title":"Returns - Money.Cldr.Number.Format.default_grouping_for!/1","ref":"Money.Cldr.Number.Format.html#default_grouping_for!/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Number.Format.default_grouping_for!(:en)\n    %{fraction: %{first: 0, rest: 0}, integer: %{first: 3, rest: 3}}","title":"Examples - Money.Cldr.Number.Format.default_grouping_for!/1","ref":"Money.Cldr.Number.Format.html#default_grouping_for!/1-examples"},{"type":"function","doc":"Return the predfined formats for a given `locale` and `number_system`.","title":"Money.Cldr.Number.Format.formats_for/2","ref":"Money.Cldr.Number.Format.html#formats_for/2"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by\n  `Money.Cldr.Locale.new!/1`. The default\n  is `Money.Cldr.get_locale/0`.\n\n* `number_system` is any valid number system or number system type returned\n  by `Money.Cldr.Number.System.number_systems_for/1`.","title":"Arguments - Money.Cldr.Number.Format.formats_for/2","ref":"Money.Cldr.Number.Format.html#formats_for/2-arguments"},{"type":"function","doc":"Money.Cldr.Number.Format.formats_for :fr, :native\n    #=> %Cldr.Number.Format{\n      accounting: \"#,##0.00 ¤;(#,##0.00 ¤)\",\n      currency: \"#,##0.00 ¤\",\n      percent: \"#,##0 %\",\n      scientific: \"#E0\",\n      standard: \"#,##0.###\"\n      currency_short: [{\"1000\", [one: \"0 k ¤\", other: \"0 k ¤\"]},\n       {\"10000\", [one: \"00 k ¤\", other: \"00 k ¤\"]},\n       {\"100000\", [one: \"000 k ¤\", other: \"000 k ¤\"]},\n       {\"1000000\", [one: \"0 M ¤\", other: \"0 M ¤\"]},\n       {\"10000000\", [one: \"00 M ¤\", other: \"00 M ¤\"]},\n       {\"100000000\", [one: \"000 M ¤\", other: \"000 M ¤\"]},\n       {\"1000000000\", [one: \"0 Md ¤\", other: \"0 Md ¤\"]},\n       {\"10000000000\", [one: \"00 Md ¤\", other: \"00 Md ¤\"]},\n       {\"100000000000\", [one: \"000 Md ¤\", other: \"000 Md ¤\"]},\n       {\"1000000000000\", [one: \"0 Bn ¤\", other: \"0 Bn ¤\"]},\n       {\"10000000000000\", [one: \"00 Bn ¤\", other: \"00 Bn ¤\"]},\n       {\"100000000000000\", [one: \"000 Bn ¤\", other: \"000 Bn ¤\"]}],\n       ...\n      }","title":"Example - Money.Cldr.Number.Format.formats_for/2","ref":"Money.Cldr.Number.Format.html#formats_for/2-example"},{"type":"function","doc":"","title":"Money.Cldr.Number.Format.formats_for!/2","ref":"Money.Cldr.Number.Format.html#formats_for!/2"},{"type":"function","doc":"Returns the minimum grouping digits for a locale.","title":"Money.Cldr.Number.Format.minimum_grouping_digits_for/1","ref":"Money.Cldr.Number.Format.html#minimum_grouping_digits_for/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by\n  `Money.Cldr.Locale.new!/1`. The default\n  is `Money.Cldr.get_locale/0`.","title":"Arguments - Money.Cldr.Number.Format.minimum_grouping_digits_for/1","ref":"Money.Cldr.Number.Format.html#minimum_grouping_digits_for/1-arguments"},{"type":"function","doc":"* `{:ok, minumum_digits}` or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Cldr.Number.Format.minimum_grouping_digits_for/1","ref":"Money.Cldr.Number.Format.html#minimum_grouping_digits_for/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Number.Format.minimum_grouping_digits_for(\"en\")\n    {:ok, 1}","title":"Examples - Money.Cldr.Number.Format.minimum_grouping_digits_for/1","ref":"Money.Cldr.Number.Format.html#minimum_grouping_digits_for/1-examples"},{"type":"function","doc":"Returns the minimum grouping digits for a locale\nor raises on error.","title":"Money.Cldr.Number.Format.minimum_grouping_digits_for!/1","ref":"Money.Cldr.Number.Format.html#minimum_grouping_digits_for!/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by\n  `Money.Cldr.Locale.new!/1`. The default\n  is `Money.Cldr.get_locale/0`.","title":"Arguments - Money.Cldr.Number.Format.minimum_grouping_digits_for!/1","ref":"Money.Cldr.Number.Format.html#minimum_grouping_digits_for!/1-arguments"},{"type":"function","doc":"* `minumum_digits` or\n\n* raises an exception.","title":"Returns - Money.Cldr.Number.Format.minimum_grouping_digits_for!/1","ref":"Money.Cldr.Number.Format.html#minimum_grouping_digits_for!/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Number.Format.minimum_grouping_digits_for!(\"en\")\n    1","title":"Examples - Money.Cldr.Number.Format.minimum_grouping_digits_for!/1","ref":"Money.Cldr.Number.Format.html#minimum_grouping_digits_for!/1-examples"},{"type":"module","doc":"","title":"Money.Cldr.Number.Formatter.Decimal","ref":"Money.Cldr.Number.Formatter.Decimal.html"},{"type":"function","doc":"","title":"Money.Cldr.Number.Formatter.Decimal.metadata!/1","ref":"Money.Cldr.Number.Formatter.Decimal.html#metadata!/1"},{"type":"function","doc":"Formats a number according to a decimal format string.","title":"Money.Cldr.Number.Formatter.Decimal.to_string/3","ref":"Money.Cldr.Number.Formatter.Decimal.html#to_string/3"},{"type":"function","doc":"* `number` is an integer, float or Decimal\n\n* `format` is a format string.  See `Money.Cldr.Number` for further information.\n\n* `options` is a map of options.  See `Money.Cldr.Number.to_string/2`\n  for further information.","title":"Arguments - Money.Cldr.Number.Formatter.Decimal.to_string/3","ref":"Money.Cldr.Number.Formatter.Decimal.html#to_string/3-arguments"},{"type":"module","doc":"Implements ordinal plural rules for numbers.","title":"Money.Cldr.Number.Ordinal","ref":"Money.Cldr.Number.Ordinal.html"},{"type":"function","doc":"The locale names for which plural rules are defined.","title":"Money.Cldr.Number.Ordinal.available_locale_names/0","ref":"Money.Cldr.Number.Ordinal.html#available_locale_names/0"},{"type":"function","doc":"The configured locales for which plural rules are defined.\n\nReturns the intersection of `Money.Cldr.known_locale_names/0` and\nthe locales for which Ordinal plural rules are defined.\n\nThere are many `Cldr` locales which don't have their own plural\nrules so this list is the intersection of `Cldr`'s configured\nlocales and those that have rules.","title":"Money.Cldr.Number.Ordinal.known_locale_names/0","ref":"Money.Cldr.Number.Ordinal.html#known_locale_names/0"},{"type":"function","doc":"Return the plural key for a given number in a given locale\n\nReturns which plural key (`:zero`, `:one`, `:two`, `:few`,\n`:many` or `:other`) a given number fits into within the\ncontext of a given locale.\n\nNote that these key names should not be interpreted\nliterally.  For example, the key returned from\n`Cldr.Number.Ordinal.plural_rule(0, \"en\")` is actually\n`:other`, not `:zero`.\n\nThis key can then be used to format a number, date, time, unit,\nlist or other content in a plural-sensitive way.","title":"Money.Cldr.Number.Ordinal.plural_rule/3","ref":"Money.Cldr.Number.Ordinal.html#plural_rule/3"},{"type":"function","doc":"* `number` is any `integer`, `float` or `Decimal`\n\n* `locale` is any locale returned by `Cldr.Locale.new!/2` or any\n  `locale_name` returned by `Money.Cldr.known_locale_names/0`\n\n* `rounding` is one of `[:down, :up, :ceiling, :floor, :half_even, :half_up, :half_down]`.  The\n  default is `:half_even`.","title":"Arguments - Money.Cldr.Number.Ordinal.plural_rule/3","ref":"Money.Cldr.Number.Ordinal.html#plural_rule/3-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.Ordinal.plural_rule 0, \"fr\"\n    :other\n\n    iex> Money.Cldr.Number.Ordinal.plural_rule 1, \"en\"\n    :one","title":"Examples - Money.Cldr.Number.Ordinal.plural_rule/3","ref":"Money.Cldr.Number.Ordinal.html#plural_rule/3-examples"},{"type":"function","doc":"Returns all the plural rules defined in CLDR.","title":"Money.Cldr.Number.Ordinal.plural_rules/0","ref":"Money.Cldr.Number.Ordinal.html#plural_rules/0"},{"type":"function","doc":"Return the plural rules for a locale.","title":"Money.Cldr.Number.Ordinal.plural_rules_for/1","ref":"Money.Cldr.Number.Ordinal.html#plural_rules_for/1"},{"type":"function","doc":"* `locale` is any locale returned by `Money.Cldr.Locale.new!/1` or any\n  `locale_name` returned by `Money.Cldr.known_locale_names/0`\n\nThe rules are returned in AST form after parsing.","title":"Arguments - Money.Cldr.Number.Ordinal.plural_rules_for/1","ref":"Money.Cldr.Number.Ordinal.html#plural_rules_for/1-arguments"},{"type":"function","doc":"Pluralize a number using ordinal plural rules\nand a substitution map.","title":"Money.Cldr.Number.Ordinal.pluralize/3","ref":"Money.Cldr.Number.Ordinal.html#pluralize/3"},{"type":"function","doc":"* `number` is an integer, float or Decimal or a `Range.t{}`.  When a range, The\n  is that in any usage, the start value is strictly less than the end value,\n  and that no values are negative. Results for any cases that do not meet\n  these criteria are undefined.\n\n* `locale` is any locale returned by `Money.Cldr.Locale.new!/1` or any\n  `locale_name` returned by `Money.Cldr.known_locale_names/0`\n\n* `substitutions` is a map that maps plural keys to a string.\n  The valid substitution keys are `:zero`, `:one`, `:two`,\n  `:few`, `:many` and `:other`.\n\nSee also `Money.Cldr.Number.Ordinal.Ordinal.plural_rule/3`.","title":"Arguments - Money.Cldr.Number.Ordinal.pluralize/3","ref":"Money.Cldr.Number.Ordinal.html#pluralize/3-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.Ordinal.pluralize 1, :en, %{one: \"one\"}\n    \"one\"\n\n    iex> Money.Cldr.Number.Ordinal.pluralize 2, :en, %{one: \"one\"}\n    nil\n\n    iex> Money.Cldr.Number.Ordinal.pluralize 2, :en, %{one: \"one\", two: \"two\"}\n    \"two\"\n\n    iex> Money.Cldr.Number.Ordinal.pluralize 22, :en, %{one: \"one\", two: \"two\", other: \"other\"}\n    \"two\"\n\n    iex> Money.Cldr.Number.Ordinal.pluralize Decimal.new(1), :en, %{one: \"one\"}\n    \"one\"\n\n    iex> Money.Cldr.Number.Ordinal.pluralize Decimal.new(2), :en, %{one: \"one\"}\n    nil\n\n    iex> Money.Cldr.Number.Ordinal.pluralize Decimal.new(2), :en, %{one: \"one\", two: \"two\"}\n    \"two\"\n\n    iex> Money.Cldr.Number.Ordinal.pluralize 1..10, \"ar\", %{one: \"one\", few: \"few\", other: \"other\"}\n    \"other\"\n\n    iex> Money.Cldr.Number.Ordinal.pluralize 1..10, \"en\", %{one: \"one\", few: \"few\", other: \"other\"}\n    \"other\"","title":"Examples - Money.Cldr.Number.Ordinal.pluralize/3","ref":"Money.Cldr.Number.Ordinal.html#pluralize/3-examples"},{"type":"module","doc":"Implements plural rules for ranges","title":"Money.Cldr.Number.PluralRule.Range","ref":"Money.Cldr.Number.PluralRule.Range.html"},{"type":"function","doc":"Returns a final plural type for a start-of-range plural\ntype, an end-of-range plural type and a locale.","title":"Money.Cldr.Number.PluralRule.Range.plural_rule/3","ref":"Money.Cldr.Number.PluralRule.Range.html#plural_rule/3"},{"type":"function","doc":"* `first` is a plural type for the start of a range\n\n* `last` is a plural type for the end of a range\n\n* `locale` is any `Cldr.LanguageTag.t` or a language name\n  (not locale name)","title":"Arguments - Money.Cldr.Number.PluralRule.Range.plural_rule/3","ref":"Money.Cldr.Number.PluralRule.Range.html#plural_rule/3-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.PluralRule.Range.plural_rule :other, :few, \"ar\"\n    :few","title":"Example - Money.Cldr.Number.PluralRule.Range.plural_rule/3","ref":"Money.Cldr.Number.PluralRule.Range.html#plural_rule/3-example"},{"type":"module","doc":"","title":"Money.Cldr.Number.Symbol","ref":"Money.Cldr.Number.Symbol.html"},{"type":"function","doc":"Returns a list of all decimal symbols defined\nby the locales configured in this backend as\na list.","title":"Money.Cldr.Number.Symbol.all_decimal_symbols/0","ref":"Money.Cldr.Number.Symbol.html#all_decimal_symbols/0"},{"type":"function","doc":"Returns a list of all decimal symbols defined\nby the locales configured in this backend as\na string.\n\nThis string can be used as a character class\nwhen builing a regular expression.","title":"Money.Cldr.Number.Symbol.all_decimal_symbols_class/0","ref":"Money.Cldr.Number.Symbol.html#all_decimal_symbols_class/0"},{"type":"function","doc":"Returns a list of all grouping symbols defined\nby the locales configured in this backend as\na list.","title":"Money.Cldr.Number.Symbol.all_grouping_symbols/0","ref":"Money.Cldr.Number.Symbol.html#all_grouping_symbols/0"},{"type":"function","doc":"Returns a list of all grouping symbols defined\nby the locales configured in this backend as\na string.\n\nThis string can be used as a character class\nwhen builing a regular expression.","title":"Money.Cldr.Number.Symbol.all_grouping_symbols_class/0","ref":"Money.Cldr.Number.Symbol.html#all_grouping_symbols_class/0"},{"type":"function","doc":"Returns a map of `Cldr.Number.Symbol.t` structs of the number symbols for each\nof the number systems of a locale.","title":"Money.Cldr.Number.Symbol.number_symbols_for/1","ref":"Money.Cldr.Number.Symbol.html#number_symbols_for/1"},{"type":"function","doc":"* `locale` is any valid locale name returned by\n  `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by\n  `Money.Cldr.Locale.new!/1`. The default\n  is `Money.Cldr.get_locale/0`.","title":"Options - Money.Cldr.Number.Symbol.number_symbols_for/1","ref":"Money.Cldr.Number.Symbol.html#number_symbols_for/1-options"},{"type":"function","doc":"iex> Money.Cldr.Number.Symbol.number_symbols_for(:th)\n    {:ok, %{\n       latn: %Cldr.Number.Symbol{\n         decimal: \".\",\n         exponential: \"E\",\n         group: \",\",\n         infinity: \"∞\",\n         list: \";\",\n         minus_sign: \"-\",\n         nan: \"NaN\",\n         per_mille: \"‰\",\n         percent_sign: \"%\",\n         plus_sign: \"+\",\n         superscripting_exponent: \"×\",\n         time_separator: \":\"\n       },\n       thai: %Cldr.Number.Symbol{\n         decimal: \".\",\n         exponential: \"E\",\n         group: \",\",\n         infinity: \"∞\",\n         list: \";\",\n         minus_sign: \"-\",\n         nan: \"NaN\",\n         per_mille: \"‰\",\n         percent_sign: \"%\",\n         plus_sign: \"+\",\n         superscripting_exponent: \"×\",\n         time_separator: \":\"\n       }\n     }}","title":"Example: - Money.Cldr.Number.Symbol.number_symbols_for/1","ref":"Money.Cldr.Number.Symbol.html#number_symbols_for/1-example"},{"type":"function","doc":"","title":"Money.Cldr.Number.Symbol.number_symbols_for/2","ref":"Money.Cldr.Number.Symbol.html#number_symbols_for/2"},{"type":"module","doc":"","title":"Money.Cldr.Number.System","ref":"Money.Cldr.Number.System.html"},{"type":"function","doc":"Returns the actual number system from a number system type.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by ``Cldr.Locale.new!/2``\n\n* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`\n\nThis function will decode a number system type into the actual\nnumber system.  If the number system provided can't be decoded\nit is returned as is.","title":"Money.Cldr.Number.System.number_system_for/2","ref":"Money.Cldr.Number.System.html#number_system_for/2"},{"type":"function","doc":"iex> Money.Cldr.Number.System.number_system_for \"th\", :latn\n    {:ok, %{digits: \"0123456789\", type: :numeric}}\n\n    iex> Money.Cldr.Number.System.number_system_for \"en\", :default\n    {:ok, %{digits: \"0123456789\", type: :numeric}}\n\n    iex> Money.Cldr.Number.System.number_system_for \"he\", :traditional\n    {:ok, %{rules: \"hebrew\", type: :algorithmic}}\n\n    iex> Money.Cldr.Number.System.number_system_for \"en\", :native\n    {:ok, %{digits: \"0123456789\", type: :numeric}}\n\n    iex> Money.Cldr.Number.System.number_system_for \"en\", :finance\n    {\n      :error,\n      {Cldr.UnknownNumberSystemError,\n        \"The number system :finance is unknown for the locale named :en. Valid number systems are %{default: :latn, native: :latn}\"}\n    }","title":"Examples - Money.Cldr.Number.System.number_system_for/2","ref":"Money.Cldr.Number.System.html#number_system_for/2-examples"},{"type":"function","doc":"Returns the number system from a language tag or\nlocale name.","title":"Money.Cldr.Number.System.number_system_from_locale/1","ref":"Money.Cldr.Number.System.html#number_system_from_locale/1"},{"type":"function","doc":"* `locale` is any language tag returned be `Cldr.Locale.new/2`\n  or a locale name in the list returned by `Cldr.known_locale_names/1`","title":"Arguments - Money.Cldr.Number.System.number_system_from_locale/1","ref":"Money.Cldr.Number.System.html#number_system_from_locale/1-arguments"},{"type":"function","doc":"* A number system name as an atom","title":"Returns - Money.Cldr.Number.System.number_system_from_locale/1","ref":"Money.Cldr.Number.System.html#number_system_from_locale/1-returns"},{"type":"function","doc":"iex> Money.Cldr.Number.System.number_system_from_locale \"en-US-u-nu-thai\"\n    :thai\n\n    iex> Money.Cldr.Number.System.number_system_from_locale \"en-US\"\n    :latn","title":"Examples - Money.Cldr.Number.System.number_system_from_locale/1","ref":"Money.Cldr.Number.System.html#number_system_from_locale/1-examples"},{"type":"function","doc":"Returns the number systems available for a locale\nor `{:error, message}` if the locale is not known.\n\n* `locale` is any valid locale name returned by `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `Money.Cldr.Locale.new!/1`","title":"Money.Cldr.Number.System.number_system_names_for/1","ref":"Money.Cldr.Number.System.html#number_system_names_for/1"},{"type":"function","doc":"iex> Money.Cldr.Number.System.number_system_names_for \"en\"\n    {:ok, [:latn]}\n\n    iex> Money.Cldr.Number.System.number_system_names_for \"zz\"\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zz\\\" is invalid\"}}","title":"Examples - Money.Cldr.Number.System.number_system_names_for/1","ref":"Money.Cldr.Number.System.html#number_system_names_for/1-examples"},{"type":"function","doc":"","title":"Money.Cldr.Number.System.number_system_names_for!/1","ref":"Money.Cldr.Number.System.html#number_system_names_for!/1"},{"type":"function","doc":"","title":"Money.Cldr.Number.System.number_system_types_for/1","ref":"Money.Cldr.Number.System.html#number_system_types_for/1"},{"type":"function","doc":"Returns the number systems available for a locale\nor `{:error, message}` if the locale is not known.\n\n* `locale` is any valid locale name returned by `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `Money.Cldr.Locale.new!/1`","title":"Money.Cldr.Number.System.number_systems_for/1","ref":"Money.Cldr.Number.System.html#number_systems_for/1"},{"type":"function","doc":"iex> Money.Cldr.Number.System.number_systems_for \"en\"\n    {:ok, %{default: :latn, native: :latn}}\n\n    iex> Money.Cldr.Number.System.number_systems_for \"th\"\n    {:ok, %{default: :latn, native: :thai}}\n\n    iex> Money.Cldr.Number.System.number_systems_for \"zz\"\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zz\\\" is invalid\"}}","title":"Examples - Money.Cldr.Number.System.number_systems_for/1","ref":"Money.Cldr.Number.System.html#number_systems_for/1-examples"},{"type":"function","doc":"","title":"Money.Cldr.Number.System.number_systems_for!/1","ref":"Money.Cldr.Number.System.html#number_systems_for!/1"},{"type":"function","doc":"","title":"Money.Cldr.Number.System.number_systems_like/2","ref":"Money.Cldr.Number.System.html#number_systems_like/2"},{"type":"function","doc":"Returns a number system name for a given locale and number system reference.\n\n* `system_name` is any number system name returned by\n  `Money.Cldr.known_number_systems/0` or a number system type\n  returned by `Money.Cldr.known_number_system_types/0`\n\n* `locale` is any valid locale name returned by `Money.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `Money.Cldr.Locale.new!/1`\n\nNumber systems can be references in one of two ways:\n\n* As a number system type such as :default, :native, :traditional and\n  :finance. This allows references to a number system for a locale in a\n  consistent fashion for a given use\n\n* WIth the number system name directly, such as :latn, :arab or any of the\n  other 70 or so\n\nThis function dereferences the supplied `system_name` and returns the\nactual system name.","title":"Money.Cldr.Number.System.system_name_from/2","ref":"Money.Cldr.Number.System.html#system_name_from/2"},{"type":"function","doc":"ex> Money.Cldr.Number.System.system_name_from(:default, \"en\")\n    {:ok, :latn}\n\n    iex> Money.Cldr.Number.System.system_name_from(\"latn\", \"en\")\n    {:ok, :latn}\n\n    iex> Money.Cldr.Number.System.system_name_from(:native, \"en\")\n    {:ok, :latn}\n\n    iex> Money.Cldr.Number.System.system_name_from(:nope, \"en\")\n    {\n      :error,\n      {Cldr.UnknownNumberSystemError, \"The number system :nope is unknown\"}\n    }\n\nNote that return value is not guaranteed to be a valid\nnumber system for the given locale as demonstrated in the third example.","title":"Examples - Money.Cldr.Number.System.system_name_from/2","ref":"Money.Cldr.Number.System.html#system_name_from/2-examples"},{"type":"function","doc":"Converts a number into the representation of\na non-latin number system.\n\nThis function converts numbers to a known\nnumber system only, it does not provide number\nformatting.\n\n* `number` is a `float`, `integer` or `Decimal`\n\n* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/0`\n\nThere are two types of number systems in CLDR:\n\n* `:numeric` in which the number system defines\n  a direct mapping between the latin digits `0..9`\n  into a the number system equivalent.  In this case,\n` to_system/2` invokes `Cldr.Number.Transliterate.transliterate_digits/3`\n  for the given number.\n\n* `:algorithmic` in which the number system\n  does not have the same structure as the `:latn`\n  number system and therefore the conversion is\n  done algorithmically.  For CLDR the algorithm\n  is implemented through `Cldr.Rbnf` rulesets.\n  These rulesets are considered by CLDR to be\n  less rigorous than the `:numeric` number systems\n  and caution and testing for a specific use case\n  is recommended.","title":"Money.Cldr.Number.System.to_system/2","ref":"Money.Cldr.Number.System.html#to_system/2"},{"type":"function","doc":"iex> Money.Cldr.Number.System.to_system 123456, :hebr\n    {:ok, \"קכ״ג׳תנ״ו\"}\n\n    iex> Money.Cldr.Number.System.to_system 123, :hans\n    {:ok, \"一百二十三\"}\n\n    iex> Money.Cldr.Number.System.to_system 123, :hant\n    {:ok, \"一百二十三\"}\n\n    iex> Money.Cldr.Number.System.to_system 123, :hansfin\n    {:ok, \"壹佰贰拾叁\"}","title":"Examples - Money.Cldr.Number.System.to_system/2","ref":"Money.Cldr.Number.System.html#to_system/2-examples"},{"type":"function","doc":"Converts a number into the representation of\na non-latin number system. Returns a converted\nstring or raises on error.\n\n* `number` is a `float`, `integer` or `Decimal`\n\n* `system_name` is any number system name returned by\n  `Money.Cldr.known_number_systems/0` or a number system type\n  returned by `Money.Cldr.known_number_system_types/0`\n\nSee `Money.Cldr.Number.System.to_system/2` for further\ninformation.","title":"Money.Cldr.Number.System.to_system!/2","ref":"Money.Cldr.Number.System.html#to_system!/2"},{"type":"function","doc":"iex> Money.Cldr.Number.System.to_system! 123, :hans\n    \"一百二十三\"\n\n    iex> Money.Cldr.Number.System.to_system! 123, :hant\n    \"一百二十三\"\n\n    iex> Money.Cldr.Number.System.to_system! 123, :hansfin\n    \"壹佰贰拾叁\"","title":"Examples - Money.Cldr.Number.System.to_system!/2","ref":"Money.Cldr.Number.System.html#to_system!/2-examples"},{"type":"module","doc":"Transliteration for digits and separators.\n\nTransliterating a string is an expensive business.  First the string has to\nbe exploded into its component graphemes.  Then for each grapheme we have\nto map to the equivalent in the other `{locale, number_system}`.  Then we\nhave to reassemble the string.\n\nEffort is made to short circuit where possible. Transliteration is not\nrequired for any `{locale, number_system}` that is the same as `{\"en\",\n\"latn\"}` since the implementation uses this combination for the placeholders during\nformatting already. When short circuiting is possible (typically the en-*\nlocales with \"latn\" number_system - the total number of short circuited\nlocales is 211 of the 537 in CLDR) the overall number formatting is twice as\nfast than when formal transliteration is required.","title":"Money.Cldr.Number.Transliterate","ref":"Money.Cldr.Number.Transliterate.html"},{"type":"module","doc":"This module includes `Cldr.Number.Transliterate.transliterate_digits/3` which transliterates\ndigits between number systems.  For example from :arabic to :latn.  Since generating a\ntransliteration map is slow, pairs of transliterations can be configured so that the\ntransliteration map is created at compile time and therefore speeding up transliteration at\nrun time.\n\nTo configure these transliteration pairs, add the to the `use Cldr` configuration\nin a backend module:\n\n    defmodule MyApp.Cldr do\n      use Cldr,\n      locale: [\"en\", \"fr\", \"th\"],\n      default_locale: \"en\",\n      precompile_transliterations: [{:latn, :thai}, {:arab, :thai}]\n    end\n\nWhere each tuple in the list configures one transliteration map.  In this example, two maps are\nconfigured: from `:latn` to `:thai` and from `:arab` to `:thai`.\n\nA list of configurable number systems is returned by `Cldr.Number.System.numeric_systems/0`.\n\nIf a transliteration is requested between two number pairs that have not been configured for\nprecompilation, a warning is logged.","title":"Configuring precompilation of digit transliterations - Money.Cldr.Number.Transliterate","ref":"Money.Cldr.Number.Transliterate.html#module-configuring-precompilation-of-digit-transliterations"},{"type":"function","doc":"Transliterates from latin digits to another number system's digits.\n\nTransliterates the latin digits 0..9 to their equivalents in\nanother number system. Also transliterates the decimal and grouping\nseparators as well as the plus, minus and exponent symbols. Any other character\nin the string will be returned \"as is\".","title":"Money.Cldr.Number.Transliterate.transliterate/3","ref":"Money.Cldr.Number.Transliterate.html#transliterate/3"},{"type":"function","doc":"* `sequence` is the string to be transliterated.\n\n* `locale` is any known locale, defaulting to `Money.Cldr.get_locale/0`.\n\n* `number_system` is any known number system. If expressed as a `string` it\n  is the actual name of a known number system. If epressed as an `atom` it is\n  used as a key to look up a number system for the locale (the usual keys are\n  `:default` and `:native` but :traditional and :finance are also part of the\n  standard). See `Money.Cldr.Number.System.number_systems_for/1` for a locale to\n  see what number system types are defined. The default is `:default`.\n\nFor available number systems see `Cldr.Number.System.number_systems/0`\nand `Money.Cldr.Number.System.number_systems_for/1`.  Also see\n`Money.Cldr.Number.Symbol.number_symbols_for/1`.","title":"Arguments - Money.Cldr.Number.Transliterate.transliterate/3","ref":"Money.Cldr.Number.Transliterate.html#transliterate/3-arguments"},{"type":"function","doc":"iex> Money.Cldr.Number.Transliterate.transliterate(\"123556\")\n    \"123556\"\n\n    iex> Money.Cldr.Number.Transliterate.transliterate(\"123,556.000\", \"fr\", :default)\n    \"123 556,000\"\n\n    iex> Money.Cldr.Number.Transliterate.transliterate(\"123556\", \"th\", :default)\n    \"123556\"\n\n    iex> Money.Cldr.Number.Transliterate.transliterate(\"123556\", \"th\", \"thai\")\n    \"๑๒๓๕๕๖\"\n\n    iex> Money.Cldr.Number.Transliterate.transliterate(\"123556\", \"th\", :native)\n    \"๑๒๓๕๕๖\"\n\n    iex> Money.Cldr.Number.Transliterate.transliterate(\"Some number is: 123556\", \"th\", \"thai\")\n    \"Some number is: ๑๒๓๕๕๖\"","title":"Examples - Money.Cldr.Number.Transliterate.transliterate/3","ref":"Money.Cldr.Number.Transliterate.html#transliterate/3-examples"},{"type":"function","doc":"","title":"Money.Cldr.Number.Transliterate.transliterate!/3","ref":"Money.Cldr.Number.Transliterate.html#transliterate!/3"},{"type":"function","doc":"Transliterates digits from one number system to another number system\n\n* `digits` is binary representation of a number\n\n* `from_system` and `to_system` are number system names in atom form.  See\n`Cldr.Number.System.numeric_systems/0` for available number systems.","title":"Money.Cldr.Number.Transliterate.transliterate_digits/3","ref":"Money.Cldr.Number.Transliterate.html#transliterate_digits/3"},{"type":"function","doc":"iex> Money.Cldr.Number.Transliterate.transliterate_digits \"٠١٢٣٤٥٦٧٨٩\", :arab, :latn\n    \"0123456789\"","title":"Example - Money.Cldr.Number.Transliterate.transliterate_digits/3","ref":"Money.Cldr.Number.Transliterate.html#transliterate_digits/3-example"},{"type":"module","doc":"Functions to implement the number system rule-based-number-format rules of CLDR.\n\nThese rules are defined only on the \"und\" locale and represent specialised\nnumber formatting.\n\nThe standard public API for RBNF is via the `Cldr.Number.to_string/2` function.\n\nThe functions on this module are defined at compile time based upon the RBNF rules\ndefined in the Unicode CLDR data repository.  Available rules are identified by:\n\n    iex> Money.Cldr.Rbnf.NumberSystem.rule_sets(:und)\n    ...> |> Enum.sort()\n    [\n      :armenian_lower,\n      :armenian_upper,\n      :cyrillic_lower,\n      :ethiopic,\n      :georgian,\n      :greek_lower,\n      :greek_upper,\n      :hebrew,\n      :hebrew_item,\n      :roman_lower,\n      :roman_upper,\n      :tamil,\n      :zz_default\n    ]\n\nA rule can then be invoked on an available rule_set.  For example\n\n    iex> Money.Cldr.Rbnf.NumberSystem.roman_upper(123, :und)\n    \"CXXIII\"\n\nThis particular call is equivalent to the call through the public API of:\n\n    iex> Money.Cldr.Number.to_string(123, format: :roman)\n    {:ok, \"CXXIII\"}","title":"Money.Cldr.Rbnf.NumberSystem","ref":"Money.Cldr.Rbnf.NumberSystem.html"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.all_rule_sets/0","ref":"Money.Cldr.Rbnf.NumberSystem.html#all_rule_sets/0"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.armenian_lower/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#armenian_lower/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.armenian_lower/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#armenian_lower/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.armenian_upper/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#armenian_upper/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.armenian_upper/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#armenian_upper/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.cyrillic_lower/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#cyrillic_lower/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.cyrillic_lower/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#cyrillic_lower/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.cyrillic_lower_1_10/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#cyrillic_lower_1_10/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.cyrillic_lower_final/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#cyrillic_lower_final/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.cyrillic_lower_post/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#cyrillic_lower_post/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.cyrillic_lower_thousands/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#cyrillic_lower_thousands/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.ethiopic/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#ethiopic/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.ethiopic/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#ethiopic/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.ethiopic_p1/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#ethiopic_p1/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.ethiopic_p2/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#ethiopic_p2/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.ethiopic_p3/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#ethiopic_p3/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.ethiopic_p/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#ethiopic_p/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.georgian/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#georgian/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.georgian/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#georgian/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.greek_lower/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#greek_lower/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.greek_lower/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#greek_lower/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.greek_numeral_majuscules/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#greek_numeral_majuscules/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.greek_numeral_minuscules/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#greek_numeral_minuscules/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.greek_upper/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#greek_upper/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.greek_upper/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#greek_upper/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.hebrew/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#hebrew/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.hebrew/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#hebrew/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.hebrew_0_99/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#hebrew_0_99/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.hebrew_item/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#hebrew_item/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.hebrew_item/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#hebrew_item/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.hebrew_item_hundreds/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#hebrew_item_hundreds/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.hebrew_thousands/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#hebrew_thousands/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.roman_lower/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#roman_lower/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.roman_lower/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#roman_lower/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.roman_upper/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#roman_upper/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.roman_upper/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#roman_upper/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.rule_sets/0","ref":"Money.Cldr.Rbnf.NumberSystem.html#rule_sets/0"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.rule_sets/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#rule_sets/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.tamil/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#tamil/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.tamil/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#tamil/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.tamil_thousands/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#tamil_thousands/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.zz_default/1","ref":"Money.Cldr.Rbnf.NumberSystem.html#zz_default/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.NumberSystem.zz_default/2","ref":"Money.Cldr.Rbnf.NumberSystem.html#zz_default/2"},{"type":"module","doc":"Functions to implement the ordinal rule-based-number-format rules of CLDR.\n\nAs CLDR notes, the data is incomplete or non-existent for many languages.  It\nis considered complete for English however.\n\nThe standard public API for RBNF is via the `Cldr.Number.to_string/2` function.\n\nThe functions on this module are defined at compile time based upon the RBNF rules\ndefined in the Unicode CLDR data repository.  Available rules are identified by:\n\n    iex> Money.Cldr.Rbnf.Ordinal.rule_sets(:en)\n    [:digits_ordinal]\n\n    iex> Money.Cldr.Rbnf.Ordinal.rule_sets(\"fr\")\n    ...> |> Enum.sort()\n    [\n      :digits_ordinal,\n      :digits_ordinal_feminine,\n      :digits_ordinal_feminine_plural,\n      :digits_ordinal_masculine,\n      :digits_ordinal_masculine_plural\n    ]\n\nA rule can then be invoked on an available rule_set.  For example\n\n    iex> Money.Cldr.Rbnf.Ordinal.digits_ordinal(123, :en)\n    \"123rd\"\n\nThis call is equivalent to the call through the public API of:\n\n    iex> Money.Cldr.Number.to_string(123, format: :ordinal)\n    {:ok, \"123rd\"}","title":"Money.Cldr.Rbnf.Ordinal","ref":"Money.Cldr.Rbnf.Ordinal.html"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.all_rule_sets/0","ref":"Money.Cldr.Rbnf.Ordinal.html#all_rule_sets/0"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.digits_ordinal/2","ref":"Money.Cldr.Rbnf.Ordinal.html#digits_ordinal/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.digits_ordinal_feminine/2","ref":"Money.Cldr.Rbnf.Ordinal.html#digits_ordinal_feminine/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.digits_ordinal_feminine_plural/2","ref":"Money.Cldr.Rbnf.Ordinal.html#digits_ordinal_feminine_plural/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.digits_ordinal_masculine/2","ref":"Money.Cldr.Rbnf.Ordinal.html#digits_ordinal_masculine/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.digits_ordinal_masculine_adjective/2","ref":"Money.Cldr.Rbnf.Ordinal.html#digits_ordinal_masculine_adjective/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.digits_ordinal_masculine_plural/2","ref":"Money.Cldr.Rbnf.Ordinal.html#digits_ordinal_masculine_plural/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.dord_femabbrev/2","ref":"Money.Cldr.Rbnf.Ordinal.html#dord_femabbrev/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.dord_mascabbrev/2","ref":"Money.Cldr.Rbnf.Ordinal.html#dord_mascabbrev/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.rule_sets/0","ref":"Money.Cldr.Rbnf.Ordinal.html#rule_sets/0"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Ordinal.rule_sets/1","ref":"Money.Cldr.Rbnf.Ordinal.html#rule_sets/1"},{"type":"module","doc":"Functions to implement the spellout rule-based-number-format rules of CLDR.\n\nAs CLDR notes, the data is incomplete or non-existent for many languages.  It\nis considered complete for English however.\n\nThe standard public API for RBNF is via the `Cldr.Number.to_string/2` function.\n\nThe functions on this module are defined at compile time based upon the RBNF rules\ndefined in the Unicode CLDR data repository.  Available rules are identified by:\n\n    iex> Money.Cldr.Rbnf.Spellout.rule_sets(\"en\")\n    ...> |> Enum.sort()\n    [\n      :spellout_cardinal,\n      :spellout_cardinal_verbose,\n      :spellout_numbering,\n      :spellout_numbering_verbose,\n      :spellout_numbering_year,\n      :spellout_ordinal,\n      :spellout_ordinal_verbose\n    ]\n\nA rule can then be invoked on an available rule_set. For example:\n\n    iex> Money.Cldr.Rbnf.Spellout.spellout_ordinal(123, \"en\")\n    \"one hundred twenty-third\"\n\nThis call is equivalent to the call through the public API of:\n\n    iex> Money.Cldr.Number.to_string(123, format: :spellout)\n    {:ok, \"one hundred twenty-three\"}","title":"Money.Cldr.Rbnf.Spellout","ref":"Money.Cldr.Rbnf.Spellout.html"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.all_rule_sets/0","ref":"Money.Cldr.Rbnf.Spellout.html#all_rule_sets/0"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.alt_ones/2","ref":"Money.Cldr.Rbnf.Spellout.html#alt_ones/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.and/2","ref":"Money.Cldr.Rbnf.Spellout.html#and/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.and_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#and_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.and_small/2","ref":"Money.Cldr.Rbnf.Spellout.html#and_small/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.and_small_n/2","ref":"Money.Cldr.Rbnf.Spellout.html#and_small_n/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal2/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal2/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal3/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal3/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal4/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal4/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal5/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal5/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal8/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal8/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal13/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal13/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal_alternate2_2/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal_alternate2_2/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal_alternate2_3/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal_alternate2_3/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal_alternate2_4/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal_alternate2_4/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal_alternate2_5/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal_alternate2_5/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal_alternate2_8/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal_alternate2_8/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cardinal_alternate2_13/2","ref":"Money.Cldr.Rbnf.Spellout.html#cardinal_alternate2_13/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cents_f/2","ref":"Money.Cldr.Rbnf.Spellout.html#cents_f/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cents_m/2","ref":"Money.Cldr.Rbnf.Spellout.html#cents_m/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.cents_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#cents_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.commas/2","ref":"Money.Cldr.Rbnf.Spellout.html#commas/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.commas_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#commas_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.et_un/2","ref":"Money.Cldr.Rbnf.Spellout.html#et_un/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.et_une/2","ref":"Money.Cldr.Rbnf.Spellout.html#et_une/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.et_unieme/2","ref":"Money.Cldr.Rbnf.Spellout.html#et_unieme/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.fem_with_a/2","ref":"Money.Cldr.Rbnf.Spellout.html#fem_with_a/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.fem_with_i/2","ref":"Money.Cldr.Rbnf.Spellout.html#fem_with_i/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.fem_with_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#fem_with_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.financialnumber2/2","ref":"Money.Cldr.Rbnf.Spellout.html#financialnumber2/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.financialnumber3/2","ref":"Money.Cldr.Rbnf.Spellout.html#financialnumber3/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.financialnumber4/2","ref":"Money.Cldr.Rbnf.Spellout.html#financialnumber4/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.financialnumber5/2","ref":"Money.Cldr.Rbnf.Spellout.html#financialnumber5/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.financialnumber8/2","ref":"Money.Cldr.Rbnf.Spellout.html#financialnumber8/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.financialnumber13/2","ref":"Money.Cldr.Rbnf.Spellout.html#financialnumber13/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.lenient_parse/2","ref":"Money.Cldr.Rbnf.Spellout.html#lenient_parse/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.mille_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#mille_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.msc_no_final/2","ref":"Money.Cldr.Rbnf.Spellout.html#msc_no_final/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.msc_with_a/2","ref":"Money.Cldr.Rbnf.Spellout.html#msc_with_a/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.msc_with_a_nofinal/2","ref":"Money.Cldr.Rbnf.Spellout.html#msc_with_a_nofinal/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.msc_with_i/2","ref":"Money.Cldr.Rbnf.Spellout.html#msc_with_i/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.msc_with_i_nofinal/2","ref":"Money.Cldr.Rbnf.Spellout.html#msc_with_i_nofinal/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.msc_with_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#msc_with_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.msc_with_o_nofinal/2","ref":"Money.Cldr.Rbnf.Spellout.html#msc_with_o_nofinal/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.msco_with_a/2","ref":"Money.Cldr.Rbnf.Spellout.html#msco_with_a/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.msco_with_i/2","ref":"Money.Cldr.Rbnf.Spellout.html#msco_with_i/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.msco_with_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#msco_with_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.number2/2","ref":"Money.Cldr.Rbnf.Spellout.html#number2/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.number3/2","ref":"Money.Cldr.Rbnf.Spellout.html#number3/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.number4/2","ref":"Money.Cldr.Rbnf.Spellout.html#number4/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.number5/2","ref":"Money.Cldr.Rbnf.Spellout.html#number5/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.number8/2","ref":"Money.Cldr.Rbnf.Spellout.html#number8/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.number13/2","ref":"Money.Cldr.Rbnf.Spellout.html#number13/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.numbering_days/2","ref":"Money.Cldr.Rbnf.Spellout.html#numbering_days/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.optional_e/2","ref":"Money.Cldr.Rbnf.Spellout.html#optional_e/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ord_de_c/2","ref":"Money.Cldr.Rbnf.Spellout.html#ord_de_c/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ord_de_n/2","ref":"Money.Cldr.Rbnf.Spellout.html#ord_de_n/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ord_e_c/2","ref":"Money.Cldr.Rbnf.Spellout.html#ord_e_c/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ord_e_n/2","ref":"Money.Cldr.Rbnf.Spellout.html#ord_e_n/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ord_te_c/2","ref":"Money.Cldr.Rbnf.Spellout.html#ord_te_c/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ord_te_n/2","ref":"Money.Cldr.Rbnf.Spellout.html#ord_te_n/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ord_teer_c/2","ref":"Money.Cldr.Rbnf.Spellout.html#ord_teer_c/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ord_teer_n/2","ref":"Money.Cldr.Rbnf.Spellout.html#ord_teer_n/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esima/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esima/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esima_with_a/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esima_with_a/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esima_with_i/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esima_with_i/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esima_with_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esima_with_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esime/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esime/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esime_with_a/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esime_with_a/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esime_with_i/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esime_with_i/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esime_with_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esime_with_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esimi/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esimi/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esimi_with_a/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esimi_with_a/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esimi_with_i/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esimi_with_i/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esimi_with_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esimi_with_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esimo/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esimo/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esimo_with_a/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esimo_with_a/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esimo_with_i/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esimo_with_i/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_esimo_with_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_esimo_with_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_ones_feminine/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_ones_feminine/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ordinal_ones_masculine/2","ref":"Money.Cldr.Rbnf.Spellout.html#ordinal_ones_masculine/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.r2d_year/2","ref":"Money.Cldr.Rbnf.Spellout.html#r2d_year/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.rule_sets/0","ref":"Money.Cldr.Rbnf.Spellout.html#rule_sets/0"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.rule_sets/1","ref":"Money.Cldr.Rbnf.Spellout.html#rule_sets/1"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_alternate2/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_alternate2/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_common/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_common/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_feminine/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_feminine/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_feminine_with_e/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_feminine_with_e/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_financial/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_financial/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_m/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_m/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_masculine/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_masculine/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_masculine_with_e/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_masculine_with_e/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_n/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_n/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_neuter/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_neuter/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_r/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_r/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_s/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_s/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_cardinal_verbose/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_cardinal_verbose/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_leading/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_leading/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_numbering/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_numbering/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_numbering_days/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_numbering_days/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_numbering_m/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_numbering_m/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_numbering_verbose/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_numbering_verbose/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_numbering_year/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_numbering_year/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_numbering_year_digits/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_numbering_year_digits/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_numbering_year_latn/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_numbering_year_latn/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_common/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_common/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_feminine/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_feminine/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_feminine_plural/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_feminine_plural/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_m/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_m/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_masculine/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_masculine/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_masculine_adjective/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_masculine_adjective/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_masculine_plural/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_masculine_plural/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_n/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_n/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_neuter/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_neuter/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_r/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_r/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_s/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_s/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.spellout_ordinal_verbose/2","ref":"Money.Cldr.Rbnf.Spellout.html#spellout_ordinal_verbose/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ste2/2","ref":"Money.Cldr.Rbnf.Spellout.html#ste2/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.ste/2","ref":"Money.Cldr.Rbnf.Spellout.html#ste/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.subcents_f/2","ref":"Money.Cldr.Rbnf.Spellout.html#subcents_f/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.subcents_m/2","ref":"Money.Cldr.Rbnf.Spellout.html#subcents_m/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.subcents_o/2","ref":"Money.Cldr.Rbnf.Spellout.html#subcents_o/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.th/2","ref":"Money.Cldr.Rbnf.Spellout.html#th/2"},{"type":"function","doc":"","title":"Money.Cldr.Rbnf.Spellout.tieth/2","ref":"Money.Cldr.Rbnf.Spellout.html#tieth/2"},{"type":"module","doc":"Functions to return lists of known, historic and\nlegal tender currencies.","title":"Money.Currency","ref":"Money.Currency.html"},{"type":"function","doc":"","title":"Money.Currency.currency_for_code/1","ref":"Money.Currency.html#currency_for_code/1"},{"type":"function","doc":"Returns the list of currently active ISO 4217 currency codes.","title":"Money.Currency.known_current_currencies/0","ref":"Money.Currency.html#known_current_currencies/0"},{"type":"function","doc":"iex> Money.Currency.known_current_currencies()\n    [:AED, :AFN, :ALL, :AMD, :ANG, :AOA, :ARS, :AUD, :AWG, :AZN, :BAM, :BBD, :BDT,\n     :BGN, :BHD, :BIF, :BMD, :BND, :BOB, :BOV, :BRL, :BSD, :BTN, :BWP, :BYN, :BZD,\n     :CAD, :CDF, :CHE, :CHF, :CHW, :CLF, :CLP, :CNY, :COP, :COU, :CRC, :CUC, :CUP,\n     :CVE, :CZK, :DJF, :DKK, :DOP, :DZD, :EGP, :ERN, :ETB, :EUR, :FJD, :FKP, :GBP,\n     :GEL, :GHS, :GIP, :GMD, :GNF, :GTQ, :GYD, :HKD, :HNL, :HRK, :HTG, :HUF, :IDR,\n     :ILS, :INR, :IQD, :IRR, :ISK, :JMD, :JOD, :JPY, :KES, :KGS, :KHR, :KMF, :KPW,\n     :KRW, :KWD, :KYD, :KZT, :LAK, :LBP, :LKR, :LRD, :LSL, :LYD, :MAD, :MDL, :MGA,\n     :MKD, :MMK, :MNT, :MOP, :MRU, :MUR, :MVR, :MWK, :MXN, :MXV, :MYR, :MZN, :NAD,\n     :NGN, :NIO, :NOK, :NPR, :NZD, :OMR, :PAB, :PEN, :PGK, :PHP, :PKR, :PLN, :PYG,\n     :QAR, :RON, :RSD, :RUB, :RWF, :SAR, :SBD, :SCR, :SDG, :SEK, :SGD, :SHP, :SLL,\n     :SOS, :SRD, :SSP, :STN, :SVC, :SYP, :SZL, :THB, :TJS, :TMT, :TND, :TOP, :TRY,\n     :TTD, :TWD, :TZS, :UAH, :UGX, :USD, :USN, :UYI, :UYU, :UYW, :UZS, :VES, :VND,\n     :VUV, :WST, :XAF, :XAG, :XAU, :XBA, :XBB, :XBC, :XBD, :XCD, :XDR, :XOF, :XPD,\n     :XPF, :XPT, :XSU, :XTS, :XUA, :XXX, :YER, :ZAR, :ZMW, :ZWL]","title":"Example: - Money.Currency.known_current_currencies/0","ref":"Money.Currency.html#known_current_currencies/0-example"},{"type":"function","doc":"Returns the list of historic ISO 4217 currency codes.","title":"Money.Currency.known_historic_currencies/0","ref":"Money.Currency.html#known_historic_currencies/0"},{"type":"function","doc":"iex> Money.Currency.known_historic_currencies()\n    [:ADP, :AFA, :ALK, :AOK, :AON, :AOR, :ARA, :ARL, :ARM, :ARP, :ATS, :AZM, :BAD,\n     :BAN, :BEC, :BEF, :BEL, :BGL, :BGM, :BGO, :BOL, :BOP, :BRB, :BRC, :BRE, :BRN,\n     :BRR, :BRZ, :BUK, :BYB, :BYR, :CLE, :CNH, :CNX, :CSD, :CSK, :CYP, :DDM, :DEM,\n     :ECS, :ECV, :EEK, :ESA, :ESB, :ESP, :FIM, :FRF, :GEK, :GHC, :GNS, :GQE, :GRD,\n     :GWE, :GWP, :HRD, :IEP, :ILP, :ILR, :ISJ, :ITL, :KRH, :KRO, :LTL, :LTT, :LUC,\n     :LUF, :LUL, :LVL, :LVR, :MAF, :MCF, :MDC, :MGF, :MKN, :MLF, :MRO, :MTL, :MTP,\n     :MVP, :MXP, :MZE, :MZM, :NIC, :NLG, :PEI, :PES, :PLZ, :PTE, :RHD, :ROL, :RUR,\n     :SDD, :SDP, :SIT, :SKK, :SLE, :SRG, :STD, :SUR, :TJR, :TMM, :TPE, :TRL, :UAK,\n     :UGS, :USS, :UYP, :VEB, :VED, :VEF, :VNN, :XCG, :XEU, :XFO, :XFU, :XRE, :YDD,\n     :YUD, :YUM, :YUN, :YUR, :ZAL, :ZMK, :ZRN, :ZRZ, :ZWD, :ZWR]","title":"Example: - Money.Currency.known_historic_currencies/0","ref":"Money.Currency.html#known_historic_currencies/0-example"},{"type":"function","doc":"Returns the list of legal tender ISO 4217 currency codes.","title":"Money.Currency.known_tender_currencies/0","ref":"Money.Currency.html#known_tender_currencies/0"},{"type":"function","doc":"iex> Money.Currency.known_tender_currencies()\n    [:ADP, :AED, :AFA, :AFN, :ALK, :ALL, :AMD, :ANG, :AOA, :AOK, :AON, :AOR, :ARA,\n     :ARL, :ARM, :ARP, :ARS, :ATS, :AUD, :AWG, :AZM, :AZN, :BAD, :BAM, :BAN, :BBD,\n     :BDT, :BEC, :BEF, :BEL, :BGL, :BGM, :BGN, :BGO, :BHD, :BIF, :BMD, :BND, :BOB,\n     :BOL, :BOP, :BOV, :BRB, :BRC, :BRE, :BRL, :BRN, :BRR, :BRZ, :BSD, :BTN, :BUK,\n     :BWP, :BYB, :BYN, :BYR, :BZD, :CAD, :CDF, :CHE, :CHF, :CHW, :CLE, :CLF, :CLP,\n     :CNH, :CNX, :CNY, :COP, :COU, :CRC, :CSD, :CSK, :CUC, :CUP, :CVE, :CYP, :CZK,\n     :DDM, :DEM, :DJF, :DKK, :DOP, :DZD, :ECS, :ECV, :EEK, :EGP, :ERN, :ESA, :ESB,\n     :ESP, :ETB, :EUR, :FIM, :FJD, :FKP, :FRF, :GBP, :GEK, :GEL, :GHC, :GHS, :GIP,\n     :GMD, :GNF, :GNS, :GQE, :GRD, :GTQ, :GWE, :GWP, :GYD, :HKD, :HNL, :HRD, :HRK,\n     :HTG, :HUF, :IDR, :IEP, :ILP, :ILR, :ILS, :INR, :IQD, :IRR, :ISJ, :ISK, :ITL,\n     :JMD, :JOD, :JPY, :KES, :KGS, :KHR, :KMF, :KPW, :KRH, :KRO, :KRW, :KWD, :KYD,\n     :KZT, :LAK, :LBP, :LKR, :LRD, :LSL, :LTL, :LTT, :LUC, :LUF, :LUL, :LVL, :LVR,\n     :LYD, :MAD, :MAF, :MCF, :MDC, :MDL, :MGA, :MGF, :MKD, :MKN, :MLF, :MMK, :MNT,\n     :MOP, :MRO, :MRU, :MTL, :MTP, :MUR, :MVP, :MVR, :MWK, :MXN, :MXP, :MXV, :MYR,\n     :MZE, :MZM, :MZN, :NAD, :NGN, :NIC, :NIO, :NLG, :NOK, :NPR, :NZD, :OMR, :PAB,\n     :PEI, :PEN, :PES, :PGK, :PHP, :PKR, :PLN, :PLZ, :PTE, :PYG, :QAR, :RHD, :ROL,\n     :RON, :RSD, :RUB, :RUR, :RWF, :SAR, :SBD, :SCR, :SDD, :SDG, :SDP, :SEK, :SGD,\n     :SHP, :SIT, :SKK, :SLE, :SLL, :SOS, :SRD, :SRG, :SSP, :STD, :STN, :SUR, :SVC,\n     :SYP, :SZL, :THB, :TJR, :TJS, :TMM, :TMT, :TND, :TOP, :TPE, :TRL, :TRY, :TTD,\n     :TWD, :TZS, :UAH, :UAK, :UGS, :UGX, :USD, :USN, :USS, :UYI, :UYP, :UYU, :UYW,\n     :UZS, :VEB, :VED, :VEF, :VES, :VND, :VNN, :VUV, :WST, :XAF, :XAG, :XAU, :XBA,\n     :XBB, :XBC, :XBD, :XCD, :XCG, :XDR, :XEU, :XFO, :XFU, :XOF, :XPD, :XPF, :XPT,\n     :XRE, :XSU, :XTS, :XUA, :XXX, :YDD, :YER, :YUD, :YUM, :YUN, :YUR, :ZAL, :ZAR,\n     :ZMK, :ZMW, :ZRN, :ZRZ, :ZWD, :ZWL, :ZWR]","title":"Example: - Money.Currency.known_tender_currencies/0","ref":"Money.Currency.html#known_tender_currencies/0-example"},{"type":"module","doc":"A set of financial functions, primarily related to discounted cash flows.\n\nSome of the algorithms are from [finance formulas](http://www.financeformulas.net)","title":"Money.Financial","ref":"Money.Financial.html"},{"type":"function","doc":"Calculates the future value for a list of cash flows and an interest rate.\n\n* `flows` is a list of tuples representing a cash flow.  Each flow is\nrepresented as a tuple of the form `{period, %Money{}}`\n\n* `interest_rate` is a float representation of an interest rate.  For\nexample, 12% would be represented as `0.12`","title":"Money.Financial.future_value/2","ref":"Money.Financial.html#future_value/2"},{"type":"function","doc":"iex> Money.Financial.future_value([{4, Money.new(:USD, 10000)}, {5, Money.new(:USD, 10000)}, {6, Money.new(:USD, 10000)}], 0.13)\n    Money.new(:USD, \"34068.99999999999999999999999\")\n\n    iex> Money.Financial.future_value [{0, Money.new(:USD, 5000)},{1, Money.new(:USD, 2000)}], 0.12\n    Money.new(:USD, \"7600.000000000000000000000000\")","title":"Example - Money.Financial.future_value/2","ref":"Money.Financial.html#future_value/2-example"},{"type":"function","doc":"Calculates the future value for a present value, an interest rate\nand a number of periods.\n\n* `present_value` is a %Money{} representation of the present value\n\n* `interest_rate` is a float representation of an interest rate.  For\nexample, 12% would be represented as `0.12`\n\n* `periods` in an integer number of periods","title":"Money.Financial.future_value/3","ref":"Money.Financial.html#future_value/3"},{"type":"function","doc":"iex> Money.Financial.future_value Money.new(:USD, 10000), 0.08, 1\n    Money.new(:USD, \"10800.00\")\n\n    iex> Money.Financial.future_value Money.new(:USD, 10000), 0.04, 2\n    Money.new(:USD, \"10816.0000\")\n\n    iex> Money.Financial.future_value Money.new(:USD, 10000), 0.02, 4\n    Money.new(:USD, \"10824.32160000\")","title":"Examples - Money.Financial.future_value/3","ref":"Money.Financial.html#future_value/3-examples"},{"type":"function","doc":"Calculates the effective interest rate for a given present value,\na future value and a number of periods.\n\n* `present_value` is a %Money{} representation of the present value\n\n* `future_value` is a %Money{} representation of the future value\n\n* `periods` is an integer number of a period","title":"Money.Financial.interest_rate/3","ref":"Money.Financial.html#interest_rate/3"},{"type":"function","doc":"iex> Money.Financial.interest_rate Money.new(:USD, 10000), Money.new(:USD, 10816), 2\n    Decimal.new(\"0.04\")\n\n    iex> Money.Financial.interest_rate Money.new(:USD, 10000), Money.new(:USD, \"10824.3216\"), 4\n    Decimal.new(\"0.02\")","title":"Examples - Money.Financial.interest_rate/3","ref":"Money.Financial.html#interest_rate/3-examples"},{"type":"function","doc":"Calculates the interal rate of return for a given list of cash flows.\n\n* `flows` is a list of tuples representing a cash flow.  Each flow is\n  represented as a tuple of the form `{period, %Money{}}`","title":"Money.Financial.internal_rate_of_return/1","ref":"Money.Financial.html#internal_rate_of_return/1"},{"type":"function","doc":"Calculates the net present value of an initial investment, a list of\ncash flows and an interest rate.\n\n* `flows` is a list of tuples representing a cash flow.  Each flow is\nrepresented as a tuple of the form `{period, %Money{}}`\n\n* `interest_rate` is a float representation of an interest rate.  For\nexample, 12% would be represented as `0.12`\n\n* `investment` is a %Money{} struct representing the initial investment","title":"Money.Financial.net_present_value/2","ref":"Money.Financial.html#net_present_value/2"},{"type":"function","doc":"iex> flows = [{0, Money.new(:USD, 5000)},{1, Money.new(:USD, 2000)},{2, Money.new(:USD, 500)},{3, Money.new(:USD,10_000)}]\n    iex> Money.Financial.net_present_value flows, 0.08, Money.new(:USD, 100)\n    Money.new(:USD, \"15118.84367220444038002337042\")\n    iex> Money.Financial.net_present_value flows, 0.08\n    Money.new(:USD, \"15218.84367220444038002337042\")","title":"Example - Money.Financial.net_present_value/2","ref":"Money.Financial.html#net_present_value/2-example"},{"type":"function","doc":"Calculates the net present value of an initial investment, a recurring\npayment, an interest rate and a number of periods\n\n* `investment` is a %Money{} struct representing the initial investment\n\n* `future_value` is a %Money{} representation of the future value\n\n* `interest_rate` is a float representation of an interest rate.  For\n  example, 12% would be represented as `0.12`\n\n* `periods` in an integer number of a period","title":"Money.Financial.net_present_value/3","ref":"Money.Financial.html#net_present_value/3"},{"type":"function","doc":"iex> Money.Financial.net_present_value Money.new(:USD, 10000), 0.13, 2\n    Money.new(:USD, \"7831.466833737959119743127888\")\n\n    iex> Money.Financial.net_present_value Money.new(:USD, 10000), 0.13, 2, Money.new(:USD, 100)\n    Money.new(:USD, \"7731.466833737959119743127888\")","title":"Example - Money.Financial.net_present_value/3","ref":"Money.Financial.html#net_present_value/3-example"},{"type":"function","doc":"","title":"Money.Financial.net_present_value/4","ref":"Money.Financial.html#net_present_value/4"},{"type":"function","doc":"Calculates the payment for a given loan or annuity given a\npresent value, an interest rate and a number of periods.\n\n* `present_value` is a %Money{} representation of the present value\n\n* `interest_rate` is a float representation of an interest rate.  For\nexample, 12% would be represented as `0.12`\n\n* `periods` is an integer number of periods","title":"Money.Financial.payment/3","ref":"Money.Financial.html#payment/3"},{"type":"function","doc":"iex> Money.Financial.payment Money.new(:USD, 100), 0.12, 20\n    Money.new(:USD, \"13.38787800396606622792492299\")","title":"Example - Money.Financial.payment/3","ref":"Money.Financial.html#payment/3-example"},{"type":"function","doc":"Calculates the number of periods between a present value and\na future value with a given interest rate.\n\n* `present_value` is a %Money{} representation of the present value\n\n* `future_value` is a %Money{} representation of the future value\n\n* `interest_rate` is a float representation of an interest rate.  For\nexample, 12% would be represented as `0.12`","title":"Money.Financial.periods/3","ref":"Money.Financial.html#periods/3"},{"type":"function","doc":"iex> Money.Financial.periods Money.new(:USD, 1500), Money.new(:USD, 2000), 0.005\n    Decimal.new(\"57.68013595323872502502238648\")","title":"Example - Money.Financial.periods/3","ref":"Money.Financial.html#periods/3-example"},{"type":"function","doc":"Calculates the present value for a list of cash flows and an interest rate.\n\n* `flows` is a list of tuples representing a cash flow.  Each flow is\nrepresented as a tuple of the form `{period, %Money{}}`\n\n* `interest_rate` is a float representation of an interest rate.  For\nexample, 12% would be represented as `0.12`","title":"Money.Financial.present_value/2","ref":"Money.Financial.html#present_value/2"},{"type":"function","doc":"iex> Money.Financial.present_value([{4, Money.new(:USD, 10000)}, {5, Money.new(:USD, 10000)}, {6, Money.new(:USD, 10000)}], 0.13)\n    Money.new(:USD, \"16363.97191111964880256655144\")\n\n    iex> Money.Financial.present_value [{0, Money.new(:USD, -1000)},{1, Money.new(:USD, -4000)}], 0.1\n    Money.new(:USD, \"-4636.363636363636363636363636\")","title":"Example - Money.Financial.present_value/2","ref":"Money.Financial.html#present_value/2-example"},{"type":"function","doc":"Calculates the present value for future value, an interest rate\nand a number of periods\n\n* `future_value` is a %Money{} representation of the future value\n\n* `interest_rate` is a float representation of an interest rate.  For\nexample, 12% would be represented as `0.12`\n\n* `periods` in an integer number of periods","title":"Money.Financial.present_value/3","ref":"Money.Financial.html#present_value/3"},{"type":"function","doc":"iex> Money.Financial.present_value Money.new(:USD, 100), 0.08, 2\n    Money.new(:USD, \"85.73388203017832647462277092\")\n\n    iex> Money.Financial.present_value Money.new(:USD, 1000), 0.10, 20\n    Money.new(:USD, \"148.6436280241436864020760472\")","title":"Examples - Money.Financial.present_value/3","ref":"Money.Financial.html#present_value/3-examples"},{"type":"module","doc":"","title":"Money.Sigil","ref":"Money.Sigil.html"},{"type":"function","doc":"Implements the sigil `~M` for Money\n\nThe lower case `~m` variant does not exist as interpolation and excape\ncharacters are not useful for Money sigils.","title":"Money.Sigil.sigil_M/2","ref":"Money.Sigil.html#sigil_M/2"},{"type":"function","doc":"iex> import Money.Sigil\n    iex> ~M[1000]usd\n    Money.new(:USD, \"1000\")\n    iex> ~M[1000.34]usd\n    Money.new(:USD, \"1000.34\")","title":"Example - Money.Sigil.sigil_M/2","ref":"Money.Sigil.html#sigil_M/2-example"},{"type":"function","doc":"","title":"Money.Sigil.validate_currency!/1","ref":"Money.Sigil.html#validate_currency!/1"},{"type":"behaviour","doc":"Implements a behaviour and functions to retrieve exchange rates\nfrom an exchange rate service.\n\nConfiguration for the exchange rate service is defined\nin a `Money.ExchangeRates.Config` struct.  A default\nconfiguration is returned by `Money.ExchangeRates.default_config/0`.\n\nThe default configuration is:\n\n    config :ex_money,\n      exchange_rate_service: false,\n      exchange_rates_retrieve_every: 300_000,\n      api_module: Money.ExchangeRates.OpenExchangeRates,\n      callback_module: Money.ExchangeRates.Callback,\n      preload_historic_rates: nil\n      log_failure: :warn,\n      log_info: :info,\n      log_success: nil\n\nThese keys are are defined as follows:\n\n* `:exchange_rate_service` is a boolean that determines whether to\n  automatically start the exchange rate retrieval service.\n  The default it false.\n\n* `:exchange_rates_retrieve_every` defines how often the exchange\n  rates are retrieved in milliseconds. The default is 5 minutes\n  (300,000 milliseconds)\n\n* `:api_module` identifies the module that does the retrieval of\n  exchange rates. This is any module that implements the\n  `Money.ExchangeRates` behaviour. The default is\n  `Money.ExchangeRates.OpenExchangeRates`\n\n* `:callback_module` defines a module that follows the\n  Money.ExchangeRates.Callback behaviour whereby the function\n  `rates_retrieved/2` is invoked after every successful retrieval\n  of exchange rates. The default is `Money.ExchangeRates.Callback`.\n\n* `:preload_historic_rates` defines a date or a date range,\n  that will be requested when the exchange rate service starts up.\n  The date or date range should be specified as either a `Date.t`\n  or a `Date.Range.t` or a tuple of `{Date.t, Date.t}` representing\n  the `from` and `to` dates for the rates to be retrieved. The\n  default is `nil` meaning no historic rates are preloaded.\n\n* `:log_failure` defines the log level at which api retrieval\n  errors are logged. The default is `:warn`\n\n* `:log_success` defines the log level at which successful api\n  retrieval notifications are logged. The default is `nil` which\n  means no logging.\n\n* `:log_info` defines the log level at which service startup messages\n  are logged. The default is `:info`.\n\n* `:retriever_options` is available for exchange rate retriever\n  module developers as a place to add retriever-specific configuration\n  information.  This information should be added in the `init/1`\n  callback in the retriever module.  See `Money.ExchangeRates.OpenExchangeRates.init/1`\n  for an example.\n\nKeys can also be configured to retrieve values from environment\nvariables. This lookup is done at runtime to facilitate deployment\nstrategies. If the value of a configuration key is\n`{:system, \"some_string\"}` then \"some_string\" is interpreted as\nan environment variable name which is passed to System.get_env/2.\n\nAn example configuration might be:\n\n    config :ex_money,\n      exchange_rate_service: {:system, \"RATE_SERVICE\"},\n      exchange_rates_retrieve_every: {:system, \"RETRIEVE_EVERY\"},","title":"Money.ExchangeRates","ref":"Money.ExchangeRates.html"},{"type":"behaviour","doc":"If you plan to use the provided Open Exchange Rates module\nto retrieve exchange rates then you should also provide the additional\nconfiguration key for `app_id`:\n\n    config :ex_money,\n      open_exchange_rates_app_id: \"your_app_id\"\n\nor configure it via environment variable:\n\n    config :ex_money,\n      open_exchange_rates_app_id: {:system, \"OPEN_EXCHANGE_RATES_APP_ID\"}\n\nThe default exchange rate retrieval module is provided in\n`Money.ExchangeRates.OpenExchangeRates` which can be used\nas a example to implement your own retrieval module for\nother services.","title":"Open Exchange Rates - Money.ExchangeRates","ref":"Money.ExchangeRates.html#module-open-exchange-rates"},{"type":"behaviour","doc":"During exchange rate service startup, the function `init/1` is called\non the configuration exchange rate retrieval module.  This module is\nexpected to return an updated configuration allowing a developer to\ncustomise how the configuration is to be managed.  See the implementation\nat `Money.ExchangeRates.OpenExchangeRates.init/1` for an example.","title":"Managing the configuration at runtime - Money.ExchangeRates","ref":"Money.ExchangeRates.html#module-managing-the-configuration-at-runtime"},{"type":"function","doc":"Returns the configuration for `ex_money` including the\nconfiguration merged from the configured exchange rates\nretriever module.","title":"Money.ExchangeRates.config/0","ref":"Money.ExchangeRates.html#config/0"},{"type":"callback","doc":"Decode the body returned from the API request and\nreturn a map of rates.  THe map of rates must have\nan upcased atom key representing an ISO 4217 currency\ncode and the value must be a Decimal number.","title":"Money.ExchangeRates.decode_rates/1","ref":"Money.ExchangeRates.html#c:decode_rates/1"},{"type":"function","doc":"Returns the default configuration for the exchange rates retriever.","title":"Money.ExchangeRates.default_config/0","ref":"Money.ExchangeRates.html#default_config/0"},{"type":"callback","doc":"Invoked to return the historic exchange rates from the configured\nexchange rate retrieval service.\n\n* `config` is an `%Money.ExchangeRataes.Config{}` struct\n\nReturns `{:ok, map_of_historic_rates}` or `{:error, reason}`","title":"Money.ExchangeRates.get_historic_rates/2","ref":"Money.ExchangeRates.html#c:get_historic_rates/2"},{"type":"callback","doc":"Invoked to return the latest exchange rates from the configured\nexchange rate retrieval service.\n\n* `config` is an `%Money.ExchangeRataes.Config{}` struct\n\nReturns `{:ok, map_of_rates}` or `{:error, reason}`","title":"Money.ExchangeRates.get_latest_rates/1","ref":"Money.ExchangeRates.html#c:get_latest_rates/1"},{"type":"function","doc":"Return historic exchange rates.\n\n* `date` is a date returned by `Date.new/3` or any struct with the\n  elements `:year`, `:month` and `:day`.\n\nReturns:\n\n* `{:ok, rates}` if exchange rates are successfully retrieved.  `rates` is a map of\n  exchange rates.\n\n* `{:error, reason}` if no exchange rates can be returned.\n\n**Note;** all dates are expected to be in the Calendar.ISO calendar\n\nThis function looks up the historic exchange rates in a an ETS table\ncalled `:exchange_rates`.  The actual retrieval of rates is requested\nthrough `Money.ExchangeRates.Retriever.historic_rates/1`.","title":"Money.ExchangeRates.historic_rates/1","ref":"Money.ExchangeRates.html#historic_rates/1"},{"type":"callback","doc":"Given the default configuration, returns an updated configuration at runtime\nduring exchange rates service startup.\n\nThis callback is optional.  If the callback is not defined, the default\nconfiguration returned by `Money.ExchangeRates.default_config/0` is used.\n\n* `config` is the configuration returned by `Money.ExchangeRates.default_config/0`\n\nThe callback is expected to return a `%Money.ExchangeRates.Config.t()` struct\nwhich may have been updated.  The configuration key `:retriever_options` is\navailable for any service-specific configuration.","title":"Money.ExchangeRates.init/1","ref":"Money.ExchangeRates.html#c:init/1"},{"type":"function","doc":"Return the timestamp of the last successful retrieval of exchange rates or\n`{:error, reason}` if no timestamp is known.","title":"Money.ExchangeRates.last_updated/0","ref":"Money.ExchangeRates.html#last_updated/0"},{"type":"function","doc":"Money.ExchangeRates.last_updated\n    #> {:ok,\n     %DateTime{calendar: Calendar.ISO, day: 20, hour: 12, microsecond: {731942, 6},\n      minute: 36, month: 11, second: 6, std_offset: 0, time_zone: \"Etc/UTC\",\n      utc_offset: 0, year: 2016, zone_abbr: \"UTC\"}}","title":"Example - Money.ExchangeRates.last_updated/0","ref":"Money.ExchangeRates.html#last_updated/0-example"},{"type":"function","doc":"Return the latest exchange rates.\n\nReturns:\n\n* `{:ok, rates}` if exchange rates are successfully retrieved.  `rates` is a map of\n  exchange rates.\n\n* `{:error, reason}` if no exchange rates can be returned.\n\nThis function looks up the latest exchange rates in a an ETS table\ncalled `:exchange_rates`.  The actual retrieval of rates is requested\nthrough `Money.ExchangeRates.Retriever.latest_rates/0`.","title":"Money.ExchangeRates.latest_rates/0","ref":"Money.ExchangeRates.html#latest_rates/0"},{"type":"function","doc":"Returns `true` if the latest exchange rates are available\nand false otherwise.","title":"Money.ExchangeRates.latest_rates_available?/0","ref":"Money.ExchangeRates.html#latest_rates_available?/0"},{"type":"type","doc":"","title":"Money.ExchangeRates.t/0","ref":"Money.ExchangeRates.html#t:t/0"},{"type":"behaviour","doc":"Defines a cache behaviour and default inplementation\nof a cache for exchange rates","title":"Money.ExchangeRates.Cache","ref":"Money.ExchangeRates.Cache.html"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.cache/0","ref":"Money.ExchangeRates.Cache.html#cache/0"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.historic_rates/1","ref":"Money.ExchangeRates.Cache.html#historic_rates/1"},{"type":"callback","doc":"Returns the exchange rates for a given\ndate.","title":"Money.ExchangeRates.Cache.historic_rates/1","ref":"Money.ExchangeRates.Cache.html#c:historic_rates/1"},{"type":"callback","doc":"Initialize the cache when the exchange rates\nretriever is started","title":"Money.ExchangeRates.Cache.init/0","ref":"Money.ExchangeRates.Cache.html#c:init/0"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.latest_rates/0","ref":"Money.ExchangeRates.Cache.html#latest_rates/0"},{"type":"callback","doc":"Retrieve the latest exchange rates from the\ncache.","title":"Money.ExchangeRates.Cache.latest_rates/0","ref":"Money.ExchangeRates.Cache.html#c:latest_rates/0"},{"type":"callback","doc":"Store the historic exchange rates for a given\ndate in the cache.","title":"Money.ExchangeRates.Cache.store_historic_rates/2","ref":"Money.ExchangeRates.Cache.html#c:store_historic_rates/2"},{"type":"callback","doc":"Store the latest exchange rates in the cache.","title":"Money.ExchangeRates.Cache.store_latest_rates/2","ref":"Money.ExchangeRates.Cache.html#c:store_latest_rates/2"},{"type":"callback","doc":"Terminate the cache when the retriver process\nstops normally","title":"Money.ExchangeRates.Cache.terminate/0","ref":"Money.ExchangeRates.Cache.html#c:terminate/0"},{"type":"module","doc":"Money.ExchangeRates.Cache implementation for\n:dets","title":"Money.ExchangeRates.Cache.Dets","ref":"Money.ExchangeRates.Cache.Dets.html"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Dets.get/1","ref":"Money.ExchangeRates.Cache.Dets.html#get/1"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Dets.historic_rates/1","ref":"Money.ExchangeRates.Cache.Dets.html#historic_rates/1"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Dets.init/0","ref":"Money.ExchangeRates.Cache.Dets.html#init/0"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Dets.last_updated/0","ref":"Money.ExchangeRates.Cache.Dets.html#last_updated/0"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Dets.latest_rates/0","ref":"Money.ExchangeRates.Cache.Dets.html#latest_rates/0"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Dets.put/2","ref":"Money.ExchangeRates.Cache.Dets.html#put/2"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Dets.store_historic_rates/2","ref":"Money.ExchangeRates.Cache.Dets.html#store_historic_rates/2"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Dets.store_latest_rates/2","ref":"Money.ExchangeRates.Cache.Dets.html#store_latest_rates/2"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Dets.terminate/0","ref":"Money.ExchangeRates.Cache.Dets.html#terminate/0"},{"type":"module","doc":"Money.ExchangeRates.Cache implementation for\n:ets and :dets","title":"Money.ExchangeRates.Cache.Ets","ref":"Money.ExchangeRates.Cache.Ets.html"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Ets.get/1","ref":"Money.ExchangeRates.Cache.Ets.html#get/1"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Ets.historic_rates/1","ref":"Money.ExchangeRates.Cache.Ets.html#historic_rates/1"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Ets.init/0","ref":"Money.ExchangeRates.Cache.Ets.html#init/0"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Ets.last_updated/0","ref":"Money.ExchangeRates.Cache.Ets.html#last_updated/0"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Ets.latest_rates/0","ref":"Money.ExchangeRates.Cache.Ets.html#latest_rates/0"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Ets.put/2","ref":"Money.ExchangeRates.Cache.Ets.html#put/2"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Ets.store_historic_rates/2","ref":"Money.ExchangeRates.Cache.Ets.html#store_historic_rates/2"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Ets.store_latest_rates/2","ref":"Money.ExchangeRates.Cache.Ets.html#store_latest_rates/2"},{"type":"function","doc":"","title":"Money.ExchangeRates.Cache.Ets.terminate/0","ref":"Money.ExchangeRates.Cache.Ets.html#terminate/0"},{"type":"module","doc":"","title":"Money.ExchangeRates.Cache.EtsDets","ref":"Money.ExchangeRates.Cache.EtsDets.html"},{"type":"macro","doc":"","title":"Money.ExchangeRates.Cache.EtsDets.define_common_functions/0","ref":"Money.ExchangeRates.Cache.EtsDets.html#define_common_functions/0"},{"type":"behaviour","doc":"Default exchange rates retrieval callback module.\n\nWhen exchange rates are successfully retrieved, the function\n`latest_rates_retrieved/2` or `historic_rates_retrieved/2` is\ncalled to perform any desired serialization or proocessing.","title":"Money.ExchangeRates.Callback","ref":"Money.ExchangeRates.Callback.html"},{"type":"function","doc":"Callback function invoked when historic exchange rates are retrieved.","title":"Money.ExchangeRates.Callback.historic_rates_retrieved/2","ref":"Money.ExchangeRates.Callback.html#historic_rates_retrieved/2"},{"type":"callback","doc":"Defines the behaviour to retrieve historic exchange rates from an external\ndata source.","title":"Money.ExchangeRates.Callback.historic_rates_retrieved/2","ref":"Money.ExchangeRates.Callback.html#c:historic_rates_retrieved/2"},{"type":"function","doc":"Callback function invoked when the latest exchange rates are retrieved.","title":"Money.ExchangeRates.Callback.latest_rates_retrieved/2","ref":"Money.ExchangeRates.Callback.html#latest_rates_retrieved/2"},{"type":"callback","doc":"Defines the behaviour to retrieve the latest exchange rates from an external\ndata source.","title":"Money.ExchangeRates.Callback.latest_rates_retrieved/2","ref":"Money.ExchangeRates.Callback.html#c:latest_rates_retrieved/2"},{"type":"module","doc":"","title":"Money.ExchangeRates.Config","ref":"Money.ExchangeRates.Config.html"},{"type":"type","doc":"","title":"Money.ExchangeRates.Config.t/0","ref":"Money.ExchangeRates.Config.html#t:t/0"},{"type":"module","doc":"Implements the `Money.ExchangeRates` for the Open Exchange\nRates service.","title":"Money.ExchangeRates.OpenExchangeRates","ref":"Money.ExchangeRates.OpenExchangeRates.html"},{"type":"module","doc":"The configuration key `:open_exchange_rates_app_id` should be\nset to your `app_id`.  for example:\n\n    config :ex_money,\n      open_exchange_rates_app_id: \"your_app_id\"\n\nor configure it via environment variable:\n\n    config :ex_money,\n      open_exchange_rates_app_id: {:system, \"OPEN_EXCHANGE_RATES_APP_ID\"}\n\nIt is also possible to configure an alternative base url for this\nservice in case it changes in the future. For example:\n\n    config :ex_money,\n      open_exchange_rates_app_id: \"your_app_id\"\n      open_exchange_rates_url: \"https://openexchangerates.org/alternative_api\"","title":"Required configuration: - Money.ExchangeRates.OpenExchangeRates","ref":"Money.ExchangeRates.OpenExchangeRates.html#module-required-configuration"},{"type":"function","doc":"","title":"Money.ExchangeRates.OpenExchangeRates.decode_rates/1","ref":"Money.ExchangeRates.OpenExchangeRates.html#decode_rates/1"},{"type":"function","doc":"Retrieves the historic exchange rates from Open Exchange Rates site.\n\n* `date` is a date returned by `Date.new/3` or any struct with the\n  elements `:year`, `:month` and `:day`.\n\n* `config` is the retrieval configuration. When invoked from the\n  exchange rates services this will be the config returned from\n  `Money.ExchangeRates.config/0`\n\nReturns:\n\n* `{:ok, rates}` if the rates can be retrieved\n\n* `{:error, reason}` if rates cannot be retrieved\n\nTypically this function is called by the exchange rates retrieval\nservice although it can be called outside that context as\nrequired.","title":"Money.ExchangeRates.OpenExchangeRates.get_historic_rates/2","ref":"Money.ExchangeRates.OpenExchangeRates.html#get_historic_rates/2"},{"type":"function","doc":"Retrieves the latest exchange rates from Open Exchange Rates site.\n\n* `config` is the retrieval configuration. When invoked from the\nexchange rates services this will be the config returned from\n`Money.ExchangeRates.config/0`\n\nReturns:\n\n* `{:ok, rates}` if the rates can be retrieved\n\n* `{:error, reason}` if rates cannot be retrieved\n\nTypically this function is called by the exchange rates retrieval\nservice although it can be called outside that context as\nrequired.","title":"Money.ExchangeRates.OpenExchangeRates.get_latest_rates/1","ref":"Money.ExchangeRates.OpenExchangeRates.html#get_latest_rates/1"},{"type":"function","doc":"Update the retriever configuration to include the requirements\nfor Open Exchange Rates.  This function is invoked when the\nexchange rate service starts up, just after the ets table\n:exchange_rates is created.\n\n* `default_config` is the configuration returned by `Money.ExchangeRates.default_config/0`\n\nReturns the configuration either unchanged or updated with\nadditional configuration specific to this exchange\nrates retrieval module.","title":"Money.ExchangeRates.OpenExchangeRates.init/1","ref":"Money.ExchangeRates.OpenExchangeRates.html#init/1"},{"type":"module","doc":"Implements a `GenServer` to retrieve exchange rates from\na configured retrieveal module on a periodic or on demand basis.\n\nBy default exchange rates are retrieved from [Open Exchange Rates](http://openexchangerates.org).\n\nThe default period of execution is 5 minutes (300_000 milliseconds). The\nperiod of retrieval is configured in `config.exs` or the appropriate\nenvironment configuration.  For example:\n\n    config :ex_money,\n      retrieve_every: 300_000","title":"Money.ExchangeRates.Retriever","ref":"Money.ExchangeRates.Retriever.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Money.ExchangeRates.Retriever.child_spec/1","ref":"Money.ExchangeRates.Retriever.html#child_spec/1"},{"type":"function","doc":"Return the current configuration of the Exchange Rates\nRetrieval service","title":"Money.ExchangeRates.Retriever.config/0","ref":"Money.ExchangeRates.Retriever.html#config/0"},{"type":"function","doc":"Delete the exchange rates retrieval service\n\nThe service can be started again with `start/1`","title":"Money.ExchangeRates.Retriever.delete/0","ref":"Money.ExchangeRates.Retriever.html#delete/0"},{"type":"function","doc":"Forces retrieval of historic exchange rates for a single date\n\n* `date` is a date returned by `Date.new/3` or any struct with the\n  elements `:year`, `:month` and `:day` or\n\n* a `Date.Range.t` created by `Date.range/2` that specifies a\n  range of dates to retrieve\n\nReturns:\n\n* `{:ok, rates}` if exchange rates request is successfully sent.\n\n* `{:error, reason}` if the request cannot be send.\n\nSends a message ot the exchange rate retrieval worker to request\nhistoric rates for a specified date or range be retrieved and\nstored.\n\nThis function does not return exchange rates, for that see\n`Money.ExchangeRates.latest_rates/0` or\n`Money.ExchangeRates.historic_rates/1`.","title":"Money.ExchangeRates.Retriever.historic_rates/1","ref":"Money.ExchangeRates.Retriever.html#historic_rates/1"},{"type":"function","doc":"Forces retrieval of historic exchange rates for a range of dates\n\n* `from` is a date returned by `Date.new/3` or any struct with the\n  elements `:year`, `:month` and `:day`.\n\n* `to` is a date returned by `Date.new/3` or any struct with the\n  elements `:year`, `:month` and `:day`.\n\nReturns:\n\n* `{:ok, rates}` if exchange rates request is successfully sent.\n\n* `{:error, reason}` if the request cannot be send.\n\nSends a message to the exchange rate retrieval process for each\ndate in the range `from`..`to` to request historic rates be\nretrieved.","title":"Money.ExchangeRates.Retriever.historic_rates/2","ref":"Money.ExchangeRates.Retriever.html#historic_rates/2"},{"type":"function","doc":"Forces retrieval of the latest exchange rates\n\nSends a message ot the exchange rate retrieval worker to request\ncurrent rates be retrieved and stored.\n\nReturns:\n\n* `{:ok, rates}` if exchange rates request is successfully sent.\n\n* `{:error, reason}` if the request cannot be send.\n\nThis function does not return exchange rates, for that see\n`Money.ExchangeRates.latest_rates/0` or\n`Money.ExchangeRates.historic_rates/1`.","title":"Money.ExchangeRates.Retriever.latest_rates/0","ref":"Money.ExchangeRates.Retriever.html#latest_rates/0"},{"type":"function","doc":"Updated the configuration for the Exchange Rate\nService","title":"Money.ExchangeRates.Retriever.reconfigure/1","ref":"Money.ExchangeRates.Retriever.html#reconfigure/1"},{"type":"function","doc":"Restart the exchange rates retrieval service","title":"Money.ExchangeRates.Retriever.restart/0","ref":"Money.ExchangeRates.Retriever.html#restart/0"},{"type":"function","doc":"Retrieve exchange rates from an external HTTP\nservice.\n\nThis function is primarily intended for use by\nan exchange rates api module.","title":"Money.ExchangeRates.Retriever.retrieve_rates/2","ref":"Money.ExchangeRates.Retriever.html#retrieve_rates/2"},{"type":"function","doc":"Starts the exchange rates retrieval service","title":"Money.ExchangeRates.Retriever.start/1","ref":"Money.ExchangeRates.Retriever.html#start/1"},{"type":"function","doc":"Stop the exchange rates retrieval service.\n\nThe service can be restarted with `restart/0`.","title":"Money.ExchangeRates.Retriever.stop/0","ref":"Money.ExchangeRates.Retriever.html#stop/0"},{"type":"module","doc":"Functions to manage the starting, stopping,\ndeleting and restarting of the Exchange\nRates Retriever.","title":"Money.ExchangeRates.Supervisor","ref":"Money.ExchangeRates.Supervisor.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Money.ExchangeRates.Supervisor.child_spec/1","ref":"Money.ExchangeRates.Supervisor.html#child_spec/1"},{"type":"function","doc":"Returns the name of the default supervisor\nwhich is `Money.Supervisor`","title":"Money.ExchangeRates.Supervisor.default_supervisor/0","ref":"Money.ExchangeRates.Supervisor.html#default_supervisor/0"},{"type":"function","doc":"Deleted the retriever child specification from\nthe exchange rates supervisor.\n\nThis is primarily of use if you want to change\nthe configuration of the retriever after it is\nstopped and before it is restarted.\n\nIn this situation the sequence of calls would be:\n\n```\niex> Money.ExchangeRates.Retriever.stop\niex> Money.ExchangeRates.Retriever.delete\niex> Money.ExchangeRates.Retriever.start(config)\n```","title":"Money.ExchangeRates.Supervisor.delete_retriever/0","ref":"Money.ExchangeRates.Supervisor.html#delete_retriever/0"},{"type":"function","doc":"Restarts a stopped retriever.\n\nSee also `Money.ExchangeRates.Retriever.stop/0`","title":"Money.ExchangeRates.Supervisor.restart_retriever/0","ref":"Money.ExchangeRates.Supervisor.html#restart_retriever/0"},{"type":"function","doc":"Returns a boolean indicating of the\nretriever process is configured and\nrunning","title":"Money.ExchangeRates.Supervisor.retriever_running?/0","ref":"Money.ExchangeRates.Supervisor.html#retriever_running?/0"},{"type":"function","doc":"Returns the status of the exchange rates\nretriever.  The returned value is one of:\n\n* `:running` if the service is running. In this\n  state the valid action is `Money.ExchangeRates.Service.stop/0`\n* `:stopped` if it is stopped. In this state\n  the valid actions are `Money.ExchangeRates.Supervisor.restart_retriever/0`\n  or `Money.ExchangeRates.Supervisor.delete_retriever/0`\n* `:not_started` if it is not configured\n  in the supervisor and is not running.  In\n  this state the only valid action is\n  `Money.ExchangeRates.Supervisor.start_retriever/1`","title":"Money.ExchangeRates.Supervisor.retriever_status/0","ref":"Money.ExchangeRates.Supervisor.html#retriever_status/0"},{"type":"function","doc":"Starts the Exchange Rates supervisor and\noptionally starts the exchange rates\nretrieval service as well.","title":"Money.ExchangeRates.Supervisor.start_link/0","ref":"Money.ExchangeRates.Supervisor.html#start_link/0"},{"type":"function","doc":"* `:restart` is a boolean value indicating\n  if the supervisor is to be restarted.  This is\n  typically used to move the supervisor from its\n  default position under the `ex_money` supervision\n  tree to a different supervision tree.  The default\n  is `false`\n\n* `:start_retriever` is a boolean indicating\n  if the exchange rates retriever is to be started\n  when the supervisor is started.  The default is\n  defined by the configuration key\n  `:auto_start_exchange_rate_service`","title":"Options - Money.ExchangeRates.Supervisor.start_link/0","ref":"Money.ExchangeRates.Supervisor.html#start_link/0-options"},{"type":"function","doc":"","title":"Money.ExchangeRates.Supervisor.start_link/1","ref":"Money.ExchangeRates.Supervisor.html#start_link/1"},{"type":"function","doc":"Starts the exchange rates retriever","title":"Money.ExchangeRates.Supervisor.start_retriever/1","ref":"Money.ExchangeRates.Supervisor.html#start_retriever/1"},{"type":"function","doc":"* `config` is a `%Money.ExchangeRages.Config{}`\n  struct returned by `Money.ExchangeRates.config/0`\n  and adjusted as required.  The default is\n  `Money.ExchangeRates.config/0`","title":"Arguments - Money.ExchangeRates.Supervisor.start_retriever/1","ref":"Money.ExchangeRates.Supervisor.html#start_retriever/1-arguments"},{"type":"function","doc":"Stop the Money.ExchangeRates.Supervisor.\n\nUnless `ex_money` is configured in `mix.exs` as\n`rumtime: false`, the Money.ExchangeRates.Supervisor\nis always started when `ex_money` starts even if the\nconfig key `:auto_start_exchange_rates_service` is\nset to `false`.\n\n\nIn some instances an application may require the\n`Money.ExchangeRates.Supervisor` to be started under\na different supervision tree.  In this case it is\nrequired to call this function first before a new\nconfiguration is started.\n\nOne use case is when the Exchange Rates service is\nconfigured with either an API module, a Callback module\nor a Cache module which uses Ecto and therefore its\na requirement that Ecto is started first.\n\nSee the README section on \"Using Ecto or other applications\nfrom within the callback module\" for an eanple of how\nto configure the supervisor in this case.","title":"Money.ExchangeRates.Supervisor.stop/1","ref":"Money.ExchangeRates.Supervisor.html#stop/1"},{"type":"function","doc":"Stop the exchange rates retriever.","title":"Money.ExchangeRates.Supervisor.stop_retriever/0","ref":"Money.ExchangeRates.Supervisor.html#stop_retriever/0"},{"type":"module","doc":"Provides functions to create, upgrade and downgrade subscriptions\nfrom one plan to another.\n\nSince moving from one plan to another may require\nprorating the payment stream at the point of transition,\nthis module is introduced to provide a single point of\ncalculation of the proration in order to give clear focus\nto the issues of calculating the carry-over amount or\nthe carry-over period at the point of plan change.","title":"Money.Subscription","ref":"Money.Subscription.html"},{"type":"module","doc":"A subscription records this current state and history of\nall plans assigned over time to a subscriber.  The definition\nis deliberately minimal to simplify integration into applications\nthat have a specific implementation of a subscription.\n\nA new subscription is created with `Money.Subscription.new/3`\nwhich has the following attributes:\n\n* `plan` which defines the initial plan for the subscription.\nThis option is required.\n\n* `effective_date` which determines the effective date of\nthe inital plan.  This option is required.\n\n* `options` which include `:created_at` and `:id` with which\n  a subscription may be annotated","title":"Defining a subscription - Money.Subscription","ref":"Money.Subscription.html#module-defining-a-subscription"},{"type":"module","doc":"Changing a subscription plan requires the following\ninformation be provided:\n\n* A Subscription or the definition of the current plan\n\n* The definition of the new plan\n\n* The strategy for changing the plan which is either:\n\n  * to have the effective date of the new plan be after\n    the current interval of the current plan\n\n  * To change the plan immediately in which case there will\n    be a credit on the current plan which needs to be applied\n    to the new plan.\n\nSee `Money.Subscription.change_plan/3`","title":"Changing a subscription plan - Money.Subscription","ref":"Money.Subscription.html#module-changing-a-subscription-plan"},{"type":"module","doc":"The first strategy simply finishes the current billing period before\nthe new plan is introduced and therefore no proration is required.\nThis is the default strategy.","title":"When the new plan is effective at the end of the current billing period - Money.Subscription","ref":"Money.Subscription.html#module-when-the-new-plan-is-effective-at-the-end-of-the-current-billing-period"},{"type":"module","doc":"If the new plan is to be effective immediately then any credit\nbalance remaining on the old plan needs to be applied to the\nnew plan.  There are two options of applying the credit:\n\n1. Reduce the billing amount of the first period of the new plan\n   be the amount of the credit left on the old plan. This means\n   that the billing amount for the first period of the new plan\n   will be different (less) than the billing amount for subsequent\n   periods on the new plan.\n\n2. Extend the first period of the new plan by the interval amount\n   that can be funded by the credit amount left on the old plan. In\n   the situation where the credit amount does not fully fund an integral\n   interval the additional interval can be truncated or rounded up to the next\n   integral period.","title":"When the new plan is effective immediately - Money.Subscription","ref":"Money.Subscription.html#module-when-the-new-plan-is-effective-immediately"},{"type":"module","doc":"This module, and `Money` in general, does not provide a full\nbilling or subscription solution - its focus is to support a reliable\nmeans of calcuating the accounting outcome of a plan change only.\nTherefore the plan definition required by `Money.Subscription` can be\nany `Map.t` that includes the following fields:\n\n* `interval` which defines the time interval for a plan. The value\n  can be one of `day`, `week`, `month` or `year`.\n\n* `interval_count` which defines the number of `interval`s for the\n  current plan interval.  This must be a positive integer.\n\n* `price` which is a `Money.t` representing the price of the plan\n  to be paid each interval count.","title":"Plan definition - Money.Subscription","ref":"Money.Subscription.html#module-plan-definition"},{"type":"module","doc":"This module calculates all subscription changes on the basis\nthat billing is done in advance.  This primarily affects the\ncalculation of plan credit when a plan changes.  The assumption\nis that the period from the start of the current interval to\nthe point of change has been consumed and therefore the credit\nis based upon that period of the plan that has not yet been\nconsumed.\n\nIf the calculation was based upon \"payment in arrears\" then\nthe credit would actually be a debit since the part of the\ncurrent period consumed has not yet been paid.","title":"Billing in advance - Money.Subscription","ref":"Money.Subscription.html#module-billing-in-advance"},{"type":"function","doc":"A `struct` defining a subscription\n\n* `:id` any term that uniquely identifies this subscription\n\n* `:plans` is a list of `{change, plan}` tuples that record the history\n  of plans assigned to this subscription\n\n* `:created_at` records the `DateTime.t` when the subscription was created","title":"Money.Subscription.__struct__/0","ref":"Money.Subscription.html#__struct__/0"},{"type":"function","doc":"Cancel a subscription's pending plan.\n\nA pending plan arise when a a `Subscription.change_plan/3` has\nbeen executed but the effective date is in the future.  Only\none plan may be pending at any one time so that if\n`Subscription.change_plan/3` is attemtped a second time an\nerror tuple will be returned.\n\n`Subscription.cancel_pending_plan/2`\ncan be used to roll back the pending plan change.","title":"Money.Subscription.cancel_pending_plan/2","ref":"Money.Subscription.html#cancel_pending_plan/2"},{"type":"function","doc":"* `:subscription` is any `Money.Subscription.t`\n\n* `:options` is a `Keyword.t`","title":"Arguments - Money.Subscription.cancel_pending_plan/2","ref":"Money.Subscription.html#cancel_pending_plan/2-arguments"},{"type":"function","doc":"* `:today` is a `Date.t` that represents today.\n  The default is `Date.utc_today`","title":"Options - Money.Subscription.cancel_pending_plan/2","ref":"Money.Subscription.html#cancel_pending_plan/2-options"},{"type":"function","doc":"* An updated `Money.Subscription.t` which may or may not\nhave had a pending plan.  If it did have a pending plan\nthat plan is deleted.  If there was no pending plan then\nthe subscription is returned unchanged.","title":"Returns - Money.Subscription.cancel_pending_plan/2","ref":"Money.Subscription.html#cancel_pending_plan/2-returns"},{"type":"function","doc":"Change plan from the current plan to a new plan.","title":"Money.Subscription.change_plan/3","ref":"Money.Subscription.html#change_plan/3"},{"type":"function","doc":"* `subscription_or_plan` is either a `Money.Subscription.t` or `Money.Subscription.Plan.t`\n  or a map with the same fields\n\n* `new_plan` is a `Money.Subscription.Plan.t` or a map with at least the fields\n  `interval`, `interval_count` and `price`\n\n* `current_interval_started` is a `Date.t` or other map with the fields `year`, `month`,\n  `day` and `calendar`\n\n* `options` is a keyword list of options the define how the change is to be made","title":"Arguments - Money.Subscription.change_plan/3","ref":"Money.Subscription.html#change_plan/3-arguments"},{"type":"function","doc":"* `:effective` defines when the new plan comes into effect.  The values are `:immediately`,\n  a `Date.t` or `:next_period`.  The default is `:next_period`.  Note that the date\n  applied in the case of `:immediately` is the date returned by `Date.utc_today`.\n\n* `:prorate` which determines how to prorate the current plan into the new plan.  The\n  options are `:price` which will reduce the price of the first period of the new plan\n  by the credit amount left on the old plan (this is the default). Or `:period` in which\n  case the first period of the new plan is extended by the `interval` amount of the new\n  plan that the credit on the old plan will fund.\n\n* `:round` determines whether when prorating the `:period` it is truncated or rounded up\n  to the next nearest full `interval_count`. Valid values are `:down`, `:half_up`,\n  `:half_even`, `:ceiling`, `:floor`, `:half_down`, `:up`.  The default is `:up`.\n\n* `:first_interval_started` determines the anchor day for monthly billing.  For\n  example if a monthly plan starts on January 31st then the next period will start\n  on February 28th (or 29th).  The period following that should, however, be March 31st.\n  If `subscription_or_plan` is a `Money.Subscription.t` then the `:first_interval_started`\n  is automatically populated from the subscription. If `:first_interval_started` is\n  `nil` then the date defined by `:effective` is used.","title":"Options - Money.Subscription.change_plan/3","ref":"Money.Subscription.html#change_plan/3-options"},{"type":"function","doc":"A `Money.Subscription.Change.t` with the following elements:\n\n* `:first_interval_starts` which is the start date of the first interval for the new\n  plan\n\n* `:first_billing_amount` is the amount to be billed, net of any credit, at\n  the `:first_interval_starts`\n\n* `:next_interval_starts` is the start date of the next interval after the `\n  first interval `including any `credit_days_applied`\n\n* `:credit_amount` is the amount of unconsumed credit of the current plan\n\n* `:credit_amount_applied` is the amount of credit applied to the new plan. If\n  the `:prorate` option is `:price` (the default) then `:first_billing_amount`\n  is the plan `:price` reduced by the `:credit_amount_applied`. If the `:prorate`\n  option is `:period` then the `:first_billing_amount` is the plan `price` and\n  the `:next_interval_date` is extended by the `:credit_days_applied`\n  instead.\n\n* `:credit_days_applied` is the number of days credit applied to the first\n  interval by adding days to the `:first_interval_starts` date.\n\n* `:credit_period_ends` is the date on which any applied credit is consumed or `nil`\n\n* `:carry_forward` is any amount of credit carried forward to a subsequent period.\n  If non-zero, this amount is a negative `Money.t`. It is non-zero when the credit\n  amount for the current plan is greater than the `:price` of the new plan.  In\n  this case the `:first_billing_amount` is zero.","title":"Returns - Money.Subscription.change_plan/3","ref":"Money.Subscription.html#change_plan/3-returns"},{"type":"function","doc":"* `{:ok, updated_subscription}` or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Subscription.change_plan/3","ref":"Money.Subscription.html#change_plan/3-returns"},{"type":"function","doc":"# Change at end of the current period so no proration\n    iex> current = Money.Subscription.Plan.new!(Money.new(:USD, 10), :month, 1)\n    iex> new = Money.Subscription.Plan.new!(Money.new(:USD, 10), :month, 3)\n    iex> Money.Subscription.change_plan current, new, current_interval_started: ~D[2018-01-01]\n    {:ok, %Money.Subscription.Change{\n      carry_forward: Money.zero(:USD),\n      credit_amount: Money.zero(:USD),\n      credit_amount_applied: Money.zero(:USD),\n      credit_days_applied: 0,\n      credit_period_ends: nil,\n      next_interval_starts: ~D[2018-05-01],\n      first_billing_amount: Money.new(:USD, 10),\n      first_interval_starts: ~D[2018-02-01]\n    }}\n\n    # Change during the current plan generates a credit amount\n    iex> current = Money.Subscription.Plan.new!(Money.new(:USD, 10), :month, 1)\n    iex> new = Money.Subscription.Plan.new!(Money.new(:USD, 10), :month, 3)\n    iex> Money.Subscription.change_plan current, new, current_interval_started: ~D[2018-01-01], effective: ~D[2018-01-15]\n    {:ok, %Money.Subscription.Change{\n      carry_forward: Money.zero(:USD),\n      credit_amount: Money.new(:USD, \"5.49\"),\n      credit_amount_applied: Money.new(:USD, \"5.49\"),\n      credit_days_applied: 0,\n      credit_period_ends: nil,\n      next_interval_starts: ~D[2018-04-15],\n      first_billing_amount: Money.new(:USD, \"4.51\"),\n      first_interval_starts: ~D[2018-01-15]\n    }}\n\n    # Change during the current plan generates a credit period\n    iex> current = Money.Subscription.Plan.new!(Money.new(:USD, 10), :month, 1)\n    iex> new = Money.Subscription.Plan.new!(Money.new(:USD, 10), :month, 3)\n    iex> Money.Subscription.change_plan current, new, current_interval_started: ~D[2018-01-01], effective: ~D[2018-01-15], prorate: :period\n    {:ok, %Money.Subscription.Change{\n      carry_forward: Money.zero(:USD),\n      credit_amount: Money.new(:USD, \"5.49\"),\n      credit_amount_applied: Money.zero(:USD),\n      credit_days_applied: 50,\n      credit_period_ends: ~D[2018-03-05],\n      next_interval_starts: ~D[2018-06-04],\n      first_billing_amount: Money.new(:USD, 10),\n      first_interval_starts: ~D[2018-01-15]\n    }}","title":"Examples - Money.Subscription.change_plan/3","ref":"Money.Subscription.html#change_plan/3-examples"},{"type":"function","doc":"Change plan from the current plan to a new plan.\n\nRetuns the plan or raises an exception on error.\n\nSee `Money.Subscription.change_plan/3` for the description\nof arguments, options and return.","title":"Money.Subscription.change_plan!/3","ref":"Money.Subscription.html#change_plan!/3"},{"type":"function","doc":"Returns the first date of the current interval of a plan.","title":"Money.Subscription.current_interval_start_date/2","ref":"Money.Subscription.html#current_interval_start_date/2"},{"type":"function","doc":"* `:subscription_or_changeset` is any`Money.Subscription.t` or\n  a `{Change.t, Plan.t}` tuple\n\n* `:options` is a keyword list of options","title":"Arguments - Money.Subscription.current_interval_start_date/2","ref":"Money.Subscription.html#current_interval_start_date/2-arguments"},{"type":"function","doc":"* `:today` is a `Date.t` that represents today.\n  The default is `Date.utc_today`","title":"Options - Money.Subscription.current_interval_start_date/2","ref":"Money.Subscription.html#current_interval_start_date/2-options"},{"type":"function","doc":"* The `Date.t` that is the first date of the current interval","title":"Returns - Money.Subscription.current_interval_start_date/2","ref":"Money.Subscription.html#current_interval_start_date/2-returns"},{"type":"function","doc":"Retrieve the plan that is currently in affect.\n\nThe plan in affect is not necessarily the first\nplan in the list.  We may have upgraded plans to\nbe in affect at some later time.","title":"Money.Subscription.current_plan/2","ref":"Money.Subscription.html#current_plan/2"},{"type":"function","doc":"* `subscription` is a `Money.Subscription.t` or any\n  map that provides the field `:plans`","title":"Arguments - Money.Subscription.current_plan/2","ref":"Money.Subscription.html#current_plan/2-arguments"},{"type":"function","doc":"* The `Money.Subscription.Plan.t` that is the plan currently in affect or\n  `nil`","title":"Returns - Money.Subscription.current_plan/2","ref":"Money.Subscription.html#current_plan/2-returns"},{"type":"function","doc":"Returns the start date of the current plan.","title":"Money.Subscription.current_plan_start_date/1","ref":"Money.Subscription.html#current_plan_start_date/1"},{"type":"function","doc":"* `subscription` is a `Money.Subscription.t` or any\n  map that provides the field `:plans`","title":"Arguments - Money.Subscription.current_plan_start_date/1","ref":"Money.Subscription.html#current_plan_start_date/1-arguments"},{"type":"function","doc":"* The start `Date.t` of the current plan","title":"Returns - Money.Subscription.current_plan_start_date/1","ref":"Money.Subscription.html#current_plan_start_date/1-returns"},{"type":"function","doc":"Returns number of days remaining in a plan interval.","title":"Money.Subscription.days_remaining/4","ref":"Money.Subscription.html#days_remaining/4"},{"type":"function","doc":"* `plan` is any `Money.Subscription.Plan.t`\n\n* `current_interval_started` is a `Date.t`\n\n* `effective_date` is a `Date.t` after the\n  `current_interval_started` and before the end of\n  the `plan_days`","title":"Arguments - Money.Subscription.days_remaining/4","ref":"Money.Subscription.html#days_remaining/4-arguments"},{"type":"function","doc":"The number of days remaining in a plan interval","title":"Returns - Money.Subscription.days_remaining/4","ref":"Money.Subscription.html#days_remaining/4-returns"},{"type":"function","doc":"iex> plan = Money.Subscription.Plan.new! Money.new!(:USD, 100), :month, 1\n    iex> Money.Subscription.days_remaining plan, ~D[2018-01-01], ~D[2018-01-02]\n    30\n    iex> Money.Subscription.days_remaining plan, ~D[2018-02-01], ~D[2018-02-02]\n    27","title":"Examples - Money.Subscription.days_remaining/4","ref":"Money.Subscription.html#days_remaining/4-examples"},{"type":"function","doc":"Returns the latest plan for a subscription.\n\nThe latest plan may not be in affect since\nits start date may be in the future.","title":"Money.Subscription.latest_plan/1","ref":"Money.Subscription.html#latest_plan/1"},{"type":"function","doc":"* `subscription` is a `Money.Subscription.t` or any\n  map that provides the field `:plans`","title":"Arguments - Money.Subscription.latest_plan/1","ref":"Money.Subscription.html#latest_plan/1-arguments"},{"type":"function","doc":"* The `Money.Subscription.Plan.t` that is the most recent\n  plan - whether or not it is the currently active plan.","title":"Returns - Money.Subscription.latest_plan/1","ref":"Money.Subscription.html#latest_plan/1-returns"},{"type":"function","doc":"Creates a new subscription.","title":"Money.Subscription.new/3","ref":"Money.Subscription.html#new/3"},{"type":"function","doc":"* `plan` is any `Money.Subscription.Plan.t` the defines the initial plan\n\n* `effective_date` is a `Date.t` that represents the effective\n  date of the initial plan. This defines the start of the first interval\n\n* `options` is a keyword list of options","title":"Arguments - Money.Subscription.new/3","ref":"Money.Subscription.html#new/3-arguments"},{"type":"function","doc":"* `:id` is any term that an application can use to uniquely identify\n  this subscription.  It is not used in any function in this module.\n\n* `:created_at` is a `DateTime.t` that records the timestamp when\n  the subscription was created.  The default is `DateTime.utc_now/0`","title":"Options - Money.Subscription.new/3","ref":"Money.Subscription.html#new/3-options"},{"type":"function","doc":"* `{:ok, Money.Subscription.t}` or\n\n* `{:error, {exception, message}}`","title":"Returns - Money.Subscription.new/3","ref":"Money.Subscription.html#new/3-returns"},{"type":"function","doc":"Creates a new subscription or raises an exception.","title":"Money.Subscription.new!/3","ref":"Money.Subscription.html#new!/3"},{"type":"function","doc":"* `plan` is any `Money.Subscription.Plan.t` the defines the initial plan\n\n* `effective_date` is a `Date.t` that represents the effective\n  date of the initial plan. This defines the start of the first interval\n\n* `:options` is a keyword list of options","title":"Arguments - Money.Subscription.new!/3","ref":"Money.Subscription.html#new!/3-arguments"},{"type":"function","doc":"* `:id` is any term that an application can use to uniquely identify\n  this subscription.  It is not used in any function in this module.\n\n* `:created_at` is a `DateTime.t` that records the timestamp when\n  the subscription was created.  The default is `DateTime.utc_now/0`","title":"Options - Money.Subscription.new!/3","ref":"Money.Subscription.html#new!/3-options"},{"type":"function","doc":"* A `Money.Subscription.t` or\n\n* raises an exception","title":"Returns - Money.Subscription.new!/3","ref":"Money.Subscription.html#new!/3-returns"},{"type":"function","doc":"Returns the next interval start date for a plan.","title":"Money.Subscription.next_interval_starts/3","ref":"Money.Subscription.html#next_interval_starts/3"},{"type":"function","doc":"* `plan` is any `Money.Subscription.Plan.t`\n\n* `:current_interval_started` is the `Date.t` that\n  represents the start of the current interval","title":"Arguments - Money.Subscription.next_interval_starts/3","ref":"Money.Subscription.html#next_interval_starts/3-arguments"},{"type":"function","doc":"The next interval start date as a `Date.t`.","title":"Returns - Money.Subscription.next_interval_starts/3","ref":"Money.Subscription.html#next_interval_starts/3-returns"},{"type":"function","doc":"iex> plan = Money.Subscription.Plan.new!(Money.new!(:USD, 100), :month)\n    iex> Money.Subscription.next_interval_starts(plan, ~D[2018-03-01])\n    ~D[2018-04-01]\n\n    iex> plan = Money.Subscription.Plan.new!(Money.new!(:USD, 100), :day, 30)\n    iex> Money.Subscription.next_interval_starts(plan, ~D[2018-02-01])\n    ~D[2018-03-03]","title":"Example - Money.Subscription.next_interval_starts/3","ref":"Money.Subscription.html#next_interval_starts/3-example"},{"type":"function","doc":"Returns number of days in a plan interval.","title":"Money.Subscription.plan_days/3","ref":"Money.Subscription.html#plan_days/3"},{"type":"function","doc":"* `plan` is any `Money.Subscription.Plan.t`\n\n* `current_interval_started` is any `Date.t`","title":"Arguments - Money.Subscription.plan_days/3","ref":"Money.Subscription.html#plan_days/3-arguments"},{"type":"function","doc":"The number of days in a plan interval.","title":"Returns - Money.Subscription.plan_days/3","ref":"Money.Subscription.html#plan_days/3-returns"},{"type":"function","doc":"iex> plan = Money.Subscription.Plan.new! Money.new!(:USD, 100), :month, 1\n    iex> Money.Subscription.plan_days plan, ~D[2018-01-01]\n    31\n    iex> Money.Subscription.plan_days plan, ~D[2018-02-01]\n    28\n    iex> Money.Subscription.plan_days plan, ~D[2018-04-01]\n    30","title":"Examples - Money.Subscription.plan_days/3","ref":"Money.Subscription.html#plan_days/3-examples"},{"type":"function","doc":"Returns a `boolean` indicating if there is a pending plan.\n\nA pending plan is one where the subscription has changed\nplans but the plan is not yet in effect.  There can only\nbe one pending plan.","title":"Money.Subscription.plan_pending?/2","ref":"Money.Subscription.html#plan_pending?/2"},{"type":"function","doc":"* `:subscription` is any `Money.Subscription.t`\n\n* `:options` is a keyword list of options","title":"Arguments - Money.Subscription.plan_pending?/2","ref":"Money.Subscription.html#plan_pending?/2-arguments"},{"type":"function","doc":"* `:today` is a `Date.t` that represents the effective\n  date used to determine is there is a pending plan.\n  The default is `Date.utc_today/1`.","title":"Options - Money.Subscription.plan_pending?/2","ref":"Money.Subscription.html#plan_pending?/2-options"},{"type":"function","doc":"* Either `true` or `false`","title":"Returns - Money.Subscription.plan_pending?/2","ref":"Money.Subscription.html#plan_pending?/2-returns"},{"type":"type","doc":"An id that uniquely identifies a subscription","title":"Money.Subscription.id/0","ref":"Money.Subscription.html#t:id/0"},{"type":"type","doc":"A Money.Subscription type","title":"Money.Subscription.t/0","ref":"Money.Subscription.html#t:t/0"},{"type":"module","doc":"Defines the structure of a plan changeset.\n\n* `:first_interval_starts` which is the start date of the first interval for the new\n  plan\n\n* `:first_billing_amount` is the amount to be billed, net of any credit, at\n  the `:first_interval_starts`\n\n* `:next_interval_starts` is the start date of the next interval after the `\n  first interval including any `credit_days_applied`\n\n* `:credit_amount` is the amount of unconsumed credit of the current plan\n\n* `:credit_amount_applied` is the amount of credit applied to the new plan. If\n  the `:prorate` option is `:price` (the default) the `:first_billing_amount`\n  is the plan `:price` reduced by the `:credit_amount_applied`. If the `:prorate`\n  option is `:period` then the `:first_billing_amount` is the plan `price and\n  the `:next_interval_date` is extended by the `:credit_days_applied`\n  instead.\n\n* `:credit_days_applied` is the number of days credit applied to the first\n  interval by adding days to the `:first_interval_starts` date.\n\n* `:credit_period_ends` is the date on which any applied credit is consumed or `nil`\n\n* `:carry_forward` is any amount of credit carried forward to a subsequent period.\n  If non-zero this amount is a negative `Money.t`. It is non-zero when the credit\n  amount for the current plan is greater than the price of the new plan.  In\n  this case the `:first_billing_amount` is zero.","title":"Money.Subscription.Change","ref":"Money.Subscription.Change.html"},{"type":"function","doc":"A struct defining the changes between two plans.","title":"Money.Subscription.Change.__struct__/0","ref":"Money.Subscription.Change.html#__struct__/0"},{"type":"type","doc":"A plan change record struct.","title":"Money.Subscription.Change.t/0","ref":"Money.Subscription.Change.html#t:t/0"},{"type":"exception","doc":"","title":"Money.Subscription.DateError","ref":"Money.Subscription.DateError.html"},{"type":"exception","doc":"","title":"Money.Subscription.NoCurrentPlan","ref":"Money.Subscription.NoCurrentPlan.html"},{"type":"module","doc":"Defines a standard subscription plan data structure.","title":"Money.Subscription.Plan","ref":"Money.Subscription.Plan.html"},{"type":"function","doc":"Defines the structure of a subscription plan.","title":"Money.Subscription.Plan.__struct__/0","ref":"Money.Subscription.Plan.html#__struct__/0"},{"type":"function","doc":"Returns `{:ok, Money.Subscription.Plan.t}` or an `{:error, reason}`\ntuple.","title":"Money.Subscription.Plan.new/3","ref":"Money.Subscription.Plan.html#new/3"},{"type":"function","doc":"* `:price` is any `Money.t`\n\n* `:interval` is the period of the plan.  The valid intervals are\n`  `:day`, `:week`, `:month` or ':year`.\n\n* `:interval_count` is an integer count of the number of `:interval`s\n  of the plan.  The default is `1`","title":"Arguments - Money.Subscription.Plan.new/3","ref":"Money.Subscription.Plan.html#new/3-arguments"},{"type":"function","doc":"A `Money.Subscription.Plan.t`","title":"Returns - Money.Subscription.Plan.new/3","ref":"Money.Subscription.Plan.html#new/3-returns"},{"type":"function","doc":"iex> Money.Subscription.Plan.new Money.new(:USD, 100), :month, 1\n    {:ok,\n     %Money.Subscription.Plan{\n       interval: :month,\n       interval_count: 1,\n       price: Money.new(:USD, 100)\n     }}\n\n    iex> Money.Subscription.Plan.new Money.new(:USD, 100), :month\n    {:ok,\n     %Money.Subscription.Plan{\n       interval: :month,\n       interval_count: 1,\n       price: Money.new(:USD, 100)\n     }}\n\n    iex> Money.Subscription.Plan.new Money.new(:USD, 100), :day, 30\n    {:ok,\n     %Money.Subscription.Plan{\n       interval: :day,\n       interval_count: 30,\n       price: Money.new(:USD, 100)\n     }}\n\n    iex> Money.Subscription.Plan.new 23, :day, 30\n    {:error, {Money.Invalid, \"Invalid subscription plan definition\"}}","title":"Examples - Money.Subscription.Plan.new/3","ref":"Money.Subscription.Plan.html#new/3-examples"},{"type":"function","doc":"Returns `{:ok, Money.Subscription.Plan.t}` or raises an\nexception.\n\nTakes the same arguments as `Money.Subscription.Plan.new/3`.","title":"Money.Subscription.Plan.new!/3","ref":"Money.Subscription.Plan.html#new!/3"},{"type":"function","doc":"iex> Money.Subscription.Plan.new! Money.new(:USD, 100), :day, 30\n    %Money.Subscription.Plan{\n      interval: :day,\n      interval_count: 30,\n      price: Money.new(:USD, 100)\n    }","title":"Example - Money.Subscription.Plan.new!/3","ref":"Money.Subscription.Plan.html#new!/3-example"},{"type":"type","doc":"A plan interval type.","title":"Money.Subscription.Plan.interval/0","ref":"Money.Subscription.Plan.html#t:interval/0"},{"type":"type","doc":"A integer interval count for a plan.","title":"Money.Subscription.Plan.interval_count/0","ref":"Money.Subscription.Plan.html#t:interval_count/0"},{"type":"type","doc":"A Subscription Plan","title":"Money.Subscription.Plan.t/0","ref":"Money.Subscription.Plan.html#t:t/0"},{"type":"exception","doc":"","title":"Money.Subscription.PlanError","ref":"Money.Subscription.PlanError.html"},{"type":"exception","doc":"","title":"Money.Subscription.PlanPending","ref":"Money.Subscription.PlanPending.html"},{"type":"exception","doc":"","title":"Money.ExchangeRateError","ref":"Money.ExchangeRateError.html"},{"type":"exception","doc":"","title":"Money.Invalid","ref":"Money.Invalid.html"},{"type":"exception","doc":"","title":"Money.InvalidAmountError","ref":"Money.InvalidAmountError.html"},{"type":"exception","doc":"","title":"Money.InvalidDigitsError","ref":"Money.InvalidDigitsError.html"},{"type":"exception","doc":"","title":"Money.ParseError","ref":"Money.ParseError.html"},{"type":"exception","doc":"","title":"Money.UnknownCurrencyError","ref":"Money.UnknownCurrencyError.html"},{"type":"extras","doc":"# Introduction to Money\n\n![Build status](https://github.com/kipcole9/money/actions/workflows/ci.yml/badge.svg)\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_money.svg)](https://hex.pm/packages/ex_money)\n[![Hex.pm](https://img.shields.io/hexpm/dw/ex_money.svg?)](https://hex.pm/packages/ex_money)\n[![Hex.pm](https://img.shields.io/hexpm/dt/ex_money.svg?)](https://hex.pm/packages/ex_money)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_money.svg)](https://hex.pm/packages/ex_money)\n\nMoney implements a set of functions to store, retrieve, convert and perform arithmetic\non a `t:Money.t/0` type that is composed of an [ISO 4217](https://www.iso.org/iso-4217-currency-codes.html) currency code or an [ISO 24165](https://www.iso.org/standard/80601.html) Digital Token Identifier (crypto currency) with a currency amount.\n\nMoney is opinionated in the interests of serving as a dependable library that can underpin accounting and financial applications.\n\nHow is this opinion expressed?\n\n1. Money must always have both a amount and a currency code or digital token identifier.\n\n2. The currency code must always be a valid [ISO 4217](https://www.iso.org/iso-4217-currency-codes.html) code or a valid [ISO 24165](https://www.iso.org/standard/80601.html) digital token idenfier. [Current](https://www.currency-iso.org/en/home/tables/table-a1.html) and [historical](https://www.currency-iso.org/en/home/tables/table-a3.html) currency codes can be used.  See the [ISO Currency](https://www.currency-iso.org/en/home/tables.html) for more information. You can also identify the relevant codes by:\n\n   * `Money.known_currencies/0` returns all the ISO 4217 currency codes known to `Money`\n   * `Money.known_current_currencies/0` returns the ISO 4217 currency codes currently in use\n   * `Money.known_historic_currencies/0` returns the list of historic ISO 4217 currency codes\n   * `Money.known_tender_currencies/0` returns the list of ISO 4217 currencies known to be legal tender\n   * `DigitalToken.tokens/0` returns a map of the known ISO 24165 digital tokens.\n\n3. Money arithmetic can only be performed when both operands are of the same currency.\n\n4. Money amounts are represented as a `Decimal`.\n\n5. Money can be serialised to the database as a composite Postgres type that includes both the amount and the currency. For MySQL, money is serialized into a json column with the amount converted to a string to preserve precision since json does not have a decimal type. Serialization is entirely optional.\n\n6. All arithmetic functions work on a `Decimal`. No rounding occurs automatically (unless expressly called out for a function, as is the case for `Money.split/2`).\n\n7. Explicit rounding obeys the rounding rules for a given currency. The rounding rules are defined by the Unicode consortium in its CLDR repository as implemented by the hex package [ex_cldr](https://hex.pm/packages/ex_cldr). These rules define the number of fractional digits for a currency and the rounding increment where appropriate.\n\n8. Money output string formatting output using the hex package [ex_cldr](https://hex.pm/packages/ex_cldr) that correctly rounds to the appropriate number of fractional digits and to the correct rounding increment for currencies that have minimum cash increments (like the Swiss Franc and Australian Dollar)","title":"Introduction to Money","ref":"readme.html"},{"type":"extras","doc":"* `Money` is supported on Elixir 1.11 and later only.","title":"Prerequisities - Introduction to Money","ref":"readme.html#prerequisities"},{"type":"extras","doc":"`Money` starts a supervisor `Money.Supervisor` by default unless the dependency is configured as `runtime: false` in `mix.exs`. If configured as `runtime: false` then the application can be started later via `Money.Application.start(:normal, supervisor_options)` where `supervisor_options` is a keyword list of options that is given the `Supervisor.start_link/2`. The default options are `[strategy: :one_for_one, name: Money.Supervisor]`.\n\nThe application supervisor is used by default to start the exchange rates service when required. The exchange rate service can be configured to run in a user defined supervision tree as explained in the next section.","title":"Supervisor configuration and operation - Introduction to Money","ref":"readme.html#supervisor-configuration-and-operation"},{"type":"extras","doc":"As of [ex_cldr_currencies version 2.6.0](https://hex.pm/packages/ex_cldr_currencies/2.6.0) it is possible to define private use currencies. These are currencies that are [ISO 4217](https://www.iso.org/iso-4217-currency-codes.html) compliant but guaranteed never to be allocated by the ISO committee and therefore safe to be used by developers.","title":"Private Use Currencies - Introduction to Money","ref":"readme.html#private-use-currencies"},{"type":"extras","doc":"See [Cldr.Currency.new/2](https://hexdocs.pm/ex_cldr_currencies/Cldr.Currency.html#new/2)","title":"Defining private use currencies - Introduction to Money","ref":"readme.html#defining-private-use-currencies"},{"type":"extras","doc":"In order to define private use currencies, a special `:ets` table is required to hold their definitions. The is implemented by a supervisor and two workers that together aim to preserve the availability of the `:ets` table as resiliently as possible. The implementation is an embedded and updated version of [eternal](https://hex.pm/packages/eternal).\n\nThe basic requirement is to add a the private use currency supervisor to your applications supervision tree. For example:\n```elixir\ndefmodule MyApp do\n  use Application\n\n  def start(_type, _args) do\n\n    # Start the service which maintains the\n    # :ets table that holds the private use currencies\n    children = [\n      Cldr.Currency\n      ...\n    ]\n\n    opts = [strategy: :one_for_one, name: MoneyTest.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\nIt is also possible to define a callback that is called when the `Cldr.Currency` supervisor is started so that private use currencies can be defined. For further information see [Defining Private Use Currencies](https://hexdocs.pm/ex_cldr_currencies/readme.html#defining-private-use-currencies).","title":"Starting the private use currency store - Introduction to Money","ref":"readme.html#starting-the-private-use-currency-store"},{"type":"extras","doc":"Money includes a process to retrieve exchange rates on a periodic basis.  These exchange rates can then be used to support currency conversion.  This service is not started by default.  If started it will attempt to retrieve exchange rates every 5 minutes by default.\n\nBy default, exchange rates are retrieved from [Open Exchange Rates](http://openexchangerates.org) however any module that conforms to the `Money.ExchangeRates` behaviour can be configured.\n\nAn optional callback module can also be defined.  This module defines a `rates_retrieved/2` function that is invoked upon every successful retrieval of exchange rates.  This might be used to serialize exchange rate to a data store or to stream rates to other applications or systems.","title":"Exchange rates and currency conversion - Introduction to Money","ref":"readme.html#exchange-rates-and-currency-conversion"},{"type":"extras","doc":"`Money` provides a set of configuration keys to customize behaviour. The default configuration is:\n\n    config :ex_money,\n      exchange_rates_retrieve_every: 300_000,\n      api_module: Money.ExchangeRates.OpenExchangeRates,\n      callback_module: Money.ExchangeRates.Callback,\n      exchange_rates_cache_module: Money.ExchangeRates.Cache.Ets,\n      preload_historic_rates: nil,\n      retriever_options: nil,\n      log_failure: :warning,\n      log_info: :info,\n      log_success: nil,\n      json_library: Jason,\n      default_cldr_backend: MyApp.Cldr,\n      exclude_protocol_implementations: []","title":"Configuration - Introduction to Money","ref":"readme.html#configuration"},{"type":"extras","doc":"* `:default_cldr_backend` defines the `Cldr` backend module that is default for `Money`.  See the [ex_cldr documentation](https://hexdocs.pm/ex_cldr/2.0.0/readme.html) for further information on how to define this module.  **This is a required option**.\n\n* `:exchange_rates_retrieve_every` defines how often the exchange rates are retrieved in milliseconds.  The default is `:never`. An `atom` value is interpreted to mean that there should be no periodic retrieval.\n\n* `:api_module` identifies the module that does the retrieval of exchange rates. This is any module that implements the `Money.ExchangeRates` behaviour.  The  default is `Money.ExchangeRates.OpenExchangeRates`.\n\n* `:exchange_rates_cache_module` defines the module that provides an exchange rates cache.  Any module that implements the `Money.ExchangeRates.Cache` behaviour.  Two alternative strategies are provided:\n\n  * `Money.ExchangeRates.Cache.Ets` which is also the default.\n  * `Money.ExchangeRates.Cache.Dets`\n\n* `:preload_historic_rates` defines a date or a date range that will be requested when the exchange rate service starts up. The date or date range should be specified as either a `Date.t` or a `Date.Range.t` or a tuple of `{Date.t, Date.t}` representing the `from` and `to` dates for the rates to be retrieved. The default is `nil` meaning no historic rates are preloaded. See [Preloading historic rates](#preloading-historic-rates) for more information.\n\n* `callback_module` defines a module that follows the `Money.ExchangeRates.Callback` behaviour whereby the function `rates_retrieved/2` is invoked after every successful retrieval of exchange rates.  The default is `Money.ExchangeRates.Callback`.\n\n* `log_failure` defines the log level at which api retrieval errors are logged.  The default is `:warning`.\n\n* `log_success` defines the log level at which successful api retrieval notifications are logged.  The default is `nil` which means no logging.\n\n* `log_info` defines the log level at which service startup messages are logged.  The default is `info`.\n\n* `:retriever_options` is available for exchange rate retriever module developers as a place to add retriever-specific configuration information.  This information should be added in the `init/1` callback in the retriever module.  See `Money.ExchangeRates.OpenExchangeRates.init/1` for an example.\n\n* `:json_library` determines which json library to be used for decoding.  Two common options are `Poison` and `Jason`. The default is `Cldr.Config.json_library/0` which is currently configured by default as `Jason`.\n\n* `:exclude_protocol_implementations` is a protocol module, or list of protocol modules, that will not be defined by `ex_money`. The default is `[]`. The protocol implementations influenced by this option at `Json.Encoder`, `Phoenix.HTML.Safe` and `Gringotts.Money`.","title":"Configuration key definitions - Introduction to Money","ref":"readme.html#configuration-key-definitions"},{"type":"extras","doc":"Note that `ex_money` does not define a json library dependency and therefore it is the users responsibility to configure the required json library as a dependency in the application's `mix.exs`.\n\nThe recommended library is [jason](https://hex.pm/packages/jason) which would be configured as:\n```\n  defp deps do\n    [\n      {:jason, \"~> 1.0\"},\n      ...\n    ]\n  end\n```\n`ex_money` depends on `ex_cldr` which provides currency and localisation data. The default configuration of `ex_money` uses the default `json_library` from `ex_cldr`.  This can be configured as follows in `config.exs`:\n```\nconfig :ex_cldr,\n  json_library: Jason\n```\nIn most cases this is not required since the presence of `Jason` (or `Poison`) is automatic.","title":"JSON library configuration - Introduction to Money","ref":"readme.html#json-library-configuration"},{"type":"extras","doc":"`Money` uses [ex_cldr](https://hex.pm/packages/ex_cldr) and [ex_cldr_numbers](https://hex.pm/packages/ex_cldr_numbers) to support configuring locales and providing locale formatting.  These packages are also the source of currency definitions, names, formats and so on.\n\nTo use `Cldr` and therefore `Money`, a backend module must be defined.  This module will host the `Cldr` data and public API used by `Money`.  A simple example would be:\n```\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"fr\", \"zh\"],\n    default_locale: \"en\",\n    providers: [Cldr.Number, Money]\nend\n```","title":"Configuring locales to support localised formatting - Introduction to Money","ref":"readme.html#configuring-locales-to-support-localised-formatting"},{"type":"extras","doc":"The current implementation will call the api_module to retrieve the historic rates once for each date in the `:preload_historic_rates` range.  Some exchange rate services, like Open Exchange Rates, provides a bulk retrieval api that can retrieve multiple dates in a single call.  However this endpoint is only available for premium subscribers and it is still charged on a \"per date retrieved\" basis. So while there is a network/performance/efficiency benefit there is no economic benefit.  Please file an issue on [github](https://github.com/kipcole9/money) if implementing a bulk api is important to you.\n\nSome examples of configuring the `:preload_historic_rates` key follow:\n\n  * `preload_historic_rates: ~D[2017-01-01]`\n  * `preload_historic_rates: Date.range(~D[2017-01-01], ~D[2017-10-01])`\n  * `preload_historic_rates: {~D[2017-01-01], ~D[2017-10-01]}`","title":"Preloading historic rates - Introduction to Money","ref":"readme.html#preloading-historic-rates"},{"type":"extras","doc":"If you plan to use the provided Open Exchange Rates module to retrieve exchange rates then you should also provide the addition configuration key for `app_id`:\n\n      config :ex_money,\n        open_exchange_rates_app_id: \"your_app_id\"\n\n  or configure it via environment variable, for example:\n\n      config :ex_money,\n        open_exchange_rates_app_id: {:system, \"OPEN_EXCHANGE_RATES_APP_ID\"}\n\nThe default exchange rate retrieval module is provided in `Money.ExchangeRates.OpenExchangeRates` which can be used as a example to implement your own retrieval module for  other services.","title":"Open Exchange Rates configuration - Introduction to Money","ref":"readme.html#open-exchange-rates-configuration"},{"type":"extras","doc":"During exchange rate service startup, the function `init/1` is called on the configured exchange rate retrieval module.  This module is expected to return an updated configuration allowing a developer to customise how the configuration is to be managed.  See the implementation at `Money.ExchangeRates.OpenExchangeRates.init/1` for an example.\n\nTo support runtime (re-)configuration the following functions are provided:\n\n  * `Money.ExchangeRates.Retriever.config/0` returns the current configuration of the exchange rates retrieval service.\n\n  * `Money.ExchangeRates.Retriever.stop/0` and `Money.ExchangeRates.Retriever.start/0` stop and start the exchange rates retrieval service respectively.\n\n  * `Money.ExchangeRates.Retriever.reconfigure/1` reconfigures the exchange rates retrieval service.  It does not restart the service, the service remains active during the recongiguration.","title":"Managing the configuration at runtime - Introduction to Money","ref":"readme.html#managing-the-configuration-at-runtime"},{"type":"extras","doc":"Keys can also be configured to retrieve values from environment variables.  This lookup is done at runtime to facilitate deployment strategies.  If the value of a configuration key is `{:system, \"some_string\"}` then `\"some_string\"` is interpreted as an environment variable name which is passed to `System.get_env/2`.  An example configuration might be:\n\n    config :ex_money,\n      auto_start_exchange_rate_service: {:system, \"RATE_SERVICE\"},\n      exchange_rates_retrieve_every: {:system, \"RETRIEVE_EVERY\"},\n      open_exchange_rates_app_id: {:system, \"OPEN_EXCHANGE_RATES_APP_ID\"}\n\nNote that the `{:system, \"ENV KEY\"}` approach is **not** currently supported for the `:preload_historic_rates` configuration key.","title":"Using Environment Variables in the configuration - Introduction to Money","ref":"readme.html#using-environment-variables-in-the-configuration"},{"type":"extras","doc":"If the exchange rate service is configured to automatically start up (because the config key `auto_start_exchange_rate_service` is set to `true`) then a supervisor process named `Money.ExchangeRates.Supervisor` is started which in turns starts a child `GenServer` called `Money.ExchangeRates.Retriever`.  It is `Money.ExchangeRates.Retriever` which will call the configured `api_module` to retrieve the rates.  It is also responsible for calling the configured `callback_module` after a successfull retrieval.\n\n                                         +-----------------+\n                                         |                 |\n    +-------------+    +-----------+     |   api_module    |-> External Service\n    |             |    |           |---> |                 |\n    | Supervisor  |--->| Retriever |     +-----------------+\n    |             |    |           |---> +-----------------+\n    +-------------+    +-----------+     |                 |\n                                         | callback_module |\n                                         |                 |\n                                         +-----------------+\n\nOn application start (or manual start if `:auto_start_exchange_rate_service` is set to `false`), `Money.ExchangeRates.Retriever` will schedule the first retrieval to be executed after immediately and then each `:exchange_rates_retrieve_every` milliseconds thereafter.","title":"The Exchange rates service process supervision and startup - Introduction to Money","ref":"readme.html#the-exchange-rates-service-process-supervision-and-startup"},{"type":"extras","doc":"If you provide your own callback module and that module depends on some other applications, like `Ecto`, already being started then automatically starting `Money.ExchangeRates.Supervisor` may not work since your `Ecto.Repo` is unlikely to have already been started.\n\nIn this situation the appropriate way to configure the exchange rates retrieval service is the following:\n\n1. Set the configuration key `auto_start_exchange_rate_service` to `false` to prevent automatic startup of the service.\n\n2. Configure your `api_module`, `callback_module` and any other required configuration as appropriate\n\n3. In your client application code, add the `Money.ExchangeRates.Supervisor` to the `children` configuration of your application.  For example, in an application that uses `Ecto` and where your `callback_module` is designed to save exchange rates to a database, your application may would look something like:\n\n```elixir\ndefmodule Application do\n  use Application\n\n  def start(_type, _args) do\n    import Supervisor.Spec\n\n    children = [\n\n      # Start your repo first so that it is running before your\n      # exchange rates callback module is called\n      supervisor(MoneyTest.Repo, []),\n\n      # Include the Money.ExchangeRates.Supervisor in your application's\n      # supervision tree.  This supervisor will start the child process\n      # Money.ExchangeRates.Retriever.\n\n      # Note the use of double `[]` around\n      # the parameters which are required to ensure that the supervisor\n      # is stopped before including in your supervisor tree.\n      # The `start_retriever: true` is optional.  The default value is `false`.\n      supervisor(Money.ExchangeRates.Supervisor, [[restart: true, start_retriever: true]])\n    ]\n\n    opts = [strategy: :one_for_one, name: Application.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```","title":"Using Ecto or other applications from within the callback module - Introduction to Money","ref":"readme.html#using-ecto-or-other-applications-from-within-the-callback-module"},{"type":"extras","doc":"","title":"API Usage Examples - Introduction to Money","ref":"readme.html#api-usage-examples"},{"type":"extras","doc":"iex> Money.new(:USD, 100)\n    #Money<:USD, 100>\n\n    iex> Money.new(100, :USD)\n    #Money<:USD, 100>\n\n    iex> Money.new(\"CHF\", \"130.02\")\n    #Money<:CHF, 130.02>\n\n    iex> Money.new(\"thb\", 11)\n    #Money<:THB, 11>\n\n    iex> Money.new(\"1.000,99\", :EUR, locale: \"de\")\n    #Money<:EUR, 1000.99>\n\n    iex> Money.parse(\"USD 100\")\n    #Money<:USD, 100>\n\n    iex> Money.parse(\"USD 100,00\", locale: \"de\")\n    #Money<:USD, 100.00>\n\nThe canonical representation of a currency code is an `atom` that is a valid\n[ISO4217](http://www.currency-iso.org/en/home/tables/table-a1.html) currency code or a `t:String.t/0` representation of an [ISO 24165](https://www.iso.org/standard/80601.html) digital token identifier. The amount of a `%Money{}` is represented by a `Decimal`.\n\nNote that the amount and currency code arguments to `Money.new/3` can be supplied in either order.","title":"Creating a %Money{} struct - Introduction to Money","ref":"readme.html#creating-a-money-struct"},{"type":"extras","doc":"`Money` provides an ability to parse strings that contain a currency and an amount.  The currency can be represented in different ways depending on the locale. See `Money.parse/2` for further information.  Some examples are:\n\n```\n  # These are the strings available for a given currency\n  # and locale that are recognised during parsing\n  iex> Cldr.Currency.strings_for_currency :AUD, \"de\"\n  [\"aud\", \"au$\", \"australischer dollar\", \"australische dollar\"]\n\n  iex> Money.parse \"$au 12 346\", locale: \"fr\"\n  #Money<:AUD, 12346>\n\n  iex> Money.parse \"12 346 dollar australien\", locale: \"fr\"\n  #Money<:AUD, 12346>\n\n  iex> Money.parse \"A$ 12346\", locale: \"en\"\n  #Money<:AUD, 12346>\n\n  iex> Money.parse \"australian dollar 12346.45\", locale: \"en\"\n  #Money<:AUD, 12346.45>\n\n  # Parse using a default currency\n  iex> Money.parse(\"100\", default_currency: :EUR)\n  #Money<:EUR, 100>\n\n  # Parse using the default currency of the locale\n\t# If no `:locale` option is provided then\n\t# the locale associated with `Money.default_backend/0`\n\t# is used.\n  iex> Money.parse(\"100\", locale: \"en\")\n  #Money<:EUR, 100>\n\n  # Parse with a default currency for the current locale\n  iex> Money.parse(\"100\", default_currency: Money.default_currency_for_locale())\n  #Money<:USD, 100>\n\n  # Note that the decimal separator in the \"de\" locale\n  # is a `.`\n  iex> Money.parse \"AU$ 12346,45\", locale: \"de\"\n  #Money<:AUD, 12346.45>\n\n  # Round trip formatting is supported\n  iex> {:ok, string} = Cldr.Number.to_string 1234, Money.Cldr, currency: :AUD\n  {:ok, \"A$1,234.00\"}\n  iex> Money.parse string\n  #Money<:AUD, 1234.00>\n\n  # Fuzzy matching is possible\n  iex> Money.parse(\"100 eurosports\", fuzzy: 0.8)\n  #Money<:EUR, 100>\n\n  iex> Money.parse(\"100 eurosports\", fuzzy: 0.9)\n  {:error,\n   {Money.Invalid, \"Unable to create money from \\\"eurosports\\\" and \\\"100\\\"\"}}\n\n  # Eligible currencies can be filtered\n  iex> Money.parse(\"100 eurosports\", fuzzy: 0.8, only: [:current])\n  #Money<:EUR, 100>\n\n  iex> Money.parse(\"100 euro\", only: [:EUR, :USD, :COP])\n  #Money<:EUR, 100>\n\n  iex> Money.parse(\"100 euro\", except: [:EUR, :USD, :COP])\n  {:error,\n    {Money.UnknownCurrencyError,\n      \"The currency \\\"euro\\\" is unknown or not supported\"}}\n\n  iex> Money.parse \"100 afghan afghanis\"\n  #Money<:AFN, 100>\n\n  iex> Money.parse \"100 afa\", only: [:current]\n  {:error,\n   {Money.UnknownCurrencyError,\n    \"The currency \\\"afa\\\" is unknown or not supported\"}}\n```","title":"Parsing money strings - Introduction to Money","ref":"readme.html#parsing-money-strings"},{"type":"extras","doc":"`Money` supports form field inputs that are a single string combining both a currency code and an amount.  When a form field (or other data) is [cast](https://hexdocs.pm/ecto/Ecto.Changeset.html#cast/4) then `Money` will attempt to parse a string field into a `Money.t` using `Money.parse/2`. Therefore simple money form input can be supported with a single input field of `type=text`.\n\nNote that when parsing the input text, the amount is interpreted in the context of the current locale set on the default backend configured for `ex_money`.  This affects how separator characters are interpreted in exactly the same way as is done for `Money.new/3`.","title":"Casting a money type (basic support for HTML forms) - Introduction to Money","ref":"readme.html#casting-a-money-type-basic-support-for-html-forms"},{"type":"extras","doc":"Float have well-known issues in computing due to issues of rounding and potential precision loss.  Internally `Money` uses `Decimal` to store the amount which allows arbitrary precision arithmetic.  `Money` also uses the `numeric` type in Postgres to preserve precision and even goes to far as to store the amount as a `string` in `MySQL` for the same reason.\n\nTherefore an error is returned if an attempt is made to use `Money.new/2` with a float amount:\n\n    {:error,\n     {Money.InvalidAmountError,\n      \"Float amounts are not supported in new/2 due to potenial rounding \" <>\n        \"and precision issues.  If absolutely required, use Money.from_float/2\"}}\n\nIf the use of `float`s is require then the function `Money.from_float/2` is provided with the same arguments as those for `Money.new/2`.  `Money.from_float/2` provides an addition check and will return an error if the precision (number of digits) of the provided float is more than 15 (the number of digits guaranteed to round-trip between a 64-bit float and a string).","title":"Float amounts cannot be provided to `Money.new/2` - Introduction to Money","ref":"readme.html#float-amounts-cannot-be-provided-to-money-new-2"},{"type":"extras","doc":"`Money` values can be compared as long as they have the same currency. The recommended function is `Money.compare/2` which, given two compatible money amounts, will return `:lt`, `:eq` or `:gt` depending on the relationship. For example:\n```\niex> Money.compare Money.new(:USD, 100), Money.new(:USD, 200)\n:lt\n\niex> Money.compare Money.new(:USD, 100), Money.new(:AUD, 200)\n{:error,\n {ArgumentError,\n  \"Cannot compare monies with different currencies. Received :USD and :AUD.\"}}\n```\n\nFrom Elixir verison `1.10.0` onwards, several functions in the `Enum` module can use the `Money.compare/2` function to simplify sorting. For example:\n```\niex> list = [Money.new(:USD, 100), Money.new(:USD, 200)]\n[#Money<:USD, 100>, #Money<:USD, 200>]\niex> Enum.sort list, Money\n[#Money<:USD, 100>, #Money<:USD, 200>]\niex> Enum.sort list, {:asc, Money}\n[#Money<:USD, 100>, #Money<:USD, 200>]\niex> Enum.sort list, {:desc, Money}\n[#Money<:USD, 200>, #Money<:USD, 100>]\n```\n\n**Note that `Enum.sort/2` will sort money amounts even when the currencies are incompatible. In this case the order of the result is not predictable. It is the developers responsibility to filter the list to compatible currencies prior to sorting. This is a limitation of the `Enum.sort/2` implementation.**","title":"Comparison functions - Introduction to Money","ref":"readme.html#comparison-functions"},{"type":"extras","doc":"An optional sigil module is available to aid in creating %Money{} structs.  It needs to be imported before use:\n\n    import Money.Sigil\n\n    ~M[100]USD\n    #> #Money<:USD, 100>","title":"Optional ~M sigil - Introduction to Money","ref":"readme.html#optional-m-sigil"},{"type":"extras","doc":"`Money` provides locale-specific formatted output that is controlled be either the locale that has been set for this process or by the `:locale` parameter supplied to `Money.to_string/2`.  Configuring your localised environment requires configuring `ex_cldr` which is a dependency to `Money`.  See the [Configuration](https://github.com/kipcole9/cldr#configuration) section of the `ex_cldr` readme for more information.\n\nThe main API for formatting `Money` is `Money.to_string/2`. Additionally formatting options are passed to `Cldr.Number.to_string/2`.  Those options are described in the [readme for ex_cldr_numbers](https://github.com/kipcole9/cldr_numbers#primary-public-api) which is also a dependency to `Money`.\n\n    iex> Money.to_string Money.new(\"thb\", 11)\n    {:ok, \"THB11.00\"}\n\n    # The default locale is \"en-001\" which is\n    # \"global english\"\n    iex> Money.to_string Money.new(\"USD\", \"234.467\")\n    {:ok, \"$US234.47\"}\n\n    # The locale \"en\" is \"American English\".  For\n    # UK English use the locale \"en-GB\".  Australian\n    # English is \"en-AU\" and so on.\n    iex> Money.to_string Money.new(\"USD\", \"234.467\"), locale: \"en\"\n    {:ok, \"$234.47\"}\n\n    iex> Money.to_string Money.new(\"USD\", \"234.467\"), format: :long\n    {:ok, \"234.47 US dollars\"}\n\n    iex> Money.to_string Money.new(\"USD\", \"234.467\"), locale: \"fr\"\n    {:ok, \"234,47 $US\"}\n\n    iex> Money.to_string Money.new(\"USD\", \"234.467\"), locale: \"de\"\n    {:ok, \"234,47 $\"}\n\n    iex> Money.to_string Money.new(\"EUR\", \"234.467\"), locale: \"de\"\n    {:ok, \"234,47 €\"}\n\n    iex> Money.to_string Money.new(\"EUR\", \"234.467\"), locale: \"fr\"\n    {:ok, \"234,47 €\"}\n\n**Note that the output is influenced by the locale in effect.**  By default the locale used is that returned by `Cldr.get_locale/0`.  Its default value is `:en-001`.  Additional locales can be configured, see `Cldr`.  The formatting options are defined in `Cldr.Number.to_string/2`.","title":"Localised Money formatting - Introduction to Money","ref":"readme.html#localised-money-formatting"},{"type":"extras","doc":"See also the module `Money.Arithmetic`:\n\n    iex> m1 = Money.new(:USD, 100)\n    #Money<:USD, 100>}\n\n    iex> m2 = Money.new(:USD, 200)\n    #Money<:USD, 200>}\n\n    iex> Money.add(m1, m2)\n    {:ok, #Money<:USD, 300>}\n\n    iex> Money.add!(m1, m2)\n    #Money<:USD, 300>\n\n    iex> m3 = Money.new(:AUD, 300)\n    #Money<:AUD, 300>\n\n    iex> Money.add Money.new(:USD, 200), Money.new(:AUD, 100)\n    {:error, {ArgumentError, \"Cannot add monies with different currencies. Received :USD and :AUD.\"}}\n\n    # Split a %Money{} returning the a dividend and a remainder. All\n    # operations respect the number of fractional digits defined for a currency\n    iex> m1 = Money.new(:USD, 100)\n    #Money<:USD, 100>\n\n    iex> Money.split(m1, 3)\n    {#Money<:USD, 33.33>, #Money<:USD, 0.01>}\n\n    # Rounding applies the currency definitions of CLDR as implemented in\n    # the hex package [ex_cldr](https://hex.pm/packages/ex_cldr)\n    iex> Money.round Money.new(:USD, \"100.678\")\n    #Money<:USD, 100.68>\n\n    iex> Money.round Money.new(:JPY, \"100.678\")\n    #Money<:JPY, 101>","title":"Arithmetic Functions - Introduction to Money","ref":"readme.html#arithmetic-functions"},{"type":"extras","doc":"A `%Money{}` struct can be converted to another currency using `Money.to_currency/3` or `Money.to_currency!/3`.  For example:\n\n    iex> Money.to_currency Money.new(:USD, 100), :AUD\n    {:ok, #Money<:AUD, 136.43>}\n\n    iex> Money.to_currency Money.new(:USD, 100), :AUD, ExchangeRates.historic_rates(~D[2017-01-01])\n    {:ok, #Money<:AUD, 128.76>}\n\n    iex> Money.to_currency Money.new(:USD, 100) , :AUDD, %{USD: Decimal.new(1), AUD: Decimal.new(0.7345)}\n    {:error, {Cldr.UnknownCurrencyError, \"Currency :AUDD is not known\"}}\n\n    iex> Money.to_currency! Money.new(:USD, 100), :XXX\n    ** (Money.ExchangeRateError) No exchange rate is available for currency :XXX\n\nA user-defined map of exchange rates can also be supplied:\n\n    iex> Money.to_currency Money.new(:USD, 100), :AUD, %{USD: Decimal.new(1.0), AUD: Decimal.new(1.3)}\n    #Money<:AUD, 130>","title":"Currency Conversion - Introduction to Money","ref":"readme.html#currency-conversion"},{"type":"extras","doc":"As noted in the [configuration](#configuration) section, `ex_money` can preload historic exchange rates when the exchange rates service starts up.  It can be anticipated that additional historic rates may be required subsequently.\n\n* `Money.ExchangeRates.Retriever.historic_rates/1` can be called to request retrieval of historic rates at any time.  This call will send a message to the retrieval service to request retrieval.  It does not return the rates.\n\n* `Money.ExchangeRates.historic_rates/1` is the partner function to `Money.ExchangeRates.latest_rates/0`.  It returns the exchange rates for a given date, and will return an error if no rates are available.","title":"Historic Conversion Rates - Introduction to Money","ref":"readme.html#historic-conversion-rates"},{"type":"extras","doc":"A set of basic financial functions are available in the module `Money.Financial`.   These functions are:\n\n* Present value: `Money.Financial.present_value/3`\n* Future value: `Money.Financial.future_value/3`\n* Interest rate: `Money.Financial.interest_rate/3`\n* Number of periods: `Money.Financial.periods/3`\n* Payment amount: `Money.Financial.payment/3`\n* Net Present Value of a set of cash flows: `Money.Financial.net_present_value/2`\n* Internal rate of return: `Money.Financial.internal_rate_of_return/1`\n\nFor more detail see `Money.Financial`.","title":"Financial Functions - Introduction to Money","ref":"readme.html#financial-functions"},{"type":"extras","doc":"Subscriptions, especially in the context of a SaaS, can involve changing plans - either from a smaller plan to a larger or a larger plan to smaller.  In either situation a credit amount needs to be calculated based upon the current plan which is then applied to the new plan.  `Money.Subscription` is a module that provides functions to support this subscription pricing, credit calculations and payment dates.\n\nThe primary functions supporting subscriptions are:\n\n* Create a new subscription: `Money.Subscription.new/3`\n* Create a subscription plan: `Money.Subscription.Plan.new/3`\n* Change a from one plan to another: `Money.Subscription.change_plan/3`\n* Calculate the start date for the next interval of a plan: `Money.Subscription.next_interval_starts/3`\n* Calculate the number of days in a plan interval: `Money.Subscription.plan_days/3`\n* Calculate the number of days left in a plan interval: `Money.Subscription.days_remaining/4`","title":"Subscriptions - Introduction to Money","ref":"readme.html#subscriptions"},{"type":"extras","doc":"# Create the current plan\n    iex> current_plan = Money.Subscription.Plan.new!(Money.new(:USD, 10), :month, 1)\n    %Money.Subscription.Plan{\n      interval: :month,\n      interval_count: 1,\n      price: #Money<:USD, 10>\n    }\n\n    # How many days in a billing period?\n    iex> Money.Subscription.plan_days current_plan, ~D[2018-03-01]\n    31\n\n    iex> Money.Subscription.plan_days current_plan, ~D[2018-02-01]\n    28\n\n    # How many days remaining in the current billing period\n    iex> Money.Subscription.days_remaining current_plan, ~D[2018-03-01], ~D[2018-03-10]\n    22\n\n    # When is the next billing date\n    iex> Money.Subscription.next_interval_starts current_plan, ~D[2018-03-01]\n    ~D[2018-04-01]\n\n    # Create a new plan\n    iex> new_plan = Money.Subscription.Plan.new!(Money.new(:USD, 10), :month, 3)\n    %Money.Subscription.Plan{\n      interval: :month,\n      interval_count: 3,\n      price: #Money<:USD, 10>\n    }\n\n    # Change plans at the end of the current billing period\n    iex> Money.Subscription.change_plan current_plan, new_plan, current_interval_started: ~D[2018-03-01]\n    %Money.Subscription.Change{\n      carry_forward: #Money<:USD, 0>,\n      credit_amount: #Money<:USD, 0>,\n      credit_amount_applied: #Money<:USD, 0>,\n      credit_days_applied: 0,\n      credit_period_ends: nil,\n      first_billing_amount: #Money<:USD, 10>,\n      first_interval_starts: ~D[2018-04-01],\n      next_interval_starts: ~D[2018-07-01]\n    }\n\n    # Change plans in the middle of the current plan period\n    # and credit the balance of the current plan to the new plan\n    iex> Money.Subscription.change_plan current_plan, new_plan, current_interval_started: ~D[2018-03-01], effective: ~D[2018-03-15]\n    %Money.Subscription.Change{\n      carry_forward: #Money<:USD, 0>,\n      credit_amount: #Money<:USD, 5.49>,\n      credit_amount_applied: #Money<:USD, 5.49>,\n      credit_days_applied: 0,\n      credit_period_ends: nil,\n      first_billing_amount: #Money<:USD, 4.51>,\n      first_interval_starts: ~D[2018-03-15],\n      next_interval_starts: ~D[2018-06-15]\n    }\n\n    # Change plans in the middle of the current plan period\n    # but instead of a monetary credit, apply the credit as\n    # extra days on the new plan in the first billing period\n    iex> Money.Subscription.change_plan current_plan, new_plan, current_interval_started: ~D[2018-03-01], effective: ~D[2018-03-15], prorate: :period\n    %Money.Subscription.Change{\n      carry_forward: #Money<:USD, 0>,\n      credit_amount: #Money<:USD, 5.49>,\n      credit_amount_applied: #Money<:USD, 0>,\n      credit_days_applied: 51,\n      credit_period_ends: ~D[2018-05-04],\n      first_billing_amount: #Money<:USD, 10>,\n      first_interval_starts: ~D[2018-03-15],\n      next_interval_starts: ~D[2018-08-05]\n    }\n\n    # Create a subscription\n    iex> plan = Money.Subscription.Plan.new!(Money.new(:USD, 200), :month, 3)\n    iex> subscription = Money.Subscription.new! plan, ~D[2018-01-01]\n    %Money.Subscription{\n      created_at: #DateTime<2018-03-23 07:45:44.418916Z>,\n      id: nil,\n      plans: [\n        {%Money.Subscription.Change{\n           carry_forward: #Money<:USD, 0>,\n           credit_amount: #Money<:USD, 0>,\n           credit_amount_applied: #Money<:USD, 0>,\n           credit_days_applied: 0,\n           credit_period_ends: nil,\n           first_billing_amount: #Money<:USD, 200>,\n           first_interval_starts: ~D[2018-01-01],\n           next_interval_starts: ~D[2018-04-01]\n         },\n         %Money.Subscription.Plan{\n           interval: :month,\n           interval_count: 3,\n           price: #Money<:USD, 200>\n         }}\n      ]\n    }\n\n    # Change a subscription's plan\n    iex> new_plan = Money.Subscription.Plan.new!(Money.new(:USD, 150), :day, 30)\n    iex> Money.Subscription.change_plan! subscription, new_plan\n    %Money.Subscription{\n      created_at: #DateTime<2018-03-23 07:47:48.593973Z>,\n      id: nil,\n      plans: [\n        {%Money.Subscription.Change{\n           carry_forward: #Money<:USD, 0>,\n           credit_amount: #Money<:USD, 0>,\n           credit_amount_applied: #Money<:USD, 0>,\n           credit_days_applied: 0,\n           credit_period_ends: nil,\n           first_billing_amount: #Money<:USD, 150>,\n           first_interval_starts: ~D[2018-04-01],\n           next_interval_starts: ~D[2018-05-01]\n         },\n         %Money.Subscription.Plan{\n           interval: :day,\n           interval_count: 30,\n           price: #Money<:USD, 150>\n         }},\n        {%Money.Subscription.Change{\n           carry_forward: #Money<:USD, 0>,\n           credit_amount: #Money<:USD, 0>,\n           credit_amount_applied: #Money<:USD, 0>,\n           credit_days_applied: 0,\n           credit_period_ends: nil,\n           first_billing_amount: #Money<:USD, 200>,\n           first_interval_starts: ~D[2018-01-01],\n           next_interval_starts: ~D[2018-04-01]\n         },\n         %Money.Subscription.Plan{\n           interval: :month,\n           interval_count: 3,\n           price: #Money<:USD, 200>\n         }}\n      ]\n    }","title":"Examples - Introduction to Money","ref":"readme.html#examples"},{"type":"extras","doc":"The companion package [ex_money_sql](https://hex.pm/packages/ex_money_sql) provides functions for the serialization of `Money` data.  See the [README](https://hexdocs.pm/ex_money_sql/readme.html) for further information.","title":"Serializing to a database with Ecto - Introduction to Money","ref":"readme.html#serializing-to-a-database-with-ecto"},{"type":"extras","doc":"`Money` can be installed by adding `ex_money` to your list of dependencies in `mix.exs` and then executing `mix deps.get`\n\n```elixir\ndef deps do\n  [\n    {:ex_money, \"~> 5.0\"},\n    ...\n  ]\nend\n```","title":"Installation - Introduction to Money","ref":"readme.html#installation"},{"type":"extras","doc":"* Fully localized formatting and rounding using [ex_cldr](https://hex.pm/packages/ex_cldr)\n\n* Provides serialization to Postgres using a composite type and MySQL using a JSON type that keeps both the currency code and the amount together removing a source of potential error\n\n* Uses the `Decimal` type in Elixir and the Postgres `numeric` type to preserve precision.  For MySQL the amount is serialised as a string to preserve precision that might otherwise be lost if stored as a JSON numeric type (which is either an integer or a float)\n\n* Includes a set of financial calculations (arithmetic and cash flow calculations) that follow solid rounding rules","title":"Why yet another Money package? - Introduction to Money","ref":"readme.html#why-yet-another-money-package"},{"type":"extras","doc":"The [github gist](https://gist.github.com/rgs/6509585) gives a good summary of the challenges of managing money in an application. The following described how `Money` handles each of these assertions.\n\n**1. You can store a price in a floating point variable.**\n\n`Money` operates and serialises in a arbitrary precision Decimal value.\n\n**2. All currencies are subdivided in 1/100th units (like US dollar/cents, euro/eurocents etc.).**\n\n`Money` leverages CLDR which defines the appropriate number of decimal places of a currency. As of CLDR version 32 there are:\n\n  * 52 currencies with zero decimal digits\n  * 241 currencies with two decimal digits\n  * 6 currencies with three decimal digits\n  * and 1 currency with four decimal digits\n\n**3. All currencies are subdivided in decimal units (like dinar/fils)**\n\n**4. All currencies currently in circulation are subdivided in decimal units. (to exclude shillings, pennies) (counter-example: MGA)**\n\n**5. All currencies are subdivided. (counter-examples: KRW, COP, JPY... Or subdivisions can be deprecated.)**\n\n`Money` correctly manages the appropriate number of decimal places for a currency.  It also round correctly when formatting a currency for output (different currencies have different rounding levels for cash or transactions).\n\n**6. Prices can't have more precision than the smaller sub-unit of the currency. (e.g. gas prices)**\n\nAll `Money` calculations are done with decimal arithmetic to the maxium precision of 28 decimal digits.\n\n**7. For any currency you can have a price of 1. (ZWL)**\n\n`Money` makes no assumption about the value assigned as long as its a real number.\n\n**8. Every country has its own currency. (EUR is the best example, but also Franc CFA, etc.)**\n\n`Money` makes no assumptions about the linkage of currencies to territories.\n\n**9. No country uses another's country official currency as its official currency. (many countries use USD: Ecuador, Micronesia...)**\n\n**10. Countries have only one currency.**\n\n`Money` doesn't link territories (countries) to a currency - it focuses only on the `Money` domain.  The addon package [cldr_territories](https://github.com/Schultzer/cldr_territories) does have knowledge of what curriencies are in effect throughout history for a given territory.  See `Cldr.Territory.info/1`.\n\n**11. Countries have only one currency currently in circulation. (Panama officially uses both PAB and USD)**\n\n`Money` makes no assumptions about currencies in circulation.\n\n**12. I'll only deal with currencies currently in circulation anyway.**\n\n`Money` makes no assumptions about currencies in circulation.\n\n**13. All currencies have an ISO 4217 3-letter code. (The Transnistrian ruble has none, for example)**\n\n`Money` does validate currency codes against the ISO 4217 list.  Custom currencies can be created in accordance with ISO 4217 using `Cldr.Currency.new/2`.\n\n**14. All currencies have a different name. (French franc, \"nouveau franc\")**\n\n`Money` has localised names for all ISO 4217 currencies in each of the over 500 locales defined by CLDR.\n\n**15. You always put the currency symbol after the price.**\n\n`Money` formats currency strings according to a format mask that is either defined by CLDR or user supplied.\n\n**16. You always put the currency symbol before the price.**\n\n`Money` formats currency strings according to a format mask that is either defined by CLDR or user supplied.\n\n**17. You always put the currency symbol either after, or before the price, never in the middle.**\n\n`Money` formats currency strings according to a format mask that is either defined by CLDR or user supplied.\n\n**18. There's only one currency symbol for any currency. (元, 角, 分 are increasing units of the Chinese renminbi.)**\n\n`Money` uses format masks defined by CLDR which, for the Chinese renminbi uses the \"￥\" symbol.\n\n**19. For a given currency, you always, but always, put the symbol in the same place.**\n\n`Money` makes no assumpions about symbol placement.  The symbol can be places anywhere in a formatted string but is typically, for CLDR format masks, placed either before or after the formatted number.\n\n**20. OK. But if you only use the ISO 4217 currency codes, you always put it before the price. (Hint: it depends on the language.)**\n\nSame as for the answer to 19 above.\n\n**21. Before the price means on the left. (ILS)**\n\n`Money` formats according to a locale and correctly places symbols for languages written right-to-left.\n\n**22. You can always use a dot (or a comma, etc.) as a decimal separator.**\n\nThe decimal separator is defined per locale according to the CLDR definitions.\n\n**23. You can always use a space (or a dot, or a comma, etc.) as a thousands separator.**\n\nThe thousands (acutally grouping since not all locales format in thousands) separator is defined per locale according to the CLDR definitions.\n\n**24. You separate big prices by grouping numbers in triplets (thousands). (One writes ¥1 0000)**\n\nGrouping is done according the CLDR definitions.  For many languages the grouping is in thousands.  Some format other ways.  For example in India numbers are formatted with the first group as a triplet and subsequent groups as doublets.\n\n**25. Prices at a single company will never range from five digits before the decimal to five digits after.**\n\n`Money`'s default precision is 28 decimal digits.  All arithmetic is done using arbitrary precision decimal arithemetic.  No round is performed unless either explicitly requested or a money value is formatted for output.  When formatting rounding is applied according the locale-specific rules.\n\n**26. Prices contains only digits and punctuation. (Germans can write 12,- €)**\n\n`Money` format masks can contain very flexible formatting masks.  A set of formats is defined for each locale and a user-defined masks can also be defined.\n\n**27. A price can be at most 10^N for some value of N.**\n\nSee the answer to 25.\n\n**28. Given two currencies, there is only one exchange rate between them at any given point in time.**\n\n`Money` supports an exchange rate mechansim, currency conversions and retrieval from external exchange rate services.  It does not impose any constraint on underlying conversion tables.\n\n**29. Given two currencies, there is at least one exchange rate between them at any given point in time. (restriction on export of MAD, ARS, CNY, for example)**\n\nSee the answer to 28.\n\n**30. And the final one: a standalone $ character is always pronounced dollar. (It's also the peso sign.)**\n\nThis is outside the domain of `Money`.","title":"Falsehoods programmers believe about prices - Introduction to Money","ref":"readme.html#falsehoods-programmers-believe-about-prices"},{"type":"extras","doc":"# Changelog\n\n**Note** `ex_money` 5.17.0 and later is supported on Elixir 1.12 and later versions only.","title":"Changelog","ref":"changelog.html"},{"type":"extras","doc":"This is the changelog for Money v5.17.2 released on September 18th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.17.2 - Changelog","ref":"changelog.html#money-v5-17-2"},{"type":"extras","doc":"* Fix implementation of `Money.exclude_protocol_implementation/1` for `Jason.Encoder`. Thanks to @wkirschbaum for the PR. Closes #171.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Add  `Money.exclude_protocol_implementation/1` for `String.Chars`. Thanks to @wkirschbaum for the PR. Closes #172.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.17.1 released on September 6th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.17.1 - Changelog","ref":"changelog.html#money-v5-17-1"},{"type":"extras","doc":"* Update `poison` optional dependency to allow `~> 6.0`.\n\n* Update `stream_data` test dependency to `~> 1.0`.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Improve specs and broaden dialyzer configuration.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.17.0 released on May 28th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.17.0 - Changelog","ref":"changelog.html#money-v5-17-0"},{"type":"extras","doc":"* Fixes warnings on Elixir 1.17.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.16.1 released on April 23rd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.16.1 - Changelog","ref":"changelog.html#money-v5-16-1"},{"type":"extras","doc":"* `Money.sum/2` default exchange rates is always `%{}` even if the exchange rate server is not running. Thanks to @haste for the report. Closes #168.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.16.0 released on April 21st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.16.0 - Changelog","ref":"changelog.html#money-v5-16-0"},{"type":"extras","doc":"* When parsing numbers, use the localized number system separators where they exist. Thanks to @pshoukry for the report. Closes #167.\n\n* Surface errors when starting the exchange rates retriever. Thanks to @danschultzer for the PR. Closes #165.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Update to [CLDR 45.0](https://cldr.unicode.org/index/downloads/cldr-45) data.\n\n* Return structured errors for `Money.ExchangeRates.latest_rates/0`, `Money.ExchangeRates.historic_rates/1`, `Money.ExchangeRates.last_updated/0` and `Money.ExchangeRates.latest_rates_available?/0` when the exchange rates retrieval process is not running.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.15.4 released on March 1st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.15.4 - Changelog","ref":"changelog.html#money-v5-15-4"},{"type":"extras","doc":"* Fix exchange rate conversions for digital tokens. Thanks much to @ddanschultzer for the PR. Closes 164.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Format the exchange rate retrieval interval used in the init message using the default `cldr` backend configured for `:ex_money`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.15.3 released on January 4th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.15.3 - Changelog","ref":"changelog.html#money-v5-15-3"},{"type":"extras","doc":"* Add `or ~> 4.0` for `:phoenix_html` dependency. Thanks to @wkirschbaum for the PR. Closes #161.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.15.2 released on November 3rd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.15.2 - Changelog","ref":"changelog.html#money-v5-15-2"},{"type":"extras","doc":"* Fix compilation warnings on doctests on Elixir 1.16.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.15.1 released on October 10th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.15.1 - Changelog","ref":"changelog.html#money-v5-15-1"},{"type":"extras","doc":"* Fixes the exchange rate retriever, removing the double retrieval loop.  Thanks to @dbernheisel for the report. Closes #152.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.15.0 released on July 24th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.15.0 - Changelog","ref":"changelog.html#money-v5-15-0"},{"type":"extras","doc":"* Adds an option `:no_fraction_if_integer` to `Money.to_string/2`. If `truthy` this option will set `fractional_digits: 0` if `money` is an integer value. This may be helpful in cases where integer money amounts such as `Money.new(:USD, 1234)` should be formatted as `$1,234` rather than `$1,234.00`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.14.1 released on July 23rd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.14.1 - Changelog","ref":"changelog.html#money-v5-14-1"},{"type":"extras","doc":"* Fix `Logger.warn/1` warnings by moving to `Logger.warning/1`.\n\n* Fix failing test case.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.14.0 released on April 29th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.14.0 - Changelog","ref":"changelog.html#money-v5-14-0"},{"type":"extras","doc":"* Adds `Money.integer?/1` to return a boolean indicatng if a money amount is an integer value (ie has no significant fractional digits).","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.13.0 released on April 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.13.0 - Changelog","ref":"changelog.html#money-v5-13-0"},{"type":"extras","doc":"* Updates to [ex_cldr version 2.37.0](https://hex.pm/packages/ex_cldr/2.37.0) which includes data from [CLDR release 43](https://cldr.unicode.org/index/downloads/cldr-43)\n\n* Tests now assume Decimal ~> 2.0 since the `Inspect` protocol implementation now emits executable code examples.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.12.4 released on March 30th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.12.4` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.25` or later.","title":"Money v5.12.4 - Changelog","ref":"changelog.html#money-v5-12-4"},{"type":"extras","doc":"* Delegates http requests (used in exchange rates retrieval) to `Cldr.Http.get_with_headers/2`. This centralizes all HTTP get requests for all `ex_cldr_*` libraries to this one function which can then be reviewed and managed for security concerns.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.12.3 released on October 13th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.12.3` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.25` or later.","title":"Money v5.12.3 - Changelog","ref":"changelog.html#money-v5-12-3"},{"type":"extras","doc":"* Fix `NaN` and `Inf` amount detection to be compatible with Decimal 1.x and 2.x. Thanks to @Lostkobrakai for the PR. Closes #144.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.12.2 released on October 13th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.12.2` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.25` or later.","title":"Money v5.12.2 - Changelog","ref":"changelog.html#money-v5-12-2"},{"type":"extras","doc":"* Don't create \"NaN\" or \"Inf\" valued Money structs. Thanks for @coladarci for the report. Closes #143.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.12.1 released on August 27th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.12.1` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.25` or later.","title":"Money v5.12.1 - Changelog","ref":"changelog.html#money-v5-12-1"},{"type":"extras","doc":"* Removes compile-time warnings for Elixir 1.14 (use `Application.compile_env/2`, not `Application.get_env/2`)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.12.0 released on June 8th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.12.0` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.25` or later.","title":"Money v5.12.0 - Changelog","ref":"changelog.html#money-v5-12-0"},{"type":"extras","doc":"* Add `Money.localize/2` to convert a money amount into the currency in affect for the given locale.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.11.0 released on May 14th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.11.0` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.25` or later.","title":"Money v5.11.0 - Changelog","ref":"changelog.html#money-v5-11-0"},{"type":"extras","doc":"* Adds support for [ISO 24165 Digital Tokens (crypto currency)](https://www.iso.org/standard/80601.html). Digital Token-based money behaves the same as currency-based money with the following exceptions due to limited data availability:\n\n  * Digital token names are not localized (there is no localised data available in CLDR)\n  * Digital token names are not pluralized (also because there is no localised data available)\n  * Digital token amounts are never rounded (there is no data available to standardise on rounding rules or the number of fractional digits to round to)","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.10.0 released on April 6th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.10.0` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.25` or later.","title":"Money v5.10.0 - Changelog","ref":"changelog.html#money-v5-10-0"},{"type":"extras","doc":"* Add `Money.zero?/1`, `Money.positive?/1` and `Money.negative?/1`. Thanks to @emaiax for the PR.\n\n* Update [CLDR](https://cldr.unicode.org) to [release 41](https://cldr.unicode.org/index/downloads/cldr-41) in [ex_cldr version 2.28.0](https://hex.pm/packages/ex_cldr/2.28.0) and [ex_cldr_numbers 2.26.0](https://hex.pm/packages/ex_cldr_numbers/2.26.0).","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.9.0 released on February 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.9.0` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.25` or later.","title":"Money v5.9.0 - Changelog","ref":"changelog.html#money-v5-9-0"},{"type":"extras","doc":"* Updates to [ex_cldr version 2.26.0](https://hex.pm/packages/ex_cldr/2.26.0) and [ex_cldr_numbers version 2.25.0](https://hex.pm/packages/ex_cldr_numbers/2.25.0) which use atoms for locale names and rbnf locale names. This is consistent with other elements of `t:Cldr.LanguageTag` where atoms are used when the cardinality of the data is fixed and relatively small and strings where the data is free format.\n\n* Adjusts the output of `Money.inspect/2` to be executable code. Instead of `#Money<:USD, 100>` the output will be `Money.new(:USD, \"100\")`. This improved developer experience by allowing for copy/paste of `inspect/2` results into `iex`. It is also in line with similar changes being made in `elixir`, `Decimal` and others.\n\n* Add documentation for `:currency_symbol` option for `Money.to_string/2`. Although its an option that is passed through to `Cldr.Number.to_string/3`, its very relevant to `t:Money` formatting.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.8.0 released on January 31st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.8.0` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.23` or later.","title":"Money v5.8.0 - Changelog","ref":"changelog.html#money-v5-8-0"},{"type":"extras","doc":"* Adds configuration option `:exclude_protocol_implementations` to omit generating implementations for one or more protocols from the list `Json.Encoder`, `Phoneix.HTML.Safe` and `Gringotts.Money`. Thanks to @jgough-playoxygen for the [suggestion](https://elixirforum.com/t/cldr-number-custom-formatter/45520).","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.7.4 released on December 23rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.7.4` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.23` or later.","title":"Money v5.7.4 - Changelog","ref":"changelog.html#money-v5-7-4"},{"type":"extras","doc":"* Fix `Money.to_integer_exp/1` when `t:Money` has a negative amount.  Thanks to @hamptokr for the report and the PR.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.7.3 released on December 19th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.7.3` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.23` or later.","title":"Money v5.7.3 - Changelog","ref":"changelog.html#money-v5-7-3"},{"type":"extras","doc":"* Fixes retrieving exchange rates on OTP releases before OTP 22.  Thanks to @fbettag for the report, collaboration and patience.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.7.2 released on December 17th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.7.2` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.23` or later.","title":"Money v5.7.2 - Changelog","ref":"changelog.html#money-v5-7-2"},{"type":"extras","doc":"* Fix spec for `Money.from_integer/3`. Thanks to @jdewar for the report.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Support a `:fractional_digits` option for `Money.from_integer/3` and improve the documentation.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.7.1 released on December 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\n**Note** `ex_money 5.7.1` is supported on Elixir 1.10 and later versions only. It also requires `ex_cldr_numbers 2.23` or later.","title":"Money v5.7.1 - Changelog","ref":"changelog.html#money-v5-7-1"},{"type":"extras","doc":"* Fix dialyzer warnings on Elixir 1.12 and 1.13\n\n* Replace `use Mix.Config` with `import Config` in configuration files since the former is deprecated.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.7.0 released on October 28th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.7.0 - Changelog","ref":"changelog.html#money-v5-7-0"},{"type":"extras","doc":"* Updates to support [CLDR release 40](https://cldr.unicode.org/index/downloads/cldr-40) via [ex_cldr version 2.24](https://hex.pm/packages/ex_cldr/2.24.0)","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"* Don't call deprecated `Cldr.Config.get_locale/2`, use `Cldr.Locale.Loader.get_locale/2` instead.","title":"Deprecations - Changelog","ref":"changelog.html#deprecations"},{"type":"extras","doc":"This is the changelog for Money v5.6.0 released on August 31st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.6.0 - Changelog","ref":"changelog.html#money-v5-6-0"},{"type":"extras","doc":"* Adds `Money.to_currency_code/1` to return the currency code part of a `t:Money`. Thanks to @Adzz for the proposal. Closes #130.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.5.5 released on August 15th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.5.5 - Changelog","ref":"changelog.html#money-v5-5-5"},{"type":"extras","doc":"* Allow either `phoenix_html` version 2.x or 3.x. Thanks to @seantanly for the PR. Closes #129.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.5.4 released on June 17th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.5.4 - Changelog","ref":"changelog.html#money-v5-5-4"},{"type":"extras","doc":"* Support `t:Cldr.Number.Format.Options` as an argument to `Money.to_string/2`.  Thanks to @jeroenvisser101 for the PR. Closes #127.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.5.3 released on May 7th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.5.3 - Changelog","ref":"changelog.html#money-v5-5-3"},{"type":"extras","doc":"* Fixes parsing money when a currency string has a \".\" in it such as \"kr.\". Thanks for the report to @Doerge. Closes #125.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.5.2 released on April 14th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.5.2 - Changelog","ref":"changelog.html#money-v5-5-2"},{"type":"extras","doc":"* Fix exception message when describing the requirement for a default backend configuration. Thanks to @holandes22 for the report. Closes #124.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.5.1 released on February 18th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.5.1 - Changelog","ref":"changelog.html#money-v5-5-1"},{"type":"extras","doc":"* Fix formatting a `t:Money` that has no `:format_options` key. That can happen if re-hydrating a `t:Money` using `:erlang.binary_to_term/1` from an older version of `ex_money` that doesn't have the `:format_options` key in the struct.  Thanks to @coladarci. Fixes #123.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.5.0 released on February 10th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.5.0 - Changelog","ref":"changelog.html#money-v5-5-0"},{"type":"extras","doc":"* Adds format options to `t:Money` to allow per-money formatting options to be applied with the `String.Chars` protocol. Thanks to @morinap for the feature request.\n\n* Adds `Money.put_format_options/2`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.4.1 released on January 7th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.4.1 - Changelog","ref":"changelog.html#money-v5-4-1"},{"type":"extras","doc":"* Update `stream_data` to remove stacktrace warning\n\n* Use `Cldr.default_backend!/0` instead of deprecated `Cldr.default_backend/0` in tests. Closes #120. Thanks to @darwintantuco.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.4.0 released on November 1st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.4.0 - Changelog","ref":"changelog.html#money-v5-4-0"},{"type":"extras","doc":"* Add support for [CLDR 38](http://cldr.unicode.org/index/downloads/cldr-38)","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.3.2 released on September 30th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.3.2 - Changelog","ref":"changelog.html#money-v5-3-2"},{"type":"extras","doc":"* Fix docs for `Money.div!/2`\n\n* Update `cldr_utils` which implements a shim for `Decimal` to support both version `1.9` and `2.0`.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.3.1 released on September 26th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.3.1 - Changelog","ref":"changelog.html#money-v5-3-1"},{"type":"extras","doc":"* Support `nimble_parsec` versions that match `~> 0.5 or ~> 1.0`","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.3.0 released on September 5th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.3.0 - Changelog","ref":"changelog.html#money-v5-3-0"},{"type":"extras","doc":"* Fix parsing money amounts to use Unicode definition of whitespace (set `[:Zs:]`). Thanks to @Sanjibukai for the report.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Add `Money.sum/2` to sum a list of `Money`, converting them if required.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.2.1 released on June 23rd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.2.1 - Changelog","ref":"changelog.html#money-v5-2-1"},{"type":"extras","doc":"* Configure the `Money.Application` supervisor via the arguments to `Money.Application.start/2` and configure defaults in `mix.exs`. This permits different restart strategies and names.\n\n* Add `Money.ExchangeRates.Supervisor.default_supervisor/0` to return the name of the default supervisor which is `Money.Supervisor`\n\n* Change `Money.ExchangeRates.Supervisor.stop/0` to become `Money.ExchangeRates.Supervisor.stop/{0, 1}` allowing the supervisor name to be passed in. The default is `Money.ExchangeRates.Supervisor.default_supervisor/0`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"* Add back the name of the Application supervisor, `Money.Supervisor`. Thanks for the report of the regression to @jeroenvisser101. Fixes #117.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.2.0 released on May 30th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.2.0 - Changelog","ref":"changelog.html#money-v5-2-0"},{"type":"extras","doc":"* Adds a configuration option `:verify_peer` which is a boolean that determines whether to verify the client certificate for any exchange rate service API call. The default is `true`. This option should not be changed without a very clear understanding of the security implications. This option will remain undocumented but supported for now.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"* Handle expired certificate errors on the exchange rates API service and log them. Thanks to @coladarci. Fixes #116","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.1.0 released on May 26th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.1.0 - Changelog","ref":"changelog.html#money-v5-1-0"},{"type":"extras","doc":"* Extract default currency from locale when calling `Money.parse/2` on a money string. The updated docs now say:\n\n  * `:default_currency` is any valid currency code or `false`\n    that will used if no currency code, symbol or description is\n    indentified in the parsed string. The default is `nil`\n    which means that the default currency associated with\n    the `:locale` option will be used. If `false` then the\n    currency assocated with the `:locale` option will not be\n    used and an error will be returned if there is no currency\n    in the string being parsed.\n\n* Add certificate verification for exchange rate retrieval","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v5.0.2 released on April 29th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.0.2 - Changelog","ref":"changelog.html#money-v5-0-2"},{"type":"extras","doc":"* Update the application supervisor spec","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.0.1 released on January 28th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.0.1 - Changelog","ref":"changelog.html#money-v5-0-1"},{"type":"extras","doc":"* Make `nimble_parsec` a required dependency since it is required for parsing money amounts. Thanks to @jonnystoten for the report.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v5.0.0 released on January 21st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v5.0.0 - Changelog","ref":"changelog.html#money-v5-0-0"},{"type":"extras","doc":"* Elixir 1.10 introduces semantic sorting for stucts that depends on the availability of a `compare/2` function that returns `:lt`, `:eq` or `:gt`.  Therefore in this release of `ex_money` the functions `compare/2` and `compare!/2` are swapped with `cmp/2` and `cmp!/2` in order to conform with this expectation. Now `compare/2` will return `:eq`, `:lt` or `:gt`. And `cmp/2` return `-1`, `0` or `1`.\n\n* Deprecate `Money.reduce/1` in favour of `Money.normalize/1` to be consistent with `Decimal` versions `1.9` and later.\n\nIt is believed and tested that `Money` version `5.0.0` is compatible with all versions of `Decimal` from `1.6` up to the as-yet-unreleased `2.0`.","title":"Breaking changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"From Elixir verison `1.10.0`, several functions in the `Enum` module can use the `Money.compare/2` function to simplify sorting. For example:\n\n```\niex> list = [Money.new(:USD, 100), Money.new(:USD, 200)]\n[#Money<:USD, 100>, #Money<:USD, 200>]\niex> Enum.sort list, Money\n[#Money<:USD, 100>, #Money<:USD, 200>]\niex> Enum.sort list, {:asc, Money}\n[#Money<:USD, 100>, #Money<:USD, 200>]\niex> Enum.sort list, {:desc, Money}\n[#Money<:USD, 200>, #Money<:USD, 100>]\n```\n**Note that `Enum.sort/2` will sort money amounts even when the currencies are incompatible. In this case the order of the result is not predictable. It is the developers responsibility to filter the list to compatible currencies prior to sorting. This is a limitation of the `Enum.sort/2` implementation.**","title":"Support of Elixir 1.10 Enum sorting - Changelog","ref":"changelog.html#support-of-elixir-1-10-enum-sorting"},{"type":"extras","doc":"* `ex_money` version `5.0.0` is compatible with `Decimal` versions from `1.6` onwards. In `Decimal` version `2.0` the same changes to `compare/2` and `cmp/2` will occur and in `Decimal` version `1.9`, `Decimal.cmp/2` is deprecated.  `ex_money` version `5.0.0` detects these different versions of `Decimal` and therefore remains compatability with `Decimal` back to version `1.6`.","title":"Notes on Decimal version support - Changelog","ref":"changelog.html#notes-on-decimal-version-support"},{"type":"extras","doc":"This is the changelog for Money v4.4.2 released on January 2nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v4.4.2 - Changelog","ref":"changelog.html#money-v4-4-2"},{"type":"extras","doc":"* Remove calls to `Code.ensure_compiled?/1` since it is deprecated in Elixir 1.10. Use instead `Cldr.Config.ensure_compiled?/1` which is added as a private API in `Cldr` version 2.12.0. This version of `Cldr` now becomes the minimum version required.\n\n* Remove spurious entries in `.dialyzer_ignore_warnings` - no entries are required and dialyzer is happy.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v4.4.1 released on November 10th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v4.4.1 - Changelog","ref":"changelog.html#money-v4-4-1"},{"type":"extras","doc":"* Fixes money parsing error. Thanks to @Doerge. Closes #112.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v4.4.0 released on November 6th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v4.4.0 - Changelog","ref":"changelog.html#money-v4-4-0"},{"type":"extras","doc":"* `Money.parse/2` until this release supported the `:currency_filter` option. It allowed for currencies to be filtered based upon their attributes (`:all`, `:current`, `:historic`, `:tender`, `:annotated`). When multiple attributes were passed in a list, a currency had to meet all of these attributes. From this release onwards, multiple attributes items are `or`ed, not `and`ed. It is expected this option is used extremely rarely and therefore of limited impact.","title":"Breaking Change - Changelog","ref":"changelog.html#breaking-change"},{"type":"extras","doc":"* `Money.parse/2` now includes the option `:default_currency` which allows for parsing a number only (without a currency code) and it will be tagged with the `:default_currency`.\n```elixir\n  iex> Money.parse(\"100\")\n  {:error,\n   {Money.Invalid,\n    \"A currency code, symbol or description must be specified but was not found in \\\"100\\\"\"}}\n  iex> Money.parse(\"100\", default_currency: :USD)\n  #Money<:USD, 100>\n```\n\n* Add `:only` and `:except` options to `Money.parse/2` to specify which currency codes or currency attributes are permitted.  `:only` and `:except` replace the option `:currency_filter` which is now deprecated. If provided, `:currency_filter` is interpreted as `:only`. An example:\n```elixir\n  iex> Money.parse(\"100 usd\", only: :current, except: :USD)\n  {:error,\n   {Money.UnknownCurrencyError,\n    \"The currency \\\"usd\\\" is unknown or not supported\"}}\n```\n\n* `Money.parse/2` now supports negative money amounts.\n```elixir\n  iex> Money.parse(\"chf -100\")\n  #Money<:CHF, -100>\n\n  iex> Money.parse(\"(chf 100)\")\n  #Money<:CHF, -100>\n```\n* The money parser has been rewritten using [nimble_parsec](https://hex,pm.packages/nimble_parsec)","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v4.3.0 released on September 8th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v4.3.0 - Changelog","ref":"changelog.html#money-v4-3-0"},{"type":"extras","doc":"* Adds a `Money` backend in the same spirit as other libraries that leverge [ex_cldr](https://hex,pm/packages/ex_cldr). Thanks to @Lostkobrakai. Closes #108. All of the functions in the `Money` module may also be called on a backend module ` .Money.fun` without having to specify a backend module since this is implicit.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"* `Money.new!/3` replaces `Money.new!/2` to accept options. Thanks to @Lostkobrakai. Closes #109.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v4.2.2 released on September 7th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v4.2.2 - Changelog","ref":"changelog.html#money-v4-2-2"},{"type":"extras","doc":"* Use `Keyword.get_lazy` when the default is `Cldr.default_backend/0` to avoid exceptions when no default backend is configured. Thanks to @Lostkobrakai. Closes #108.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v4.2.1 released on September 2nd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v4.2.1 - Changelog","ref":"changelog.html#money-v4-2-1"},{"type":"extras","doc":"* Fixes parsing of money amount that have a single digit amount. Closes #107.  Thanks to @njwest","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v4.2.0 released on 21 August, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v4.2.0 - Changelog","ref":"changelog.html#money-v4-2-0"},{"type":"extras","doc":"* Move the `Money.Migration` module to [ex_money_ecto](https://hex.pm/packages/ex_money_sql) where it belongs","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* `Money.default_backend/0` will now either use the backend configured under the `:default_cldr_backend` key of `ex_money` or `Cldr.default_backend/0`. In either case an exeption will be raised if no default backend is configured.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v4.1.0 released on July 13th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v4.1.0 - Changelog","ref":"changelog.html#money-v4-1-0"},{"type":"extras","doc":"* Adds `Money.abs/1`. Thanks to @jeremyjh.\n\n* Improve `@doc` consistency using `","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"Arguments` not `## Options`. - Changelog","ref":"changelog.html#arguments-not-options"},{"type":"extras","doc":"This is the changelog for Money v4.0.0 released on July 8th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v4.0.0 - Changelog","ref":"changelog.html#money-v4-0-0"},{"type":"extras","doc":"* Functions related to the serialization of money types have been extracted to the library [ex_money_sql](https://hex.pm/packages/ex_money_sql).  For applications using the dependency `ex_money` that *do not* require serialization no changes are required.  For applications using serialization, the dependency should be changed to `ex_money_sql` (which in turn depends on `ex_money`).\n\n* Supports Elixir 1.6 and later only","title":"Breaking Changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"This is the changelog for Money v3.4.4 released on June 2nd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.4.4 - Changelog","ref":"changelog.html#money-v3-4-4"},{"type":"extras","doc":"* Supports passing an `Cldr.Number.Formation.Options.t` as alternative to a `Keyword.t` for options to `Money.to_string/2`.  Performance is doubled when using pre-validated options which is useful if formatting is being executed in a tight loop.\n\nAn example of this usage is:\n\n```elixir\n  iex> money = Money.new(:USD, 100)\n\n  # Apply any options required as a keyword list\n  # Money will take care of managing the `:currency` option\n  iex> options = []\n\n  iex> {:ok, options} = Cldr.Number.Format.Options.validate_options(0, backend, options)\n  iex> Money.to_string(money, options)\n```\n\nThe `0` in `validate_options` is used to determine the sign of the amount because that can influence formatting - for example the accounting format often uses `(1234)` as its format.  If you know your amounts are always positive, just use `0`.\n\nIf the use case may have both positive and negative amounts, generate two option sets (one with the positive number and one with the negative).  Then use the appropriate option set.  For example:\n\n```elixir\n  iex> money = Money.new(:USD, 1234)\n\n  # Add options as required\n  # Money will take care of managing the `:currency` option\n  iex> options = []\n\n  iex> {:ok, positive_options} = Cldr.Number.Format.Options.validate_options(0, backend, options)\n  iex> {:ok, negative_options} = Cldr.Number.Format.Options.validate_options(-1, backend, options)\n\n  iex> if Money.cmp(money, Money.zero(:USD)) == :gt do\n  ...>   Money.to_string(money, positive_options)\n  ...> else\n  ...>   Money.to_string(money, negative_options)\n  ...> end\n```","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v3.4.3 released on June 2nd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.4.3 - Changelog","ref":"changelog.html#money-v3-4-3"},{"type":"extras","doc":"* Ensure `Money.to_string!/2` properly raises\n\n* Add specs for `Money.to_string/2` and `Money.to_string!/2`\n\nThanks to @rodrigues for the report and PR.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v3.4.2 released on April 16th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.4.2 - Changelog","ref":"changelog.html#money-v3-4-2"},{"type":"extras","doc":"* `Money.put_fraction/2` now correctly allows setting the fraction to 0.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* `Money.round/2` allows setting `:currency_digits` to an integer number of digits in addition to the options `:iso`, `:cash` and `:accounting`.  The default remains `:iso`.\n\n* Improves the documentation for `Money.to_string/2`.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v3.4.1 released on April 5th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.4.1 - Changelog","ref":"changelog.html#money-v3-4-1"},{"type":"extras","doc":"* Fix `README.md` markdown formatting error.  Thanks to @fireproofsocks for the report and @lostkobrakai for the fix.  Closes #99.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v3.4.0 released on March 28th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.4.0 - Changelog","ref":"changelog.html#money-v3-4-0"},{"type":"extras","doc":"* Updates to [CLDR version 35.0.0](http://cldr.unicode.org/index/downloads/cldr-35) released on March 27th 2019 through `ex_cldr` version 2.6.0.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v3.3.1 released on March 8th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.3.1 - Changelog","ref":"changelog.html#money-v3-3-1"},{"type":"extras","doc":"* Fix or silence dialyzer warnings","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v3.3.0 released on February 24th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.3.0 - Changelog","ref":"changelog.html#money-v3-3-0"},{"type":"extras","doc":"* Adds `Money.put_fraction/2`. This will set the fractional part of a money to the specified integer amount.  Examples:\n```\n  iex> Money.put_fraction Money.new(:USD, \"2.49\"), 99\n  #Money<:USD, 2.99>\n\n  iex> Money.put_fraction Money.new(:USD, \"2.49\"), 999\n  {:error,\n   {Money.InvalidAmountError, \"Rounding up to 999 is invalid for currency :USD\"}}\n```","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"* Parsing money strings now uses a more complete set of character definitions for decimal and grouping separators based upon the `characters.json` file of the \"en\" locale.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v3.2.4 released on February 13th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.2.4 - Changelog","ref":"changelog.html#money-v3-2-4"},{"type":"extras","doc":"* Updates to [ex_cldr_currencies version 2.1.2](https://hex.pm/packages/ex_cldr_currencies/2.1.2) which correctly removes duplicate currency strings when the same string referred to different currency codes. See the [changelog](https://github.com/kipcole9/cldr_currencies/blob/v2.1.2/CHANGELOG.md) for further detail.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Adds a `:fuzzy` option to `Money.parse/2` that uses `String.jaro_distance/2` to help determine if the provided currency text can be resolved as a currency code.  For example:\n```\n  iex> Money.parse(\"100 eurosports\", fuzzy: 0.8)\n  #Money<:EUR, 100>\n\n  iex> Money.parse(\"100 eurosports\", fuzzy: 0.9)\n  {:error,\n   {Money.Invalid, \"Unable to create money from \\\\\"eurosports\\\\\" and \\\\\"100\\\\\"\"}}\n```","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v3.2.3 released on February 12th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.2.3 - Changelog","ref":"changelog.html#money-v3-2-3"},{"type":"extras","doc":"* Correctly parse money strings with unicode currency symbols like \"€\". Closes #95.  Thanks to @crbelaus.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v3.2.2 released on February 10th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.2.2 - Changelog","ref":"changelog.html#money-v3-2-2"},{"type":"extras","doc":"* Improves parsing of money strings. Parsing now uses various strings that [CLDR](https://cldr.unicode.org) knows about.  Some examples:\n\n```elixir\n iex> Money.parse \"$au 12 346\", locale: \"fr\"\n #Money<:AUD, 12346>\n iex> Money.parse \"12 346 dollar australien\", locale: \"fr\"\n #Money<:AUD, 12346>\n iex> Money.parse \"A$ 12346\", locale: \"en\"\n #Money<:AUD, 12346>\n iex> Money.parse \"australian dollar 12346.45\", locale: \"en\"\n #Money<:AUD, 12346.45>\n iex> Money.parse \"AU$ 12346,45\", locale: \"de\"\n #Money<:AUD, 12346.45>\n\n # Can also return the strings available for a given currency\n # and locale\n iex> Cldr.Currency.strings_for_currency :AUD, \"de\"\n [\"aud\", \"au$\", \"australischer dollar\", \"australische dollar\"]\n\n # Round trip formatting also seems to be ok\n iex> {:ok, string} = Cldr.Number.to_string 1234, Money.Cldr, currency: :AUD\n iex> Money.parse string\n #Money<:AUD, 1234.00>\n```","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v3.2.1 released on February 2nd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.2.1 - Changelog","ref":"changelog.html#money-v3-2-1"},{"type":"extras","doc":"* Added `Money.Ecto.Composite.Type.cast/1` and `Money.Ecto.Map.Type.cast/1` for a `String.t` parameter. When a `String.t` is provided, `cast/1` will call `Money.parse/2` to create the `Money.t`.\n\n* `Money.new/3` now uses the current locale on the default backend if no locale or backend is specified. This means that `Money.Ecto.Composite.Type.cast/1` and `Money.Ecto.Map.Type.cast/1` will be parsed using the locale that has been set for the current process in the default backend. As a result, a simple `type=text` form field can be used to input a money type (currency code and amount in a single string) that can then be cast to a `Money.t`.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v3.2.0 released on February 1st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.2.0 - Changelog","ref":"changelog.html#money-v3-2-0"},{"type":"extras","doc":"* Correctly generate `migrations_path/1` function based upon whether `Ecto` is configured and which version","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Adds `Money.parse/2` which will parse a string comprising a currency code and an amount. It will return a `Money.t` or an error.  This function may be helpful in supporting money input in HTML forms.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"This is the changelog for Money v3.1.0 released on December 30th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)","title":"Money v3.1.0 - Changelog","ref":"changelog.html#money-v3-1-0"},{"type":"extras","doc":"* Fix typo in `exchange_rates_retriever.ex`.  Thanks to @lostkobrakai.  Closes #91.\n\n* Remove obsolete `cldr` compiler\n\n* Changes the `sum` aggregate function for `money_with_currency` to be `STRICT` which means it handles `NULL` columns in the same way as the standard `SUM` function.  Thanks to @lostkobrakai.  Closes #88.\n\n* Fixes documentation link errors\n\n* Fix unhandled terminate typo error in exchange rates server. Thanks to @xavier. Closes #90.","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"This is the changelog for Money v3.0.0 released on November 23rd, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/money/tags)\n\nThe primary purpose of this release is to support ex_cldr version 2.0","title":"Money v3.0.0 - Changelog","ref":"changelog.html#money-v3-0-0"},{"type":"extras","doc":"* `Money.from_tuple/1` has been removed\n* Uses [ex_cldr](https://hex.pm/packages/ex_cldr/2.0.0) version 2.  Please see [the changelog](https://github.com/kipcole9/cldr/blob/v2.0.1/CHANGELOG.md#migrating-from-cldr-1x-to-cldr-version-2x) for configuration changes that are required.\n* Requires a default_cldr_backend to be configured in `config.exs`.  For example:\n```\n  config :ex_money,\n    ...\n    default_cldr_backend: MyApp.Cldr\n  end\n```","title":"Breaking changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"","title":"LICENSE","ref":"license.html"},{"type":"extras","doc":"Copyright 2017-2021 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","title":"License - LICENSE","ref":"license.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}